var searchIndex = {};
searchIndex["alloc"] = {"doc":"The Rust core allocation and collections library","items":[[0,"allocator","alloc","",null,null],[3,"Excess","alloc::allocator","Represents the combination of a starting address and a total capacity of the returned block.",null,null],[12,"0","","",0,null],[12,"1","","",0,null],[3,"Layout","","Layout of a block of memory.",null,null],[4,"AllocErr","","The `AllocErr` error specifies whether an allocation failure is specifically due to resource exhaustion or if it is due to something wrong when combining the given input arguments with this allocator.",null,null],[13,"Exhausted","","Error due to hitting some resource limit or otherwise running out of memory. This condition strongly implies that some series of deallocations would allow a subsequent reissuing of the original allocation request to succeed.",1,null],[12,"request","alloc::allocator::AllocErr","",1,null],[13,"Unsupported","alloc::allocator","Error due to allocator being fundamentally incapable of satisfying the original request. This condition implies that such an allocation request will never succeed on the given allocator, regardless of environment, memory pressure, or other contextual conditions.",1,null],[12,"details","alloc::allocator::AllocErr","",1,null],[3,"CannotReallocInPlace","alloc::allocator","The `CannotReallocInPlace` error is used when `grow_in_place` or `shrink_in_place` were unable to reuse the given memory block for a requested layout.",null,null],[4,"CollectionAllocErr","","Augments `AllocErr` with a CapacityOverflow variant.",null,null],[13,"CapacityOverflow","","Error due to the computed capacity exceeding the collection's maximum (usually `isize::MAX` bytes).",2,null],[13,"AllocErr","","Error due to the allocator (see the `AllocErr` type's docs).",2,null],[8,"Alloc","","An implementation of `Alloc` can allocate, reallocate, and deallocate arbitrary blocks of data described via `Layout`.",null,null],[10,"alloc","","Returns a pointer meeting the size and alignment guarantees of `layout`.",3,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[10,"dealloc","","Deallocate the memory referenced by `ptr`.",3,null],[11,"oom","","Allocator-specific method for signaling an out-of-memory condition.",3,null],[11,"usable_size","","Returns bounds on the guaranteed usable size of a successful allocation created with the specified `layout`.",3,null],[11,"realloc","","Returns a pointer suitable for holding data described by `new_layout`, meeting its size and alignment guarantees. To accomplish this, this may extend or shrink the allocation referenced by `ptr` to fit `new_layout`.",3,null],[11,"alloc_zeroed","","Behaves like `alloc`, but also ensures that the contents are set to zero before being returned.",3,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"alloc_excess","","Behaves like `alloc`, but also returns the whole size of the returned block. For some `layout` inputs, like arrays, this may include extra storage usable for additional data.",3,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["excess","allocerr"],"name":"result"}}],[11,"realloc_excess","","Behaves like `realloc`, but also returns the whole size of the returned block. For some `layout` inputs, like arrays, this may include extra storage usable for additional data.",3,null],[11,"grow_in_place","","Attempts to extend the allocation referenced by `ptr` to fit `new_layout`.",3,null],[11,"shrink_in_place","","Attempts to shrink the allocation referenced by `ptr` to fit `new_layout`.",3,null],[11,"alloc_one","","Allocates a block suitable for holding an instance of `T`.",3,{"inputs":[{"name":"self"}],"output":{"generics":["nonnull","allocerr"],"name":"result"}}],[11,"dealloc_one","","Deallocates a block suitable for holding an instance of `T`.",3,null],[11,"alloc_array","","Allocates a block suitable for holding `n` instances of `T`.",3,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["nonnull","allocerr"],"name":"result"}}],[11,"realloc_array","","Reallocates a block previously suitable for holding `n_old` instances of `T`, returning a block suitable for holding `n_new` instances of `T`.",3,{"inputs":[{"name":"self"},{"name":"nonnull"},{"name":"usize"},{"name":"usize"}],"output":{"generics":["nonnull","allocerr"],"name":"result"}}],[11,"dealloc_array","","Deallocates a block suitable for holding `n` instances of `T`.",3,{"inputs":[{"name":"self"},{"name":"nonnull"},{"name":"usize"}],"output":{"generics":["allocerr"],"name":"result"}}],[0,"heap","alloc","",null,null],[3,"Heap","alloc::heap","",null,null],[11,"clone","","",4,{"inputs":[{"name":"self"}],"output":{"name":"heap"}}],[11,"default","","",4,{"inputs":[],"output":{"name":"heap"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"alloc","","",4,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"oom","","",4,null],[11,"dealloc","","",4,null],[11,"usable_size","","",4,null],[11,"realloc","","",4,null],[11,"alloc_zeroed","","",4,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"alloc_excess","","",4,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["excess","allocerr"],"name":"result"}}],[11,"realloc_excess","","",4,null],[11,"grow_in_place","","",4,null],[11,"shrink_in_place","","",4,null],[0,"boxed","alloc","A pointer type for heap allocation.",null,null],[3,"ExchangeHeapSingleton","alloc::boxed","This the singleton type used solely for `boxed::HEAP`.",null,null],[3,"Box","","A pointer type for heap allocation.",null,null],[3,"IntermediateBox","","`IntermediateBox` represents uninitialized backing storage for `Box`.",null,null],[3,"PinBox","","A pinned, heap allocated reference.",null,null],[17,"HEAP","","A value that represents the heap. This is the default place that the `box` keyword allocates into when no place is supplied.",null,null],[8,"FnBox","","`FnBox` is a version of the `FnOnce` intended for use with boxed closure objects. The idea is that where one would normally store a `Box<FnOnce()>` in a data structure, you should use `Box<FnBox()>`. The two traits behave essentially the same, except that a `FnBox` closure can only be called if it is boxed. (Note that `FnBox` may be deprecated in the future if `Box<FnOnce()>` closures become directly usable.)",null,null],[16,"Output","","",5,null],[10,"call_box","","",5,null],[11,"clone","","",6,{"inputs":[{"name":"self"}],"output":{"name":"exchangeheapsingleton"}}],[11,"pointer","","",7,null],[11,"make_place","","",7,{"inputs":[],"output":{"name":"intermediatebox"}}],[11,"finalize","","",7,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"finalize","","",8,{"inputs":[{"name":"intermediatebox"}],"output":{"name":"box"}}],[11,"make_place","","",6,{"inputs":[{"name":"self"}],"output":{"name":"intermediatebox"}}],[11,"drop","","",7,{"inputs":[{"name":"self"}],"output":null}],[11,"new","","Allocates memory on the heap and then places `x` into it.",8,{"inputs":[{"name":"t"}],"output":{"name":"box"}}],[11,"from_raw","","Constructs a box from a raw pointer.",8,null],[11,"into_raw","","Consumes the `Box`, returning the wrapped raw pointer.",8,null],[11,"into_raw_non_null","","Consumes the `Box`, returning the wrapped pointer as `NonNull<T>`.",8,{"inputs":[{"name":"box"}],"output":{"name":"nonnull"}}],[11,"into_unique","","",8,{"inputs":[{"name":"box"}],"output":{"name":"unique"}}],[11,"leak","","Consumes and leaks the `Box`, returning a mutable reference, `&'a mut T`. Here, the lifetime `'a` may be chosen to be `'static`.",8,{"inputs":[{"name":"box"}],"output":{"name":"t"}}],[11,"drop","","",8,{"inputs":[{"name":"self"}],"output":null}],[11,"default","","Creates a `Box<T>`, with the `Default` value for T.",8,{"inputs":[],"output":{"name":"box"}}],[11,"default","","",8,{"inputs":[],"output":{"name":"box"}}],[11,"default","","",8,{"inputs":[],"output":{"generics":["str"],"name":"box"}}],[11,"clone","","Returns a new box with a `clone()` of this box's contents.",8,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"clone_from","","Copies `source`'s contents into `self` without creating a new allocation.",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":null}],[11,"clone","","",8,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"ne","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"le","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"ge","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"gt","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"cmp","","",8,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"ordering"}}],[11,"hash","","",8,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"finish","","",8,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"write","","",8,null],[11,"write_u8","","",8,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"write_u16","","",8,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"write_u32","","",8,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"write_u64","","",8,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"write_u128","","",8,{"inputs":[{"name":"self"},{"name":"u128"}],"output":null}],[11,"write_usize","","",8,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"write_i8","","",8,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"write_i16","","",8,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"write_i32","","",8,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"write_i64","","",8,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"write_i128","","",8,{"inputs":[{"name":"self"},{"name":"i128"}],"output":null}],[11,"write_isize","","",8,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"from","","",8,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",8,null],[11,"from","","",8,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"box"}}],[11,"from","","",8,{"inputs":[{"generics":["str"],"name":"box"}],"output":{"name":"self"}}],[11,"downcast","","Attempt to downcast the box to a concrete type.",8,{"inputs":[{"name":"self"}],"output":{"generics":["box","box"],"name":"result"}}],[11,"downcast","","Attempt to downcast the box to a concrete type.",8,{"inputs":[{"name":"self"}],"output":{"generics":["box","box"],"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"deref","","",8,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",8,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"next","","",8,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",8,null],[11,"nth","","",8,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next_back","","",8,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",8,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",8,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"call_once","","",8,{"inputs":[{"name":"self"},{"name":"a"}],"output":{"name":"r"}}],[11,"call_once","","",8,{"inputs":[{"name":"self"},{"name":"a"}],"output":{"name":"r"}}],[11,"clone","","",8,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"borrow","","",8,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"borrow_mut","","",8,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_ref","","",8,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_mut","","",8,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"resume","","",8,{"inputs":[{"name":"self"}],"output":{"name":"generatorstate"}}],[11,"new","","Allocate memory on the heap, move the data into it and pin it.",9,{"inputs":[{"name":"t"}],"output":{"name":"pinbox"}}],[11,"as_pin","","Get a pinned reference to the data in this PinBox.",9,{"inputs":[{"name":"self"}],"output":{"name":"pin"}}],[11,"get_mut","","Get a mutable reference to the data inside this PinBox.",9,{"inputs":[{"name":"pinbox"}],"output":{"name":"t"}}],[11,"unpin","","Convert this PinBox into an unpinned Box.",9,{"inputs":[{"name":"pinbox"}],"output":{"name":"box"}}],[11,"from","","",9,{"inputs":[{"name":"box"}],"output":{"name":"pinbox"}}],[11,"from","","",8,{"inputs":[{"name":"pinbox"}],"output":{"name":"box"}}],[11,"deref","","",9,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",9,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"arc","alloc","Thread-safe reference-counting pointers.",null,null],[3,"Arc","alloc::arc","A thread-safe reference-counting pointer. 'Arc' stands for 'Atomically Reference Counted'.",null,null],[3,"Weak","","`Weak` is a version of [`Arc`] that holds a non-owning reference to the managed value. The value is accessed by calling [`upgrade`] on the `Weak` pointer, which returns an [`Option`]`<`[`Arc`]`<T>>`.",null,null],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Constructs a new `Arc<T>`.",11,{"inputs":[{"name":"t"}],"output":{"name":"arc"}}],[11,"try_unwrap","","Returns the contained value, if the `Arc` has exactly one strong reference.",11,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"into_raw","","Consumes the `Arc`, returning the wrapped pointer.",11,null],[11,"from_raw","","Constructs an `Arc` from a raw pointer.",11,null],[11,"downgrade","","Creates a new [`Weak`][weak] pointer to this value.",11,{"inputs":[{"name":"self"}],"output":{"name":"weak"}}],[11,"weak_count","","Gets the number of [`Weak`][weak] pointers to this value.",11,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"strong_count","","Gets the number of strong (`Arc`) pointers to this value.",11,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"ptr_eq","","Returns true if the two `Arc`s point to the same value (not just values that compare as equal).",11,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","Makes a clone of the `Arc` pointer.",11,{"inputs":[{"name":"self"}],"output":{"name":"arc"}}],[11,"deref","","",11,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"make_mut","","Makes a mutable reference into the given `Arc`.",11,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get_mut","","Returns a mutable reference to the inner value, if there are no other `Arc` or [`Weak`][weak] pointers to the same value.",11,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"drop","","Drops the `Arc`.",11,{"inputs":[{"name":"self"}],"output":null}],[11,"new","","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",10,{"inputs":[],"output":{"name":"weak"}}],[11,"upgrade","","Attempts to upgrade the `Weak` pointer to an [`Arc`], extending the lifetime of the value if successful.",10,{"inputs":[{"name":"self"}],"output":{"generics":["arc"],"name":"option"}}],[11,"clone","","Makes a clone of the `Weak` pointer that points to the same value.",10,{"inputs":[{"name":"self"}],"output":{"name":"weak"}}],[11,"default","","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",10,{"inputs":[],"output":{"name":"weak"}}],[11,"drop","","Drops the `Weak` pointer.",10,{"inputs":[{"name":"self"}],"output":null}],[11,"eq","","Equality for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"ne","","Inequality for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"partial_cmp","","Partial comparison for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","Less-than comparison for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"le","","'Less than or equal to' comparison for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"gt","","Greater-than comparison for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"ge","","'Greater than or equal to' comparison for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"cmp","","Comparison for two `Arc`s.",11,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"ordering"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Creates a new `Arc<T>`, with the `Default` value for `T`.",11,{"inputs":[],"output":{"name":"arc"}}],[11,"hash","","",11,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"from","","",11,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",11,null],[11,"from","","",11,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"arc"}}],[11,"from","","",11,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"arc"}}],[11,"from","","",11,{"inputs":[{"name":"box"}],"output":{"name":"arc"}}],[11,"from","","",11,{"inputs":[{"name":"vec"}],"output":{"name":"arc"}}],[11,"borrow","","",11,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_ref","","",11,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[0,"rc","alloc","Single-threaded reference-counting pointers. 'Rc' stands for 'Reference Counted'.",null,null],[3,"Rc","alloc::rc","A single-threaded reference-counting pointer. 'Rc' stands for 'Reference Counted'.",null,null],[3,"Weak","","`Weak` is a version of [`Rc`] that holds a non-owning reference to the managed value. The value is accessed by calling [`upgrade`] on the `Weak` pointer, which returns an [`Option`]`<`[`Rc`]`<T>>`.",null,null],[11,"new","","Constructs a new `Rc<T>`.",12,{"inputs":[{"name":"t"}],"output":{"name":"rc"}}],[11,"try_unwrap","","Returns the contained value, if the `Rc` has exactly one strong reference.",12,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"into_raw","","Consumes the `Rc`, returning the wrapped pointer.",12,null],[11,"from_raw","","Constructs an `Rc` from a raw pointer.",12,null],[11,"downgrade","","Creates a new [`Weak`][weak] pointer to this value.",12,{"inputs":[{"name":"self"}],"output":{"name":"weak"}}],[11,"weak_count","","Gets the number of [`Weak`][weak] pointers to this value.",12,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"strong_count","","Gets the number of strong (`Rc`) pointers to this value.",12,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"get_mut","","Returns a mutable reference to the inner value, if there are no other `Rc` or [`Weak`][weak] pointers to the same value.",12,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"ptr_eq","","Returns true if the two `Rc`s point to the same value (not just values that compare as equal).",12,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"make_mut","","Makes a mutable reference into the given `Rc`.",12,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"downcast","","Attempt to downcast the `Rc<Any>` to a concrete type.",12,{"inputs":[{"name":"self"}],"output":{"generics":["rc","rc"],"name":"result"}}],[11,"deref","","",12,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"drop","","Drops the `Rc`.",12,{"inputs":[{"name":"self"}],"output":null}],[11,"clone","","Makes a clone of the `Rc` pointer.",12,{"inputs":[{"name":"self"}],"output":{"name":"rc"}}],[11,"default","","Creates a new `Rc<T>`, with the `Default` value for `T`.",12,{"inputs":[],"output":{"name":"rc"}}],[11,"eq","","Equality for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"ne","","Inequality for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"partial_cmp","","Partial comparison for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","Less-than comparison for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"le","","'Less than or equal to' comparison for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"gt","","Greater-than comparison for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"ge","","'Greater than or equal to' comparison for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"cmp","","Comparison for two `Rc`s.",12,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"ordering"}}],[11,"hash","","",12,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",12,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",12,null],[11,"from","","",12,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"rc"}}],[11,"from","","",12,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"rc"}}],[11,"from","","",12,{"inputs":[{"name":"box"}],"output":{"name":"rc"}}],[11,"from","","",12,{"inputs":[{"name":"vec"}],"output":{"name":"rc"}}],[11,"new","","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",13,{"inputs":[],"output":{"name":"weak"}}],[11,"upgrade","","Attempts to upgrade the `Weak` pointer to an [`Rc`], extending the lifetime of the value if successful.",13,{"inputs":[{"name":"self"}],"output":{"generics":["rc"],"name":"option"}}],[11,"drop","","Drops the `Weak` pointer.",13,{"inputs":[{"name":"self"}],"output":null}],[11,"clone","","Makes a clone of the `Weak` pointer that points to the same value.",13,{"inputs":[{"name":"self"}],"output":{"name":"weak"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",13,{"inputs":[],"output":{"name":"weak"}}],[11,"borrow","","",12,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_ref","","",12,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[0,"raw_vec","alloc","",null,null],[3,"RawVec","alloc::raw_vec","A low-level utility for more ergonomically allocating, reallocating, and deallocating a buffer of memory on the heap without having to worry about all the corner cases involved. This type is excellent for building your own data structures like Vec and VecDeque. In particular:",null,null],[11,"new_in","","Like `new` but parameterized over the choice of allocator for the returned RawVec.",14,{"inputs":[{"name":"a"}],"output":{"name":"self"}}],[11,"with_capacity_in","","Like `with_capacity` but parameterized over the choice of allocator for the returned RawVec.",14,{"inputs":[{"name":"usize"},{"name":"a"}],"output":{"name":"self"}}],[11,"with_capacity_zeroed_in","","Like `with_capacity_zeroed` but parameterized over the choice of allocator for the returned RawVec.",14,{"inputs":[{"name":"usize"},{"name":"a"}],"output":{"name":"self"}}],[11,"new","","Creates the biggest possible RawVec (on the system heap) without allocating. If T has positive size, then this makes a RawVec with capacity 0. If T has 0 size, then it makes a RawVec with capacity `usize::MAX`. Useful for implementing delayed allocation.",14,{"inputs":[],"output":{"name":"self"}}],[11,"with_capacity","","Creates a RawVec (on the system heap) with exactly the capacity and alignment requirements for a `[T; cap]`. This is equivalent to calling RawVec::new when `cap` is 0 or T is zero-sized. Note that if `T` is zero-sized this means you will not get a RawVec with the requested capacity!",14,{"inputs":[{"name":"usize"}],"output":{"name":"self"}}],[11,"with_capacity_zeroed","","Like `with_capacity` but guarantees the buffer is zeroed.",14,{"inputs":[{"name":"usize"}],"output":{"name":"self"}}],[11,"from_raw_parts_in","","Reconstitutes a RawVec from a pointer, capacity, and allocator.",14,null],[11,"from_raw_parts","","Reconstitutes a RawVec from a pointer, capacity.",14,null],[11,"from_box","","Converts a `Box<[T]>` into a `RawVec<T>`.",14,{"inputs":[{"name":"box"}],"output":{"name":"self"}}],[11,"ptr","","Gets a raw pointer to the start of the allocation. Note that this is Unique::empty() if `cap = 0` or T is zero-sized. In the former case, you must be careful.",14,null],[11,"cap","","Gets the capacity of the allocation.",14,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"alloc","","Returns a shared reference to the allocator backing this RawVec.",14,{"inputs":[{"name":"self"}],"output":{"name":"a"}}],[11,"alloc_mut","","Returns a mutable reference to the allocator backing this RawVec.",14,{"inputs":[{"name":"self"}],"output":{"name":"a"}}],[11,"double","","Doubles the size of the type's backing allocation. This is common enough to want to do that it's easiest to just have a dedicated method. Slightly more efficient logic can be provided for this than the general case.",14,{"inputs":[{"name":"self"}],"output":null}],[11,"double_in_place","","Attempts to double the size of the type's backing allocation in place. This is common enough to want to do that it's easiest to just have a dedicated method. Slightly more efficient logic can be provided for this than the general case.",14,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"try_reserve_exact","","Ensures that the buffer contains at least enough space to hold `used_cap + needed_extra_cap` elements. If it doesn't already, will reallocate the minimum possible amount of memory necessary. Generally this will be exactly the amount of memory necessary, but in principle the allocator is free to give back more than we asked for.",14,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"reserve_exact","","",14,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":null}],[11,"try_reserve","","Ensures that the buffer contains at least enough space to hold `used_cap + needed_extra_cap` elements. If it doesn't already have enough capacity, will reallocate enough space plus comfortable slack space to get amortized `O(1)` behavior. Will limit this behavior if it would needlessly cause itself to panic.",14,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"reserve","","The same as try_reserve, but errors are lowered to a call to oom().",14,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":null}],[11,"reserve_in_place","","Attempts to ensure that the buffer contains at least enough space to hold `used_cap + needed_extra_cap` elements. If it doesn't already have enough capacity, will reallocate in place enough space plus comfortable slack space to get amortized `O(1)` behavior. Will limit this behaviour if it would needlessly cause itself to panic.",14,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"shrink_to_fit","","Shrinks the allocation down to the specified amount. If the given amount is 0, actually completely deallocates.",14,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"into_box","","Converts the entire buffer into `Box<[T]>`.",14,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"dealloc_buffer","","Frees the memory owned by the RawVec without trying to Drop its contents.",14,{"inputs":[{"name":"self"}],"output":null}],[11,"drop","","Frees the memory owned by the RawVec without trying to Drop its contents.",14,{"inputs":[{"name":"self"}],"output":null}],[0,"binary_heap","alloc","A priority queue implemented with a binary heap.",null,null],[3,"BinaryHeap","alloc::binary_heap","A priority queue implemented with a binary heap.",null,null],[3,"PeekMut","","Structure wrapping a mutable reference to the greatest item on a `BinaryHeap`.",null,null],[3,"Iter","","An iterator over the elements of a `BinaryHeap`.",null,null],[3,"IntoIter","","An owning iterator over the elements of a `BinaryHeap`.",null,null],[3,"Drain","","A draining iterator over the elements of a `BinaryHeap`.",null,null],[3,"BinaryHeapPlace","","",null,null],[11,"fmt","","",15,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"drop","","",15,{"inputs":[{"name":"self"}],"output":null}],[11,"deref","","",15,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",15,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"pop","","Removes the peeked value from the heap and returns it.",15,{"inputs":[{"name":"peekmut"}],"output":{"name":"t"}}],[11,"clone","","",16,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"clone_from","","",16,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"default","","Creates an empty `BinaryHeap<T>`.",16,{"inputs":[],"output":{"name":"binaryheap"}}],[11,"fmt","","",16,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates an empty `BinaryHeap` as a max-heap.",16,{"inputs":[],"output":{"name":"binaryheap"}}],[11,"with_capacity","","Creates an empty `BinaryHeap` with a specific capacity. This preallocates enough memory for `capacity` elements, so that the `BinaryHeap` does not have to be reallocated until it contains at least that many values.",16,{"inputs":[{"name":"usize"}],"output":{"name":"binaryheap"}}],[11,"iter","","Returns an iterator visiting all values in the underlying vector, in arbitrary order.",16,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"peek","","Returns the greatest item in the binary heap, or `None` if it is empty.",16,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"peek_mut","","Returns a mutable reference to the greatest item in the binary heap, or `None` if it is empty.",16,{"inputs":[{"name":"self"}],"output":{"generics":["peekmut"],"name":"option"}}],[11,"capacity","","Returns the number of elements the binary heap can hold without reallocating.",16,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve_exact","","Reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `BinaryHeap`. Does nothing if the capacity is already sufficient.",16,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the `BinaryHeap`. The collection may reserve more space to avoid frequent reallocations.",16,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shrink_to_fit","","Discards as much additional capacity as possible.",16,{"inputs":[{"name":"self"}],"output":null}],[11,"shrink_to","","Discards capacity with a lower bound.",16,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"pop","","Removes the greatest item from the binary heap and returns it, or `None` if it is empty.",16,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push","","Pushes an item onto the binary heap.",16,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"into_vec","","Consumes the `BinaryHeap` and returns the underlying vector in arbitrary order.",16,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"into_sorted_vec","","Consumes the `BinaryHeap` and returns a vector in sorted (ascending) order.",16,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"len","","Returns the length of the binary heap.",16,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Checks if the binary heap is empty.",16,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"drain","","Clears the binary heap, returning an iterator over the removed elements.",16,{"inputs":[{"name":"self"}],"output":{"name":"drain"}}],[11,"clear","","Drops all items from the binary heap.",16,{"inputs":[{"name":"self"}],"output":null}],[11,"append","","Moves all the elements of `other` into `self`, leaving `other` empty.",16,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"fmt","","",17,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",17,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"next","","",17,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",17,null],[11,"next_back","","",17,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is_empty","","",17,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",18,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"fmt","","",18,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",18,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",18,null],[11,"next_back","","",18,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is_empty","","",18,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",19,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",19,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",19,null],[11,"next_back","","",19,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is_empty","","",19,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"from","","",16,{"inputs":[{"name":"vec"}],"output":{"name":"binaryheap"}}],[11,"from_iter","","",16,{"inputs":[{"name":"i"}],"output":{"name":"binaryheap"}}],[11,"into_iter","","Creates a consuming iterator, that is, one that moves each value out of the binary heap in arbitrary order. The binary heap cannot be used after calling this.",16,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"extend","","",16,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"extend","","",16,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"fmt","","",20,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"pointer","","",20,null],[11,"finalize","","",20,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[0,"borrow","alloc","A module for working with borrowed data.",null,null],[8,"Borrow","alloc::borrow","A trait for borrowing data.",null,null],[10,"borrow","","Immutably borrows from an owned value.",21,{"inputs":[{"name":"self"}],"output":{"name":"borrowed"}}],[8,"BorrowMut","","A trait for mutably borrowing data.",null,null],[10,"borrow_mut","","Mutably borrows from an owned value.",22,{"inputs":[{"name":"self"}],"output":{"name":"borrowed"}}],[4,"Cow","","A clone-on-write smart pointer.",null,null],[13,"Borrowed","","Borrowed data.",23,null],[13,"Owned","","Owned data.",23,null],[8,"ToOwned","","A generalization of `Clone` to borrowed data.",null,null],[16,"Owned","","",24,null],[10,"to_owned","","Creates owned data from borrowed data, usually by cloning.",24,null],[11,"clone_into","","Uses borrowed data to replace owned data, usually by cloning.",24,null],[11,"borrow","","",23,{"inputs":[{"name":"self"}],"output":{"name":"b"}}],[11,"clone","","",23,{"inputs":[{"name":"self"}],"output":{"name":"cow"}}],[11,"clone_from","","",23,{"inputs":[{"name":"self"},{"name":"cow"}],"output":null}],[11,"to_mut","","Acquires a mutable reference to the owned form of the data.",23,null],[11,"into_owned","","Extracts the owned data.",23,null],[11,"deref","","",23,{"inputs":[{"name":"self"}],"output":{"name":"b"}}],[11,"cmp","","",23,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"ordering"}}],[11,"eq","","",23,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",23,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"fmt","","",23,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",23,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Creates an owned Cow<'a, B> with the default value for the contained owned value.",23,{"inputs":[],"output":{"name":"cow"}}],[11,"hash","","",23,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"as_ref","","",23,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"add","","",23,null],[11,"add","","",23,null],[11,"add_assign","","",23,{"inputs":[{"name":"self"},{"name":"str"}],"output":null}],[11,"add_assign","","",23,{"inputs":[{"name":"self"},{"generics":["str"],"name":"cow"}],"output":null}],[0,"fmt","alloc","Utilities for formatting and printing `String`s.",null,null],[3,"Formatter","alloc::fmt","A struct to represent both where to emit formatting strings to and how they should be formatted. A mutable version of this is passed to all formatting traits.",null,null],[6,"Result","","The type returned by formatter methods.",null,null],[8,"Write","","A collection of methods that are required to format a message into a stream.",null,null],[10,"write_str","","Writes a slice of bytes into this writer, returning whether the write succeeded.",25,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_char","","Writes a [`char`] into this writer, returning whether the write succeeded.",25,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_fmt","","Glue for usage of the [`write!`] macro with implementors of this trait.",25,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[8,"Binary","","`b` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",26,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Octal","","`o` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",27,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Debug","","`?` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",28,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Display","","Format trait for an empty format, `{}`.",null,null],[10,"fmt","","Formats the value using the given formatter.",29,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"LowerHex","","`x` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",30,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Pointer","","`p` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",31,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"UpperHex","","`X` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",32,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"LowerExp","","`e` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",33,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"UpperExp","","`E` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",34,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[3,"Error","","The error type which is returned from formatting a message into a stream.",null,null],[5,"write","","The `write` function takes an output stream, and an `Arguments` struct that can be precompiled with the `format_args!` macro.",null,{"inputs":[{"name":"write"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[3,"Arguments","","This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.",null,null],[3,"DebugList","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugMap","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugSet","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugStruct","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugTuple","","A struct to help with `fmt::Debug` implementations.",null,null],[5,"format","","The `format` function takes an [`Arguments`] struct and returns the resulting formatted string.",null,{"inputs":[{"name":"arguments"}],"output":{"name":"string"}}],[0,"linked_list","alloc","A doubly-linked list with owned nodes.",null,null],[3,"LinkedList","alloc::linked_list","A doubly-linked list with owned nodes.",null,null],[3,"Iter","","An iterator over the elements of a `LinkedList`.",null,null],[3,"IterMut","","A mutable iterator over the elements of a `LinkedList`.",null,null],[3,"IntoIter","","An owning iterator over the elements of a `LinkedList`.",null,null],[3,"DrainFilter","","An iterator produced by calling `drain_filter` on LinkedList.",null,null],[3,"FrontPlace","","A place for insertion at the front of a `LinkedList`.",null,null],[3,"BackPlace","","A place for insertion at the back of a `LinkedList`.",null,null],[11,"fmt","","",35,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",35,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",36,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",37,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"fmt","","",37,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Creates an empty `LinkedList<T>`.",38,{"inputs":[],"output":{"name":"self"}}],[11,"new","","Creates an empty `LinkedList`.",38,{"inputs":[],"output":{"name":"self"}}],[11,"append","","Moves all elements from `other` to the end of the list.",38,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"iter","","Provides a forward iterator.",38,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Provides a forward iterator with mutable references.",38,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"is_empty","","Returns `true` if the `LinkedList` is empty.",38,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","","Returns the length of the `LinkedList`.",38,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"clear","","Removes all elements from the `LinkedList`.",38,{"inputs":[{"name":"self"}],"output":null}],[11,"contains","","Returns `true` if the `LinkedList` contains an element equal to the given value.",38,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"front","","Provides a reference to the front element, or `None` if the list is empty.",38,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"front_mut","","Provides a mutable reference to the front element, or `None` if the list is empty.",38,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back","","Provides a reference to the back element, or `None` if the list is empty.",38,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back_mut","","Provides a mutable reference to the back element, or `None` if the list is empty.",38,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push_front","","Adds an element first in the list.",38,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"pop_front","","Removes the first element and returns it, or `None` if the list is empty.",38,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push_back","","Appends an element to the back of a list",38,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"pop_back","","Removes the last element from a list and returns it, or `None` if it is empty.",38,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_off","","Splits the list into two at the given index. Returns everything after the given index, including the index.",38,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"linkedlist"}}],[11,"drain_filter","","Creates an iterator which uses a closure to determine if an element should be removed.",38,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"drainfilter"}}],[11,"front_place","","Returns a place for insertion at the front of the list.",38,{"inputs":[{"name":"self"}],"output":{"name":"frontplace"}}],[11,"back_place","","Returns a place for insertion at the back of the list.",38,{"inputs":[{"name":"self"}],"output":{"name":"backplace"}}],[11,"drop","","",38,{"inputs":[{"name":"self"}],"output":null}],[11,"next","","",35,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",35,null],[11,"next_back","","",35,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",36,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",36,null],[11,"next_back","","",36,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"insert_next","","Inserts the given element just after the element most recently returned by `.next()`. The inserted element does not appear in the iteration.",36,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"peek_next","","Provides a reference to the next element, without changing the iterator.",36,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",39,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",39,null],[11,"drop","","",39,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",39,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",37,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",37,null],[11,"next_back","","",37,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"from_iter","","",38,{"inputs":[{"name":"i"}],"output":{"name":"self"}}],[11,"into_iter","","Consumes the list into an iterator yielding elements by value.",38,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"extend","","",38,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"extend","","",38,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"eq","","",38,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",38,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",38,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",38,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"ordering"}}],[11,"clone","","",38,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",38,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",38,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"fmt","","",40,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"make_place","","",40,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pointer","","",40,null],[11,"finalize","","",40,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",41,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"make_place","","",41,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pointer","","",41,null],[11,"finalize","","",41,{"inputs":[{"name":"self"}],"output":null}],[0,"slice","alloc","A dynamically-sized view into a contiguous sequence, `[T]`.",null,null],[3,"Chunks","alloc::slice","An iterator over a slice in (non-overlapping) chunks (`chunk_size` elements at a time).",null,null],[3,"Windows","","An iterator over overlapping subslices of length `size`.",null,null],[3,"Iter","","Immutable slice iterator",null,null],[3,"IterMut","","Mutable slice iterator.",null,null],[3,"SplitMut","","An iterator over the subslices of the vector which are separated by elements that match `pred`.",null,null],[3,"ChunksMut","","An iterator over a slice in (non-overlapping) mutable chunks (`chunk_size` elements at a time). When the slice len is not evenly divided by the chunk size, the last slice of the iteration will be the remainder.",null,null],[3,"Split","","An iterator over subslices separated by elements that match a predicate function.",null,null],[3,"SplitN","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits.",null,null],[3,"RSplitN","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.",null,null],[3,"SplitNMut","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits.",null,null],[3,"RSplitNMut","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.",null,null],[3,"RSplit","","An iterator over subslices separated by elements that match a predicate function, starting from the end of the slice.",null,null],[3,"RSplitMut","","An iterator over the subslices of the vector which are separated by elements that match `pred`, starting from the end of the slice.",null,null],[5,"from_raw_parts","","Forms a slice from a pointer and a length.",null,null],[5,"from_raw_parts_mut","","Performs the same functionality as `from_raw_parts`, except that a mutable slice is returned.",null,null],[5,"from_ref","","Converts a reference to T into a slice of length 1 (without copying).",null,null],[5,"from_ref_mut","","Converts a reference to T into a slice of length 1 (without copying).",null,null],[8,"SliceIndex","","A helper trait used for indexing operations.",null,null],[16,"Output","","The output type returned by methods.",42,null],[10,"get","","Returns a shared reference to the output at this location, if in bounds.",42,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[10,"get_mut","","Returns a mutable reference to the output at this location, if in bounds.",42,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[10,"get_unchecked","","Returns a shared reference to the output at this location, without performing any bounds checking.",42,null],[10,"get_unchecked_mut","","Returns a mutable reference to the output at this location, without performing any bounds checking.",42,null],[10,"index","","Returns a shared reference to the output at this location, panicking if out of bounds.",42,null],[10,"index_mut","","Returns a mutable reference to the output at this location, panicking if out of bounds.",42,null],[3,"ExactChunks","","An iterator over a slice in (non-overlapping) chunks (`chunk_size` elements at a time).",null,null],[3,"ExactChunksMut","","An iterator over a slice in (non-overlapping) mutable chunks (`chunk_size` elements at a time). When the slice len is not evenly divided by the chunk size, the last up to `chunk_size-1` elements will be omitted.",null,null],[8,"SliceConcatExt","","An extension trait for concatenating slices",null,null],[16,"Output","","The resulting type after concatenation",43,null],[10,"concat","","Flattens a slice of `T` into a single value `Self::Output`.",43,null],[10,"join","","Flattens a slice of `T` into a single value `Self::Output`, placing a given separator between each.",43,null],[10,"connect","","",43,null],[0,"str","alloc","Unicode string slices.",null,null],[8,"FromStr","alloc::str","A trait to abstract the idea of creating a new instance of a type from a string.",null,null],[16,"Err","","The associated error which can be returned from parsing.",44,null],[10,"from_str","","Parses a string `s` to return a value of this type.",44,{"inputs":[{"name":"str"}],"output":{"name":"result"}}],[3,"Utf8Error","","Errors which can occur when attempting to interpret a sequence of [`u8`] as a string.",null,null],[3,"Lines","","An iterator over the lines of a string, as string slices.",null,null],[3,"LinesAny","","Created with the method [`lines_any`].",null,null],[3,"Split","","Created with the method [`split`].",null,null],[3,"RSplit","","Created with the method [`rsplit`].",null,null],[3,"SplitN","","Created with the method [`splitn`].",null,null],[3,"RSplitN","","Created with the method [`rsplitn`].",null,null],[3,"SplitTerminator","","Created with the method [`split_terminator`].",null,null],[3,"RSplitTerminator","","Created with the method [`rsplit_terminator`].",null,null],[3,"Matches","","Created with the method [`matches`].",null,null],[3,"RMatches","","Created with the method [`rmatches`].",null,null],[3,"MatchIndices","","Created with the method [`match_indices`].",null,null],[3,"RMatchIndices","","Created with the method [`rmatch_indices`].",null,null],[5,"from_utf8","","Converts a slice of bytes to a string slice.",null,null],[5,"from_utf8_mut","","Converts a mutable slice of bytes to a mutable string slice.",null,null],[3,"Chars","","An iterator over the [`char`]s of a string slice.",null,null],[3,"CharIndices","","An iterator over the [`char`]s of a string slice, and their positions.",null,null],[3,"Bytes","","An iterator over the bytes of a string slice.",null,null],[5,"from_utf8_unchecked","","Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8.",null,null],[5,"from_utf8_unchecked_mut","","Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8; mutable version.",null,null],[3,"ParseBoolError","","An error returned when parsing a `bool` using [`from_str`] fails",null,null],[3,"SplitWhitespace","","An iterator over the non-whitespace substrings of a string, separated by any amount of whitespace.",null,null],[0,"pattern","","The string Pattern API.",null,null],[8,"Pattern","alloc::str::pattern","A string pattern.",null,null],[16,"Searcher","","Associated searcher for this pattern",45,null],[10,"into_searcher","","Constructs the associated searcher from `self` and the `haystack` to search in.",45,null],[11,"is_contained_in","","Checks whether the pattern matches anywhere in the haystack",45,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_prefix_of","","Checks whether the pattern matches at the front of the haystack",45,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_suffix_of","","Checks whether the pattern matches at the back of the haystack",45,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[4,"SearchStep","","Result of calling `Searcher::next()` or `ReverseSearcher::next_back()`.",null,null],[13,"Match","","Expresses that a match of the pattern has been found at `haystack[a..b]`.",46,null],[13,"Reject","","Expresses that `haystack[a..b]` has been rejected as a possible match of the pattern.",46,null],[13,"Done","","Expresses that every byte of the haystack has been visited, ending the iteration.",46,null],[8,"Searcher","","A searcher for a string pattern.",null,null],[10,"haystack","","Getter for the underlying string to be searched in",47,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[10,"next","","Performs the next search step starting from the front.",47,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","Find the next `Match` result. See `next()`",47,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","Find the next `Reject` result. See `next()` and `next_match()`",47,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[8,"ReverseSearcher","","A reverse searcher for a string pattern.",null,null],[10,"next_back","","Performs the next search step starting from the back.",48,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","Find the next `Match` result. See `next_back()`",48,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","Find the next `Reject` result. See `next_back()`",48,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[8,"DoubleEndedSearcher","","A marker trait to express that a `ReverseSearcher` can be used for a `DoubleEndedIterator` implementation.",null,null],[3,"CharSearcher","","Associated type for `<char as Pattern<'a>>::Searcher`.",null,null],[3,"CharSliceSearcher","","Associated type for `<&[char] as Pattern<'a>>::Searcher`.",null,null],[3,"CharPredicateSearcher","","Associated type for `<F as Pattern<'a>>::Searcher`.",null,null],[3,"StrSearcher","","Associated type for `<&str as Pattern<'a>>::Searcher`.",null,null],[3,"EncodeUtf16","alloc::str","An iterator of [`u16`] over the string encoded as UTF-16.",null,null],[5,"from_boxed_utf8_unchecked","","Converts a boxed slice of bytes to a boxed string slice without checking that the string contains valid UTF-8.",null,{"inputs":[{"name":"box"}],"output":{"generics":["str"],"name":"box"}}],[11,"clone","","",49,{"inputs":[{"name":"self"}],"output":{"name":"encodeutf16"}}],[11,"fmt","","",49,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",49,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"option"}}],[11,"size_hint","","",49,null],[0,"string","alloc","A UTF-8 encoded, growable string.",null,null],[3,"String","alloc::string","A UTF-8 encoded, growable string.",null,null],[3,"FromUtf8Error","","A possible error value when converting a `String` from a UTF-8 byte vector.",null,null],[3,"FromUtf16Error","","A possible error value when converting a `String` from a UTF-16 byte slice.",null,null],[3,"Drain","","A draining iterator for `String`.",null,null],[4,"ParseError","","An error when parsing a `String`.",null,null],[8,"ToString","","A trait for converting a value to a `String`.",null,null],[10,"to_string","","Converts the given value to a `String`.",50,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"partial_cmp","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"le","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"gt","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ge","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"cmp","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"ordering"}}],[11,"fmt","","",52,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",53,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new empty `String`.",51,{"inputs":[],"output":{"name":"string"}}],[11,"with_capacity","","Creates a new empty `String` with a particular capacity.",51,{"inputs":[{"name":"usize"}],"output":{"name":"string"}}],[11,"from_utf8","","Converts a vector of bytes to a `String`.",51,{"inputs":[{"generics":["u8"],"name":"vec"}],"output":{"generics":["string","fromutf8error"],"name":"result"}}],[11,"from_utf8_lossy","","Converts a slice of bytes to a string, including invalid characters.",51,null],[11,"from_utf16","","Decode a UTF-16 encoded vector `v` into a `String`, returning [`Err`] if `v` contains any invalid data.",51,null],[11,"from_utf16_lossy","","Decode a UTF-16 encoded slice `v` into a `String`, replacing invalid data with the replacement character (U+FFFD).",51,null],[11,"from_raw_parts","","Creates a new `String` from a length, capacity, and pointer.",51,null],[11,"from_utf8_unchecked","","Converts a vector of bytes to a `String` without checking that the string contains valid UTF-8.",51,{"inputs":[{"generics":["u8"],"name":"vec"}],"output":{"name":"string"}}],[11,"into_bytes","","Converts a `String` into a byte vector.",51,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"as_str","","Extracts a string slice containing the entire string.",51,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"as_mut_str","","Converts a `String` into a mutable string slice.",51,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"push_str","","Appends a given string slice onto the end of this `String`.",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":null}],[11,"capacity","","Returns this `String`'s capacity, in bytes.",51,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve","","Ensures that this `String`'s capacity is at least `additional` bytes larger than its length.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"reserve_exact","","Ensures that this `String`'s capacity is `additional` bytes larger than its length.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"try_reserve","","Tries to reserve capacity for at least `additional` more elements to be inserted in the given `String`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"try_reserve_exact","","Tries to reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `String`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"shrink_to_fit","","Shrinks the capacity of this `String` to match its length.",51,{"inputs":[{"name":"self"}],"output":null}],[11,"shrink_to","","Shrinks the capacity of this `String` with a lower bound.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"push","","Appends the given [`char`] to the end of this `String`.",51,{"inputs":[{"name":"self"},{"name":"char"}],"output":null}],[11,"as_bytes","","Returns a byte slice of this `String`'s contents.",51,null],[11,"truncate","","Shortens this `String` to the specified length.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"pop","","Removes the last character from the string buffer and returns it.",51,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"remove","","Removes a [`char`] from this `String` at a byte position and returns it.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"char"}}],[11,"retain","","Retains only the characters specified by the predicate.",51,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"insert","","Inserts a character into this `String` at a byte position.",51,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"char"}],"output":null}],[11,"insert_str","","Inserts a string slice into this `String` at a byte position.",51,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"str"}],"output":null}],[11,"as_mut_vec","","Returns a mutable reference to the contents of this `String`.",51,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"len","","Returns the length of this `String`, in bytes.",51,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if this `String` has a length of zero.",51,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"split_off","","Splits the string into two at the given index.",51,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"string"}}],[11,"clear","","Truncates this `String`, removing all contents.",51,{"inputs":[{"name":"self"}],"output":null}],[11,"drain","","Creates a draining iterator that removes the specified range in the string and yields the removed chars.",51,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"drain"}}],[11,"splice","","Creates a splicing iterator that removes the specified range in the string, and replaces it with the given string. The given string doesn't need to be the same length as the range.",51,{"inputs":[{"name":"self"},{"name":"r"},{"name":"str"}],"output":null}],[11,"into_boxed_str","","Converts this `String` into a [`Box`]`<`[`str`]`>`.",51,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"box"}}],[11,"as_bytes","","Returns a slice of [`u8`]s bytes that were attempted to convert to a `String`.",52,null],[11,"into_bytes","","Returns the bytes that were attempted to convert to a `String`.",52,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"utf8_error","","Fetch a `Utf8Error` to get more details about the conversion failure.",52,{"inputs":[{"name":"self"}],"output":{"name":"utf8error"}}],[11,"fmt","","",52,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",53,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",51,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"clone_from","","",51,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"from_iter","","",51,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","","",51,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","","",51,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","","",51,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","","",51,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"extend","","",51,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"extend","","",51,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"extend","","",51,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"extend","","",51,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"extend","","",51,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"eq","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ne","","",51,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"eq","","",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","","",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","alloc::borrow","",23,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",23,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","","",23,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",23,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","","",23,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ne","","",23,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"eq","alloc::string","",51,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"ne","","",51,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"default","","Creates an empty `String`.",51,{"inputs":[],"output":{"name":"string"}}],[11,"fmt","","",51,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",51,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",51,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"string"}}],[11,"add_assign","","",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":null}],[11,"index","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"range"}],"output":{"name":"str"}}],[11,"index","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeto"}],"output":{"name":"str"}}],[11,"index","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangefrom"}],"output":{"name":"str"}}],[11,"index","","",51,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"str"}}],[11,"index","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeinclusive"}],"output":{"name":"str"}}],[11,"index","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangetoinclusive"}],"output":{"name":"str"}}],[11,"index_mut","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"range"}],"output":{"name":"str"}}],[11,"index_mut","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeto"}],"output":{"name":"str"}}],[11,"index_mut","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangefrom"}],"output":{"name":"str"}}],[11,"index_mut","","",51,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"str"}}],[11,"index_mut","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeinclusive"}],"output":{"name":"str"}}],[11,"index_mut","","",51,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangetoinclusive"}],"output":{"name":"str"}}],[11,"deref","","",51,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"deref_mut","","",51,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"from_str","","",51,{"inputs":[{"name":"str"}],"output":{"generics":["string","parseerror"],"name":"result"}}],[11,"clone","","",54,{"inputs":[{"name":"self"}],"output":{"name":"parseerror"}}],[11,"fmt","","",54,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",54,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",54,{"inputs":[{"name":"self"},{"name":"parseerror"}],"output":{"name":"bool"}}],[11,"to_string","alloc::borrow","",23,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"to_string","alloc::string","",51,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"as_ref","","",51,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"as_ref","","",51,null],[11,"from","","",51,{"inputs":[{"name":"str"}],"output":{"name":"string"}}],[11,"from","","",51,{"inputs":[{"generics":["str"],"name":"box"}],"output":{"name":"string"}}],[11,"from","alloc::boxed","",8,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"box"}}],[11,"from","alloc::string","",51,{"inputs":[{"generics":["str"],"name":"cow"}],"output":{"name":"string"}}],[11,"from","alloc::borrow","",23,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from","","",23,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from_iter","","",23,{"inputs":[{"name":"i"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from_iter","","",23,{"inputs":[{"name":"i"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from_iter","","",23,{"inputs":[{"name":"i"}],"output":{"generics":["str"],"name":"cow"}}],[11,"write_str","alloc::string","",51,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"result"}}],[11,"write_char","","",51,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"result"}}],[11,"fmt","","",55,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"drop","","",55,{"inputs":[{"name":"self"}],"output":null}],[11,"next","","",55,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",55,null],[11,"next_back","","",55,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[0,"vec","alloc","A contiguous growable array type with heap-allocated contents, written `Vec<T>`.",null,null],[3,"Vec","alloc::vec","A contiguous growable array type, written `Vec<T>` but pronounced 'vector'.",null,null],[3,"IntoIter","","An iterator that moves out of a vector.",null,null],[3,"Drain","","A draining iterator for `Vec<T>`.",null,null],[3,"PlaceBack","","A place for insertion at the back of a `Vec`.",null,null],[3,"Splice","","A splicing iterator for `Vec`.",null,null],[3,"DrainFilter","","An iterator produced by calling `drain_filter` on Vec.",null,null],[11,"new","","Constructs a new, empty `Vec<T>`.",56,{"inputs":[],"output":{"name":"vec"}}],[11,"with_capacity","","Constructs a new, empty `Vec<T>` with the specified capacity.",56,{"inputs":[{"name":"usize"}],"output":{"name":"vec"}}],[11,"from_raw_parts","","Creates a `Vec<T>` directly from the raw components of another vector.",56,null],[11,"capacity","","Returns the number of elements the vector can hold without reallocating.",56,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the given `Vec<T>`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"reserve_exact","","Reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `Vec<T>`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"try_reserve","","Tries to reserve capacity for at least `additional` more elements to be inserted in the given `Vec<T>`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"try_reserve_exact","","Tries to reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `Vec<T>`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"shrink_to_fit","","Shrinks the capacity of the vector as much as possible.",56,{"inputs":[{"name":"self"}],"output":null}],[11,"shrink_to","","Shrinks the capacity of the vector with a lower bound.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"into_boxed_slice","","Converts the vector into [`Box<[T]>`][owned slice].",56,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"truncate","","Shortens the vector, keeping the first `len` elements and dropping the rest.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"as_slice","","Extracts a slice containing the entire vector.",56,null],[11,"as_mut_slice","","Extracts a mutable slice of the entire vector.",56,null],[11,"set_len","","Sets the length of a vector.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"swap_remove","","Removes an element from the vector and returns it.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"t"}}],[11,"insert","","Inserts an element at position `index` within the vector, shifting all elements after it to the right.",56,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"t"}],"output":null}],[11,"remove","","Removes and returns the element at position `index` within the vector, shifting all elements after it to the left.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"t"}}],[11,"retain","","Retains only the elements specified by the predicate.",56,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"dedup_by_key","","Removes all but the first of consecutive elements in the vector that resolve to the same key.",56,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"dedup_by","","Removes all but the first of consecutive elements in the vector satisfying a given equality relation.",56,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"push","","Appends an element to the back of a collection.",56,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"place_back","","Returns a place for insertion at the back of the `Vec`.",56,{"inputs":[{"name":"self"}],"output":{"name":"placeback"}}],[11,"pop","","Removes the last element from a vector and returns it, or [`None`] if it is empty.",56,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"append","","Moves all the elements of `other` into `Self`, leaving `other` empty.",56,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"drain","","Creates a draining iterator that removes the specified range in the vector and yields the removed items.",56,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"drain"}}],[11,"clear","","Clears the vector, removing all values.",56,{"inputs":[{"name":"self"}],"output":null}],[11,"len","","Returns the number of elements in the vector, also referred to as its 'length'.",56,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the vector contains no elements.",56,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"split_off","","Splits the collection into two at the given index.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"resize","","Resizes the `Vec` in-place so that `len` is equal to `new_len`.",56,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"t"}],"output":null}],[11,"extend_from_slice","","Clones and appends all elements in a slice to the `Vec`.",56,null],[11,"resize_default","","Resizes the `Vec` in-place so that `len` is equal to `new_len`.",56,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"dedup","","Removes consecutive repeated elements in the vector.",56,{"inputs":[{"name":"self"}],"output":null}],[11,"remove_item","","Removes the first instance of `item` from the vector if the item exists.",56,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[11,"clone","","",56,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"clone_from","","",56,{"inputs":[{"name":"self"},{"name":"vec"}],"output":null}],[11,"hash","","",56,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"index","","",56,null],[11,"index_mut","","",56,null],[11,"deref","","",56,null],[11,"deref_mut","","",56,null],[11,"from_iter","","",56,{"inputs":[{"name":"i"}],"output":{"name":"vec"}}],[11,"into_iter","","Creates a consuming iterator, that is, one that moves each value out of the vector (from start to end). The vector cannot be used after calling this.",56,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"extend","","",56,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"splice","","Creates a splicing iterator that replaces the specified range in the vector with the given `replace_with` iterator and yields the removed items. `replace_with` does not need to be the same length as `range`.",56,{"inputs":[{"name":"self"},{"name":"r"},{"name":"i"}],"output":{"name":"splice"}}],[11,"drain_filter","","Creates an iterator which uses a closure to determine if an element should be removed.",56,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"drainfilter"}}],[11,"extend","","",56,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"eq","","",56,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"ne","","",56,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","alloc::borrow","",23,null],[11,"ne","","",23,null],[11,"eq","","",23,null],[11,"ne","","",23,null],[11,"eq","","",23,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"ne","","",23,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"eq","alloc::vec","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"eq","","",56,null],[11,"ne","","",56,null],[11,"partial_cmp","","",56,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",56,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"ordering"}}],[11,"drop","","",56,{"inputs":[{"name":"self"}],"output":null}],[11,"default","","Creates an empty `Vec<T>`.",56,{"inputs":[],"output":{"name":"vec"}}],[11,"fmt","","",56,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"as_ref","","",56,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"as_mut","","",56,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"as_ref","","",56,null],[11,"as_mut","","",56,null],[11,"from","","",56,null],[11,"from","","",56,null],[11,"from","","",56,{"inputs":[{"name":"cow"}],"output":{"name":"vec"}}],[11,"from","","",56,{"inputs":[{"name":"box"}],"output":{"name":"vec"}}],[11,"from","alloc::boxed","",8,{"inputs":[{"name":"vec"}],"output":{"name":"box"}}],[11,"from","alloc::vec","",56,{"inputs":[{"name":"str"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"from","alloc::borrow","",23,null],[11,"from","","",23,{"inputs":[{"name":"vec"}],"output":{"name":"cow"}}],[11,"from_iter","","",23,{"inputs":[{"name":"i"}],"output":{"name":"cow"}}],[11,"fmt","alloc::vec","",57,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"as_slice","","Returns the remaining items of this iterator as a slice.",57,null],[11,"as_mut_slice","","Returns the remaining items of this iterator as a mutable slice.",57,null],[11,"next","","",57,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",57,null],[11,"count","","",57,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next_back","","",57,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is_empty","","",57,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",57,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"drop","","",57,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",58,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",58,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",58,null],[11,"next_back","","",58,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"drop","","",58,{"inputs":[{"name":"self"}],"output":null}],[11,"is_empty","","",58,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",59,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"make_place","","",59,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pointer","","",59,null],[11,"finalize","","",59,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"fmt","","",60,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",60,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",60,null],[11,"next_back","","",60,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"drop","","",60,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",61,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",61,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",61,null],[11,"drop","","",61,{"inputs":[{"name":"self"}],"output":null}],[0,"vec_deque","alloc","A double-ended queue implemented with a growable ring buffer.",null,null],[3,"VecDeque","alloc::vec_deque","A double-ended queue implemented with a growable ring buffer.",null,null],[3,"Iter","","An iterator over the elements of a `VecDeque`.",null,null],[3,"IterMut","","A mutable iterator over the elements of a `VecDeque`.",null,null],[3,"IntoIter","","An owning iterator over the elements of a `VecDeque`.",null,null],[3,"Drain","","A draining iterator over the elements of a `VecDeque`.",null,null],[3,"PlaceBack","","A place for insertion at the back of a `VecDeque`.",null,null],[3,"PlaceFront","","A place for insertion at the front of a `VecDeque`.",null,null],[11,"clone","","",62,{"inputs":[{"name":"self"}],"output":{"name":"vecdeque"}}],[11,"drop","","",62,{"inputs":[{"name":"self"}],"output":null}],[11,"default","","Creates an empty `VecDeque<T>`.",62,{"inputs":[],"output":{"name":"vecdeque"}}],[11,"new","","Creates an empty `VecDeque`.",62,{"inputs":[],"output":{"name":"vecdeque"}}],[11,"with_capacity","","Creates an empty `VecDeque` with space for at least `n` elements.",62,{"inputs":[{"name":"usize"}],"output":{"name":"vecdeque"}}],[11,"get","","Retrieves an element in the `VecDeque` by index.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"get_mut","","Retrieves an element in the `VecDeque` mutably by index.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"swap","","Swaps elements at indices `i` and `j`.",62,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":null}],[11,"capacity","","Returns the number of elements the `VecDeque` can hold without reallocating.",62,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve_exact","","Reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `VecDeque`. Does nothing if the capacity is already sufficient.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the given `VecDeque`. The collection may reserve more space to avoid frequent reallocations.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"try_reserve_exact","","Tries to reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `VecDeque<T>`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"try_reserve","","Tries to reserve capacity for at least `additional` more elements to be inserted in the given `VecDeque<T>`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"shrink_to_fit","","Shrinks the capacity of the `VecDeque` as much as possible.",62,{"inputs":[{"name":"self"}],"output":null}],[11,"shrink_to","","Shrinks the capacity of the `VecDeque` with a lower bound.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"truncate","","Shortens the `VecDeque`, dropping excess elements from the back.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"iter","","Returns a front-to-back iterator.",62,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Returns a front-to-back iterator that returns mutable references.",62,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"as_slices","","Returns a pair of slices which contain, in order, the contents of the `VecDeque`.",62,null],[11,"as_mut_slices","","Returns a pair of slices which contain, in order, the contents of the `VecDeque`.",62,null],[11,"len","","Returns the number of elements in the `VecDeque`.",62,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the `VecDeque` is empty.",62,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"drain","","Create a draining iterator that removes the specified range in the `VecDeque` and yields the removed items.",62,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"drain"}}],[11,"clear","","Clears the `VecDeque`, removing all values.",62,{"inputs":[{"name":"self"}],"output":null}],[11,"contains","","Returns `true` if the `VecDeque` contains an element equal to the given value.",62,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"front","","Provides a reference to the front element, or `None` if the `VecDeque` is empty.",62,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"front_mut","","Provides a mutable reference to the front element, or `None` if the `VecDeque` is empty.",62,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back","","Provides a reference to the back element, or `None` if the `VecDeque` is empty.",62,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back_mut","","Provides a mutable reference to the back element, or `None` if the `VecDeque` is empty.",62,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"pop_front","","Removes the first element and returns it, or `None` if the `VecDeque` is empty.",62,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push_front","","Prepends an element to the `VecDeque`.",62,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"push_back","","Appends an element to the back of the `VecDeque`.",62,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"pop_back","","Removes the last element from the `VecDeque` and returns it, or `None` if it is empty.",62,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"swap_remove_back","","Removes an element from anywhere in the `VecDeque` and returns it, replacing it with the last element.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"swap_remove_front","","Removes an element from anywhere in the `VecDeque` and returns it, replacing it with the first element.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"insert","","Inserts an element at `index` within the `VecDeque`, shifting all elements with indices greater than or equal to `index` towards the back.",62,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"t"}],"output":null}],[11,"remove","","Removes and returns the element at `index` from the `VecDeque`. Whichever end is closer to the removal point will be moved to make room, and all the affected elements will be moved to new positions. Returns `None` if `index` is out of bounds.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"split_off","","Splits the `VecDeque` into two at the given index.",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"append","","Moves all the elements of `other` into `Self`, leaving `other` empty.",62,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"retain","","Retains only the elements specified by the predicate.",62,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"place_back","","Returns a place for insertion at the back of the `VecDeque`.",62,{"inputs":[{"name":"self"}],"output":{"name":"placeback"}}],[11,"place_front","","Returns a place for insertion at the front of the `VecDeque`.",62,{"inputs":[{"name":"self"}],"output":{"name":"placefront"}}],[11,"resize","","Modifies the `VecDeque` in-place so that `len()` is equal to new_len, either by removing excess elements from the back or by appending clones of `value` to the back.",62,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"t"}],"output":null}],[11,"fmt","","",63,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",63,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"next","","",63,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",63,null],[11,"fold","","",63,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next_back","","",63,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"rfold","","",63,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"is_empty","","",63,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",64,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",64,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",64,null],[11,"fold","","",64,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next_back","","",64,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"rfold","","",64,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"is_empty","","",64,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",65,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"fmt","","",65,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",65,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",65,null],[11,"next_back","","",65,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is_empty","","",65,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",66,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"drop","","",66,{"inputs":[{"name":"self"}],"output":null}],[11,"next","","",66,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",66,null],[11,"next_back","","",66,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"eq","","",62,{"inputs":[{"name":"self"},{"name":"vecdeque"}],"output":{"name":"bool"}}],[11,"eq","","",62,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"eq","","",62,null],[11,"partial_cmp","","",62,{"inputs":[{"name":"self"},{"name":"vecdeque"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",62,{"inputs":[{"name":"self"},{"name":"vecdeque"}],"output":{"name":"ordering"}}],[11,"hash","","",62,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"index","","",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"a"}}],[11,"index_mut","","",62,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"a"}}],[11,"from_iter","","",62,{"inputs":[{"name":"t"}],"output":{"name":"vecdeque"}}],[11,"into_iter","","Consumes the `VecDeque` into a front-to-back iterator yielding elements by value.",62,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"extend","","",62,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"extend","","",62,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"fmt","","",62,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",62,{"inputs":[{"name":"vec"}],"output":{"name":"self"}}],[11,"from","alloc::vec","",56,{"inputs":[{"name":"vecdeque"}],"output":{"name":"self"}}],[11,"fmt","alloc::vec_deque","",67,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"make_place","","",67,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pointer","","",67,null],[11,"finalize","","",67,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"fmt","","",68,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"make_place","","",68,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pointer","","",68,null],[11,"finalize","","",68,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[0,"btree_map","alloc","A map based on a B-Tree.",null,null],[3,"BTreeMap","alloc::btree_map","A map based on a B-Tree.",null,null],[3,"Iter","","An iterator over the entries of a `BTreeMap`.",null,null],[3,"IterMut","","A mutable iterator over the entries of a `BTreeMap`.",null,null],[3,"IntoIter","","An owning iterator over the entries of a `BTreeMap`.",null,null],[3,"Keys","","An iterator over the keys of a `BTreeMap`.",null,null],[3,"Values","","An iterator over the values of a `BTreeMap`.",null,null],[3,"ValuesMut","","A mutable iterator over the values of a `BTreeMap`.",null,null],[3,"Range","","An iterator over a sub-range of entries in a `BTreeMap`.",null,null],[3,"RangeMut","","A mutable iterator over a sub-range of entries in a `BTreeMap`.",null,null],[3,"VacantEntry","","A view into a vacant entry in a `BTreeMap`. It is part of the [`Entry`] enum.",null,null],[3,"OccupiedEntry","","A view into an occupied entry in a `BTreeMap`. It is part of the [`Entry`] enum.",null,null],[4,"Entry","","A view into a single entry in a map, which may either be vacant or occupied.",null,null],[13,"Vacant","","A vacant entry.",69,null],[13,"Occupied","","An occupied entry.",69,null],[0,"btree_set","alloc","A set based on a B-Tree.",null,null],[3,"BTreeSet","alloc::btree_set","A set based on a B-Tree.",null,null],[3,"Iter","","An iterator over the items of a `BTreeSet`.",null,null],[3,"IntoIter","","An owning iterator over the items of a `BTreeSet`.",null,null],[3,"Range","","An iterator over a sub-range of items in a `BTreeSet`.",null,null],[3,"Difference","","A lazy iterator producing elements in the difference of `BTreeSet`s.",null,null],[3,"SymmetricDifference","","A lazy iterator producing elements in the symmetric difference of `BTreeSet`s.",null,null],[3,"Intersection","","A lazy iterator producing elements in the intersection of `BTreeSet`s.",null,null],[3,"Union","","A lazy iterator producing elements in the union of `BTreeSet`s.",null,null],[14,"vec","alloc","Creates a [`Vec`] containing the arguments.",null,null],[14,"format","","Creates a `String` using interpolation of runtime expressions.",null,null],[11,"is_empty","alloc::slice","",70,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","","",71,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","alloc::str","",72,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",72,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","alloc::slice","",73,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","","",74,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next","alloc::str","",75,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","alloc::slice","",76,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",76,null],[11,"count","","",76,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",76,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",76,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","alloc::str","",77,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","alloc::slice","",78,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",78,null],[11,"count","","",78,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",78,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",78,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",79,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",79,null],[11,"next","","",80,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",80,null],[11,"next","alloc::str","",81,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","alloc::slice","",82,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",82,null],[11,"next","alloc::str","",83,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",83,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",83,null],[11,"last","","",83,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",84,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","alloc::slice","",71,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",71,null],[11,"count","","",71,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",71,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",71,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",71,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",71,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"position","","",71,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",71,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next","alloc::str","",85,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","alloc::slice","",86,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",86,null],[11,"next","","",70,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",70,null],[11,"count","","",70,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",70,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",70,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",70,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",70,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"position","","",70,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",70,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next","alloc::str","",87,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"count","","",87,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",87,null],[11,"last","","",87,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next","","",88,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"size_hint","","",88,null],[11,"next","alloc::slice","",89,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",89,null],[11,"next","alloc::str","",90,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","","",72,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"size_hint","","",72,null],[11,"count","","",72,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",72,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",72,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"all","","",72,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"any","","",72,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"find","","",72,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"position","","",72,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",72,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next","","",91,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",92,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"size_hint","","",92,null],[11,"next","","",93,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","alloc::slice","",74,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",74,null],[11,"count","","",74,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",74,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",74,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",73,null],[11,"count","","",73,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",73,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",94,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",94,null],[11,"next","","",95,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",95,null],[11,"count","","",95,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",95,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",95,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",96,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",96,null],[11,"next","alloc::str","",97,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","alloc::slice","",98,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",98,null],[11,"next","alloc::str","",99,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"hash","alloc::fmt","",100,null],[11,"clone","alloc::str::pattern","",101,{"inputs":[{"name":"self"}],"output":{"name":"strsearcher"}}],[11,"clone","alloc::str","",83,{"inputs":[{"name":"self"}],"output":{"name":"charindices"}}],[11,"clone","alloc::slice","",96,{"inputs":[{"name":"self"}],"output":{"name":"split"}}],[11,"clone","alloc::str","",91,{"inputs":[{"name":"self"}],"output":{"name":"rmatchindices"}}],[11,"clone","","",102,{"inputs":[{"name":"self"}],"output":{"name":"utf8error"}}],[11,"clone","","",90,{"inputs":[{"name":"self"}],"output":{"name":"rsplit"}}],[11,"clone","alloc::fmt","",100,{"inputs":[{"name":"self"}],"output":{"name":"error"}}],[11,"clone","alloc::allocator","",1,{"inputs":[{"name":"self"}],"output":{"name":"allocerr"}}],[11,"clone","alloc::str::pattern","",103,{"inputs":[{"name":"self"}],"output":{"name":"charslicesearcher"}}],[11,"clone","alloc::str","",72,{"inputs":[{"name":"self"}],"output":{"name":"bytes"}}],[11,"clone","","",88,{"inputs":[{"name":"self"}],"output":{"name":"lines"}}],[11,"clone","alloc::allocator","",2,{"inputs":[{"name":"self"}],"output":{"name":"collectionallocerr"}}],[11,"clone","","",104,{"inputs":[{"name":"self"}],"output":{"name":"layout"}}],[11,"clone","alloc::slice","",76,{"inputs":[{"name":"self"}],"output":{"name":"windows"}}],[11,"clone","alloc::str::pattern","",46,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"clone","alloc::str","",93,{"inputs":[{"name":"self"}],"output":{"name":"rmatches"}}],[11,"clone","alloc::fmt","",105,{"inputs":[{"name":"self"}],"output":{"name":"arguments"}}],[11,"clone","alloc::str","",99,{"inputs":[{"name":"self"}],"output":{"name":"rsplitn"}}],[11,"clone","","",75,{"inputs":[{"name":"self"}],"output":{"name":"splitn"}}],[11,"clone","","",97,{"inputs":[{"name":"self"}],"output":{"name":"matches"}}],[11,"clone","","",85,{"inputs":[{"name":"self"}],"output":{"name":"splitterminator"}}],[11,"clone","alloc::slice","",70,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","alloc::str","",92,{"inputs":[{"name":"self"}],"output":{"name":"linesany"}}],[11,"clone","alloc::slice","",86,{"inputs":[{"name":"self"}],"output":{"name":"rsplit"}}],[11,"clone","alloc::str::pattern","",106,{"inputs":[{"name":"self"}],"output":{"name":"charpredicatesearcher"}}],[11,"clone","alloc::allocator","",107,{"inputs":[{"name":"self"}],"output":{"name":"cannotreallocinplace"}}],[11,"clone","alloc::str","",84,{"inputs":[{"name":"self"}],"output":{"name":"rsplitterminator"}}],[11,"clone","","",77,{"inputs":[{"name":"self"}],"output":{"name":"matchindices"}}],[11,"clone","alloc::slice","",95,{"inputs":[{"name":"self"}],"output":{"name":"chunks"}}],[11,"clone","alloc::str","",81,{"inputs":[{"name":"self"}],"output":{"name":"split"}}],[11,"clone","alloc::slice","",73,{"inputs":[{"name":"self"}],"output":{"name":"exactchunks"}}],[11,"clone","alloc::str","",108,{"inputs":[{"name":"self"}],"output":{"name":"parseboolerror"}}],[11,"clone","alloc::str::pattern","",109,{"inputs":[{"name":"self"}],"output":{"name":"charsearcher"}}],[11,"clone","alloc::str","",87,{"inputs":[{"name":"self"}],"output":{"name":"chars"}}],[11,"write_str","alloc::fmt","",110,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_char","","",110,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_fmt","","",110,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[11,"next_back","alloc::str::pattern","",103,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",103,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","",103,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",106,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",106,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","",106,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",101,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",101,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",109,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",109,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"from","alloc::allocator","",2,{"inputs":[{"name":"allocerr"}],"output":{"name":"collectionallocerr"}}],[11,"eq","alloc::str::pattern","",46,{"inputs":[{"name":"self"},{"name":"searchstep"}],"output":{"name":"bool"}}],[11,"ne","","",46,{"inputs":[{"name":"self"},{"name":"searchstep"}],"output":{"name":"bool"}}],[11,"eq","alloc::allocator","",1,{"inputs":[{"name":"self"},{"name":"allocerr"}],"output":{"name":"bool"}}],[11,"ne","","",1,{"inputs":[{"name":"self"},{"name":"allocerr"}],"output":{"name":"bool"}}],[11,"eq","","",107,{"inputs":[{"name":"self"},{"name":"cannotreallocinplace"}],"output":{"name":"bool"}}],[11,"eq","alloc::fmt","",100,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"name":"bool"}}],[11,"eq","alloc::str","",102,{"inputs":[{"name":"self"},{"name":"utf8error"}],"output":{"name":"bool"}}],[11,"ne","","",102,{"inputs":[{"name":"self"},{"name":"utf8error"}],"output":{"name":"bool"}}],[11,"eq","alloc::allocator","",104,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"name":"bool"}}],[11,"ne","","",104,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"name":"bool"}}],[11,"eq","","",2,{"inputs":[{"name":"self"},{"name":"collectionallocerr"}],"output":{"name":"bool"}}],[11,"ne","","",2,{"inputs":[{"name":"self"},{"name":"collectionallocerr"}],"output":{"name":"bool"}}],[11,"eq","alloc::str","",108,{"inputs":[{"name":"self"},{"name":"parseboolerror"}],"output":{"name":"bool"}}],[11,"ne","","",108,{"inputs":[{"name":"self"},{"name":"parseboolerror"}],"output":{"name":"bool"}}],[11,"cmp","alloc::fmt","",100,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",100,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"fmt","","",100,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",108,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::fmt","",105,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::allocator","",107,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",102,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::allocator","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::fmt","",100,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",88,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",91,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",96,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",70,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",80,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",73,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",85,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::allocator","",104,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",79,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",89,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",92,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",102,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",77,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",97,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",99,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",76,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",108,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::allocator","",2,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str::pattern","",109,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",84,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",98,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::allocator","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str::pattern","",103,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",72,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",78,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::fmt","",105,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",74,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::allocator","",107,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",90,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::allocator","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",81,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",87,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",93,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str::pattern","",46,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",95,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",82,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str::pattern","",106,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",71,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",94,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str","",83,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",75,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::str::pattern","",101,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","alloc::slice","",86,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"as_ref","","",70,null],[11,"default","alloc::fmt","",100,{"inputs":[],"output":{"name":"error"}}],[11,"next_back","alloc::str","",84,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",91,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",85,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",88,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",77,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","alloc::slice","",86,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",76,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",78,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",96,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",80,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","alloc::str","",81,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","alloc::slice","",95,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","alloc::str","",90,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",72,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"rfind","","",72,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"next_back","alloc::slice","",70,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",70,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",70,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","alloc::str","",83,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",87,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next_back","","",92,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","alloc::slice","",74,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","alloc::str","",97,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","alloc::slice","",71,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",71,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",71,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","alloc::str","",93,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","alloc::slice","",82,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"haystack","alloc::str::pattern","",103,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",103,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",103,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","",103,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"haystack","","",106,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",106,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",106,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","",106,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"haystack","","",109,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",109,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",109,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"haystack","","",101,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",101,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",101,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","alloc::str","",111,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",111,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"fmt","","",111,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"clone","","",111,{"inputs":[{"name":"self"}],"output":{"name":"splitwhitespace"}}],[11,"from_size_align","alloc::allocator","Constructs a `Layout` from a given `size` and `align`, or returns `None` if any of the following conditions are not met:",104,{"inputs":[{"name":"usize"},{"name":"usize"}],"output":{"generics":["layout"],"name":"option"}}],[11,"from_size_align_unchecked","","Creates a layout, bypassing all checks.",104,{"inputs":[{"name":"usize"},{"name":"usize"}],"output":{"name":"layout"}}],[11,"size","","The minimum size in bytes for a memory block of this layout.",104,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"align","","The minimum byte alignment for a memory block of this layout.",104,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"new","","Constructs a `Layout` suitable for holding a value of type `T`.",104,{"inputs":[],"output":{"name":"layout"}}],[11,"for_value","","Produces layout describing a record that could be used to allocate backing structure for `T` (which could be a trait or other unsized type like a slice).",104,{"inputs":[{"name":"t"}],"output":{"name":"layout"}}],[11,"align_to","","Creates a layout describing the record that can hold a value of the same layout as `self`, but that also is aligned to alignment `align` (measured in bytes).",104,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"layout"}}],[11,"padding_needed_for","","Returns the amount of padding we must insert after `self` to ensure that the following address will satisfy `align` (measured in bytes).",104,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"repeat","","Creates a layout describing the record for `n` instances of `self`, with a suitable amount of padding between each to ensure that each instance is given its requested size and alignment. On success, returns `(k, offs)` where `k` is the layout of the array and `offs` is the distance between the start of each element in the array.",104,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"extend","","Creates a layout describing the record for `self` followed by `next`, including any necessary padding to ensure that `next` will be properly aligned. Note that the result layout will satisfy the alignment properties of both `self` and `next`.",104,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"name":"option"}}],[11,"repeat_packed","","Creates a layout describing the record for `n` instances of `self`, with no padding between each instance.",104,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["layout"],"name":"option"}}],[11,"extend_packed","","Creates a layout describing the record for `self` followed by `next` with no additional padding between the two. Since no padding is inserted, the alignment of `next` is irrelevant, and is not incorporated at all into the resulting layout.",104,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"name":"option"}}],[11,"array","","Creates a layout describing the record for a `[T; n]`.",104,{"inputs":[{"name":"usize"}],"output":{"generics":["layout"],"name":"option"}}],[11,"invalid_input","","",1,{"inputs":[{"name":"str"}],"output":{"name":"allocerr"}}],[11,"is_memory_exhausted","","",1,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_request_unsupported","","",1,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"description","","",1,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",107,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"from","alloc::vec","",56,{"inputs":[{"name":"binaryheap"}],"output":{"name":"vec"}}],[11,"drop","alloc::btree_map","",112,{"inputs":[{"name":"self"}],"output":null}],[11,"clone","","",112,{"inputs":[{"name":"self"}],"output":{"name":"btreemap"}}],[11,"fmt","","",113,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",114,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",115,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",116,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",117,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",118,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",119,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",120,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",69,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",121,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",122,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Makes a new empty BTreeMap with a reasonable choice for B.",112,{"inputs":[],"output":{"name":"btreemap"}}],[11,"clear","","Clears the map, removing all values.",112,{"inputs":[{"name":"self"}],"output":null}],[11,"get","","Returns a reference to the value corresponding to the key.",112,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"get_key_value","","Returns the key-value pair corresponding to the supplied key.",112,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"contains_key","","Returns `true` if the map contains a value for the specified key.",112,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"get_mut","","Returns a mutable reference to the value corresponding to the key.",112,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"insert","","Inserts a key-value pair into the map.",112,{"inputs":[{"name":"self"},{"name":"k"},{"name":"v"}],"output":{"name":"option"}}],[11,"remove","","Removes a key from the map, returning the value at the key if the key was previously in the map.",112,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"append","","Moves all elements from `other` into `Self`, leaving `other` empty.",112,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"range","","Constructs a double-ended iterator over a sub-range of elements in the map. The simplest way is to use the range syntax `min..max`, thus `range(min..max)` will yield elements from min (inclusive) to max (exclusive). The range may also be entered as `(Bound<T>, Bound<T>)`, so for example `range((Excluded(4), Included(10)))` will yield a left-exclusive, right-inclusive range from 4 to 10.",112,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"range"}}],[11,"range_mut","","Constructs a mutable double-ended iterator over a sub-range of elements in the map. The simplest way is to use the range syntax `min..max`, thus `range(min..max)` will yield elements from min (inclusive) to max (exclusive). The range may also be entered as `(Bound<T>, Bound<T>)`, so for example `range((Excluded(4), Included(10)))` will yield a left-exclusive, right-inclusive range from 4 to 10.",112,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"rangemut"}}],[11,"entry","","Gets the given key's corresponding entry in the map for in-place manipulation.",112,{"inputs":[{"name":"self"},{"name":"k"}],"output":{"name":"entry"}}],[11,"split_off","","Splits the collection into two at the given key. Returns everything after the given key, including the key.",112,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"self"}}],[11,"next","","",113,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",113,null],[11,"next_back","","",113,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",113,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"clone","","",113,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"next","","",114,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",114,null],[11,"next_back","","",114,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",114,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"into_iter","","",112,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"drop","","",115,{"inputs":[{"name":"self"}],"output":null}],[11,"next","","",115,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",115,null],[11,"next_back","","",115,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",115,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next","","",116,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",116,null],[11,"next_back","","",116,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",116,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"clone","","",116,{"inputs":[{"name":"self"}],"output":{"name":"keys"}}],[11,"next","","",117,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",117,null],[11,"next_back","","",117,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",117,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"clone","","",117,{"inputs":[{"name":"self"}],"output":{"name":"values"}}],[11,"next","","",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",118,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",118,null],[11,"next_back","","",118,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",118,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next_back","","",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",119,{"inputs":[{"name":"self"}],"output":{"name":"range"}}],[11,"next","","",120,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",120,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"from_iter","","",112,{"inputs":[{"name":"t"}],"output":{"name":"btreemap"}}],[11,"extend","","",112,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"extend","","",112,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"hash","","",112,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"default","","Creates an empty `BTreeMap<K, V>`.",112,{"inputs":[],"output":{"name":"btreemap"}}],[11,"eq","","",112,{"inputs":[{"name":"self"},{"name":"btreemap"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",112,{"inputs":[{"name":"self"},{"name":"btreemap"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",112,{"inputs":[{"name":"self"},{"name":"btreemap"}],"output":{"name":"ordering"}}],[11,"fmt","","",112,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"index","","Returns a reference to the value corresponding to the supplied key.",112,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"v"}}],[11,"iter","","Gets an iterator over the entries of the map, sorted by key.",112,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Gets a mutable iterator over the entries of the map, sorted by key.",112,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"keys","","Gets an iterator over the keys of the map, in sorted order.",112,{"inputs":[{"name":"self"}],"output":{"name":"keys"}}],[11,"values","","Gets an iterator over the values of the map, in order by key.",112,{"inputs":[{"name":"self"}],"output":{"name":"values"}}],[11,"values_mut","","Gets a mutable iterator over the values of the map, in order by key.",112,{"inputs":[{"name":"self"}],"output":{"name":"valuesmut"}}],[11,"len","","Returns the number of elements in the map.",112,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the map contains no elements.",112,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or_insert","","Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.",69,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"or_insert_with","","Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.",69,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"v"}}],[11,"key","","Returns a reference to this entry's key.",69,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"and_modify","","Provides in-place mutable access to an occupied entry before any potential inserts into the map.",69,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"self"}}],[11,"or_default","","Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.",69,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"key","","Gets a reference to the key that would be used when inserting a value through the VacantEntry.",121,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"into_key","","Take ownership of the key.",121,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"insert","","Sets the value of the entry with the `VacantEntry`'s key, and returns a mutable reference to it.",121,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"key","","Gets a reference to the key in the entry.",122,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"remove_entry","","Take ownership of the key and value from the map.",122,null],[11,"get","","Gets a reference to the value in the entry.",122,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"get_mut","","Gets a mutable reference to the value in the entry.",122,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"into_mut","","Converts the entry into a mutable reference to its value.",122,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"insert","","Sets the value of the entry with the `OccupiedEntry`'s key, and returns the entry's old value.",122,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"remove","","Takes the value of the entry out of the map, and returns it.",122,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"clone","alloc::btree_set","",123,{"inputs":[{"name":"self"}],"output":{"name":"btreeset"}}],[11,"hash","","",123,null],[11,"eq","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"ne","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"cmp","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"le","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"gt","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"ge","","",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"fmt","","",124,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",125,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",126,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",127,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",128,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",129,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",130,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Makes a new `BTreeSet` with a reasonable choice of B.",123,{"inputs":[],"output":{"name":"btreeset"}}],[11,"range","","Constructs a double-ended iterator over a sub-range of elements in the set. The simplest way is to use the range syntax `min..max`, thus `range(min..max)` will yield elements from min (inclusive) to max (exclusive). The range may also be entered as `(Bound<T>, Bound<T>)`, so for example `range((Excluded(4), Included(10)))` will yield a left-exclusive, right-inclusive range from 4 to 10.",123,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"range"}}],[11,"difference","","Visits the values representing the difference, i.e. the values that are in `self` but not in `other`, in ascending order.",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"difference"}}],[11,"symmetric_difference","","Visits the values representing the symmetric difference, i.e. the values that are in `self` or in `other` but not in both, in ascending order.",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"symmetricdifference"}}],[11,"intersection","","Visits the values representing the intersection, i.e. the values that are both in `self` and `other`, in ascending order.",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"intersection"}}],[11,"union","","Visits the values representing the union, i.e. all the values in `self` or `other`, without duplicates, in ascending order.",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"union"}}],[11,"clear","","Clears the set, removing all values.",123,{"inputs":[{"name":"self"}],"output":null}],[11,"contains","","Returns `true` if the set contains a value.",123,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"get","","Returns a reference to the value in the set, if any, that is equal to the given value.",123,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"is_disjoint","","Returns `true` if `self` has no elements in common with `other`. This is equivalent to checking for an empty intersection.",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"is_subset","","Returns `true` if the set is a subset of another, i.e. `other` contains at least all the values in `self`.",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"is_superset","","Returns `true` if the set is a superset of another, i.e. `self` contains at least all the values in `other`.",123,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"insert","","Adds a value to the set.",123,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"replace","","Adds a value to the set, replacing the existing value, if any, that is equal to the given one. Returns the replaced value.",123,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[11,"remove","","Removes a value from the set. Returns `true` if the value was present in the set.",123,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"take","","Removes and returns the value in the set, if any, that is equal to the given one.",123,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"append","","Moves all elements from `other` into `Self`, leaving `other` empty.",123,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"split_off","","Splits the collection into two at the given key. Returns everything after the given key, including the key.",123,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"self"}}],[11,"iter","","Gets an iterator that visits the values in the `BTreeSet` in ascending order.",123,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"len","","Returns the number of elements in the set.",123,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the set contains no elements.",123,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"from_iter","","",123,{"inputs":[{"name":"i"}],"output":{"name":"btreeset"}}],[11,"into_iter","","Gets an iterator for moving out the `BTreeSet`'s contents.",123,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"extend","","",123,{"inputs":[{"name":"self"},{"name":"iter"}],"output":null}],[11,"extend","","",123,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"default","","Makes an empty `BTreeSet<T>` with a reasonable choice of B.",123,{"inputs":[],"output":{"name":"btreeset"}}],[11,"fmt","","",123,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",124,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"next","","",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",124,null],[11,"next_back","","",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",124,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next","","",125,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",125,null],[11,"next_back","","",125,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",125,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"clone","","",126,{"inputs":[{"name":"self"}],"output":{"name":"range"}}],[11,"next","","",126,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",126,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",127,{"inputs":[{"name":"self"}],"output":{"name":"difference"}}],[11,"next","","",127,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",127,null],[11,"clone","","",128,{"inputs":[{"name":"self"}],"output":{"name":"symmetricdifference"}}],[11,"next","","",128,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",128,null],[11,"clone","","",129,{"inputs":[{"name":"self"}],"output":{"name":"intersection"}}],[11,"next","","",129,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",129,null],[11,"clone","","",130,{"inputs":[{"name":"self"}],"output":{"name":"union"}}],[11,"next","","",130,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",130,null],[11,"pad_integral","alloc::fmt","Performs the correct padding for an integer which has already been emitted into a str. The str should not contain the sign for the integer, that will be added by this method.",110,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"str"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"pad","","This function takes a string slice and emits it to the internal buffer after applying the relevant formatting flags specified. The flags recognized for generic strings are:",110,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_str","","Writes some data to the underlying buffer contained within this formatter.",110,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_fmt","","Writes some formatted information into this instance",110,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[11,"flags","","Flags for formatting",110,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"fill","","Character used as 'fill' whenever there is alignment",110,{"inputs":[{"name":"self"}],"output":{"name":"char"}}],[11,"align","","Flag indicating what form of alignment was requested",110,{"inputs":[{"name":"self"}],"output":{"name":"alignment"}}],[11,"width","","Optionally specified integer width that the output should be.",110,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"precision","","Optionally specified precision for numeric types.",110,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"sign_plus","","Determines if the `+` flag was specified.",110,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"sign_minus","","Determines if the `-` flag was specified.",110,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"alternate","","Determines if the `#` flag was specified.",110,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"sign_aware_zero_pad","","Determines if the `0` flag was specified.",110,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"debug_struct","","Creates a [`DebugStruct`] builder designed to assist with creation of [`fmt::Debug`] implementations for structs.",110,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"debugstruct"}}],[11,"debug_tuple","","Creates a `DebugTuple` builder designed to assist with creation of `fmt::Debug` implementations for tuple structs.",110,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"debugtuple"}}],[11,"debug_list","","Creates a `DebugList` builder designed to assist with creation of `fmt::Debug` implementations for list-like structures.",110,{"inputs":[{"name":"self"}],"output":{"name":"debuglist"}}],[11,"debug_set","","Creates a `DebugSet` builder designed to assist with creation of `fmt::Debug` implementations for set-like structures.",110,{"inputs":[{"name":"self"}],"output":{"name":"debugset"}}],[11,"debug_map","","Creates a `DebugMap` builder designed to assist with creation of `fmt::Debug` implementations for map-like structures.",110,{"inputs":[{"name":"self"}],"output":{"name":"debugmap"}}],[11,"entry","","Adds a new entry to the list output.",131,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debuglist"}}],[11,"entries","","Adds the contents of an iterator of entries to the list output.",131,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debuglist"}}],[11,"finish","","Finishes output and returns any error encountered.",131,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"entry","","Adds a new entry to the map output.",132,{"inputs":[{"name":"self"},{"name":"debug"},{"name":"debug"}],"output":{"name":"debugmap"}}],[11,"entries","","Adds the contents of an iterator of entries to the map output.",132,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debugmap"}}],[11,"finish","","Finishes output and returns any error encountered.",132,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"entry","","Adds a new entry to the set output.",133,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debugset"}}],[11,"entries","","Adds the contents of an iterator of entries to the set output.",133,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debugset"}}],[11,"finish","","Finishes output and returns any error encountered.",133,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"field","","Adds a new field to the generated struct output.",134,{"inputs":[{"name":"self"},{"name":"str"},{"name":"debug"}],"output":{"name":"debugstruct"}}],[11,"finish","","Finishes output and returns any error encountered.",134,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"field","","Adds a new field to the generated tuple struct output.",135,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debugtuple"}}],[11,"finish","","Finishes output and returns any error encountered.",135,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"as_slice","alloc::slice","View the underlying data as a subslice of the original data.",70,null],[11,"into_slice","","View the underlying data as a subslice of the original data.",71,null],[11,"borrow","alloc::vec","",56,null],[11,"borrow_mut","","",56,null],[11,"valid_up_to","alloc::str","Returns the index in the given string up to which valid UTF-8 was verified.",102,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"error_len","","Provide more information about the failure:",102,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"as_str","","View the underlying data as a subslice of the original data.",87,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"as_str","","View the underlying data as a subslice of the original data.",83,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"borrow","alloc::string","",51,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"from","alloc::vec","",56,{"inputs":[{"name":"string"}],"output":{"generics":["u8"],"name":"vec"}}]],"paths":[[3,"Excess"],[4,"AllocErr"],[4,"CollectionAllocErr"],[8,"Alloc"],[3,"Heap"],[8,"FnBox"],[3,"ExchangeHeapSingleton"],[3,"IntermediateBox"],[3,"Box"],[3,"PinBox"],[3,"Weak"],[3,"Arc"],[3,"Rc"],[3,"Weak"],[3,"RawVec"],[3,"PeekMut"],[3,"BinaryHeap"],[3,"Iter"],[3,"IntoIter"],[3,"Drain"],[3,"BinaryHeapPlace"],[8,"Borrow"],[8,"BorrowMut"],[4,"Cow"],[8,"ToOwned"],[8,"Write"],[8,"Binary"],[8,"Octal"],[8,"Debug"],[8,"Display"],[8,"LowerHex"],[8,"Pointer"],[8,"UpperHex"],[8,"LowerExp"],[8,"UpperExp"],[3,"Iter"],[3,"IterMut"],[3,"IntoIter"],[3,"LinkedList"],[3,"DrainFilter"],[3,"FrontPlace"],[3,"BackPlace"],[8,"SliceIndex"],[8,"SliceConcatExt"],[8,"FromStr"],[8,"Pattern"],[4,"SearchStep"],[8,"Searcher"],[8,"ReverseSearcher"],[3,"EncodeUtf16"],[8,"ToString"],[3,"String"],[3,"FromUtf8Error"],[3,"FromUtf16Error"],[4,"ParseError"],[3,"Drain"],[3,"Vec"],[3,"IntoIter"],[3,"Drain"],[3,"PlaceBack"],[3,"Splice"],[3,"DrainFilter"],[3,"VecDeque"],[3,"Iter"],[3,"IterMut"],[3,"IntoIter"],[3,"Drain"],[3,"PlaceBack"],[3,"PlaceFront"],[4,"Entry"],[3,"Iter"],[3,"IterMut"],[3,"Bytes"],[3,"ExactChunks"],[3,"ExactChunksMut"],[3,"SplitN"],[3,"Windows"],[3,"MatchIndices"],[3,"ChunksMut"],[3,"RSplitN"],[3,"SplitMut"],[3,"Split"],[3,"RSplitMut"],[3,"CharIndices"],[3,"RSplitTerminator"],[3,"SplitTerminator"],[3,"RSplit"],[3,"Chars"],[3,"Lines"],[3,"SplitNMut"],[3,"RSplit"],[3,"RMatchIndices"],[3,"LinesAny"],[3,"RMatches"],[3,"RSplitNMut"],[3,"Chunks"],[3,"Split"],[3,"Matches"],[3,"SplitN"],[3,"RSplitN"],[3,"Error"],[3,"StrSearcher"],[3,"Utf8Error"],[3,"CharSliceSearcher"],[3,"Layout"],[3,"Arguments"],[3,"CharPredicateSearcher"],[3,"CannotReallocInPlace"],[3,"ParseBoolError"],[3,"CharSearcher"],[3,"Formatter"],[3,"SplitWhitespace"],[3,"BTreeMap"],[3,"Iter"],[3,"IterMut"],[3,"IntoIter"],[3,"Keys"],[3,"Values"],[3,"ValuesMut"],[3,"Range"],[3,"RangeMut"],[3,"VacantEntry"],[3,"OccupiedEntry"],[3,"BTreeSet"],[3,"Iter"],[3,"IntoIter"],[3,"Range"],[3,"Difference"],[3,"SymmetricDifference"],[3,"Intersection"],[3,"Union"],[3,"DebugList"],[3,"DebugMap"],[3,"DebugSet"],[3,"DebugStruct"],[3,"DebugTuple"]]};
searchIndex["core"] = {"doc":"The Rust Core Library","items":[[0,"isize","core","The pointer-sized signed integer type.",null,null],[17,"MIN","core::isize","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i8","core","The 8-bit signed integer type.",null,null],[17,"MIN","core::i8","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i16","core","The 16-bit signed integer type.",null,null],[17,"MIN","core::i16","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i32","core","The 32-bit signed integer type.",null,null],[17,"MIN","core::i32","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i64","core","The 64-bit signed integer type.",null,null],[17,"MIN","core::i64","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i128","core","The 128-bit signed integer type.",null,null],[17,"MIN","core::i128","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"usize","core","The pointer-sized unsigned integer type.",null,null],[17,"MIN","core::usize","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u8","core","The 8-bit unsigned integer type.",null,null],[17,"MIN","core::u8","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u16","core","The 16-bit unsigned integer type.",null,null],[17,"MIN","core::u16","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u32","core","The 32-bit unsigned integer type.",null,null],[17,"MIN","core::u32","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u64","core","The 64-bit unsigned integer type.",null,null],[17,"MIN","core::u64","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u128","core","The 128-bit unsigned integer type.",null,null],[17,"MIN","core::u128","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"f32","core","This module provides constants which are specific to the implementation of the `f32` floating point data type.",null,null],[0,"consts","core::f32","Basic mathematical constants.",null,null],[17,"PI","core::f32::consts","Archimedes' constant (π)",null,null],[17,"FRAC_PI_2","","π/2",null,null],[17,"FRAC_PI_3","","π/3",null,null],[17,"FRAC_PI_4","","π/4",null,null],[17,"FRAC_PI_6","","π/6",null,null],[17,"FRAC_PI_8","","π/8",null,null],[17,"FRAC_1_PI","","1/π",null,null],[17,"FRAC_2_PI","","2/π",null,null],[17,"FRAC_2_SQRT_PI","","2/sqrt(π)",null,null],[17,"SQRT_2","","sqrt(2)",null,null],[17,"FRAC_1_SQRT_2","","1/sqrt(2)",null,null],[17,"E","","Euler's number (e)",null,null],[17,"LOG2_E","","log2(e)",null,null],[17,"LOG10_E","","log10(e)",null,null],[17,"LN_2","","ln(2)",null,null],[17,"LN_10","","ln(10)",null,null],[17,"RADIX","core::f32","The radix or base of the internal representation of `f32`.",null,null],[17,"MANTISSA_DIGITS","","Number of significant digits in base 2.",null,null],[17,"DIGITS","","Approximate number of significant digits in base 10.",null,null],[17,"EPSILON","","Difference between `1.0` and the next largest representable number.",null,null],[17,"MIN","","Smallest finite `f32` value.",null,null],[17,"MIN_POSITIVE","","Smallest positive normal `f32` value.",null,null],[17,"MAX","","Largest finite `f32` value.",null,null],[17,"MIN_EXP","","One greater than the minimum possible normal power of 2 exponent.",null,null],[17,"MAX_EXP","","Maximum possible power of 2 exponent.",null,null],[17,"MIN_10_EXP","","Minimum possible normal power of 10 exponent.",null,null],[17,"MAX_10_EXP","","Maximum possible power of 10 exponent.",null,null],[17,"NAN","","Not a Number (NaN).",null,null],[17,"INFINITY","","Infinity (∞).",null,null],[17,"NEG_INFINITY","","Negative infinity (-∞).",null,null],[0,"f64","core","This module provides constants which are specific to the implementation of the `f64` floating point data type.",null,null],[0,"consts","core::f64","Basic mathematical constants.",null,null],[17,"PI","core::f64::consts","Archimedes' constant (π)",null,null],[17,"FRAC_PI_2","","π/2",null,null],[17,"FRAC_PI_3","","π/3",null,null],[17,"FRAC_PI_4","","π/4",null,null],[17,"FRAC_PI_6","","π/6",null,null],[17,"FRAC_PI_8","","π/8",null,null],[17,"FRAC_1_PI","","1/π",null,null],[17,"FRAC_2_PI","","2/π",null,null],[17,"FRAC_2_SQRT_PI","","2/sqrt(π)",null,null],[17,"SQRT_2","","sqrt(2)",null,null],[17,"FRAC_1_SQRT_2","","1/sqrt(2)",null,null],[17,"E","","Euler's number (e)",null,null],[17,"LOG2_E","","log2(e)",null,null],[17,"LOG10_E","","log10(e)",null,null],[17,"LN_2","","ln(2)",null,null],[17,"LN_10","","ln(10)",null,null],[17,"RADIX","core::f64","The radix or base of the internal representation of `f64`.",null,null],[17,"MANTISSA_DIGITS","","Number of significant digits in base 2.",null,null],[17,"DIGITS","","Approximate number of significant digits in base 10.",null,null],[17,"EPSILON","","Difference between `1.0` and the next largest representable number.",null,null],[17,"MIN","","Smallest finite `f64` value.",null,null],[17,"MIN_POSITIVE","","Smallest positive normal `f64` value.",null,null],[17,"MAX","","Largest finite `f64` value.",null,null],[17,"MIN_EXP","","One greater than the minimum possible normal power of 2 exponent.",null,null],[17,"MAX_EXP","","Maximum possible power of 2 exponent.",null,null],[17,"MIN_10_EXP","","Minimum possible normal power of 10 exponent.",null,null],[17,"MAX_10_EXP","","Maximum possible power of 10 exponent.",null,null],[17,"NAN","","Not a Number (NaN).",null,null],[17,"INFINITY","","Infinity (∞).",null,null],[17,"NEG_INFINITY","","Negative infinity (-∞).",null,null],[0,"num","core","Numeric traits and functions for the built-in numeric types.",null,null],[3,"NonZeroU8","core::num","An integer that is known not to equal zero.",null,null],[3,"NonZeroU16","","An integer that is known not to equal zero.",null,null],[3,"NonZeroU32","","An integer that is known not to equal zero.",null,null],[3,"NonZeroU64","","An integer that is known not to equal zero.",null,null],[3,"NonZeroU128","","An integer that is known not to equal zero.",null,null],[3,"NonZeroUsize","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI8","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI16","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI32","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI64","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI128","","An integer that is known not to equal zero.",null,null],[3,"NonZeroIsize","","An integer that is known not to equal zero.",null,null],[3,"Wrapping","","Provides intentionally-wrapped arithmetic on `T`.",null,null],[12,"0","","",0,null],[3,"TryFromIntError","","The error type returned when a checked integral type conversion fails.",null,null],[3,"ParseIntError","","An error which can be returned when parsing an integer.",null,null],[3,"ParseFloatError","","An error which can be returned when parsing a float.",null,null],[4,"FpCategory","","A classification of floating point numbers.",null,null],[13,"Nan","","\"Not a Number\", often obtained by dividing by zero.",1,null],[13,"Infinite","","Positive or negative infinity.",1,null],[13,"Zero","","Positive or negative zero.",1,null],[13,"Subnormal","","De-normalized floating point representation (less precise than `Normal`).",1,null],[13,"Normal","","A regular floating point number.",1,null],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",0,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"add","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"add","","",0,null],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"add_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"sub","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"sub","","",0,null],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"sub_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"mul","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"mul","","",0,null],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"mul_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"div","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"div","","",0,null],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"div_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"rem","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"rem","","",0,null],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"rem_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"not","","",0,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"bitxor","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"bitxor","","",0,null],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"bitxor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitor","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"bitor","","",0,null],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"bitor_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"bitand","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"bitand","","",0,null],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":null}],[11,"bitand_assign","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":null}],[11,"neg","","",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",0,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",0,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"fmt","","",2,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",2,{"inputs":[{"name":"self"}],"output":{"name":"parsefloaterror"}}],[11,"eq","","",2,{"inputs":[{"name":"self"},{"name":"parsefloaterror"}],"output":{"name":"bool"}}],[11,"ne","","",2,{"inputs":[{"name":"self"},{"name":"parsefloaterror"}],"output":{"name":"bool"}}],[11,"fmt","","",2,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",3,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou8"}}],[11,"eq","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"ne","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"cmp","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"le","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"gt","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"ge","","",3,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"hash","","",3,null],[11,"new_unchecked","","Create a non-zero without checking the value.",3,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",3,{"inputs":[{"name":"u8"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",3,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",4,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou16"}}],[11,"eq","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"ne","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"cmp","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"le","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"gt","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"ge","","",4,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"hash","","",4,null],[11,"new_unchecked","","Create a non-zero without checking the value.",4,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",4,{"inputs":[{"name":"u16"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",4,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",5,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou32"}}],[11,"eq","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"ne","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"cmp","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"le","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"gt","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"ge","","",5,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"hash","","",5,null],[11,"new_unchecked","","Create a non-zero without checking the value.",5,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",5,{"inputs":[{"name":"u32"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",5,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",6,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou64"}}],[11,"eq","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"ne","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"cmp","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"le","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"gt","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"ge","","",6,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"hash","","",6,null],[11,"new_unchecked","","Create a non-zero without checking the value.",6,{"inputs":[{"name":"u64"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",6,{"inputs":[{"name":"u64"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",6,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",7,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou128"}}],[11,"eq","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"ne","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"cmp","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"le","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"gt","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"ge","","",7,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"hash","","",7,null],[11,"new_unchecked","","Create a non-zero without checking the value.",7,{"inputs":[{"name":"u128"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",7,{"inputs":[{"name":"u128"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",7,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",8,{"inputs":[{"name":"self"}],"output":{"name":"nonzerousize"}}],[11,"eq","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"ne","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"cmp","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"le","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"gt","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"ge","","",8,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"hash","","",8,null],[11,"new_unchecked","","Create a non-zero without checking the value.",8,{"inputs":[{"name":"usize"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",8,{"inputs":[{"name":"usize"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",8,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",9,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi8"}}],[11,"eq","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"ne","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"cmp","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"le","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"gt","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"ge","","",9,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"hash","","",9,null],[11,"new_unchecked","","Create a non-zero without checking the value.",9,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",9,{"inputs":[{"name":"i8"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",9,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",10,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi16"}}],[11,"eq","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"ne","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"cmp","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"le","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"gt","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"ge","","",10,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"hash","","",10,null],[11,"new_unchecked","","Create a non-zero without checking the value.",10,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",10,{"inputs":[{"name":"i16"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",10,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",11,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi32"}}],[11,"eq","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"ne","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"cmp","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"le","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"gt","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"ge","","",11,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"hash","","",11,null],[11,"new_unchecked","","Create a non-zero without checking the value.",11,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",11,{"inputs":[{"name":"i32"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",11,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",12,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi64"}}],[11,"eq","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"ne","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"cmp","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"le","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"gt","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"ge","","",12,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"hash","","",12,null],[11,"new_unchecked","","Create a non-zero without checking the value.",12,{"inputs":[{"name":"i64"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",12,{"inputs":[{"name":"i64"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",12,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",13,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi128"}}],[11,"eq","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"ne","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"cmp","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"le","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"gt","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"ge","","",13,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"hash","","",13,null],[11,"new_unchecked","","Create a non-zero without checking the value.",13,{"inputs":[{"name":"i128"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",13,{"inputs":[{"name":"i128"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",13,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",14,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroisize"}}],[11,"eq","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"ne","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"cmp","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"le","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"gt","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"ge","","",14,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"hash","","",14,null],[11,"new_unchecked","","Create a non-zero without checking the value.",14,{"inputs":[{"name":"isize"}],"output":{"name":"self"}}],[11,"new","","Create a non-zero if the given value is not zero.",14,{"inputs":[{"name":"isize"}],"output":{"name":"option"}}],[11,"get","","Returns the value as a primitive type.",14,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"ne","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"le","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"gt","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"ge","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"cmp","","",0,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"ordering"}}],[11,"clone","","",0,{"inputs":[{"name":"self"}],"output":{"name":"wrapping"}}],[11,"default","","",0,{"inputs":[],"output":{"name":"wrapping"}}],[11,"hash","","",0,null],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",1,{"inputs":[{"name":"self"}],"output":{"name":"fpcategory"}}],[11,"eq","","",1,{"inputs":[{"name":"self"},{"name":"fpcategory"}],"output":{"name":"bool"}}],[11,"fmt","","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",15,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",15,{"inputs":[{"name":"self"}],"output":{"name":"tryfrominterror"}}],[11,"fmt","","",15,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",15,null],[11,"fmt","","",16,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",16,{"inputs":[{"name":"self"}],"output":{"name":"parseinterror"}}],[11,"eq","","",16,{"inputs":[{"name":"self"},{"name":"parseinterror"}],"output":{"name":"bool"}}],[11,"ne","","",16,{"inputs":[{"name":"self"},{"name":"parseinterror"}],"output":{"name":"bool"}}],[11,"fmt","","",16,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"prelude","core","The libcore prelude",null,null],[0,"v1","core::prelude","The core prelude",null,null],[0,"intrinsics","core","rustc compiler intrinsics.",null,null],[5,"atomic_cxchg","core::intrinsics","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::SeqCst` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Acquire` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_rel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Release` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acqrel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_relaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Relaxed` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_failacq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acq_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Acquire` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acqrel_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchgweak","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::SeqCst` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Acquire` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_rel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Release` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acqrel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_relaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Relaxed` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_failacq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acq_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Acquire` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acqrel_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_load","","Loads the current value of the pointer. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `load` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::load`.",null,null],[5,"atomic_load_acq","","Loads the current value of the pointer. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `load` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::load`.",null,null],[5,"atomic_load_relaxed","","Loads the current value of the pointer. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `load` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::load`.",null,null],[5,"atomic_load_unordered","","",null,null],[5,"atomic_store","","Stores the value at the specified memory location. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `store` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::store`.",null,null],[5,"atomic_store_rel","","Stores the value at the specified memory location. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `store` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::store`.",null,null],[5,"atomic_store_relaxed","","Stores the value at the specified memory location. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `store` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::store`.",null,null],[5,"atomic_store_unordered","","",null,null],[5,"atomic_xchg","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_acq","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_rel","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_acqrel","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_relaxed","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xadd","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_acq","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_rel","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::Release` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_acqrel","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_relaxed","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xsub","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_acq","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_rel","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::Release` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_acqrel","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_relaxed","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_and","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_acq","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_rel","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_acqrel","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_relaxed","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_nand","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_acq","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_rel","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_acqrel","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_relaxed","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_or","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_acq","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_rel","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_acqrel","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_relaxed","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_xor","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_acq","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_rel","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_acqrel","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_relaxed","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_max","","",null,null],[5,"atomic_max_acq","","",null,null],[5,"atomic_max_rel","","",null,null],[5,"atomic_max_acqrel","","",null,null],[5,"atomic_max_relaxed","","",null,null],[5,"atomic_min","","",null,null],[5,"atomic_min_acq","","",null,null],[5,"atomic_min_rel","","",null,null],[5,"atomic_min_acqrel","","",null,null],[5,"atomic_min_relaxed","","",null,null],[5,"atomic_umin","","",null,null],[5,"atomic_umin_acq","","",null,null],[5,"atomic_umin_rel","","",null,null],[5,"atomic_umin_acqrel","","",null,null],[5,"atomic_umin_relaxed","","",null,null],[5,"atomic_umax","","",null,null],[5,"atomic_umax_acq","","",null,null],[5,"atomic_umax_rel","","",null,null],[5,"atomic_umax_acqrel","","",null,null],[5,"atomic_umax_relaxed","","",null,null],[5,"prefetch_read_data","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"prefetch_write_data","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"prefetch_read_instruction","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"prefetch_write_instruction","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"atomic_fence","","",null,null],[5,"atomic_fence_acq","","",null,null],[5,"atomic_fence_rel","","",null,null],[5,"atomic_fence_acqrel","","",null,null],[5,"atomic_singlethreadfence","","A compiler-only memory barrier.",null,null],[5,"atomic_singlethreadfence_acq","","",null,null],[5,"atomic_singlethreadfence_rel","","",null,null],[5,"atomic_singlethreadfence_acqrel","","",null,null],[5,"rustc_peek","","Magic intrinsic that derives its meaning from attributes attached to the function.",null,null],[5,"abort","","Aborts the execution of the process.",null,null],[5,"unreachable","","Tells LLVM that this point in the code is not reachable, enabling further optimizations.",null,null],[5,"assume","","Informs the optimizer that a condition is always true. If the condition is false, the behavior is undefined.",null,null],[5,"likely","","Hints to the compiler that branch condition is likely to be true. Returns the value passed to it.",null,null],[5,"unlikely","","Hints to the compiler that branch condition is likely to be false. Returns the value passed to it.",null,null],[5,"breakpoint","","Executes a breakpoint trap, for inspection by a debugger.",null,null],[5,"size_of","","The size of a type in bytes.",null,null],[5,"move_val_init","","Moves a value to an uninitialized memory location.",null,null],[5,"min_align_of","","",null,null],[5,"pref_align_of","","",null,null],[5,"size_of_val","","The size of the referenced value in bytes.",null,null],[5,"min_align_of_val","","",null,null],[5,"type_name","","Gets a static string slice containing the name of a type.",null,null],[5,"type_id","","Gets an identifier which is globally unique to the specified type. This function will return the same value for a type regardless of whichever crate it is invoked in.",null,null],[5,"init","","Creates a value initialized to zero.",null,null],[5,"uninit","","Creates an uninitialized value.",null,null],[5,"transmute","","Reinterprets the bits of a value of one type as another type.",null,null],[5,"needs_drop","","Returns `true` if the actual type given as `T` requires drop glue; returns `false` if the actual type provided for `T` implements `Copy`.",null,null],[5,"offset","","Calculates the offset from a pointer.",null,null],[5,"arith_offset","","Calculates the offset from a pointer, potentially wrapping.",null,null],[5,"copy_nonoverlapping","","Copies `count * size_of<T>` bytes from `src` to `dst`. The source and destination may not overlap.",null,null],[5,"copy","","Copies `count * size_of<T>` bytes from `src` to `dst`. The source and destination may overlap.",null,null],[5,"write_bytes","","Invokes memset on the specified pointer, setting `count * size_of::<T>()` bytes of memory starting at `dst` to `val`.",null,null],[5,"volatile_copy_nonoverlapping_memory","","Equivalent to the appropriate `llvm.memcpy.p0i8.0i8.*` intrinsic, with a size of `count` * `size_of::<T>()` and an alignment of `min_align_of::<T>()`",null,null],[5,"volatile_copy_memory","","Equivalent to the appropriate `llvm.memmove.p0i8.0i8.*` intrinsic, with a size of `count` * `size_of::<T>()` and an alignment of `min_align_of::<T>()`",null,null],[5,"volatile_set_memory","","Equivalent to the appropriate `llvm.memset.p0i8.*` intrinsic, with a size of `count` * `size_of::<T>()` and an alignment of `min_align_of::<T>()`.",null,null],[5,"volatile_load","","Perform a volatile load from the `src` pointer. The stabilized version of this intrinsic is `std::ptr::read_volatile`.",null,null],[5,"volatile_store","","Perform a volatile store to the `dst` pointer. The stabilized version of this intrinsic is `std::ptr::write_volatile`.",null,null],[5,"sqrtf32","","Returns the square root of an `f32`",null,null],[5,"sqrtf64","","Returns the square root of an `f64`",null,null],[5,"powif32","","Raises an `f32` to an integer power.",null,null],[5,"powif64","","Raises an `f64` to an integer power.",null,null],[5,"sinf32","","Returns the sine of an `f32`.",null,null],[5,"sinf64","","Returns the sine of an `f64`.",null,null],[5,"cosf32","","Returns the cosine of an `f32`.",null,null],[5,"cosf64","","Returns the cosine of an `f64`.",null,null],[5,"powf32","","Raises an `f32` to an `f32` power.",null,null],[5,"powf64","","Raises an `f64` to an `f64` power.",null,null],[5,"expf32","","Returns the exponential of an `f32`.",null,null],[5,"expf64","","Returns the exponential of an `f64`.",null,null],[5,"exp2f32","","Returns 2 raised to the power of an `f32`.",null,null],[5,"exp2f64","","Returns 2 raised to the power of an `f64`.",null,null],[5,"logf32","","Returns the natural logarithm of an `f32`.",null,null],[5,"logf64","","Returns the natural logarithm of an `f64`.",null,null],[5,"log10f32","","Returns the base 10 logarithm of an `f32`.",null,null],[5,"log10f64","","Returns the base 10 logarithm of an `f64`.",null,null],[5,"log2f32","","Returns the base 2 logarithm of an `f32`.",null,null],[5,"log2f64","","Returns the base 2 logarithm of an `f64`.",null,null],[5,"fmaf32","","Returns `a * b + c` for `f32` values.",null,null],[5,"fmaf64","","Returns `a * b + c` for `f64` values.",null,null],[5,"fabsf32","","Returns the absolute value of an `f32`.",null,null],[5,"fabsf64","","Returns the absolute value of an `f64`.",null,null],[5,"copysignf32","","Copies the sign from `y` to `x` for `f32` values.",null,null],[5,"copysignf64","","Copies the sign from `y` to `x` for `f64` values.",null,null],[5,"floorf32","","Returns the largest integer less than or equal to an `f32`.",null,null],[5,"floorf64","","Returns the largest integer less than or equal to an `f64`.",null,null],[5,"ceilf32","","Returns the smallest integer greater than or equal to an `f32`.",null,null],[5,"ceilf64","","Returns the smallest integer greater than or equal to an `f64`.",null,null],[5,"truncf32","","Returns the integer part of an `f32`.",null,null],[5,"truncf64","","Returns the integer part of an `f64`.",null,null],[5,"rintf32","","Returns the nearest integer to an `f32`. May raise an inexact floating-point exception if the argument is not an integer.",null,null],[5,"rintf64","","Returns the nearest integer to an `f64`. May raise an inexact floating-point exception if the argument is not an integer.",null,null],[5,"nearbyintf32","","Returns the nearest integer to an `f32`.",null,null],[5,"nearbyintf64","","Returns the nearest integer to an `f64`.",null,null],[5,"roundf32","","Returns the nearest integer to an `f32`. Rounds half-way cases away from zero.",null,null],[5,"roundf64","","Returns the nearest integer to an `f64`. Rounds half-way cases away from zero.",null,null],[5,"fadd_fast","","Float addition that allows optimizations based on algebraic rules. May assume inputs are finite.",null,null],[5,"fsub_fast","","Float subtraction that allows optimizations based on algebraic rules. May assume inputs are finite.",null,null],[5,"fmul_fast","","Float multiplication that allows optimizations based on algebraic rules. May assume inputs are finite.",null,null],[5,"fdiv_fast","","Float division that allows optimizations based on algebraic rules. May assume inputs are finite.",null,null],[5,"frem_fast","","Float remainder that allows optimizations based on algebraic rules. May assume inputs are finite.",null,null],[5,"ctpop","","Returns the number of bits set in an integer type `T`",null,null],[5,"ctlz","","Returns the number of leading unset bits (zeroes) in an integer type `T`.",null,null],[5,"ctlz_nonzero","","Like `ctlz`, but extra-unsafe as it returns `undef` when given an `x` with value `0`.",null,null],[5,"cttz","","Returns the number of trailing unset bits (zeroes) in an integer type `T`.",null,null],[5,"cttz_nonzero","","Like `cttz`, but extra-unsafe as it returns `undef` when given an `x` with value `0`.",null,null],[5,"bswap","","Reverses the bytes in an integer type `T`.",null,null],[5,"bitreverse","","Reverses the bits in an integer type `T`.",null,null],[5,"add_with_overflow","","Performs checked integer addition. The stabilized versions of this intrinsic are available on the integer primitives via the `overflowing_add` method. For example, `std::u32::overflowing_add`",null,null],[5,"sub_with_overflow","","Performs checked integer subtraction The stabilized versions of this intrinsic are available on the integer primitives via the `overflowing_sub` method. For example, `std::u32::overflowing_sub`",null,null],[5,"mul_with_overflow","","Performs checked integer multiplication The stabilized versions of this intrinsic are available on the integer primitives via the `overflowing_mul` method. For example, `std::u32::overflowing_mul`",null,null],[5,"exact_div","","Performs an exact division, resulting in undefined behavior where `x % y != 0` or `y == 0` or `x == T::min_value() && y == -1`",null,null],[5,"unchecked_div","","Performs an unchecked division, resulting in undefined behavior where y = 0 or x = `T::min_value()` and y = -1",null,null],[5,"unchecked_rem","","Returns the remainder of an unchecked division, resulting in undefined behavior where y = 0 or x = `T::min_value()` and y = -1",null,null],[5,"unchecked_shl","","Performs an unchecked left shift, resulting in undefined behavior when y < 0 or y >= N, where N is the width of T in bits.",null,null],[5,"unchecked_shr","","Performs an unchecked right shift, resulting in undefined behavior when y < 0 or y >= N, where N is the width of T in bits.",null,null],[5,"overflowing_add","","Returns (a + b) mod 2N, where N is the width of T in bits. The stabilized versions of this intrinsic are available on the integer primitives via the `wrapping_add` method. For example, `std::u32::wrapping_add`",null,null],[5,"overflowing_sub","","Returns (a - b) mod 2N, where N is the width of T in bits. The stabilized versions of this intrinsic are available on the integer primitives via the `wrapping_sub` method. For example, `std::u32::wrapping_sub`",null,null],[5,"overflowing_mul","","Returns (a * b) mod 2N, where N is the width of T in bits. The stabilized versions of this intrinsic are available on the integer primitives via the `wrapping_mul` method. For example, `std::u32::wrapping_mul`",null,null],[5,"discriminant_value","","Returns the value of the discriminant for the variant in 'v', cast to a `u64`; if `T` has no discriminant, returns 0.",null,null],[5,"try","","Rust's \"try catch\" construct which invokes the function pointer `f` with the data pointer `data`.",null,null],[5,"align_offset","","Computes the byte offset that needs to be applied to `ptr` in order to make it aligned to `align`. If it is not possible to align `ptr`, the implementation returns `usize::max_value()`.",null,null],[5,"nontemporal_store","","Emits a `!nontemporal` store according to LLVM (see their docs). Probably will never become stable.",null,null],[0,"mem","core","Basic functions for dealing with memory.",null,null],[3,"Discriminant","core::mem","Opaque type representing the discriminant of an enum.",null,null],[3,"Pin","","A pinned reference.",null,null],[19,"ManuallyDrop","","A wrapper to inhibit compiler from automatically calling `T`’s destructor.",null,null],[5,"forget","","Leaks a value: takes ownership and \"forgets\" about the value without running its destructor.",null,{"inputs":[{"name":"t"}],"output":null}],[5,"size_of","","Returns the size of a type in bytes.",null,{"inputs":[],"output":{"name":"usize"}}],[5,"size_of_val","","Returns the size of the pointed-to value in bytes.",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"min_align_of","","Returns the [ABI]-required minimum alignment of a type.",null,{"inputs":[],"output":{"name":"usize"}}],[5,"min_align_of_val","","Returns the [ABI]-required minimum alignment of the type of the value that `val` points to.",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"align_of","","Returns the [ABI]-required minimum alignment of a type.",null,{"inputs":[],"output":{"name":"usize"}}],[5,"align_of_val","","Returns the [ABI]-required minimum alignment of the type of the value that `val` points to.",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"needs_drop","","Returns whether dropping values of type `T` matters.",null,{"inputs":[],"output":{"name":"bool"}}],[5,"zeroed","","Creates a value whose bytes are all zero.",null,{"inputs":[],"output":{"name":"t"}}],[5,"uninitialized","","Bypasses Rust's normal memory-initialization checks by pretending to produce a value of type `T`, while doing nothing at all.",null,{"inputs":[],"output":{"name":"t"}}],[5,"swap","","Swaps the values at two mutable locations, without deinitializing either one.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":null}],[5,"replace","","Replaces the value at a mutable location with a new one, returning the old value, without deinitializing either one.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"drop","","Disposes of a value.",null,{"inputs":[{"name":"t"}],"output":null}],[5,"transmute_copy","","Interprets `src` as having type `&U`, and then reads `src` without moving the contained value.",null,{"inputs":[{"name":"t"}],"output":{"name":"u"}}],[5,"discriminant","","Returns a value uniquely identifying the enum variant in `v`.",null,{"inputs":[{"name":"t"}],"output":{"name":"discriminant"}}],[5,"unreachable","","Tells LLVM that this point in the code is not reachable, enabling further optimizations.",null,null],[11,"clone","","",17,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",17,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"hash","","",17,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"fmt","","",17,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Wrap a value to be manually dropped.",18,{"inputs":[{"name":"t"}],"output":{"name":"manuallydrop"}}],[11,"into_inner","","Extract the value from the ManuallyDrop container.",18,{"inputs":[{"name":"manuallydrop"}],"output":{"name":"t"}}],[11,"drop","","Manually drops the contained value.",18,{"inputs":[{"name":"manuallydrop"}],"output":null}],[11,"deref","","",18,null],[11,"deref_mut","","",18,null],[11,"fmt","","",18,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",18,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"clone_from","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"default","","",18,{"inputs":[],"output":{"name":"self"}}],[11,"eq","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"le","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"gt","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ge","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"cmp","","",18,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"ordering"}}],[11,"hash","","",18,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"new","","Construct a new `Pin` around a reference to some data of a type that implements `Unpin`.",19,{"inputs":[{"name":"t"}],"output":{"name":"pin"}}],[11,"new_unchecked","","Construct a new `Pin` around a reference to some data of a type that may or may not implement `Unpin`.",19,{"inputs":[{"name":"t"}],"output":{"name":"pin"}}],[11,"borrow","","Borrow a Pin for a shorter lifetime than it already has.",19,{"inputs":[{"name":"pin"}],"output":{"name":"pin"}}],[11,"get_mut","","Get a mutable reference to the data inside of this `Pin`.",19,{"inputs":[{"name":"pin"}],"output":{"name":"t"}}],[11,"map","","Construct a new pin by mapping the interior value.",19,{"inputs":[{"name":"pin"},{"name":"f"}],"output":{"name":"pin"}}],[11,"deref","","",19,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",19,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"fmt","","",19,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",19,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",19,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"nonzero","core","Exposes the NonZero lang item which provides optimization hints.",null,null],[3,"NonZero","core::nonzero","A wrapper type for raw pointers and integers that will never be NULL or 0 that might allow certain optimizations.",null,null],[8,"Zeroable","","Unsafe trait to indicate what types are usable with the NonZero struct",null,null],[10,"is_zero","","Whether this value is zero",20,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",21,{"inputs":[{"name":"self"}],"output":{"name":"nonzero"}}],[11,"eq","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"name":"bool"}}],[11,"ne","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"name":"bool"}}],[11,"cmp","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"name":"bool"}}],[11,"le","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"name":"bool"}}],[11,"gt","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"name":"bool"}}],[11,"ge","","",21,{"inputs":[{"name":"self"},{"name":"nonzero"}],"output":{"name":"bool"}}],[11,"fmt","","",21,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",21,null],[11,"new_unchecked","","Creates an instance of NonZero with the provided value. You must indeed ensure that the value is actually \"non-zero\".",21,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"new","","Creates an instance of NonZero with the provided value.",21,{"inputs":[{"name":"t"}],"output":{"name":"option"}}],[11,"get","","Gets the inner value.",21,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"from","","",21,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",21,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",21,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[0,"ptr","core","Raw, unsafe pointers, `*const T`, and `*mut T`.",null,null],[3,"Unique","core::ptr","A wrapper around a raw non-null `*mut T` that indicates that the possessor of this wrapper owns the referent. Useful for building abstractions like `Box<T>`, `Vec<T>`, `String`, and `HashMap<K, V>`.",null,null],[3,"NonNull","","`*mut T` but non-zero and covariant.",null,null],[5,"drop_in_place","","Executes the destructor (if any) of the pointed-to value.",null,null],[5,"null","","Creates a null raw pointer.",null,null],[5,"null_mut","","Creates a null mutable raw pointer.",null,null],[5,"swap","","Swaps the values at two mutable locations of the same type, without deinitializing either.",null,null],[5,"swap_nonoverlapping","","Swaps a sequence of values at two mutable locations of the same type.",null,null],[5,"replace","","Replaces the value at `dest` with `src`, returning the old value, without dropping either.",null,null],[5,"read","","Reads the value from `src` without moving it. This leaves the memory in `src` unchanged.",null,null],[5,"read_unaligned","","Reads the value from `src` without moving it. This leaves the memory in `src` unchanged.",null,null],[5,"write","","Overwrites a memory location with the given value without reading or dropping the old value.",null,null],[5,"write_unaligned","","Overwrites a memory location with the given value without reading or dropping the old value.",null,null],[5,"read_volatile","","Performs a volatile read of the value from `src` without moving it. This leaves the memory in `src` unchanged.",null,null],[5,"write_volatile","","Performs a volatile write of a memory location with the given value without reading or dropping the old value.",null,null],[5,"eq","","Compare raw pointers for equality.",null,null],[11,"fmt","","",22,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"empty","","Creates a new `Unique` that is dangling, but well-aligned.",22,{"inputs":[],"output":{"name":"self"}}],[11,"new_unchecked","","Creates a new `Unique`.",22,null],[11,"new","","Creates a new `Unique` if `ptr` is non-null.",22,null],[11,"as_ptr","","Acquires the underlying `*mut` pointer.",22,null],[11,"as_ref","","Dereferences the content.",22,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_mut","","Mutably dereferences the content.",22,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"clone","","",22,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",22,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",22,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",22,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",22,{"inputs":[{"name":"nonnull"}],"output":{"name":"self"}}],[11,"dangling","","Creates a new `NonNull` that is dangling, but well-aligned.",23,{"inputs":[],"output":{"name":"self"}}],[11,"new_unchecked","","Creates a new `NonNull`.",23,null],[11,"new","","Creates a new `NonNull` if `ptr` is non-null.",23,null],[11,"as_ptr","","Acquires the underlying `*mut` pointer.",23,null],[11,"as_ref","","Dereferences the content.",23,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_mut","","Mutably dereferences the content.",23,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"cast","","Cast to a pointer of another type",23,{"inputs":[{"name":"self"}],"output":{"name":"nonnull"}}],[11,"clone","","",23,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",23,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",23,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",23,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"cmp","","",23,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",23,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"hash","","",23,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"from","","",23,{"inputs":[{"name":"unique"}],"output":{"name":"self"}}],[11,"from","","",23,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from","","",23,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[0,"marker","core","Primitive traits and types representing basic properties of types.",null,null],[3,"PhantomData","core::marker","Zero-sized type used to mark things that \"act like\" they own a `T`.",null,null],[8,"Send","","Types that can be transferred across thread boundaries.",null,null],[8,"Sized","","Types with a constant size known at compile time.",null,null],[8,"Unsize","","Types that can be \"unsized\" to a dynamically-sized type.",null,null],[8,"Copy","","Types whose values can be duplicated simply by copying bits.",null,null],[8,"Sync","","Types for which it is safe to share references between threads.",null,null],[8,"Unpin","","Types which can be moved out of a `Pin`.",null,null],[11,"hash","","",24,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"eq","","",24,{"inputs":[{"name":"self"},{"name":"phantomdata"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",24,{"inputs":[{"name":"self"},{"name":"phantomdata"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",24,{"inputs":[{"name":"self"},{"name":"phantomdata"}],"output":{"name":"ordering"}}],[11,"clone","","",24,{"inputs":[{"name":"self"}],"output":{"name":"phantomdata"}}],[11,"default","","",24,{"inputs":[],"output":{"name":"phantomdata"}}],[0,"ops","core","Overloadable operators.",null,null],[3,"Range","core::ops","A (half-open) range bounded inclusively below and exclusively above (`start..end`).",null,null],[12,"start","","The lower bound of the range (inclusive).",25,null],[12,"end","","The upper bound of the range (exclusive).",25,null],[3,"RangeFrom","","A range only bounded inclusively below (`start..`).",null,null],[12,"start","","The lower bound of the range (inclusive).",26,null],[3,"RangeFull","","An unbounded range (`..`).",null,null],[3,"RangeTo","","A range only bounded exclusively above (`..end`).",null,null],[12,"end","","The upper bound of the range (exclusive).",27,null],[3,"RangeInclusive","","An range bounded inclusively below and above (`start..=end`).",null,null],[12,"start","","The lower bound of the range (inclusive).",28,null],[12,"end","","The upper bound of the range (inclusive).",28,null],[3,"RangeToInclusive","","A range only bounded inclusively above (`..=end`).",null,null],[12,"end","","The upper bound of the range (inclusive)",29,null],[4,"Bound","","An endpoint of a range of keys.",null,null],[13,"Included","","An inclusive bound.",30,null],[13,"Excluded","","An exclusive bound.",30,null],[13,"Unbounded","","An infinite endpoint. Indicates that there is no bound in this direction.",30,null],[4,"GeneratorState","","The result of a generator resumption.",null,null],[13,"Yielded","","The generator suspended with a value.",31,null],[13,"Complete","","The generator completed with a return value.",31,null],[11,"clone","","",31,{"inputs":[{"name":"self"}],"output":{"name":"generatorstate"}}],[11,"eq","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"ne","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"le","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"gt","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"ge","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"cmp","","",31,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"ordering"}}],[11,"fmt","","",31,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",31,null],[11,"clone","","",32,{"inputs":[{"name":"self"}],"output":{"name":"rangefull"}}],[11,"eq","","",32,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"bool"}}],[11,"hash","","",32,null],[11,"fmt","","",32,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",25,{"inputs":[{"name":"self"}],"output":{"name":"range"}}],[11,"eq","","",25,{"inputs":[{"name":"self"},{"name":"range"}],"output":{"name":"bool"}}],[11,"ne","","",25,{"inputs":[{"name":"self"},{"name":"range"}],"output":{"name":"bool"}}],[11,"hash","","",25,null],[11,"fmt","","",25,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",25,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"is_empty","","Returns `true` if the range contains no items.",25,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",26,{"inputs":[{"name":"self"}],"output":{"name":"rangefrom"}}],[11,"eq","","",26,{"inputs":[{"name":"self"},{"name":"rangefrom"}],"output":{"name":"bool"}}],[11,"ne","","",26,{"inputs":[{"name":"self"},{"name":"rangefrom"}],"output":{"name":"bool"}}],[11,"hash","","",26,null],[11,"fmt","","",26,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",26,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"clone","","",27,{"inputs":[{"name":"self"}],"output":{"name":"rangeto"}}],[11,"eq","","",27,{"inputs":[{"name":"self"},{"name":"rangeto"}],"output":{"name":"bool"}}],[11,"ne","","",27,{"inputs":[{"name":"self"},{"name":"rangeto"}],"output":{"name":"bool"}}],[11,"hash","","",27,null],[11,"fmt","","",27,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",27,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"clone","","",28,{"inputs":[{"name":"self"}],"output":{"name":"rangeinclusive"}}],[11,"eq","","",28,{"inputs":[{"name":"self"},{"name":"rangeinclusive"}],"output":{"name":"bool"}}],[11,"ne","","",28,{"inputs":[{"name":"self"},{"name":"rangeinclusive"}],"output":{"name":"bool"}}],[11,"hash","","",28,null],[11,"fmt","","",28,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",28,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"is_empty","","Returns `true` if the range contains no items.",28,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",29,{"inputs":[{"name":"self"}],"output":{"name":"rangetoinclusive"}}],[11,"eq","","",29,{"inputs":[{"name":"self"},{"name":"rangetoinclusive"}],"output":{"name":"bool"}}],[11,"ne","","",29,{"inputs":[{"name":"self"},{"name":"rangetoinclusive"}],"output":{"name":"bool"}}],[11,"hash","","",29,null],[11,"fmt","","",29,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",29,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"clone","","",30,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"fmt","","",30,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",30,null],[11,"eq","","",30,{"inputs":[{"name":"self"},{"name":"bound"}],"output":{"name":"bool"}}],[11,"ne","","",30,{"inputs":[{"name":"self"},{"name":"bound"}],"output":{"name":"bool"}}],[11,"start","","",32,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",32,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",26,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",26,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",27,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",27,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",25,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",25,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",28,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",28,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",29,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",29,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",26,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",26,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",27,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",27,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",25,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",25,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",28,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",28,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",29,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",29,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[8,"Add","","The addition operator `+`.",null,null],[16,"Output","","The resulting type after applying the `+` operator.",33,null],[10,"add","","Performs the `+` operation.",33,null],[8,"Sub","","The subtraction operator `-`.",null,null],[16,"Output","","The resulting type after applying the `-` operator.",34,null],[10,"sub","","Performs the `-` operation.",34,null],[8,"Mul","","The multiplication operator `*`.",null,null],[16,"Output","","The resulting type after applying the `*` operator.",35,null],[10,"mul","","Performs the `*` operation.",35,null],[8,"Div","","The division operator `/`.",null,null],[16,"Output","","The resulting type after applying the `/` operator.",36,null],[10,"div","","Performs the `/` operation.",36,null],[8,"Rem","","The remainder operator `%`.",null,null],[16,"Output","","The resulting type after applying the `%` operator.",37,null],[10,"rem","","Performs the `%` operation.",37,null],[8,"Neg","","The unary negation operator `-`.",null,null],[16,"Output","","The resulting type after applying the `-` operator.",38,null],[10,"neg","","Performs the unary `-` operation.",38,null],[8,"AddAssign","","The addition assignment operator `+=`.",null,null],[10,"add_assign","","Performs the `+=` operation.",39,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"SubAssign","","The subtraction assignment operator `-=`.",null,null],[10,"sub_assign","","Performs the `-=` operation.",40,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"MulAssign","","The multiplication assignment operator `*=`.",null,null],[10,"mul_assign","","Performs the `*=` operation.",41,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"DivAssign","","The division assignment operator `/=`.",null,null],[10,"div_assign","","Performs the `/=` operation.",42,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"RemAssign","","The remainder assignment operator `%=`.",null,null],[10,"rem_assign","","Performs the `%=` operation.",43,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"Not","","The unary logical negation operator `!`.",null,null],[16,"Output","","The resulting type after applying the `!` operator.",44,null],[10,"not","","Performs the unary `!` operation.",44,null],[8,"BitAnd","","The bitwise AND operator `&`.",null,null],[16,"Output","","The resulting type after applying the `&` operator.",45,null],[10,"bitand","","Performs the `&` operation.",45,null],[8,"BitOr","","The bitwise OR operator `|`.",null,null],[16,"Output","","The resulting type after applying the `|` operator.",46,null],[10,"bitor","","Performs the `|` operation.",46,null],[8,"BitXor","","The bitwise XOR operator `^`.",null,null],[16,"Output","","The resulting type after applying the `^` operator.",47,null],[10,"bitxor","","Performs the `^` operation.",47,null],[8,"Shl","","The left shift operator `<<`.",null,null],[16,"Output","","The resulting type after applying the `<<` operator.",48,null],[10,"shl","","Performs the `<<` operation.",48,null],[8,"Shr","","The right shift operator `>>`.",null,null],[16,"Output","","The resulting type after applying the `>>` operator.",49,null],[10,"shr","","Performs the `>>` operation.",49,null],[8,"BitAndAssign","","The bitwise AND assignment operator `&=`.",null,null],[10,"bitand_assign","","Performs the `&=` operation.",50,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"BitOrAssign","","The bitwise OR assignment operator `|=`.",null,null],[10,"bitor_assign","","Performs the `|=` operation.",51,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"BitXorAssign","","The bitwise XOR assignment operator `^=`.",null,null],[10,"bitxor_assign","","Performs the `^=` operation.",52,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"ShlAssign","","The left shift assignment operator `<<=`.",null,null],[10,"shl_assign","","Performs the `<<=` operation.",53,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"ShrAssign","","The right shift assignment operator `>>=`.",null,null],[10,"shr_assign","","Performs the `>>=` operation.",54,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":null}],[8,"Deref","","Used for immutable dereferencing operations, like `*v`.",null,null],[16,"Target","","The resulting type after dereferencing.",55,null],[10,"deref","","Dereferences the value.",55,null],[8,"DerefMut","","Used for mutable dereferencing operations, like in `*v = 1;`.",null,null],[10,"deref_mut","","Mutably dereferences the value.",56,null],[8,"Drop","","Used to run some code when a value goes out of scope. This is sometimes called a 'destructor'.",null,null],[10,"drop","","Executes the destructor for this type.",57,{"inputs":[{"name":"self"}],"output":null}],[8,"Fn","","The version of the call operator that takes an immutable receiver.",null,null],[10,"call","","Performs the call operation.",58,null],[8,"FnMut","","The version of the call operator that takes a mutable receiver.",null,null],[10,"call_mut","","Performs the call operation.",59,null],[8,"FnOnce","","The version of the call operator that takes a by-value receiver.",null,null],[16,"Output","","The returned type after the call operator is used.",60,null],[10,"call_once","","Performs the call operation.",60,null],[8,"Index","","Used for indexing operations (`container[index]`) in immutable contexts.",null,null],[16,"Output","","The returned type after indexing.",61,null],[10,"index","","Performs the indexing (`container[index]`) operation.",61,null],[8,"IndexMut","","Used for indexing operations (`container[index]`) in mutable contexts.",null,null],[10,"index_mut","","Performs the mutable indexing (`container[index]`) operation.",62,null],[8,"RangeBounds","","`RangeBounds` is implemented by Rust's built-in range types, produced by range syntax like `..`, `a..`, `..b` or `c..d`.",null,null],[10,"start","","Start index bound.",63,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[10,"end","","End index bound.",63,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[8,"Try","","A trait for customizing the behavior of the `?` operator.",null,null],[16,"Ok","","The type of this value when viewed as successful.",64,null],[16,"Error","","The type of this value when viewed as failed.",64,null],[10,"into_result","","Applies the \"?\" operator. A return of `Ok(t)` means that the execution should continue normally, and the result of `?` is the value `t`. A return of `Err(e)` means that execution should branch to the innermost enclosing `catch`, or return from the function.",64,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[10,"from_error","","Wrap an error value to construct the composite result. For example, `Result::Err(x)` and `Result::from_error(x)` are equivalent.",64,null],[10,"from_ok","","Wrap an OK value to construct the composite result. For example, `Result::Ok(x)` and `Result::from_ok(x)` are equivalent.",64,null],[8,"Generator","","The trait implemented by builtin generator types.",null,null],[16,"Yield","","The type of value this generator yields.",65,null],[16,"Return","","The type of value this generator returns.",65,null],[10,"resume","","Resumes the execution of this generator.",65,{"inputs":[{"name":"self"}],"output":{"name":"generatorstate"}}],[8,"Place","","Both `PLACE <- EXPR` and `box EXPR` desugar into expressions that allocate an intermediate \"place\" that holds uninitialized state.  The desugaring evaluates EXPR, and writes the result at the address returned by the `pointer` method of this trait.",null,null],[10,"pointer","","Returns the address where the input value will be written. Note that the data at this address is generally uninitialized, and thus one should use `ptr::write` for initializing it.",66,null],[8,"Placer","","Interface to implementations of  `PLACE <- EXPR`.",null,null],[16,"Place","","`Place` is the intermediate agent guarding the uninitialized state for `Data`.",67,null],[10,"make_place","","Creates a fresh place from `self`.",67,null],[8,"InPlace","","Specialization of `Place` trait supporting `PLACE <- EXPR`.",null,null],[16,"Owner","","`Owner` is the type of the end value of `PLACE <- EXPR`",68,null],[10,"finalize","","Converts self into the final value, shifting deallocation/cleanup responsibilities (if any remain), over to the returned instance of `Owner` and forgetting self.",68,null],[8,"Boxed","","Core trait for the `box EXPR` form.",null,null],[16,"Data","","The kind of data that is stored in this kind of box.",69,null],[16,"Place","","The place that will negotiate the storage of the data.",69,null],[10,"finalize","","Converts filled place into final owning value, shifting deallocation/cleanup responsibilities (if any remain), over to returned instance of `Self` and forgetting `filled`.",69,null],[8,"BoxPlace","","Specialization of `Place` trait supporting `box EXPR`.",null,null],[10,"make_place","","Creates a globally fresh place.",70,{"inputs":[],"output":{"name":"self"}}],[8,"CoerceUnsized","","Trait that indicates that this is a pointer or a wrapper for one, where unsizing can be performed on the pointee.",null,null],[0,"cmp","core","Functionality for ordering and comparison.",null,null],[3,"Reverse","core::cmp","A helper struct for reverse ordering.",null,null],[12,"0","","",71,null],[4,"Ordering","","An `Ordering` is the result of a comparison between two values.",null,null],[13,"Less","","An ordering where a compared value is less [than another].",72,null],[13,"Equal","","An ordering where a compared value is equal [to another].",72,null],[13,"Greater","","An ordering where a compared value is greater [than another].",72,null],[5,"min","","Compares and returns the minimum of two values.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"max","","Compares and returns the maximum of two values.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[8,"PartialEq","","Trait for equality comparisons which are partial equivalence relations.",null,null],[10,"eq","","This method tests for `self` and `other` values to be equal, and is used by `==`.",73,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"ne","","This method tests for `!=`.",73,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[8,"Eq","","Trait for equality comparisons which are equivalence relations.",null,null],[8,"Ord","","Trait for types that form a total order.",null,null],[10,"cmp","","This method returns an `Ordering` between `self` and `other`.",74,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"ordering"}}],[11,"max","","Compares and returns the maximum of two values.",74,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"min","","Compares and returns the minimum of two values.",74,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[8,"PartialOrd","","Trait for values that can be compared for a sort-order.",null,null],[10,"partial_cmp","","This method returns an ordering between `self` and `other` values if one exists.",75,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","This method tests less than (for `self` and `other`) and is used by the `<` operator.",75,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"le","","This method tests less than or equal to (for `self` and `other`) and is used by the `<=` operator.",75,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"gt","","This method tests greater than (for `self` and `other`) and is used by the `>` operator.",75,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"ge","","This method tests greater than or equal to (for `self` and `other`) and is used by the `>=` operator.",75,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"clone","","",72,{"inputs":[{"name":"self"}],"output":{"name":"ordering"}}],[11,"eq","","",72,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"fmt","","",72,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",72,null],[11,"reverse","","Reverses the `Ordering`.",72,{"inputs":[{"name":"self"}],"output":{"name":"ordering"}}],[11,"then","","Chains two orderings.",72,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"ordering"}}],[11,"then_with","","Chains the ordering with the given function.",72,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"ordering"}}],[11,"eq","","",71,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"ne","","",71,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"fmt","","",71,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",71,{"inputs":[{"name":"self"}],"output":{"name":"reverse"}}],[11,"default","","",71,{"inputs":[],"output":{"name":"reverse"}}],[11,"hash","","",71,null],[11,"partial_cmp","","",71,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",71,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"le","","",71,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ge","","",71,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"gt","","",71,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"cmp","","",71,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"ordering"}}],[11,"cmp","","",72,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","",72,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"generics":["ordering"],"name":"option"}}],[0,"clone","core","The `Clone` trait for types that cannot be 'implicitly copied'.",null,null],[8,"Clone","core::clone","A common trait for the ability to explicitly duplicate an object.",null,null],[10,"clone","","Returns a copy of the value.",76,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"clone_from","","Performs copy-assignment from `source`.",76,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[0,"default","core","The `Default` trait for types which may have meaningful default values.",null,null],[8,"Default","core::default","A trait for giving a type a useful default value.",null,null],[10,"default","","Returns the \"default value\" for a type.",77,{"inputs":[],"output":{"name":"self"}}],[0,"convert","core","Traits for conversions between types.",null,null],[8,"AsRef","core::convert","A cheap reference-to-reference conversion. Used to convert a value to a reference value within generic code.",null,null],[10,"as_ref","","Performs the conversion.",78,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[8,"AsMut","","A cheap, mutable reference-to-mutable reference conversion.",null,null],[10,"as_mut","","Performs the conversion.",79,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[8,"Into","","A conversion that consumes `self`, which may or may not be expensive. The reciprocal of [`From`][From].",null,null],[10,"into","","Performs the conversion.",80,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[8,"From","","Simple and safe type conversions in to `Self`. It is the reciprocal of `Into`.",null,null],[10,"from","","Performs the conversion.",81,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[8,"TryInto","","An attempted conversion that consumes `self`, which may or may not be expensive.",null,null],[16,"Error","","The type returned in the event of a conversion error.",82,null],[10,"try_into","","Performs the conversion.",82,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[8,"TryFrom","","Attempt to construct `Self` via a conversion.",null,null],[16,"Error","","The type returned in the event of a conversion error.",83,null],[10,"try_from","","Performs the conversion.",83,{"inputs":[{"name":"t"}],"output":{"name":"result"}}],[0,"borrow","core","A module for working with borrowed data.",null,null],[8,"Borrow","core::borrow","A trait for borrowing data.",null,null],[10,"borrow","","Immutably borrows from an owned value.",84,{"inputs":[{"name":"self"}],"output":{"name":"borrowed"}}],[8,"BorrowMut","","A trait for mutably borrowing data.",null,null],[10,"borrow_mut","","Mutably borrows from an owned value.",85,{"inputs":[{"name":"self"}],"output":{"name":"borrowed"}}],[0,"any","core","This module implements the `Any` trait, which enables dynamic typing of any `'static` type through runtime reflection.",null,null],[3,"TypeId","core::any","A `TypeId` represents a globally unique identifier for a type.",null,null],[8,"Any","","A type to emulate dynamic typing.",null,null],[10,"get_type_id","","Gets the `TypeId` of `self`.",86,{"inputs":[{"name":"self"}],"output":{"name":"typeid"}}],[11,"fmt","","",86,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",86,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"is","","Returns `true` if the boxed type is the same as `T`.",86,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"downcast_ref","","Returns some reference to the boxed value if it is of type `T`, or `None` if it isn't.",86,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast_mut","","Returns some mutable reference to the boxed value if it is of type `T`, or `None` if it isn't.",86,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is","","Forwards to the method defined on the type `Any`.",86,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"downcast_ref","","Forwards to the method defined on the type `Any`.",86,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast_mut","","Forwards to the method defined on the type `Any`.",86,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",87,{"inputs":[{"name":"self"}],"output":{"name":"typeid"}}],[11,"eq","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"ne","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"le","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"gt","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"ge","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"cmp","","",87,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"ordering"}}],[11,"fmt","","",87,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",87,null],[11,"of","","Returns the `TypeId` of the type this generic function has been instantiated with.",87,{"inputs":[],"output":{"name":"typeid"}}],[0,"array","core","Implementations of things like `Eq` for fixed-length arrays up to a certain length. Eventually we should able to generalize to all lengths.",null,null],[3,"TryFromSliceError","core::array","The error type returned when a conversion from a slice to an array fails.",null,null],[8,"FixedSizeArray","","Utility trait implemented only on arrays of fixed size",null,null],[10,"as_slice","","Converts the array to immutable slice",88,null],[10,"as_mut_slice","","Converts the array to mutable slice",88,null],[11,"fmt","","",89,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",89,{"inputs":[{"name":"self"}],"output":{"name":"tryfromsliceerror"}}],[11,"fmt","","",89,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"ascii","core","Operations on ASCII strings and characters.",null,null],[3,"EscapeDefault","core::ascii","An iterator over the escaped version of a byte.",null,null],[5,"escape_default","","Returns an iterator that produces an escaped version of a `u8`.",null,{"inputs":[{"name":"u8"}],"output":{"name":"escapedefault"}}],[11,"next","","",90,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"size_hint","","",90,null],[11,"next_back","","",90,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"fmt","","",90,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"sync","core","Synchronization primitives",null,null],[0,"atomic","core::sync","Atomic types",null,null],[3,"AtomicBool","core::sync::atomic","A boolean type which can be safely shared between threads.",null,null],[3,"AtomicPtr","","A raw pointer type which can be safely shared between threads.",null,null],[3,"AtomicI8","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicU8","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicI16","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicU16","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicI32","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicU32","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicI64","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicU64","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicIsize","","An integer type which can be safely shared between threads.",null,null],[3,"AtomicUsize","","An integer type which can be safely shared between threads.",null,null],[4,"Ordering","","Atomic memory orderings",null,null],[13,"Relaxed","","No ordering constraints, only atomic operations.",91,null],[13,"Release","","When coupled with a store, all previous writes become visible to the other threads that perform a load with [`Acquire`] ordering on the same value.",91,null],[13,"Acquire","","When coupled with a load, all subsequent loads will see data written before a store with [`Release`] ordering on the same value in other threads.",91,null],[13,"AcqRel","","Has the effects of both [`Acquire`] and [`Release`] together.",91,null],[13,"SeqCst","","Like `AcqRel` with the additional guarantee that all threads see all sequentially consistent operations in the same order.",91,null],[5,"spin_loop_hint","","Save power or switch hyperthreads in a busy-wait spin-loop.",null,{"inputs":[],"output":null}],[5,"fence","","An atomic fence.",null,{"inputs":[{"name":"ordering"}],"output":null}],[5,"compiler_fence","","A compiler memory fence.",null,{"inputs":[{"name":"ordering"}],"output":null}],[17,"ATOMIC_BOOL_INIT","","An [`AtomicBool`] initialized to `false`.",null,null],[17,"ATOMIC_I8_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_U8_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_I16_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_U16_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_I32_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_U32_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_I64_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_U64_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_ISIZE_INIT","","An atomic integer initialized to `0`.",null,null],[17,"ATOMIC_USIZE_INIT","","An atomic integer initialized to `0`.",null,null],[11,"default","","Creates an `AtomicBool` initialized to `false`.",92,{"inputs":[],"output":{"name":"self"}}],[11,"default","","Creates a null `AtomicPtr<T>`.",93,{"inputs":[],"output":{"name":"atomicptr"}}],[11,"clone","","",91,{"inputs":[{"name":"self"}],"output":{"name":"ordering"}}],[11,"fmt","","",91,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new `AtomicBool`.",92,{"inputs":[{"name":"bool"}],"output":{"name":"atomicbool"}}],[11,"get_mut","","Returns a mutable reference to the underlying [`bool`].",92,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",92,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"load","","Loads a value from the bool.",92,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"store","","Stores a value into the bool.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the bool, returning the previous value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"compare_and_swap","","Stores a value into the [`bool`] if the current value is the same as the `current` value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"compare_exchange","","Stores a value into the [`bool`] if the current value is the same as the `current` value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"bool"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["bool","bool"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the [`bool`] if the current value is the same as the `current` value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"bool"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["bool","bool"],"name":"result"}}],[11,"fetch_and","","Logical \"and\" with a boolean value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"fetch_nand","","Logical \"nand\" with a boolean value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"fetch_or","","Logical \"or\" with a boolean value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"fetch_xor","","Logical \"xor\" with a boolean value.",92,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"new","","Creates a new `AtomicPtr`.",93,null],[11,"get_mut","","Returns a mutable reference to the underlying pointer.",93,null],[11,"into_inner","","Consumes the atomic and returns the contained value.",93,null],[11,"load","","Loads a value from the pointer.",93,null],[11,"store","","Stores a value into the pointer.",93,null],[11,"swap","","Stores a value into the pointer, returning the previous value.",93,null],[11,"compare_and_swap","","Stores a value into the pointer if the current value is the same as the `current` value.",93,null],[11,"compare_exchange","","Stores a value into the pointer if the current value is the same as the `current` value.",93,null],[11,"compare_exchange_weak","","Stores a value into the pointer if the current value is the same as the `current` value.",93,null],[11,"from","","",92,{"inputs":[{"name":"bool"}],"output":{"name":"self"}}],[11,"from","","",93,null],[11,"default","","",94,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",94,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"fmt","","",94,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",94,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",94,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",94,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"load","","Loads a value from the atomic integer.",94,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"store","","Stores a value into the atomic integer.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"i8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i8","i8"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"i8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i8","i8"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",94,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"default","","",95,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",95,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"fmt","","",95,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",95,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",95,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",95,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"load","","Loads a value from the atomic integer.",95,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"store","","Stores a value into the atomic integer.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"u8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u8","u8"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"u8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u8","u8"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",95,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"default","","",96,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",96,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"fmt","","",96,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",96,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",96,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",96,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"load","","Loads a value from the atomic integer.",96,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"store","","Stores a value into the atomic integer.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"i16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i16","i16"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"i16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i16","i16"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",96,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"default","","",97,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",97,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"fmt","","",97,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",97,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",97,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",97,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"load","","Loads a value from the atomic integer.",97,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"store","","Stores a value into the atomic integer.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"u16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u16","u16"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"u16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u16","u16"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",97,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"default","","",98,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",98,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"fmt","","",98,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",98,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",98,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",98,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"load","","Loads a value from the atomic integer.",98,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"store","","Stores a value into the atomic integer.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"i32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i32","i32"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"i32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i32","i32"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",98,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"default","","",99,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",99,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"fmt","","",99,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",99,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",99,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",99,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"load","","Loads a value from the atomic integer.",99,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"store","","Stores a value into the atomic integer.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"u32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u32","u32"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"u32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u32","u32"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",99,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"default","","",100,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",100,{"inputs":[{"name":"i64"}],"output":{"name":"self"}}],[11,"fmt","","",100,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",100,{"inputs":[{"name":"i64"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",100,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",100,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"load","","Loads a value from the atomic integer.",100,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"store","","Stores a value into the atomic integer.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"i64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i64","i64"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"i64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i64","i64"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",100,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"default","","",101,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",101,{"inputs":[{"name":"u64"}],"output":{"name":"self"}}],[11,"fmt","","",101,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",101,{"inputs":[{"name":"u64"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",101,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",101,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"load","","Loads a value from the atomic integer.",101,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"store","","Stores a value into the atomic integer.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"u64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u64","u64"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"u64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u64","u64"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",101,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"default","","",102,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",102,{"inputs":[{"name":"isize"}],"output":{"name":"self"}}],[11,"fmt","","",102,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",102,{"inputs":[{"name":"isize"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",102,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",102,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"load","","Loads a value from the atomic integer.",102,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"store","","Stores a value into the atomic integer.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"isize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["isize","isize"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"isize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["isize","isize"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",102,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"default","","",103,{"inputs":[],"output":{"name":"self"}}],[11,"from","","",103,{"inputs":[{"name":"usize"}],"output":{"name":"self"}}],[11,"fmt","","",103,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new atomic integer.",103,{"inputs":[{"name":"usize"}],"output":{"name":"self"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",103,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",103,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"load","","Loads a value from the atomic integer.",103,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"store","","Stores a value into the atomic integer.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":null}],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",103,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fmt","","",92,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",93,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",93,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"cell","core","Shareable mutable containers.",null,null],[3,"Cell","core::cell","A mutable memory location.",null,null],[3,"RefCell","","A mutable memory location with dynamically checked borrow rules",null,null],[3,"BorrowError","","An error returned by `RefCell::try_borrow`.",null,null],[3,"BorrowMutError","","An error returned by `RefCell::try_borrow_mut`.",null,null],[3,"Ref","","Wraps a borrowed reference to a value in a `RefCell` box. A wrapper type for an immutably borrowed value from a `RefCell<T>`.",null,null],[3,"RefMut","","A wrapper type for a mutably borrowed value from a `RefCell<T>`.",null,null],[3,"UnsafeCell","","The core primitive for interior mutability in Rust.",null,null],[11,"get","","Returns a copy of the contained value.",104,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"clone","","",104,{"inputs":[{"name":"self"}],"output":{"name":"cell"}}],[11,"default","","Creates a `Cell<T>`, with the `Default` value for T.",104,{"inputs":[],"output":{"name":"cell"}}],[11,"eq","","",104,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",104,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",104,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"le","","",104,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"gt","","",104,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"ge","","",104,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"cmp","","",104,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"ordering"}}],[11,"from","","",104,{"inputs":[{"name":"t"}],"output":{"name":"cell"}}],[11,"new","","Creates a new `Cell` containing the given value.",104,{"inputs":[{"name":"t"}],"output":{"name":"cell"}}],[11,"as_ptr","","Returns a raw pointer to the underlying data in this cell.",104,null],[11,"get_mut","","Returns a mutable reference to the underlying data.",104,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"set","","Sets the contained value.",104,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"swap","","Swaps the values of two Cells. Difference with `std::mem::swap` is that this function doesn't require `&mut` reference.",104,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"replace","","Replaces the contained value, and returns it.",104,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"into_inner","","Unwraps the value.",104,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"take","","Takes the value of the cell, leaving `Default::default()` in its place.",104,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"fmt","","",105,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",105,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",106,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",106,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new `RefCell` containing `value`.",107,{"inputs":[{"name":"t"}],"output":{"name":"refcell"}}],[11,"into_inner","","Consumes the `RefCell`, returning the wrapped value.",107,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"replace","","Replaces the wrapped value with a new one, returning the old value, without deinitializing either one.",107,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"replace_with","","Replaces the wrapped value with a new one computed from `f`, returning the old value, without deinitializing either one.",107,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"swap","","Swaps the wrapped value of `self` with the wrapped value of `other`, without deinitializing either one.",107,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"borrow","","Immutably borrows the wrapped value.",107,{"inputs":[{"name":"self"}],"output":{"name":"ref"}}],[11,"try_borrow","","Immutably borrows the wrapped value, returning an error if the value is currently mutably borrowed.",107,{"inputs":[{"name":"self"}],"output":{"generics":["ref","borrowerror"],"name":"result"}}],[11,"borrow_mut","","Mutably borrows the wrapped value.",107,{"inputs":[{"name":"self"}],"output":{"name":"refmut"}}],[11,"try_borrow_mut","","Mutably borrows the wrapped value, returning an error if the value is currently borrowed.",107,{"inputs":[{"name":"self"}],"output":{"generics":["refmut","borrowmuterror"],"name":"result"}}],[11,"as_ptr","","Returns a raw pointer to the underlying data in this cell.",107,null],[11,"get_mut","","Returns a mutable reference to the underlying data.",107,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"clone","","Panics",107,{"inputs":[{"name":"self"}],"output":{"name":"refcell"}}],[11,"default","","Creates a `RefCell<T>`, with the `Default` value for T.",107,{"inputs":[],"output":{"name":"refcell"}}],[11,"eq","","Panics",107,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"partial_cmp","","Panics",107,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","Panics",107,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"le","","Panics",107,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"gt","","Panics",107,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"ge","","Panics",107,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"cmp","","Panics",107,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"ordering"}}],[11,"from","","",107,{"inputs":[{"name":"t"}],"output":{"name":"refcell"}}],[11,"deref","","",108,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"clone","","Copies a `Ref`.",108,{"inputs":[{"name":"ref"}],"output":{"name":"ref"}}],[11,"map","","Make a new `Ref` for a component of the borrowed data.",108,{"inputs":[{"name":"ref"},{"name":"f"}],"output":{"name":"ref"}}],[11,"fmt","","",108,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"map","","Make a new `RefMut` for a component of the borrowed data, e.g. an enum variant.",109,{"inputs":[{"name":"refmut"},{"name":"f"}],"output":{"name":"refmut"}}],[11,"deref","","",109,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",109,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"fmt","","",109,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Constructs a new instance of `UnsafeCell` which will wrap the specified value.",110,{"inputs":[{"name":"t"}],"output":{"name":"unsafecell"}}],[11,"into_inner","","Unwraps the value.",110,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get","","Gets a mutable pointer to the wrapped value.",110,null],[11,"default","","Creates an `UnsafeCell`, with the `Default` value for T.",110,{"inputs":[],"output":{"name":"unsafecell"}}],[11,"from","","",110,{"inputs":[{"name":"t"}],"output":{"name":"unsafecell"}}],[0,"char","core","Character manipulation.",null,null],[3,"ParseCharError","core::char","An error which can be returned when parsing a char.",null,null],[3,"CharTryFromError","","The error type returned when a conversion from u32 to char fails.",null,null],[3,"EscapeUnicode","","Returns an iterator that yields the hexadecimal Unicode escape of a character, as `char`s.",null,null],[3,"EscapeDefault","","An iterator that yields the literal escape code of a `char`.",null,null],[3,"EscapeDebug","","An iterator that yields the literal escape code of a `char`.",null,null],[3,"DecodeUtf8","","An iterator over an iterator of bytes of the characters the bytes represent as UTF-8",null,null],[3,"InvalidSequence","","`<DecodeUtf8 as Iterator>::next` returns this for an invalid input sequence.",null,null],[5,"from_u32","","Converts a `u32` to a `char`.",null,{"inputs":[{"name":"u32"}],"output":{"generics":["char"],"name":"option"}}],[5,"from_u32_unchecked","","Converts a `u32` to a `char`, ignoring validity.",null,{"inputs":[{"name":"u32"}],"output":{"name":"char"}}],[5,"from_digit","","Converts a digit in the given radix to a `char`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"generics":["char"],"name":"option"}}],[5,"decode_utf8","","Decodes an `Iterator` of bytes as UTF-8.",null,{"inputs":[{"name":"i"}],"output":{"name":"decodeutf8"}}],[17,"MAX","","The highest valid code point a `char` can have.",null,null],[11,"clone","","",111,{"inputs":[{"name":"self"}],"output":{"name":"parsecharerror"}}],[11,"fmt","","",111,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",111,{"inputs":[{"name":"self"},{"name":"parsecharerror"}],"output":{"name":"bool"}}],[11,"ne","","",111,{"inputs":[{"name":"self"},{"name":"parsecharerror"}],"output":{"name":"bool"}}],[11,"fmt","","",111,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",112,{"inputs":[{"name":"self"}],"output":{"name":"chartryfromerror"}}],[11,"fmt","","",112,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",112,{"inputs":[{"name":"self"},{"name":"chartryfromerror"}],"output":{"name":"bool"}}],[11,"ne","","",112,{"inputs":[{"name":"self"},{"name":"chartryfromerror"}],"output":{"name":"bool"}}],[11,"fmt","","",112,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",113,{"inputs":[{"name":"self"}],"output":{"name":"escapeunicode"}}],[11,"fmt","","",113,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",113,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",113,null],[11,"count","","",113,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",113,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"len","","",113,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",113,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",114,{"inputs":[{"name":"self"}],"output":{"name":"escapedefault"}}],[11,"fmt","","",114,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",114,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",114,null],[11,"count","","",114,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",114,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["char"],"name":"option"}}],[11,"last","","",114,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"len","","",114,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",114,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",115,{"inputs":[{"name":"self"}],"output":{"name":"escapedebug"}}],[11,"fmt","","",115,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",115,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",115,null],[11,"fmt","","",115,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",116,{"inputs":[{"name":"self"}],"output":{"name":"decodeutf8"}}],[11,"fmt","","",116,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",117,{"inputs":[{"name":"self"},{"name":"invalidsequence"}],"output":{"name":"bool"}}],[11,"ne","","",117,{"inputs":[{"name":"self"},{"name":"invalidsequence"}],"output":{"name":"bool"}}],[11,"fmt","","",117,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",116,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"size_hint","","",116,null],[0,"panic","core","Panic support in the standard library.",null,null],[3,"PanicInfo","core::panic","A struct providing information about a panic.",null,null],[3,"Location","","A struct containing information about the location of a panic.",null,null],[11,"fmt","","",118,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"payload","","Returns the payload associated with the panic.",118,{"inputs":[{"name":"self"}],"output":{"name":"any"}}],[11,"message","","If the `panic!` macro from the `core` crate (not from `std`) was used with a formatting string and some additional arguments, returns that message ready to be used for example with [`fmt::write`]",118,{"inputs":[{"name":"self"}],"output":{"generics":["arguments"],"name":"option"}}],[11,"location","","Returns information about the location from which the panic originated, if available.",118,{"inputs":[{"name":"self"}],"output":{"generics":["location"],"name":"option"}}],[11,"fmt","","",118,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",119,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"file","","Returns the name of the source file from which the panic originated.",119,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"line","","Returns the line number from which the panic originated.",119,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"column","","Returns the column from which the panic originated.",119,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"fmt","","",119,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"panicking","core","Panic support for libcore",null,null],[5,"panic","core::panicking","",null,null],[5,"panic_fmt","","",null,null],[0,"iter","core","Composable external iteration.",null,null],[3,"Repeat","core::iter","An iterator that repeats an element endlessly.",null,null],[3,"RepeatWith","","An iterator that repeats elements of type `A` endlessly by applying the provided closure `F: FnMut() -> A`.",null,null],[3,"Empty","","An iterator that yields nothing.",null,null],[3,"Once","","An iterator that yields an element exactly once.",null,null],[3,"Rev","","A double-ended iterator with the direction inverted.",null,null],[3,"Cloned","","An iterator that clones the elements of an underlying iterator.",null,null],[3,"Cycle","","An iterator that repeats endlessly.",null,null],[3,"StepBy","","An iterator for stepping iterators by a custom amount.",null,null],[3,"Chain","","An iterator that strings two iterators together.",null,null],[3,"Zip","","An iterator that iterates two other iterators simultaneously.",null,null],[3,"Map","","An iterator that maps the values of `iter` with `f`.",null,null],[3,"Filter","","An iterator that filters the elements of `iter` with `predicate`.",null,null],[3,"FilterMap","","An iterator that uses `f` to both filter and map elements from `iter`.",null,null],[3,"Enumerate","","An iterator that yields the current count and the element during iteration.",null,null],[3,"Peekable","","An iterator with a `peek()` that returns an optional reference to the next element.",null,null],[3,"SkipWhile","","An iterator that rejects elements while `predicate` is true.",null,null],[3,"TakeWhile","","An iterator that only accepts elements while `predicate` is true.",null,null],[3,"Skip","","An iterator that skips over `n` elements of `iter`.",null,null],[3,"Take","","An iterator that only iterates over the first `n` iterations of `iter`.",null,null],[3,"Scan","","An iterator to maintain state while iterating another iterator.",null,null],[3,"FlatMap","","An iterator that maps each element to an iterator, and yields the elements of the produced iterators.",null,null],[3,"Flatten","","An iterator that flattens one level of nesting in an iterator of things that can be turned into iterators.",null,null],[3,"Fuse","","An iterator that yields `None` forever after the underlying iterator yields `None` once.",null,null],[3,"Inspect","","An iterator that calls a function with a reference to each element before yielding it.",null,null],[5,"repeat","","Creates a new iterator that endlessly repeats a single element.",null,{"inputs":[{"name":"t"}],"output":{"name":"repeat"}}],[5,"repeat_with","","Creates a new iterator that repeats elements of type `A` endlessly by applying the provided closure, the repeater, `F: FnMut() -> A`.",null,{"inputs":[{"name":"f"}],"output":{"name":"repeatwith"}}],[5,"empty","","Creates an iterator that yields nothing.",null,{"inputs":[],"output":{"name":"empty"}}],[5,"once","","Creates an iterator that yields an element exactly once.",null,{"inputs":[{"name":"t"}],"output":{"name":"once"}}],[11,"next","core::ops","",25,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",25,null],[11,"nth","","",25,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",25,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"min","","",25,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"max","","",25,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",25,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",26,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",26,null],[11,"nth","","",26,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next","","",28,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",28,null],[11,"nth","","",28,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",28,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"min","","",28,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"max","","",28,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",28,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"next_back","","",28,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",28,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"clone","core::iter","",120,{"inputs":[{"name":"self"}],"output":{"name":"repeat"}}],[11,"fmt","","",120,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",120,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",120,null],[11,"next_back","","",120,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",121,{"inputs":[{"name":"self"}],"output":{"name":"repeatwith"}}],[11,"fmt","","",121,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",121,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",121,null],[11,"next_back","","",121,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",122,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",122,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",122,null],[11,"next_back","","",122,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",122,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"clone","","",122,{"inputs":[{"name":"self"}],"output":{"name":"empty"}}],[11,"default","","",122,{"inputs":[],"output":{"name":"empty"}}],[11,"clone","","",123,{"inputs":[{"name":"self"}],"output":{"name":"once"}}],[11,"fmt","","",123,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",123,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",123,null],[11,"next_back","","",123,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","","",123,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"sum","core::num","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"sum","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"product","","",0,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[8,"Iterator","core::iter","An interface for dealing with iterators.",null,null],[16,"Item","","The type of the elements being iterated over.",124,null],[10,"next","","Advances the iterator and returns the next value.",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","Returns the bounds on the remaining length of the iterator.",124,null],[11,"count","","Consumes the iterator, counting the number of iterations and returning it.",124,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","Consumes the iterator, returning the last element.",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","Returns the `n`th element of the iterator.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"step_by","","Creates an iterator starting at the same point, but stepping by the given amount at each iteration.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"stepby"}}],[11,"chain","","Takes two iterators and creates a new iterator over both in sequence.",124,{"inputs":[{"name":"self"},{"name":"u"}],"output":{"name":"chain"}}],[11,"zip","","'Zips up' two iterators into a single iterator of pairs.",124,{"inputs":[{"name":"self"},{"name":"u"}],"output":{"name":"zip"}}],[11,"map","","Takes a closure and creates an iterator which calls that closure on each element.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"map"}}],[11,"for_each","","Calls a closure on each element of an iterator.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"filter","","Creates an iterator which uses a closure to determine if an element should be yielded.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"filter"}}],[11,"filter_map","","Creates an iterator that both filters and maps.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"filtermap"}}],[11,"enumerate","","Creates an iterator which gives the current iteration count as well as the next value.",124,{"inputs":[{"name":"self"}],"output":{"name":"enumerate"}}],[11,"peekable","","Creates an iterator which can use `peek` to look at the next element of the iterator without consuming it.",124,{"inputs":[{"name":"self"}],"output":{"name":"peekable"}}],[11,"skip_while","","Creates an iterator that [`skip`]s elements based on a predicate.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"skipwhile"}}],[11,"take_while","","Creates an iterator that yields elements based on a predicate.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"takewhile"}}],[11,"skip","","Creates an iterator that skips the first `n` elements.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"skip"}}],[11,"take","","Creates an iterator that yields its first `n` elements.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"take"}}],[11,"scan","","An iterator adaptor similar to [`fold`] that holds internal state and produces a new iterator.",124,{"inputs":[{"name":"self"},{"name":"st"},{"name":"f"}],"output":{"name":"scan"}}],[11,"flat_map","","Creates an iterator that works like map, but flattens nested structure.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"flatmap"}}],[11,"flatten","","Creates an iterator that flattens nested structure.",124,{"inputs":[{"name":"self"}],"output":{"name":"flatten"}}],[11,"fuse","","Creates an iterator which ends after the first [`None`].",124,{"inputs":[{"name":"self"}],"output":{"name":"fuse"}}],[11,"inspect","","Do something with each element of an iterator, passing the value on.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"inspect"}}],[11,"by_ref","","Borrows an iterator, rather than consuming it.",124,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"collect","","Transforms an iterator into a collection.",124,{"inputs":[{"name":"self"}],"output":{"name":"b"}}],[11,"partition","","Consumes an iterator, creating two collections from it.",124,null],[11,"try_fold","","An iterator method that applies a function as long as it returns successfully, producing a single, final value.",124,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"try_for_each","","An iterator method that applies a fallible function to each item in the iterator, stopping at the first error and returning that error.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","An iterator method that applies a function, producing a single, final value.",124,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"b"}}],[11,"all","","Tests if every element of the iterator matches a predicate.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"any","","Tests if any element of the iterator matches a predicate.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"find","","Searches for an element of an iterator that satisfies a predicate.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"position","","Searches for an element in an iterator, returning its index.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","Searches for an element in an iterator from the right, returning its index.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"max","","Returns the maximum element of an iterator.",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"min","","Returns the minimum element of an iterator.",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"max_by_key","","Returns the element that gives the maximum value from the specified function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"max_by","","Returns the element that gives the maximum value with respect to the specified comparison function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"min_by_key","","Returns the element that gives the minimum value from the specified function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"min_by","","Returns the element that gives the minimum value with respect to the specified comparison function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"rev","","Reverses an iterator's direction.",124,{"inputs":[{"name":"self"}],"output":{"name":"rev"}}],[11,"unzip","","Converts an iterator of pairs into a pair of containers.",124,null],[11,"cloned","","Creates an iterator which [`clone`]s all of its elements.",124,{"inputs":[{"name":"self"}],"output":{"name":"cloned"}}],[11,"cycle","","Repeats an iterator endlessly.",124,{"inputs":[{"name":"self"}],"output":{"name":"cycle"}}],[11,"sum","","Sums the elements of an iterator.",124,{"inputs":[{"name":"self"}],"output":{"name":"s"}}],[11,"product","","Iterates over the entire iterator, multiplying all the elements",124,{"inputs":[{"name":"self"}],"output":{"name":"p"}}],[11,"cmp","","Lexicographically compares the elements of this `Iterator` with those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","Lexicographically compares the elements of this `Iterator` with those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","Determines if the elements of this `Iterator` are equal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"ne","","Determines if the elements of this `Iterator` are unequal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"lt","","Determines if the elements of this `Iterator` are lexicographically less than those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"le","","Determines if the elements of this `Iterator` are lexicographically less or equal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"gt","","Determines if the elements of this `Iterator` are lexicographically greater than those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"ge","","Determines if the elements of this `Iterator` are lexicographically greater than or equal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[8,"Step","","Objects that can be stepped over in both directions.",null,null],[10,"steps_between","","Returns the number of steps between two step objects. The count is inclusive of `start` and exclusive of `end`.",125,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[10,"replace_one","","Replaces this step with `1`, returning itself",125,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"replace_zero","","Replaces this step with `0`, returning itself",125,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"add_one","","Adds one to this step, returning the result",125,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"sub_one","","Subtracts one to this step, returning the result",125,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"add_usize","","Add an usize, returning None on overflow",125,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[8,"FromIterator","","Conversion from an `Iterator`.",null,null],[10,"from_iter","","Creates a value from an iterator.",126,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[8,"IntoIterator","","Conversion into an `Iterator`.",null,null],[16,"Item","","The type of the elements being iterated over.",127,null],[16,"IntoIter","","Which kind of iterator are we turning this into?",127,null],[10,"into_iter","","Creates an iterator from a value.",127,null],[8,"DoubleEndedIterator","","An iterator able to yield elements from both ends.",null,null],[10,"next_back","","Removes and returns an element from the end of the iterator.",128,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","This is the reverse version of [`try_fold()`]: it takes elements starting from the back of the iterator.",128,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","An iterator method that reduces the iterator's elements to a single, final value, starting from the back.",128,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"b"}}],[11,"rfind","","Searches for an element of an iterator from the right that satisfies a predicate.",128,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[8,"Extend","","Extend a collection with the contents of an iterator.",null,null],[10,"extend","","Extends a collection with the contents of an iterator.",129,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[8,"ExactSizeIterator","","An iterator that knows its exact length.",null,null],[11,"len","","Returns the exact number of times the iterator will iterate.",130,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns whether the iterator is empty.",130,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[8,"Sum","","Trait to represent types that can be created by summing up an iterator.",null,null],[10,"sum","","Method which takes an iterator and generates `Self` from the elements by \"summing up\" the items.",131,{"inputs":[{"name":"i"}],"output":{"name":"self"}}],[8,"Product","","Trait to represent types that can be created by multiplying elements of an iterator.",null,null],[10,"product","","Method which takes an iterator and generates `Self` from the elements by multiplying the items.",132,{"inputs":[{"name":"i"}],"output":{"name":"self"}}],[8,"FusedIterator","","An iterator that always continues to yield `None` when exhausted.",null,null],[8,"TrustedLen","","An iterator that reports an accurate length using size_hint.",null,null],[11,"clone","","",133,{"inputs":[{"name":"self"}],"output":{"name":"rev"}}],[11,"fmt","","",133,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",133,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",133,null],[11,"try_fold","","",133,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",133,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"find","","",133,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"rposition","","",133,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next_back","","",133,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",133,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",133,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"rfind","","",133,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"len","","",133,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",133,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",134,{"inputs":[{"name":"self"}],"output":{"name":"cloned"}}],[11,"fmt","","",134,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",134,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",134,null],[11,"try_fold","","",134,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",134,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next_back","","",134,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",134,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",134,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"len","","",134,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",134,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",135,{"inputs":[{"name":"self"}],"output":{"name":"cycle"}}],[11,"fmt","","",135,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",135,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",135,null],[11,"clone","","",136,{"inputs":[{"name":"self"}],"output":{"name":"stepby"}}],[11,"fmt","","",136,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",136,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",136,null],[11,"nth","","",136,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"clone","","",137,{"inputs":[{"name":"self"}],"output":{"name":"chain"}}],[11,"fmt","","",137,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",137,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",137,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"try_fold","","",137,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",137,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"nth","","",137,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"find","","",137,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"last","","",137,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",137,null],[11,"next_back","","",137,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",137,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",137,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"clone","","",138,{"inputs":[{"name":"self"}],"output":{"name":"zip"}}],[11,"fmt","","",138,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",138,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",138,null],[11,"nth","","",138,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next_back","","",138,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",139,{"inputs":[{"name":"self"}],"output":{"name":"map"}}],[11,"fmt","","",139,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",139,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",139,null],[11,"try_fold","","",139,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"r"}}],[11,"fold","","",139,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"acc"}}],[11,"next_back","","",139,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",139,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"r"}}],[11,"rfold","","",139,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"acc"}}],[11,"len","","",139,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",139,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",140,{"inputs":[{"name":"self"}],"output":{"name":"filter"}}],[11,"fmt","","",140,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",140,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",140,null],[11,"count","","",140,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"try_fold","","",140,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",140,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",140,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",140,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",140,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"clone","","",141,{"inputs":[{"name":"self"}],"output":{"name":"filtermap"}}],[11,"fmt","","",141,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",141,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",141,null],[11,"try_fold","","",141,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",141,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",141,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",141,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",141,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"clone","","",142,{"inputs":[{"name":"self"}],"output":{"name":"enumerate"}}],[11,"fmt","","",142,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","Overflow Behavior",142,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",142,null],[11,"nth","","",142,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"count","","",142,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"try_fold","","",142,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",142,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",142,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",142,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",142,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"len","","",142,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",142,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",143,{"inputs":[{"name":"self"}],"output":{"name":"peekable"}}],[11,"fmt","","",143,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",143,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",143,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",143,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",143,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",143,null],[11,"try_fold","","",143,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",143,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"peek","","Returns a reference to the next() value without advancing the iterator.",143,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",144,{"inputs":[{"name":"self"}],"output":{"name":"skipwhile"}}],[11,"fmt","","",144,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",144,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",144,null],[11,"try_fold","","",144,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",144,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"clone","","",145,{"inputs":[{"name":"self"}],"output":{"name":"takewhile"}}],[11,"fmt","","",145,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",145,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",145,null],[11,"try_fold","","",145,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"clone","","",146,{"inputs":[{"name":"self"}],"output":{"name":"skip"}}],[11,"fmt","","",146,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",146,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",146,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"count","","",146,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",146,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",146,null],[11,"try_fold","","",146,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",146,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",146,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",146,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"clone","","",147,{"inputs":[{"name":"self"}],"output":{"name":"take"}}],[11,"fmt","","",147,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",147,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",147,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"size_hint","","",147,null],[11,"try_fold","","",147,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"clone","","",148,{"inputs":[{"name":"self"}],"output":{"name":"scan"}}],[11,"fmt","","",148,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",148,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",148,null],[11,"try_fold","","",148,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"clone","","",149,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",149,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",149,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",149,null],[11,"try_fold","","",149,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",149,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",149,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",149,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",149,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"fmt","","",150,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",150,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"next","","",150,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",150,null],[11,"try_fold","","",150,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",150,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",150,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",150,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",150,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"clone","","",151,{"inputs":[{"name":"self"}],"output":{"name":"fuse"}}],[11,"fmt","","",151,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",151,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",151,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",151,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",151,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",151,null],[11,"try_fold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",151,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","","",151,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",151,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",151,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",151,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",151,null],[11,"try_fold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",151,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",151,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"len","","",151,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",151,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",152,{"inputs":[{"name":"self"}],"output":{"name":"inspect"}}],[11,"fmt","","",152,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",152,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",152,null],[11,"try_fold","","",152,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",152,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",152,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",152,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",152,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"len","","",152,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",152,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[0,"option","core","Optional values.",null,null],[3,"Iter","core::option","An iterator over a reference to the [`Some`] variant of an [`Option`].",null,null],[3,"IterMut","","An iterator over a mutable reference to the [`Some`] variant of an [`Option`].",null,null],[3,"IntoIter","","An iterator over the value in [`Some`] variant of an [`Option`].",null,null],[3,"NoneError","","The error type that results from applying the try operator (`?`) to a `None` value. If you wish to allow `x?` (where `x` is an `Option<T>`) to be converted into your error type, you can implement `impl From<NoneError>` for `YourErrorType`. In that case, `x?` within a function that returns `Result<_, YourErrorType>` will translate a `None` value into an `Err` result.",null,null],[4,"Option","","The `Option` type. See the module level documentation for more.",null,null],[13,"None","","No value",153,null],[13,"Some","","Some value `T`",153,null],[11,"clone","","",153,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"eq","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"ne","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"le","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"gt","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"ge","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"cmp","","",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"ordering"}}],[11,"fmt","","",153,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",153,null],[11,"is_some","","Returns `true` if the option is a [`Some`] value.",153,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_none","","Returns `true` if the option is a [`None`] value.",153,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"as_ref","","Converts from `Option<T>` to `Option<&T>`.",153,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"as_mut","","Converts from `Option<T>` to `Option<&mut T>`.",153,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"expect","","Unwraps an option, yielding the content of a [`Some`].",153,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"t"}}],[11,"unwrap","","Moves the value `v` out of the `Option<T>` if it is [`Some(v)`].",153,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"unwrap_or","","Returns the contained value or a default.",153,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"unwrap_or_else","","Returns the contained value or computes it from a closure.",153,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"map","","Maps an `Option<T>` to `Option<U>` by applying a function to a contained value.",153,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"map_or","","Applies a function to the contained value (if any), or returns the provided default (if not).",153,{"inputs":[{"name":"self"},{"name":"u"},{"name":"f"}],"output":{"name":"u"}}],[11,"map_or_else","","Applies a function to the contained value (if any), or computes a default (if not).",153,{"inputs":[{"name":"self"},{"name":"d"},{"name":"f"}],"output":{"name":"u"}}],[11,"ok_or","","Transforms the `Option<T>` into a [`Result<T, E>`], mapping [`Some(v)`] to [`Ok(v)`] and [`None`] to [`Err(err)`].",153,{"inputs":[{"name":"self"},{"name":"e"}],"output":{"name":"result"}}],[11,"ok_or_else","","Transforms the `Option<T>` into a [`Result<T, E>`], mapping [`Some(v)`] to [`Ok(v)`] and [`None`] to [`Err(err())`].",153,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"result"}}],[11,"iter","","Returns an iterator over the possibly contained value.",153,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Returns a mutable iterator over the possibly contained value.",153,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"and","","Returns [`None`] if the option is [`None`], otherwise returns `optb`.",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"option"}}],[11,"and_then","","Returns [`None`] if the option is [`None`], otherwise calls `f` with the wrapped value and returns the result.",153,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"filter","","Returns `None` if the option is `None`, otherwise calls `predicate` with the wrapped value and returns:",153,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"self"}}],[11,"or","","Returns the option if it contains a value, otherwise returns `optb`.",153,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"option"}}],[11,"or_else","","Returns the option if it contains a value, otherwise calls `f` and returns the result.",153,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"get_or_insert","","Inserts `v` into the option if it is [`None`], then returns a mutable reference to the contained value.",153,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"get_or_insert_with","","Inserts a value computed from `f` into the option if it is [`None`], then returns a mutable reference to the contained value.",153,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"take","","Takes the value out of the option, leaving a [`None`] in its place.",153,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"cloned","","Maps an `Option<&T>` to an `Option<T>` by cloning the contents of the option.",153,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"cloned","","Maps an `Option<&mut T>` to an `Option<T>` by cloning the contents of the option.",153,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"unwrap_or_default","","Returns the contained value or a default",153,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"transpose","","Transposes an `Option` of a `Result` into a `Result` of an `Option`.",153,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"default","","Returns [`None`].",153,{"inputs":[],"output":{"name":"option"}}],[11,"into_iter","","Returns a consuming iterator over the possibly contained value.",153,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"from","","",153,{"inputs":[{"name":"t"}],"output":{"name":"option"}}],[11,"fmt","","",154,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",154,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",154,null],[11,"next_back","","",154,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",154,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"fmt","","",155,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",155,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",155,null],[11,"next_back","","",155,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",156,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"fmt","","",156,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",156,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",156,null],[11,"next_back","","",156,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"from_iter","","Takes each element in the [`Iterator`]: if it is [`None`], no further elements are taken, and the [`None`] is returned. Should no [`None`] occur, a container with the values of each `Option` is returned.",153,{"inputs":[{"name":"i"}],"output":{"name":"option"}}],[11,"clone","","",157,{"inputs":[{"name":"self"}],"output":{"name":"noneerror"}}],[11,"eq","","",157,{"inputs":[{"name":"self"},{"name":"noneerror"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",157,{"inputs":[{"name":"self"},{"name":"noneerror"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",157,{"inputs":[{"name":"self"},{"name":"noneerror"}],"output":{"name":"ordering"}}],[11,"fmt","","",157,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",157,null],[11,"into_result","","",153,{"inputs":[{"name":"self"}],"output":{"generics":["noneerror"],"name":"result"}}],[11,"from_ok","","",153,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from_error","","",153,{"inputs":[{"name":"noneerror"}],"output":{"name":"self"}}],[0,"raw","core","Contains struct definitions for the layout of compiler built-in types.",null,null],[3,"TraitObject","core::raw","The representation of a trait object like `&SomeTrait`.",null,null],[12,"data","","",158,null],[12,"vtable","","",158,null],[11,"clone","","",158,{"inputs":[{"name":"self"}],"output":{"name":"traitobject"}}],[0,"result","core","Error handling with the `Result` type.",null,null],[3,"Iter","core::result","An iterator over a reference to the [`Ok`] variant of a [`Result`].",null,null],[3,"IterMut","","An iterator over a mutable reference to the [`Ok`] variant of a [`Result`].",null,null],[3,"IntoIter","","An iterator over the value in a [`Ok`] variant of a [`Result`].",null,null],[4,"Result","","`Result` is a type that represents either success ([`Ok`]) or failure ([`Err`]).",null,null],[13,"Ok","","Contains the success value",159,null],[13,"Err","","Contains the error value",159,null],[11,"clone","","",159,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"eq","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"ne","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"le","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"gt","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"ge","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"cmp","","",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"ordering"}}],[11,"fmt","","",159,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",159,null],[11,"is_ok","","Returns `true` if the result is [`Ok`].",159,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_err","","Returns `true` if the result is [`Err`].",159,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"ok","","Converts from `Result<T, E>` to [`Option<T>`].",159,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"err","","Converts from `Result<T, E>` to [`Option<E>`].",159,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"as_ref","","Converts from `Result<T, E>` to `Result<&T, &E>`.",159,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"as_mut","","Converts from `Result<T, E>` to `Result<&mut T, &mut E>`.",159,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"map","","Maps a `Result<T, E>` to `Result<U, E>` by applying a function to a contained [`Ok`] value, leaving an [`Err`] value untouched.",159,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"result"}}],[11,"map_err","","Maps a `Result<T, E>` to `Result<T, F>` by applying a function to a contained [`Err`] value, leaving an [`Ok`] value untouched.",159,{"inputs":[{"name":"self"},{"name":"o"}],"output":{"name":"result"}}],[11,"iter","","Returns an iterator over the possibly contained value.",159,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Returns a mutable iterator over the possibly contained value.",159,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"and","","Returns `res` if the result is [`Ok`], otherwise returns the [`Err`] value of `self`.",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"result"}}],[11,"and_then","","Calls `op` if the result is [`Ok`], otherwise returns the [`Err`] value of `self`.",159,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"result"}}],[11,"or","","Returns `res` if the result is [`Err`], otherwise returns the [`Ok`] value of `self`.",159,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"result"}}],[11,"or_else","","Calls `op` if the result is [`Err`], otherwise returns the [`Ok`] value of `self`.",159,{"inputs":[{"name":"self"},{"name":"o"}],"output":{"name":"result"}}],[11,"unwrap_or","","Unwraps a result, yielding the content of an [`Ok`]. Else, it returns `optb`.",159,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"unwrap_or_else","","Unwraps a result, yielding the content of an [`Ok`]. If the value is an [`Err`] then it calls `op` with its value.",159,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"unwrap","","Unwraps a result, yielding the content of an [`Ok`].",159,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"expect","","Unwraps a result, yielding the content of an [`Ok`].",159,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"t"}}],[11,"unwrap_err","","Unwraps a result, yielding the content of an [`Err`].",159,{"inputs":[{"name":"self"}],"output":{"name":"e"}}],[11,"expect_err","","Unwraps a result, yielding the content of an [`Err`].",159,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"e"}}],[11,"unwrap_or_default","","Returns the contained value or a default",159,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"transpose","","Transposes a `Result` of an `Option` into an `Option` of a `Result`.",159,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"into_iter","","Returns a consuming iterator over the possibly contained value.",159,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"fmt","","",160,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",160,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",160,null],[11,"next_back","","",160,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",160,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"fmt","","",161,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",161,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",161,null],[11,"next_back","","",161,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",162,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"fmt","","",162,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",162,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",162,null],[11,"next_back","","",162,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"from_iter","","Takes each element in the `Iterator`: if it is an `Err`, no further elements are taken, and the `Err` is returned. Should no `Err` occur, a container with the values of each `Result` is returned.",159,{"inputs":[{"name":"i"}],"output":{"name":"result"}}],[11,"into_result","","",159,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"from_ok","","",159,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"from_error","","",159,{"inputs":[{"name":"e"}],"output":{"name":"self"}}],[0,"slice","core","Slice management and manipulation",null,null],[3,"Iter","core::slice","Immutable slice iterator",null,null],[3,"IterMut","","Mutable slice iterator.",null,null],[3,"Split","","An iterator over subslices separated by elements that match a predicate function.",null,null],[3,"SplitMut","","An iterator over the subslices of the vector which are separated by elements that match `pred`.",null,null],[3,"RSplit","","An iterator over subslices separated by elements that match a predicate function, starting from the end of the slice.",null,null],[3,"RSplitMut","","An iterator over the subslices of the vector which are separated by elements that match `pred`, starting from the end of the slice.",null,null],[3,"SplitN","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits.",null,null],[3,"RSplitN","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.",null,null],[3,"SplitNMut","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits.",null,null],[3,"RSplitNMut","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.",null,null],[3,"Windows","","An iterator over overlapping subslices of length `size`.",null,null],[3,"Chunks","","An iterator over a slice in (non-overlapping) chunks (`chunk_size` elements at a time).",null,null],[3,"ChunksMut","","An iterator over a slice in (non-overlapping) mutable chunks (`chunk_size` elements at a time). When the slice len is not evenly divided by the chunk size, the last slice of the iteration will be the remainder.",null,null],[3,"ExactChunks","","An iterator over a slice in (non-overlapping) chunks (`chunk_size` elements at a time).",null,null],[3,"ExactChunksMut","","An iterator over a slice in (non-overlapping) mutable chunks (`chunk_size` elements at a time). When the slice len is not evenly divided by the chunk size, the last up to `chunk_size-1` elements will be omitted.",null,null],[5,"from_raw_parts","","Forms a slice from a pointer and a length.",null,null],[5,"from_raw_parts_mut","","Performs the same functionality as `from_raw_parts`, except that a mutable slice is returned.",null,null],[5,"from_ref","","Converts a reference to T into a slice of length 1 (without copying).",null,null],[5,"from_ref_mut","","Converts a reference to T into a slice of length 1 (without copying).",null,null],[0,"memchr","","Pure rust memchr implementation, taken from rust-memchr",null,null],[5,"memchr","core::slice::memchr","Return the first index matching the byte `x` in `text`.",null,null],[5,"memrchr","","Return the last index matching the byte `x` in `text`.",null,null],[8,"SliceExt","core::slice","Extension methods for slices.",null,null],[16,"Item","","",163,null],[10,"split_at","","",163,null],[10,"iter","","",163,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[10,"split","","",163,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"split"}}],[10,"rsplit","","",163,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rsplit"}}],[10,"splitn","","",163,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"splitn"}}],[10,"rsplitn","","",163,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"rsplitn"}}],[10,"windows","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"windows"}}],[10,"chunks","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"chunks"}}],[10,"exact_chunks","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"exactchunks"}}],[10,"get","","",163,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[10,"first","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"split_first","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"split_last","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"last","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"get_unchecked","","",163,null],[10,"as_ptr","","",163,null],[10,"binary_search","","",163,null],[10,"binary_search_by","","",163,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"generics":["usize","usize"],"name":"result"}}],[10,"binary_search_by_key","","",163,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"generics":["usize","usize"],"name":"result"}}],[10,"len","","",163,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",163,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"get_mut","","",163,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[10,"iter_mut","","",163,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[10,"first_mut","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"split_first_mut","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"split_last_mut","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"last_mut","","",163,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[10,"split_mut","","",163,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"splitmut"}}],[10,"rsplit_mut","","",163,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rsplitmut"}}],[10,"splitn_mut","","",163,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"splitnmut"}}],[10,"rsplitn_mut","","",163,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"rsplitnmut"}}],[10,"chunks_mut","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"chunksmut"}}],[10,"exact_chunks_mut","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"exactchunksmut"}}],[10,"swap","","",163,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":null}],[10,"split_at_mut","","",163,null],[10,"reverse","","",163,{"inputs":[{"name":"self"}],"output":null}],[10,"get_unchecked_mut","","",163,null],[10,"as_mut_ptr","","",163,null],[10,"contains","","",163,null],[10,"starts_with","","",163,null],[10,"ends_with","","",163,null],[10,"rotate_left","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[10,"rotate_right","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[10,"clone_from_slice","","",163,null],[10,"copy_from_slice","","",163,null],[10,"swap_with_slice","","",163,null],[10,"sort_unstable","","",163,{"inputs":[{"name":"self"}],"output":null}],[10,"sort_unstable_by","","",163,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[10,"sort_unstable_by_key","","",163,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[8,"SliceIndex","","A helper trait used for indexing operations.",null,null],[16,"Output","","The output type returned by methods.",164,null],[10,"get","","Returns a shared reference to the output at this location, if in bounds.",164,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[10,"get_mut","","Returns a mutable reference to the output at this location, if in bounds.",164,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[10,"get_unchecked","","Returns a shared reference to the output at this location, without performing any bounds checking.",164,null],[10,"get_unchecked_mut","","Returns a mutable reference to the output at this location, without performing any bounds checking.",164,null],[10,"index","","Returns a shared reference to the output at this location, panicking if out of bounds.",164,null],[10,"index_mut","","Returns a mutable reference to the output at this location, panicking if out of bounds.",164,null],[11,"get","core::ops","",25,null],[11,"get_mut","","",25,null],[11,"get_unchecked","","",25,null],[11,"get_unchecked_mut","","",25,null],[11,"index","","",25,null],[11,"index_mut","","",25,null],[11,"get","","",27,null],[11,"get_mut","","",27,null],[11,"get_unchecked","","",27,null],[11,"get_unchecked_mut","","",27,null],[11,"index","","",27,null],[11,"index_mut","","",27,null],[11,"get","","",26,null],[11,"get_mut","","",26,null],[11,"get_unchecked","","",26,null],[11,"get_unchecked_mut","","",26,null],[11,"index","","",26,null],[11,"index_mut","","",26,null],[11,"get","","",32,null],[11,"get_mut","","",32,null],[11,"get_unchecked","","",32,null],[11,"get_unchecked_mut","","",32,null],[11,"index","","",32,null],[11,"index_mut","","",32,null],[11,"get","","",28,null],[11,"get_mut","","",28,null],[11,"get_unchecked","","",28,null],[11,"get_unchecked_mut","","",28,null],[11,"index","","",28,null],[11,"index_mut","","",28,null],[11,"get","","",29,null],[11,"get_mut","","",29,null],[11,"get_unchecked","","",29,null],[11,"get_unchecked_mut","","",29,null],[11,"index","","",29,null],[11,"index_mut","","",29,null],[11,"fmt","core::slice","",165,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"as_slice","","View the underlying data as a subslice of the original data.",165,null],[11,"next","","",165,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",165,null],[11,"count","","",165,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",165,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",165,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",165,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",165,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"position","","",165,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",165,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next_back","","",165,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",165,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",165,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"is_empty","","",165,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",165,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"as_ref","","",165,null],[11,"fmt","","",166,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"into_slice","","View the underlying data as a subslice of the original data.",166,null],[11,"next","","",166,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",166,null],[11,"count","","",166,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",166,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",166,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",166,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",166,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"position","","",166,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",166,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next_back","","",166,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",166,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",166,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"is_empty","","",166,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",167,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",167,{"inputs":[{"name":"self"}],"output":{"name":"split"}}],[11,"next","","",167,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",167,null],[11,"next_back","","",167,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",168,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",168,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",168,null],[11,"next_back","","",168,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",169,{"inputs":[{"name":"self"}],"output":{"name":"rsplit"}}],[11,"fmt","","",169,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",169,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",169,null],[11,"next_back","","",169,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",170,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",170,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",170,null],[11,"next_back","","",170,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",171,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",172,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",173,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",174,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",171,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",171,null],[11,"next","","",172,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",172,null],[11,"next","","",173,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",173,null],[11,"next","","",174,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",174,null],[11,"fmt","","",175,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",175,{"inputs":[{"name":"self"}],"output":{"name":"windows"}}],[11,"next","","",175,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",175,null],[11,"count","","",175,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",175,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",175,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",175,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",176,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",176,{"inputs":[{"name":"self"}],"output":{"name":"chunks"}}],[11,"next","","",176,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",176,null],[11,"count","","",176,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",176,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",176,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",176,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",177,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",177,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",177,null],[11,"count","","",177,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",177,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",177,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",177,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",178,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",178,{"inputs":[{"name":"self"}],"output":{"name":"exactchunks"}}],[11,"next","","",178,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",178,null],[11,"count","","",178,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",178,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",178,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",178,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is_empty","","",178,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",179,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",179,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",179,null],[11,"count","","",179,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",179,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",179,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",179,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is_empty","","",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[0,"str","core","String manipulation",null,null],[3,"ParseBoolError","core::str","An error returned when parsing a `bool` using [`from_str`] fails",null,null],[3,"Utf8Error","","Errors which can occur when attempting to interpret a sequence of [`u8`] as a string.",null,null],[3,"Chars","","An iterator over the [`char`]s of a string slice.",null,null],[3,"CharIndices","","An iterator over the [`char`]s of a string slice, and their positions.",null,null],[3,"Bytes","","An iterator over the bytes of a string slice.",null,null],[3,"Split","","Created with the method [`split`].",null,null],[3,"RSplit","","Created with the method [`rsplit`].",null,null],[3,"SplitTerminator","","Created with the method [`split_terminator`].",null,null],[3,"RSplitTerminator","","Created with the method [`rsplit_terminator`].",null,null],[3,"SplitN","","Created with the method [`splitn`].",null,null],[3,"RSplitN","","Created with the method [`rsplitn`].",null,null],[3,"MatchIndices","","Created with the method [`match_indices`].",null,null],[3,"RMatchIndices","","Created with the method [`rmatch_indices`].",null,null],[3,"Matches","","Created with the method [`matches`].",null,null],[3,"RMatches","","Created with the method [`rmatches`].",null,null],[3,"Lines","","An iterator over the lines of a string, as string slices.",null,null],[3,"LinesAny","","Created with the method [`lines_any`].",null,null],[5,"from_utf8","","Converts a slice of bytes to a string slice.",null,null],[5,"from_utf8_mut","","Converts a mutable slice of bytes to a mutable string slice.",null,null],[5,"from_utf8_unchecked","","Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8.",null,null],[5,"from_utf8_unchecked_mut","","Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8; mutable version.",null,null],[5,"next_code_point","","Reads the next code point out of a byte iterator (assuming a UTF-8-like encoding).",null,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"option"}}],[5,"utf8_char_width","","Given a first byte, determines how many bytes are in this UTF-8 character.",null,{"inputs":[{"name":"u8"}],"output":{"name":"usize"}}],[0,"pattern","","The string Pattern API.",null,null],[3,"CharSearcher","core::str::pattern","Associated type for `<char as Pattern<'a>>::Searcher`.",null,null],[3,"CharSliceSearcher","","Associated type for `<&[char] as Pattern<'a>>::Searcher`.",null,null],[3,"CharPredicateSearcher","","Associated type for `<F as Pattern<'a>>::Searcher`.",null,null],[3,"StrSearcher","","Associated type for `<&str as Pattern<'a>>::Searcher`.",null,null],[4,"SearchStep","","Result of calling `Searcher::next()` or `ReverseSearcher::next_back()`.",null,null],[13,"Match","","Expresses that a match of the pattern has been found at `haystack[a..b]`.",180,null],[13,"Reject","","Expresses that `haystack[a..b]` has been rejected as a possible match of the pattern.",180,null],[13,"Done","","Expresses that every byte of the haystack has been visited, ending the iteration.",180,null],[8,"Pattern","","A string pattern.",null,null],[16,"Searcher","","Associated searcher for this pattern",181,null],[10,"into_searcher","","Constructs the associated searcher from `self` and the `haystack` to search in.",181,null],[11,"is_contained_in","","Checks whether the pattern matches anywhere in the haystack",181,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_prefix_of","","Checks whether the pattern matches at the front of the haystack",181,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_suffix_of","","Checks whether the pattern matches at the back of the haystack",181,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[8,"Searcher","","A searcher for a string pattern.",null,null],[10,"haystack","","Getter for the underlying string to be searched in",182,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[10,"next","","Performs the next search step starting from the front.",182,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","Find the next `Match` result. See `next()`",182,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","Find the next `Reject` result. See `next()` and `next_match()`",182,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[8,"ReverseSearcher","","A reverse searcher for a string pattern.",null,null],[10,"next_back","","Performs the next search step starting from the back.",183,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","Find the next `Match` result. See `next_back()`",183,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","Find the next `Reject` result. See `next_back()`",183,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[8,"DoubleEndedSearcher","","A marker trait to express that a `ReverseSearcher` can be used for a `DoubleEndedIterator` implementation.",null,null],[11,"clone","","",180,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"eq","","",180,{"inputs":[{"name":"self"},{"name":"searchstep"}],"output":{"name":"bool"}}],[11,"ne","","",180,{"inputs":[{"name":"self"},{"name":"searchstep"}],"output":{"name":"bool"}}],[11,"fmt","","",180,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",184,{"inputs":[{"name":"self"}],"output":{"name":"charsearcher"}}],[11,"fmt","","",184,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"haystack","","",184,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",184,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",184,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",184,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",184,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",185,{"inputs":[{"name":"self"}],"output":{"name":"charslicesearcher"}}],[11,"fmt","","",185,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"haystack","","",185,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",185,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",185,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","",185,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",185,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",185,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","",185,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",186,{"inputs":[{"name":"self"}],"output":{"name":"charpredicatesearcher"}}],[11,"fmt","","",186,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"haystack","","",186,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",186,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",186,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","",186,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",186,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",186,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","",186,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",187,{"inputs":[{"name":"self"}],"output":{"name":"strsearcher"}}],[11,"fmt","","",187,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"haystack","","",187,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",187,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",187,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",187,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",187,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"get","core::ops","",32,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",32,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",32,null],[11,"get_unchecked_mut","","",32,null],[11,"index","","",32,null],[11,"index_mut","","",32,null],[11,"get","","",25,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",25,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",25,null],[11,"get_unchecked_mut","","",25,null],[11,"index","","",25,null],[11,"index_mut","","",25,null],[11,"get","","",27,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",27,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",27,null],[11,"get_unchecked_mut","","",27,null],[11,"index","","",27,null],[11,"index_mut","","",27,null],[11,"get","","",26,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",26,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",26,null],[11,"get_unchecked_mut","","",26,null],[11,"index","","",26,null],[11,"index_mut","","",26,null],[11,"get","","",28,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",28,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",28,null],[11,"get_unchecked_mut","","",28,null],[11,"index","","",28,null],[11,"index_mut","","",28,null],[11,"get","","",29,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",29,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",29,null],[11,"get_unchecked_mut","","",29,null],[11,"index","","",29,null],[11,"index_mut","","",29,null],[8,"FromStr","core::str","A trait to abstract the idea of creating a new instance of a type from a string.",null,null],[16,"Err","","The associated error which can be returned from parsing.",188,null],[10,"from_str","","Parses a string `s` to return a value of this type.",188,{"inputs":[{"name":"str"}],"output":{"name":"result"}}],[11,"fmt","","",189,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",189,{"inputs":[{"name":"self"}],"output":{"name":"parseboolerror"}}],[11,"eq","","",189,{"inputs":[{"name":"self"},{"name":"parseboolerror"}],"output":{"name":"bool"}}],[11,"ne","","",189,{"inputs":[{"name":"self"},{"name":"parseboolerror"}],"output":{"name":"bool"}}],[11,"fmt","","",189,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",190,{"inputs":[{"name":"self"},{"name":"utf8error"}],"output":{"name":"bool"}}],[11,"ne","","",190,{"inputs":[{"name":"self"},{"name":"utf8error"}],"output":{"name":"bool"}}],[11,"clone","","",190,{"inputs":[{"name":"self"}],"output":{"name":"utf8error"}}],[11,"fmt","","",190,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"valid_up_to","","Returns the index in the given string up to which valid UTF-8 was verified.",190,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"error_len","","Provide more information about the failure:",190,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"fmt","","",190,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",191,{"inputs":[{"name":"self"}],"output":{"name":"chars"}}],[11,"fmt","","",191,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",191,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"count","","",191,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",191,null],[11,"last","","",191,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next_back","","",191,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"as_str","","View the underlying data as a subslice of the original data.",191,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"clone","","",192,{"inputs":[{"name":"self"}],"output":{"name":"charindices"}}],[11,"fmt","","",192,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",192,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",192,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",192,null],[11,"last","","",192,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",192,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"as_str","","View the underlying data as a subslice of the original data.",192,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"clone","","",193,{"inputs":[{"name":"self"}],"output":{"name":"bytes"}}],[11,"fmt","","",193,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",193,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"size_hint","","",193,null],[11,"count","","",193,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",193,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",193,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"all","","",193,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"any","","",193,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"find","","",193,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"position","","",193,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",193,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next_back","","",193,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"rfind","","",193,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"len","","",193,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",193,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",194,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",194,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",194,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",195,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",195,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",195,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"next_back","","",194,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",195,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"fmt","","",196,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",196,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",196,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",197,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",197,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",197,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"next_back","","",196,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",197,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"fmt","","",198,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",198,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",198,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",199,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",199,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",199,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",200,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",200,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",200,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",201,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",201,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",201,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"next_back","","",200,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",201,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"fmt","","",202,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",202,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",202,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"fmt","","",203,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",203,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",203,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"next_back","","",202,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",203,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",204,{"inputs":[{"name":"self"}],"output":{"name":"lines"}}],[11,"fmt","","",204,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",204,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"size_hint","","",204,null],[11,"next_back","","",204,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","","",205,{"inputs":[{"name":"self"}],"output":{"name":"linesany"}}],[11,"fmt","","",205,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",205,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"size_hint","","",205,null],[11,"next_back","","",205,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[0,"hash","core","Generic hashing support.",null,null],[3,"SipHasher","core::hash","An implementation of SipHash 2-4.",null,null],[3,"BuildHasherDefault","","Used to create a default [`BuildHasher`] instance for types that implement [`Hasher`] and [`Default`].",null,null],[11,"fmt","","",206,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",206,{"inputs":[{"name":"self"}],"output":{"name":"siphasher"}}],[11,"default","","",206,{"inputs":[],"output":{"name":"siphasher"}}],[11,"new","","Creates a new `SipHasher` with the two initial keys set to 0.",206,{"inputs":[],"output":{"name":"siphasher"}}],[11,"new_with_keys","","Creates a `SipHasher` that is keyed off the provided keys.",206,{"inputs":[{"name":"u64"},{"name":"u64"}],"output":{"name":"siphasher"}}],[11,"write","","",206,null],[11,"finish","","",206,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[8,"Hash","","A hashable type.",null,null],[10,"hash","","Feeds this value into the given [`Hasher`].",207,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"hash_slice","","Feeds a slice of this type into the given [`Hasher`].",207,null],[8,"Hasher","","A trait for hashing an arbitrary stream of bytes.",null,null],[10,"finish","","Returns the hash value for the values written so far.",208,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"write","","Writes some data into this `Hasher`.",208,null],[11,"write_u8","","Writes a single `u8` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"write_u16","","Writes a single `u16` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"write_u32","","Writes a single `u32` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"write_u64","","Writes a single `u64` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"write_u128","","Writes a single `u128` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"u128"}],"output":null}],[11,"write_usize","","Writes a single `usize` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"write_i8","","Writes a single `i8` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"write_i16","","Writes a single `i16` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"write_i32","","Writes a single `i32` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"write_i64","","Writes a single `i64` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"write_i128","","Writes a single `i128` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"i128"}],"output":null}],[11,"write_isize","","Writes a single `isize` into this hasher.",208,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[8,"BuildHasher","","A trait for creating instances of [`Hasher`].",null,null],[16,"Hasher","","Type of the hasher that will be created.",209,null],[10,"build_hasher","","Creates a new hasher.",209,null],[11,"fmt","","",210,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"build_hasher","","",210,{"inputs":[{"name":"self"}],"output":{"name":"h"}}],[11,"clone","","",210,{"inputs":[{"name":"self"}],"output":{"name":"buildhasherdefault"}}],[11,"default","","",210,{"inputs":[],"output":{"name":"buildhasherdefault"}}],[0,"fmt","core","Utilities for formatting and printing strings.",null,null],[3,"DebugStruct","core::fmt","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugTuple","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugSet","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugList","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugMap","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"Error","","The error type which is returned from formatting a message into a stream.",null,null],[3,"Formatter","","A struct to represent both where to emit formatting strings to and how they should be formatted. A mutable version of this is passed to all formatting traits.",null,null],[3,"Arguments","","This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.",null,null],[4,"Alignment","","Possible alignments returned by `Formatter::align`",null,null],[13,"Left","","Indication that contents should be left-aligned.",211,null],[13,"Right","","Indication that contents should be right-aligned.",211,null],[13,"Center","","Indication that contents should be center-aligned.",211,null],[13,"Unknown","","No alignment was requested.",211,null],[5,"write","","The `write` function takes an output stream, and an `Arguments` struct that can be precompiled with the `format_args!` macro.",null,{"inputs":[{"name":"write"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"field","","Adds a new field to the generated struct output.",212,{"inputs":[{"name":"self"},{"name":"str"},{"name":"debug"}],"output":{"name":"debugstruct"}}],[11,"finish","","Finishes output and returns any error encountered.",212,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"field","","Adds a new field to the generated tuple struct output.",213,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debugtuple"}}],[11,"finish","","Finishes output and returns any error encountered.",213,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"entry","","Adds a new entry to the set output.",214,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debugset"}}],[11,"entries","","Adds the contents of an iterator of entries to the set output.",214,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debugset"}}],[11,"finish","","Finishes output and returns any error encountered.",214,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"entry","","Adds a new entry to the list output.",215,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debuglist"}}],[11,"entries","","Adds the contents of an iterator of entries to the list output.",215,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debuglist"}}],[11,"finish","","Finishes output and returns any error encountered.",215,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"entry","","Adds a new entry to the map output.",216,{"inputs":[{"name":"self"},{"name":"debug"},{"name":"debug"}],"output":{"name":"debugmap"}}],[11,"entries","","Adds the contents of an iterator of entries to the map output.",216,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debugmap"}}],[11,"finish","","Finishes output and returns any error encountered.",216,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[6,"Result","","The type returned by formatter methods.",null,null],[8,"Write","","A collection of methods that are required to format a message into a stream.",null,null],[10,"write_str","","Writes a slice of bytes into this writer, returning whether the write succeeded.",217,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"result"}}],[11,"write_char","","Writes a [`char`] into this writer, returning whether the write succeeded.",217,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"result"}}],[11,"write_fmt","","Glue for usage of the [`write!`] macro with implementors of this trait.",217,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[8,"Debug","","`?` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",218,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"Display","","Format trait for an empty format, `{}`.",null,null],[10,"fmt","","Formats the value using the given formatter.",219,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"Octal","","`o` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",220,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"Binary","","`b` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",221,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"LowerHex","","`x` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",222,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"UpperHex","","`X` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",223,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"Pointer","","`p` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",224,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"LowerExp","","`e` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",225,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[8,"UpperExp","","`E` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",226,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",211,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",227,{"inputs":[{"name":"self"}],"output":{"name":"error"}}],[11,"fmt","","",227,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","",227,{"inputs":[],"output":{"name":"error"}}],[11,"hash","","",227,null],[11,"cmp","","",227,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"name":"ordering"}}],[11,"eq","","",227,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",227,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"clone","","",228,{"inputs":[{"name":"self"}],"output":{"name":"arguments"}}],[11,"fmt","","",228,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",228,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"pad_integral","","Performs the correct padding for an integer which has already been emitted into a str. The str should not contain the sign for the integer, that will be added by this method.",229,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"str"},{"name":"str"}],"output":{"name":"result"}}],[11,"pad","","This function takes a string slice and emits it to the internal buffer after applying the relevant formatting flags specified. The flags recognized for generic strings are:",229,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"result"}}],[11,"write_str","","Writes some data to the underlying buffer contained within this formatter.",229,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"result"}}],[11,"write_fmt","","Writes some formatted information into this instance",229,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"flags","","Flags for formatting",229,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"fill","","Character used as 'fill' whenever there is alignment",229,{"inputs":[{"name":"self"}],"output":{"name":"char"}}],[11,"align","","Flag indicating what form of alignment was requested",229,{"inputs":[{"name":"self"}],"output":{"name":"alignment"}}],[11,"width","","Optionally specified integer width that the output should be.",229,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"precision","","Optionally specified precision for numeric types.",229,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"sign_plus","","Determines if the `+` flag was specified.",229,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"sign_minus","","Determines if the `-` flag was specified.",229,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"alternate","","Determines if the `#` flag was specified.",229,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"sign_aware_zero_pad","","Determines if the `0` flag was specified.",229,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"debug_struct","","Creates a [`DebugStruct`] builder designed to assist with creation of [`fmt::Debug`] implementations for structs.",229,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"debugstruct"}}],[11,"debug_tuple","","Creates a `DebugTuple` builder designed to assist with creation of `fmt::Debug` implementations for tuple structs.",229,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"debugtuple"}}],[11,"debug_list","","Creates a `DebugList` builder designed to assist with creation of `fmt::Debug` implementations for list-like structures.",229,{"inputs":[{"name":"self"}],"output":{"name":"debuglist"}}],[11,"debug_set","","Creates a `DebugSet` builder designed to assist with creation of `fmt::Debug` implementations for set-like structures.",229,{"inputs":[{"name":"self"}],"output":{"name":"debugset"}}],[11,"debug_map","","Creates a `DebugMap` builder designed to assist with creation of `fmt::Debug` implementations for map-like structures.",229,{"inputs":[{"name":"self"}],"output":{"name":"debugmap"}}],[11,"write_str","","",229,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"result"}}],[11,"write_char","","",229,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"result"}}],[11,"write_fmt","","",229,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"fmt","","",227,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","core::marker","",24,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","core::cell","",104,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",107,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",108,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",109,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",110,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"time","core","Temporal quantification.",null,null],[3,"Duration","core::time","A `Duration` type to represent a span of time, typically used for system timeouts.",null,null],[11,"clone","","",230,{"inputs":[{"name":"self"}],"output":{"name":"duration"}}],[11,"eq","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"ne","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"le","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"gt","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"ge","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"cmp","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"ordering"}}],[11,"fmt","","",230,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",230,null],[11,"default","","",230,{"inputs":[],"output":{"name":"duration"}}],[11,"new","","Creates a new `Duration` from the specified number of whole seconds and additional nanoseconds.",230,{"inputs":[{"name":"u64"},{"name":"u32"}],"output":{"name":"duration"}}],[11,"from_secs","","Creates a new `Duration` from the specified number of whole seconds.",230,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"from_millis","","Creates a new `Duration` from the specified number of milliseconds.",230,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"from_micros","","Creates a new `Duration` from the specified number of microseconds.",230,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"from_nanos","","Creates a new `Duration` from the specified number of nanoseconds.",230,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"as_secs","","Returns the number of whole seconds contained by this `Duration`.",230,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"subsec_millis","","Returns the fractional part of this `Duration`, in milliseconds.",230,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"subsec_micros","","Returns the fractional part of this `Duration`, in microseconds.",230,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"subsec_nanos","","Returns the fractional part of this `Duration`, in nanoseconds.",230,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"checked_add","","Checked `Duration` addition. Computes `self + other`, returning [`None`] if overflow occurred.",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"generics":["duration"],"name":"option"}}],[11,"checked_sub","","Checked `Duration` subtraction. Computes `self - other`, returning [`None`] if the result would be negative or if overflow occurred.",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"generics":["duration"],"name":"option"}}],[11,"checked_mul","","Checked `Duration` multiplication. Computes `self * other`, returning [`None`] if overflow occurred.",230,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["duration"],"name":"option"}}],[11,"checked_div","","Checked `Duration` division. Computes `self / other`, returning [`None`] if `other == 0`.",230,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["duration"],"name":"option"}}],[11,"add","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"duration"}}],[11,"add_assign","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":null}],[11,"sub","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"duration"}}],[11,"sub_assign","","",230,{"inputs":[{"name":"self"},{"name":"duration"}],"output":null}],[11,"mul","","",230,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"duration"}}],[11,"mul_assign","","",230,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"div","","",230,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"duration"}}],[11,"div_assign","","",230,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"sum","","",230,{"inputs":[{"name":"i"}],"output":{"name":"duration"}}],[11,"sum","","",230,{"inputs":[{"name":"i"}],"output":{"name":"duration"}}],[0,"heap","core","",null,null],[3,"Excess","core::heap","Represents the combination of a starting address and a total capacity of the returned block.",null,null],[12,"0","","",231,null],[12,"1","","",231,null],[3,"Layout","","Layout of a block of memory.",null,null],[3,"CannotReallocInPlace","","The `CannotReallocInPlace` error is used when `grow_in_place` or `shrink_in_place` were unable to reuse the given memory block for a requested layout.",null,null],[4,"AllocErr","","The `AllocErr` error specifies whether an allocation failure is specifically due to resource exhaustion or if it is due to something wrong when combining the given input arguments with this allocator.",null,null],[13,"Exhausted","","Error due to hitting some resource limit or otherwise running out of memory. This condition strongly implies that some series of deallocations would allow a subsequent reissuing of the original allocation request to succeed.",232,null],[12,"request","core::heap::AllocErr","",232,null],[13,"Unsupported","core::heap","Error due to allocator being fundamentally incapable of satisfying the original request. This condition implies that such an allocation request will never succeed on the given allocator, regardless of environment, memory pressure, or other contextual conditions.",232,null],[12,"details","core::heap::AllocErr","",232,null],[4,"CollectionAllocErr","core::heap","Augments `AllocErr` with a CapacityOverflow variant.",null,null],[13,"CapacityOverflow","","Error due to the computed capacity exceeding the collection's maximum (usually `isize::MAX` bytes).",233,null],[13,"AllocErr","","Error due to the allocator (see the `AllocErr` type's docs).",233,null],[8,"Alloc","","An implementation of `Alloc` can allocate, reallocate, and deallocate arbitrary blocks of data described via `Layout`.",null,null],[10,"alloc","","Returns a pointer meeting the size and alignment guarantees of `layout`.",234,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[10,"dealloc","","Deallocate the memory referenced by `ptr`.",234,null],[11,"oom","","Allocator-specific method for signaling an out-of-memory condition.",234,null],[11,"usable_size","","Returns bounds on the guaranteed usable size of a successful allocation created with the specified `layout`.",234,null],[11,"realloc","","Returns a pointer suitable for holding data described by `new_layout`, meeting its size and alignment guarantees. To accomplish this, this may extend or shrink the allocation referenced by `ptr` to fit `new_layout`.",234,null],[11,"alloc_zeroed","","Behaves like `alloc`, but also ensures that the contents are set to zero before being returned.",234,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"alloc_excess","","Behaves like `alloc`, but also returns the whole size of the returned block. For some `layout` inputs, like arrays, this may include extra storage usable for additional data.",234,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["excess","allocerr"],"name":"result"}}],[11,"realloc_excess","","Behaves like `realloc`, but also returns the whole size of the returned block. For some `layout` inputs, like arrays, this may include extra storage usable for additional data.",234,null],[11,"grow_in_place","","Attempts to extend the allocation referenced by `ptr` to fit `new_layout`.",234,null],[11,"shrink_in_place","","Attempts to shrink the allocation referenced by `ptr` to fit `new_layout`.",234,null],[11,"alloc_one","","Allocates a block suitable for holding an instance of `T`.",234,{"inputs":[{"name":"self"}],"output":{"generics":["nonnull","allocerr"],"name":"result"}}],[11,"dealloc_one","","Deallocates a block suitable for holding an instance of `T`.",234,{"inputs":[{"name":"self"},{"name":"nonnull"}],"output":null}],[11,"alloc_array","","Allocates a block suitable for holding `n` instances of `T`.",234,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["nonnull","allocerr"],"name":"result"}}],[11,"realloc_array","","Reallocates a block previously suitable for holding `n_old` instances of `T`, returning a block suitable for holding `n_new` instances of `T`.",234,{"inputs":[{"name":"self"},{"name":"nonnull"},{"name":"usize"},{"name":"usize"}],"output":{"generics":["nonnull","allocerr"],"name":"result"}}],[11,"dealloc_array","","Deallocates a block suitable for holding `n` instances of `T`.",234,{"inputs":[{"name":"self"},{"name":"nonnull"},{"name":"usize"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"fmt","","",231,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",235,{"inputs":[{"name":"self"}],"output":{"name":"layout"}}],[11,"fmt","","",235,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",235,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"name":"bool"}}],[11,"ne","","",235,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"name":"bool"}}],[11,"from_size_align","","Constructs a `Layout` from a given `size` and `align`, or returns `None` if any of the following conditions are not met:",235,{"inputs":[{"name":"usize"},{"name":"usize"}],"output":{"generics":["layout"],"name":"option"}}],[11,"from_size_align_unchecked","","Creates a layout, bypassing all checks.",235,{"inputs":[{"name":"usize"},{"name":"usize"}],"output":{"name":"layout"}}],[11,"size","","The minimum size in bytes for a memory block of this layout.",235,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"align","","The minimum byte alignment for a memory block of this layout.",235,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"new","","Constructs a `Layout` suitable for holding a value of type `T`.",235,{"inputs":[],"output":{"name":"self"}}],[11,"for_value","","Produces layout describing a record that could be used to allocate backing structure for `T` (which could be a trait or other unsized type like a slice).",235,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"align_to","","Creates a layout describing the record that can hold a value of the same layout as `self`, but that also is aligned to alignment `align` (measured in bytes).",235,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"padding_needed_for","","Returns the amount of padding we must insert after `self` to ensure that the following address will satisfy `align` (measured in bytes).",235,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"repeat","","Creates a layout describing the record for `n` instances of `self`, with a suitable amount of padding between each to ensure that each instance is given its requested size and alignment. On success, returns `(k, offs)` where `k` is the layout of the array and `offs` is the distance between the start of each element in the array.",235,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"extend","","Creates a layout describing the record for `self` followed by `next`, including any necessary padding to ensure that `next` will be properly aligned. Note that the result layout will satisfy the alignment properties of both `self` and `next`.",235,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"option"}}],[11,"repeat_packed","","Creates a layout describing the record for `n` instances of `self`, with no padding between each instance.",235,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"extend_packed","","Creates a layout describing the record for `self` followed by `next` with no additional padding between the two. Since no padding is inserted, the alignment of `next` is irrelevant, and is not incorporated at all into the resulting layout.",235,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"option"}}],[11,"array","","Creates a layout describing the record for a `[T; n]`.",235,{"inputs":[{"name":"usize"}],"output":{"name":"option"}}],[11,"clone","","",232,{"inputs":[{"name":"self"}],"output":{"name":"allocerr"}}],[11,"eq","","",232,{"inputs":[{"name":"self"},{"name":"allocerr"}],"output":{"name":"bool"}}],[11,"ne","","",232,{"inputs":[{"name":"self"},{"name":"allocerr"}],"output":{"name":"bool"}}],[11,"fmt","","",232,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"invalid_input","","",232,{"inputs":[{"name":"str"}],"output":{"name":"self"}}],[11,"is_memory_exhausted","","",232,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_request_unsupported","","",232,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"description","","",232,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"fmt","","",232,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",236,{"inputs":[{"name":"self"}],"output":{"name":"cannotreallocinplace"}}],[11,"eq","","",236,{"inputs":[{"name":"self"},{"name":"cannotreallocinplace"}],"output":{"name":"bool"}}],[11,"fmt","","",236,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",236,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"fmt","","",236,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",233,{"inputs":[{"name":"self"}],"output":{"name":"collectionallocerr"}}],[11,"eq","","",233,{"inputs":[{"name":"self"},{"name":"collectionallocerr"}],"output":{"name":"bool"}}],[11,"ne","","",233,{"inputs":[{"name":"self"},{"name":"collectionallocerr"}],"output":{"name":"bool"}}],[11,"fmt","","",233,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",233,{"inputs":[{"name":"allocerr"}],"output":{"name":"self"}}],[0,"simd","core","Platform independent SIMD vector types and operations.",null,null],[3,"i8x2","core::simd","A 16-bit wide vector with 2 `i8` lanes.",null,null],[3,"u8x2","","A 16-bit wide vector with 2 `u8` lanes.",null,null],[3,"b8x2","","A 16-bit wide vector with 2 `bool` lanes.",null,null],[3,"i16x2","","A 32-bit wide vector with 2 `i16` lanes.",null,null],[3,"u16x2","","A 32-bit wide vector with 2 `u16` lanes.",null,null],[3,"i8x4","","A 32-bit wide vector with 4 `i8` lanes.",null,null],[3,"u8x4","","A 32-bit wide vector with 4 `u8` lanes.",null,null],[3,"b8x4","","A 32-bit wide vector with 4 `bool` lanes.",null,null],[3,"i8x8","","A 64-bit vector with 8 `i8` lanes.",null,null],[3,"u8x8","","A 64-bit vector with 8 `u8` lanes.",null,null],[3,"b8x8","","A 64-bit vector with 8 `bool` lanes.",null,null],[3,"i16x4","","A 64-bit vector with 4 `i16` lanes.",null,null],[3,"u16x4","","A 64-bit vector with 4 `u16` lanes.",null,null],[3,"i32x2","","A 64-bit vector with 2 `i32` lanes.",null,null],[3,"u32x2","","A 64-bit vector with 2 `u32` lanes.",null,null],[3,"f32x2","","A 64-bit vector with 2 `f32` lanes.",null,null],[3,"i8x16","","A 128-bit vector with 16 `i8` lanes.",null,null],[3,"u8x16","","A 128-bit vector with 16 `u8` lanes.",null,null],[3,"b8x16","","A 128-bit vector with 16 `bool` lanes.",null,null],[3,"i16x8","","A 128-bit vector with 8 `i16` lanes.",null,null],[3,"u16x8","","A 128-bit vector with 8 `u16` lanes.",null,null],[3,"i32x4","","A 128-bit vector with 4 `i32` lanes.",null,null],[3,"u32x4","","A 128-bit vector with 4 `u32` lanes.",null,null],[3,"f32x4","","A 128-bit vector with 4 `f32` lanes.",null,null],[3,"i64x2","","A 128-bit vector with 2 `u64` lanes.",null,null],[3,"u64x2","","A 128-bit vector with 2 `u64` lanes.",null,null],[3,"f64x2","","A 128-bit vector with 2 `f64` lanes.",null,null],[3,"i8x32","","A 256-bit vector with 32 `i8` lanes.",null,null],[3,"u8x32","","A 256-bit vector with 32 `u8` lanes.",null,null],[3,"b8x32","","A 256-bit vector with 32 `bool` lanes.",null,null],[3,"i16x16","","A 256-bit vector with 16 `i16` lanes.",null,null],[3,"u16x16","","A 256-bit vector with 16 `u16` lanes.",null,null],[3,"i32x8","","A 256-bit vector with 8 `i32` lanes.",null,null],[3,"u32x8","","A 256-bit vector with 8 `u32` lanes.",null,null],[3,"f32x8","","A 256-bit vector with 8 `f32` lanes.",null,null],[3,"i64x4","","A 256-bit vector with 4 `i64` lanes.",null,null],[3,"u64x4","","A 256-bit vector with 4 `u64` lanes.",null,null],[3,"f64x4","","A 256-bit vector with 4 `f64` lanes.",null,null],[3,"i8x64","","A 512-bit vector with 64 `i8` lanes.",null,null],[3,"u8x64","","A 512-bit vector with 64 `u8` lanes.",null,null],[3,"b8x64","","A 512-bit vector with 64 `bool` lanes.",null,null],[3,"i16x32","","A 512-bit vector with 32 `i16` lanes.",null,null],[3,"u16x32","","A 512-bit vector with 32 `u16` lanes.",null,null],[3,"i32x16","","A 512-bit vector with 16 `i32` lanes.",null,null],[3,"u32x16","","A 512-bit vector with 16 `u32` lanes.",null,null],[3,"f32x16","","A 512-bit vector with 16 `f32` lanes.",null,null],[3,"i64x8","","A 512-bit vector with 8 `i64` lanes.",null,null],[3,"u64x8","","A 512-bit vector with 8 `u64` lanes.",null,null],[3,"f64x8","","A 512-bit vector with 8 `f64` lanes.",null,null],[8,"FromBits","","Safe lossless bitwise conversion from `T` to `Self`.",null,null],[10,"from_bits","","Safe lossless bitwise from `T` to `Self`.",237,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[8,"IntoBits","","Safe lossless bitwise conversion from `Self` to `T`.",null,null],[10,"into_bits","","Safe lossless bitwise transmute from `self` to `T`.",238,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[0,"arch","core","Platform dependent vendor intrinsics.",null,null],[0,"x86","core::arch","Platform-specific intrinsics for the `x86` platform.",null,null],[3,"__m64","core::arch::x86","64-bit wide integer vector type, x86-specific",null,null],[3,"__m128i","","128-bit wide integer vector type, x86-specific",null,null],[3,"__m128","","128-bit wide set of four `f32` types, x86-specific",null,null],[3,"__m128d","","128-bit wide set of two `f64` types, x86-specific",null,null],[3,"__m256i","","256-bit wide integer vector type, x86-specific",null,null],[3,"__m256","","256-bit wide set of eight `f32` types, x86-specific",null,null],[3,"__m256d","","256-bit wide set of four `f64` types, x86-specific",null,null],[3,"CpuidResult","","Result of the `cpuid` instruction.",null,null],[12,"eax","","EAX register.",239,null],[12,"ebx","","EBX register.",239,null],[12,"ecx","","ECX register.",239,null],[12,"edx","","EDX register.",239,null],[5,"__readeflags","","Reads EFLAGS.",null,{"inputs":[],"output":{"name":"u32"}}],[5,"__writeeflags","","Write EFLAGS.",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_bswap","","Return an integer with the reversed byte order of x",null,{"inputs":[{"name":"i32"}],"output":{"name":"i32"}}],[5,"_rdtsc","","Reads the current value of the processor’s time-stamp counter.",null,{"inputs":[],"output":{"name":"i64"}}],[5,"__rdtscp","","Reads the current value of the processor’s time-stamp counter and the `IA32_TSC_AUX MSR`.",null,null],[5,"__cpuid_count","","Returns the result of the `cpuid` instruction for a given `leaf` (`EAX`) and `sub_leaf` (`ECX`).",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"cpuidresult"}}],[5,"__cpuid","","See `__cpuid_count`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"cpuidresult"}}],[5,"has_cpuid","","Does the host support the `cpuid` instruction?",null,{"inputs":[],"output":{"name":"bool"}}],[5,"__get_cpuid_max","","Returns the highest-supported `leaf` (`EAX`) and sub-leaf (`ECX`) `cpuid` values.",null,null],[5,"_xsave","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xrstor","","Perform a full or partial restore of the enabled processor states using the state information stored in memory at `mem_addr`.",null,null],[5,"_xsetbv","","Copy 64-bits from `val` to the extended control register (`XCR`) specified by `a`.",null,{"inputs":[{"name":"u32"},{"name":"u64"}],"output":null}],[5,"_xgetbv","","Reads the contents of the extended control register `XCR` specified in `xcr_no`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u64"}}],[5,"_xsaveopt","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xsavec","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xsaves","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`",null,null],[5,"_xrstors","","Perform a full or partial restore of the enabled processor states using the state information stored in memory at `mem_addr`.",null,null],[5,"_mm_add_ss","","Adds the first component of `a` and `b`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_add_ps","","Adds __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sub_ss","","Subtracts the first component of `b` from `a`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sub_ps","","Subtracts __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_mul_ss","","Multiplies the first component of `a` and `b`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_mul_ps","","Multiplies __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_div_ss","","Divides the first component of `b` by `a`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_div_ps","","Divides __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sqrt_ss","","Return the square root of the first single-precision (32-bit) floating-point element in `a`, the other elements are unchanged.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sqrt_ps","","Return the square root of packed single-precision (32-bit) floating-point elements in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rcp_ss","","Return the approximate reciprocal of the first single-precision (32-bit) floating-point element in `a`, the other elements are unchanged.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rcp_ps","","Return the approximate reciprocal of packed single-precision (32-bit) floating-point elements in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rsqrt_ss","","Return the approximate reciprocal square root of the fist single-precision (32-bit) floating-point elements in `a`, the other elements are unchanged.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rsqrt_ps","","Return the approximate reciprocal square root of packed single-precision (32-bit) floating-point elements in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_min_ss","","Compare the first single-precision (32-bit) floating-point element of `a` and `b`, and return the minimum value in the first element of the return value, the other elements are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_min_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return the corresponding minimum values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_max_ss","","Compare the first single-precision (32-bit) floating-point element of `a` and `b`, and return the maximum value in the first element of the return value, the other elements are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_max_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return the corresponding maximum values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_and_ps","","Bitwise AND of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_andnot_ps","","Bitwise AND-NOT of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_or_ps","","Bitwise OR of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_xor_ps","","Bitwise exclusive OR of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpeq_ss","","Compare the lowest `f32` of both inputs for equality. The lowest 32 bits of the result will be `0xffffffff` if the two inputs are equal, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmplt_ss","","Compare the lowest `f32` of both inputs for less than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is less than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmple_ss","","Compare the lowest `f32` of both inputs for less than or equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is less than or equal `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpgt_ss","","Compare the lowest `f32` of both inputs for greater than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is greater than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpge_ss","","Compare the lowest `f32` of both inputs for greater than or equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is greater than or equal `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpneq_ss","","Compare the lowest `f32` of both inputs for inequality. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not equal to `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnlt_ss","","Compare the lowest `f32` of both inputs for not-less-than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not less than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnle_ss","","Compare the lowest `f32` of both inputs for not-less-than-or-equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not less than or equal to `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpngt_ss","","Compare the lowest `f32` of both inputs for not-greater-than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not greater than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnge_ss","","Compare the lowest `f32` of both inputs for not-greater-than-or-equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not greater than or equal to `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpord_ss","","Check if the lowest `f32` of both inputs are ordered. The lowest 32 bits of the result will be `0xffffffff` if neither of `a.extract(0)` or `b.extract(0)` is a NaN, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpunord_ss","","Check if the lowest `f32` of both inputs are unordered. The lowest 32 bits of the result will be `0xffffffff` if any of `a.extract(0)` or `b.extract(0)` is a NaN, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpeq_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input elements were equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmplt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is less than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmple_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is less than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpgt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is greater than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpge_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is greater than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpneq_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input elements are not equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnlt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not less than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnle_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not less than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpngt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not greater than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnge_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not greater than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpord_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. Returns four floats that have one of two possible bit patterns. The element in the output vector will be `0xffffffff` if the input elements in `a` and `b` are ordered (i.e., neither of them is a NaN), or 0 otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpunord_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. Returns four floats that have one of two possible bit patterns. The element in the output vector will be `0xffffffff` if the input elements in `a` and `b` are unordered (i.e., at least on of them is a NaN), or 0 otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_comieq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comilt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comile_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than or equal to the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comigt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comige_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than or equal to the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comineq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are not equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomieq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are equal, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomilt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomile_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than or equal to the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomigt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomige_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than or equal to the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomineq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are not equal, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvtss_si32","","Convert the lowest 32 bit float in the input vector to a 32 bit integer.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvt_ss2si","","Alias for `_mm_cvtss_si32`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvttss_si32","","Convert the lowest 32 bit float in the input vector to a 32 bit integer with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvtt_ss2si","","Alias for `_mm_cvttss_si32`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvtss_f32","","Extract the lowest 32 bit float from the input vector.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"f32"}}],[5,"_mm_cvtsi32_ss","","Convert a 32 bit integer to a 32 bit float. The result vector is the input vector `a` with the lowest 32 bit float replaced by the converted integer.",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_cvt_si2ss","","Alias for `_mm_cvtsi32_ss`.",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_set_ss","","Construct a `__m128` with the lowest element set to `a` and the rest set to zero.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_set1_ps","","Construct a `__m128` with all element set to `a`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_set_ps1","","Alias for `_mm_set1_ps`",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_set_ps","","Construct a `__m128` from four floating point values highest to lowest.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_setr_ps","","Construct a `__m128` from four floating point values lowest to highest.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_setzero_ps","","Construct a `__m128` with all elements initialized to zero.",null,{"inputs":[],"output":{"name":"__m128"}}],[5,"_mm_shuffle_ps","","Shuffle packed single-precision (32-bit) floating-point elements in `a` and `b` using `mask`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"u32"}],"output":{"name":"__m128"}}],[5,"_mm_unpackhi_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the higher half of `a` and `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_unpacklo_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the lower half of `a` and `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_movehl_ps","","Combine higher half of `a` and `b`. The highwe half of `b` occupies the lower half of result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_movelh_ps","","Combine lower half of `a` and `b`. The lower half of `b` occupies the higher half of result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_movemask_ps","","Return a mask of the most significant bit of each element in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_loadh_pi","","Set the upper two single-precision floating-point values with 64 bits of data loaded from the address `p`; the lower two values are passed through from `a`.",null,null],[5,"_mm_loadl_pi","","Load two floats from `p` into the lower half of a `__m128`. The upper half is copied from the upper half of `a`.",null,null],[5,"_mm_load_ss","","Construct a `__m128` with the lowest element read from `p` and the other elements set to zero.",null,null],[5,"_mm_load1_ps","","Construct a `__m128` by duplicating the value read from `p` into all elements.",null,null],[5,"_mm_load_ps1","","Alias for `_mm_load1_ps`",null,null],[5,"_mm_load_ps","","Load four `f32` values from aligned memory into a `__m128`. If the pointer is not aligned to a 128-bit boundary (16 bytes) a general protection fault will be triggered (fatal program crash).",null,null],[5,"_mm_loadu_ps","","Load four `f32` values from memory into a `__m128`. There are no restrictions on memory alignment. For aligned memory `_mm_load_ps` may be faster.",null,null],[5,"_mm_loadr_ps","","Load four `f32` values from aligned memory into a `__m128` in reverse order.",null,null],[5,"_mm_storeh_pi","","Store the upper half of `a` (64 bits) into memory.",null,null],[5,"_mm_storel_pi","","Store the lower half of `a` (64 bits) into memory.",null,null],[5,"_mm_store_ss","","Store the lowest 32 bit float of `a` into memory.",null,null],[5,"_mm_store1_ps","","Store the lowest 32 bit float of `a` repeated four times into aligned memory.",null,null],[5,"_mm_store_ps1","","Alias for `_mm_store1_ps`",null,null],[5,"_mm_store_ps","","Store four 32-bit floats into aligned memory.",null,null],[5,"_mm_storeu_ps","","Store four 32-bit floats into memory. There are no restrictions on memory alignment. For aligned memory `_mm_store_ps` may be faster.",null,null],[5,"_mm_storer_ps","","Store four 32-bit floats into aligned memory in reverse order.",null,null],[5,"_mm_move_ss","","Return a `__m128` with the first component from `b` and the remaining components from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sfence","","Perform a serializing operation on all store-to-memory instructions that were issued prior to this instruction.",null,{"inputs":[],"output":null}],[5,"_mm_getcsr","","Get the unsigned 32-bit value of the MXCSR control and status register.",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_mm_setcsr","","Set the MXCSR register with the 32-bit unsigned integer value.",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_GET_EXCEPTION_MASK","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_GET_EXCEPTION_STATE","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_GET_FLUSH_ZERO_MODE","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_GET_ROUNDING_MODE","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_SET_EXCEPTION_MASK","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_SET_EXCEPTION_STATE","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_SET_FLUSH_ZERO_MODE","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_SET_ROUNDING_MODE","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_mm_prefetch","","Fetch the cache line that contains address `p` using the given `strategy`.",null,null],[5,"_mm_undefined_ps","","Return vector of type __m128 with undefined elements.",null,{"inputs":[],"output":{"name":"__m128"}}],[5,"_MM_TRANSPOSE4_PS","","Transpose the 4x4 matrix formed by 4 rows of __m128 in place.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"__m128"},{"name":"__m128"}],"output":null}],[5,"_mm_stream_ps","","Stores `a` into the memory at `mem_addr` using a non-temporal memory hint.",null,null],[5,"_mm_stream_pi","","Store 64-bits of integer data from a into memory using a non-temporal memory hint.",null,null],[5,"_mm_max_pi16","","Compares the packed 16-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pmaxsw","","Compares the packed 16-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_max_pu8","","Compares the packed 8-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pmaxub","","Compares the packed 8-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_min_pi16","","Compares the packed 16-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pminsw","","Compares the packed 16-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_min_pu8","","Compares the packed 8-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pminub","","Compares the packed 8-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_mulhi_pu16","","Multiplies packed 16-bit unsigned integer values and writes the high-order 16 bits of each 32-bit product to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pmulhuw","","Multiplies packed 16-bit unsigned integer values and writes the high-order 16 bits of each 32-bit product to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_avg_pu8","","Computes the rounded averages of the packed unsigned 8-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pavgb","","Computes the rounded averages of the packed unsigned 8-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_avg_pu16","","Computes the rounded averages of the packed unsigned 16-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pavgw","","Computes the rounded averages of the packed unsigned 16-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sad_pu8","","Subtracts the corresponding 8-bit unsigned integer values of the two 64-bit vector operands and computes the absolute value for each of the difference. Then sum of the 8 absolute differences is written to the bits [15:0] of the destination; the remaining bits [63:16] are cleared.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psadbw","","Subtracts the corresponding 8-bit unsigned integer values of the two 64-bit vector operands and computes the absolute value for each of the difference. Then sum of the 8 absolute differences is written to the bits [15:0] of the destination; the remaining bits [63:16] are cleared.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cvtpi32_ps","","Converts two elements of a 64-bit vector of [2 x i32] into two floating point values and writes them to the lower 64-bits of the destination. The remaining higher order elements of the destination are copied from the corresponding elements in the first operand.",null,{"inputs":[{"name":"__m128"},{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvt_pi2ps","","Converts two elements of a 64-bit vector of [2 x i32] into two floating point values and writes them to the lower 64-bits of the destination. The remaining higher order elements of the destination are copied from the corresponding elements in the first operand.",null,{"inputs":[{"name":"__m128"},{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpi8_ps","","Converts the lower 4 8-bit values of `a` into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpu8_ps","","Converts the lower 4 8-bit values of `a` into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpi16_ps","","Converts a 64-bit vector of `i16`s into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpu16_ps","","Converts a 64-bit vector of `i16`s into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpi32x2_ps","","Converts the two 32-bit signed integer values from each 64-bit vector operand of [2 x i32] into a 128-bit vector of [4 x float].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_maskmove_si64","","Conditionally copies the values from each 8-bit element in the first 64-bit integer vector operand to the specified memory location, as specified by the most significant bit in the corresponding element in the second 64-bit integer vector operand.",null,null],[5,"_m_maskmovq","","Conditionally copies the values from each 8-bit element in the first 64-bit integer vector operand to the specified memory location, as specified by the most significant bit in the corresponding element in the second 64-bit integer vector operand.",null,null],[5,"_mm_extract_pi16","","Extracts 16-bit element from a 64-bit vector of [4 x i16] and returns it, as specified by the immediate integer operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_m_pextrw","","Extracts 16-bit element from a 64-bit vector of [4 x i16] and returns it, as specified by the immediate integer operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_insert_pi16","","Copies data from the 64-bit vector of [4 x i16] to the destination, and inserts the lower 16-bits of an integer operand at the 16-bit offset specified by the immediate operand `n`.",null,{"inputs":[{"name":"__m64"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_m_pinsrw","","Copies data from the 64-bit vector of [4 x i16] to the destination, and inserts the lower 16-bits of an integer operand at the 16-bit offset specified by the immediate operand `n`.",null,{"inputs":[{"name":"__m64"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_movemask_pi8","","Takes the most significant bit from each 8-bit element in a 64-bit integer vector to create a 16-bit mask value. Zero-extends the value to 32-bit integer and writes it to the destination.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"i32"}}],[5,"_m_pmovmskb","","Takes the most significant bit from each 8-bit element in a 64-bit integer vector to create a 16-bit mask value. Zero-extends the value to 32-bit integer and writes it to the destination.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"i32"}}],[5,"_mm_shuffle_pi16","","Shuffles the 4 16-bit integers from a 64-bit integer vector to the destination, as specified by the immediate value operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_m_pshufw","","Shuffles the 4 16-bit integers from a 64-bit integer vector to the destination, as specified by the immediate value operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_cvttps_pi32","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtt_ps2pi","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtps_pi32","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvt_ps2pi","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtps_pi16","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 16-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtps_pi8","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 8-bit integers, and returns theem in the lower 4 elements of the result.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_pause","","Provide a hint to the processor that the code sequence is a spin-wait loop.",null,{"inputs":[],"output":null}],[5,"_mm_clflush","","Invalidate and flush the cache line that contains `p` from all levels of the cache hierarchy.",null,null],[5,"_mm_lfence","","Perform a serializing operation on all load-from-memory instructions that were issued prior to this instruction.",null,{"inputs":[],"output":null}],[5,"_mm_mfence","","Perform a serializing operation on all load-from-memory and store-to-memory instructions that were issued prior to this instruction.",null,{"inputs":[],"output":null}],[5,"_mm_add_epi8","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_epi16","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_epi32","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_epi64","","Add packed 64-bit integers in `a` and \"b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epi8","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epi16","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epu8","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epu16","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_avg_epu8","","Average packed unsigned 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_avg_epu16","","Average packed unsigned 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_madd_epi16","","Multiply and then horizontally add signed 16 bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mulhi_epi16","","Multiply the packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mulhi_epu16","","Multiply the packed unsigned 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mullo_epi16","","Multiply the packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mul_epu32","","Multiply the low unsigned 32-bit integers from each packed 64-bit element in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sad_epu8","","Sum the absolute differences of packed unsigned 8-bit integers.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi32","","Subtract packed 32-bit integers in `b` from packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi64","","Subtract packed 64-bit integers in `b` from packed 64-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epu8","","Subtract packed unsigned 8-bit integers in `b` from packed unsigned 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epu16","","Subtract packed unsigned 16-bit integers in `b` from packed unsigned 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_si128","","Shift `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_bslli_si128","","Shift `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_bsrli_si128","","Shift `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_epi16","","Shift packed 16-bit integers in `a` left by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sll_epi16","","Shift packed 16-bit integers in `a` left by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_epi32","","Shift packed 32-bit integers in `a` left by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sll_epi32","","Shift packed 32-bit integers in `a` left by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_epi64","","Shift packed 64-bit integers in `a` left by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sll_epi64","","Shift packed 64-bit integers in `a` left by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srai_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sra_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srai_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sra_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_si128","","Shift `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srl_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srl_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_epi64","","Shift packed 64-bit integers in `a` right by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srl_epi64","","Shift packed 64-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_and_si128","","Compute the bitwise AND of 128 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_andnot_si128","","Compute the bitwise NOT of 128 bits (representing integer data) in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_or_si128","","Compute the bitwise OR of 128 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_xor_si128","","Compute the bitwise XOR of 128 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi8","","Compare packed 8-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi16","","Compare packed 16-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi32","","Compare packed 32-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpgt_epi8","","Compare packed 8-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpgt_epi16","","Compare packed 16-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpgt_epi32","","Compare packed 32-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmplt_epi8","","Compare packed 8-bit integers in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmplt_epi16","","Compare packed 16-bit integers in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmplt_epi32","","Compare packed 32-bit integers in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi32_pd","","Convert the lower two packed 32-bit integers in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128d"}}],[5,"_mm_cvtsi32_sd","","Return `a` with its lower element replaced by `b` after converting it to an `f64`.",null,{"inputs":[{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_cvtepi32_ps","","Convert packed 32-bit integers in `a` to packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128"}}],[5,"_mm_cvtps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsi32_si128","","Return a vector whose lowest element is `a` and all higher elements are `0`.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsi128_si32","","Return the lowest element of `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_set_epi64x","","Set packed 64-bit integers with the supplied values, from highest to lowest.",null,{"inputs":[{"name":"i64"},{"name":"i64"}],"output":{"name":"__m128i"}}],[5,"_mm_set_epi32","","Set packed 32-bit integers with the supplied values.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_set_epi16","","Set packed 16-bit integers with the supplied values.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m128i"}}],[5,"_mm_set_epi8","","Set packed 8-bit integers with the supplied values.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi64x","","Broadcast 64-bit integer `a` to all elements.",null,{"inputs":[{"name":"i64"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi32","","Broadcast 32-bit integer `a` to all elements.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi16","","Broadcast 16-bit integer `a` to all elements.",null,{"inputs":[{"name":"i16"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi8","","Broadcast 8-bit integer `a` to all elements.",null,{"inputs":[{"name":"i8"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi32","","Set packed 32-bit integers with the supplied values in reverse order.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi16","","Set packed 16-bit integers with the supplied values in reverse order.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi8","","Set packed 8-bit integers with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m128i"}}],[5,"_mm_setzero_si128","","Returns a vector with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m128i"}}],[5,"_mm_loadl_epi64","","Load 64-bit integer from memory into first element of returned vector.",null,null],[5,"_mm_load_si128","","Load 128-bits of integer data from memory into a new vector.",null,null],[5,"_mm_loadu_si128","","Load 128-bits of integer data from memory into a new vector.",null,null],[5,"_mm_maskmoveu_si128","","Conditionally store 8-bit integer elements from `a` into memory using `mask`.",null,null],[5,"_mm_store_si128","","Store 128-bits of integer data from `a` into memory.",null,null],[5,"_mm_storeu_si128","","Store 128-bits of integer data from `a` into memory.",null,null],[5,"_mm_storel_epi64","","Store the lower 64-bit integer `a` to a memory location.",null,null],[5,"_mm_stream_si128","","Stores a 128-bit integer vector to a 128-bit aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm_stream_si32","","Stores a 32-bit integer value in the specified memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm_move_epi64","","Return a vector where the low element is extracted from `a` and its upper element is zero.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packs_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using signed saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packs_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using signed saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packus_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using unsigned saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_extract_epi16","","Return the `imm8` element of `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_insert_epi16","","Return a new vector where the `imm8` element of `a` is replaced with `i`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_movemask_epi8","","Return a mask of the most significant bit of each element in `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_shuffle_epi32","","Shuffle 32-bit integers in `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_shufflehi_epi16","","Shuffle 16-bit integers in the high 64 bits of `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_shufflelo_epi16","","Shuffle 16-bit integers in the low 64 bits of `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi8","","Unpack and interleave 8-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi16","","Unpack and interleave 16-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi32","","Unpack and interleave 32-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi64","","Unpack and interleave 64-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi8","","Unpack and interleave 8-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi16","","Unpack and interleave 16-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi32","","Unpack and interleave 32-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi64","","Unpack and interleave 64-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_sd","","Return a new vector with the low element of `a` replaced by the sum of the low elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_add_pd","","Add packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_div_sd","","Return a new vector with the low element of `a` replaced by the result of diving the lower element of `a` by the lower element of `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_div_pd","","Divide packed double-precision (64-bit) floating-point elements in `a` by packed elements in `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_max_sd","","Return a new vector with the low element of `a` replaced by the maximum of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_max_pd","","Return a new vector with the maximum values from corresponding elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_min_sd","","Return a new vector with the low element of `a` replaced by the minimum of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_min_pd","","Return a new vector with the minimum values from corresponding elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_mul_sd","","Return a new vector with the low element of `a` replaced by multiplying the low elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_mul_pd","","Multiply packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sqrt_sd","","Return a new vector with the low element of `a` replaced by the square root of the lower element `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sqrt_pd","","Return a new vector with the square root of each of the values in `a`.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sub_sd","","Return a new vector with the low element of `a` replaced by subtracting the low element by `b` from the low element of `a`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sub_pd","","Subtract packed double-precision (64-bit) floating-point elements in `b` from `a`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_and_pd","","Compute the bitwise AND of packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_andnot_pd","","Compute the bitwise NOT of `a` and then AND with `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_or_pd","","Compute the bitwise OR of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_xor_pd","","Compute the bitwise OR of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpeq_sd","","Return a new vector with the low element of `a` replaced by the equality comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmplt_sd","","Return a new vector with the low element of `a` replaced by the less-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmple_sd","","Return a new vector with the low element of `a` replaced by the less-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpgt_sd","","Return a new vector with the low element of `a` replaced by the greater-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpge_sd","","Return a new vector with the low element of `a` replaced by the greater-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpord_sd","","Return a new vector with the low element of `a` replaced by the result of comparing both of the lower elements of `a` and `b` to `NaN`. If neither are equal to `NaN` then `0xFFFFFFFFFFFFFFFF` is used and `0` otherwise.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpunord_sd","","Return a new vector with the low element of `a` replaced by the result of comparing both of the lower elements of `a` and `b` to `NaN`. If either is equal to `NaN` then `0xFFFFFFFFFFFFFFFF` is used and `0` otherwise.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpneq_sd","","Return a new vector with the low element of `a` replaced by the not-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnlt_sd","","Return a new vector with the low element of `a` replaced by the not-less-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnle_sd","","Return a new vector with the low element of `a` replaced by the not-less-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpngt_sd","","Return a new vector with the low element of `a` replaced by the not-greater-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnge_sd","","Return a new vector with the low element of `a` replaced by the not-greater-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpeq_pd","","Compare corresponding elements in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmplt_pd","","Compare corresponding elements in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmple_pd","","Compare corresponding elements in `a` and `b` for less-than-or-equal",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpgt_pd","","Compare corresponding elements in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpge_pd","","Compare corresponding elements in `a` and `b` for greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpord_pd","","Compare corresponding elements in `a` and `b` to see if neither is `NaN`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpunord_pd","","Compare corresponding elements in `a` and `b` to see if either is `NaN`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpneq_pd","","Compare corresponding elements in `a` and `b` for not-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnlt_pd","","Compare corresponding elements in `a` and `b` for not-less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnle_pd","","Compare corresponding elements in `a` and `b` for not-less-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpngt_pd","","Compare corresponding elements in `a` and `b` for not-greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnge_pd","","Compare corresponding elements in `a` and `b` for not-greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_comieq_sd","","Compare the lower element of `a` and `b` for equality.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comilt_sd","","Compare the lower element of `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comile_sd","","Compare the lower element of `a` and `b` for less-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comigt_sd","","Compare the lower element of `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comige_sd","","Compare the lower element of `a` and `b` for greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comineq_sd","","Compare the lower element of `a` and `b` for not-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomieq_sd","","Compare the lower element of `a` and `b` for equality.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomilt_sd","","Compare the lower element of `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomile_sd","","Compare the lower element of `a` and `b` for less-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomigt_sd","","Compare the lower element of `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomige_sd","","Compare the lower element of `a` and `b` for greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomineq_sd","","Compare the lower element of `a` and `b` for not-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_cvtpd_ps","","Convert packed double-precision (64-bit) floating-point elements in \"a\" to packed single-precision (32-bit) floating-point elements",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128"}}],[5,"_mm_cvtps_pd","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128d"}}],[5,"_mm_cvtpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsd_si32","","Convert the lower double-precision (64-bit) floating-point element in a to a 32-bit integer.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_cvtsd_ss","","Convert the lower double-precision (64-bit) floating-point element in `b` to a single-precision (32-bit) floating-point element, store the result in the lower element of the return value, and copy the upper element from `a` to the upper element the return value.",null,{"inputs":[{"name":"__m128"},{"name":"__m128d"}],"output":{"name":"__m128"}}],[5,"_mm_cvtsd_f64","","Return the lower double-precision (64-bit) floating-point element of \"a\".",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"f64"}}],[5,"_mm_cvtss_sd","","Convert the lower single-precision (32-bit) floating-point element in `b` to a double-precision (64-bit) floating-point element, store the result in the lower element of the return value, and copy the upper element from `a` to the upper element the return value.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128"}],"output":{"name":"__m128d"}}],[5,"_mm_cvttpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128i"}}],[5,"_mm_cvttsd_si32","","Convert the lower double-precision (64-bit) floating-point element in `a` to a 32-bit integer with truncation.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_cvttps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128i"}}],[5,"_mm_set_sd","","Copy double-precision (64-bit) floating-point element `a` to the lower element of the packed 64-bit return value.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_set1_pd","","Broadcast double-precision (64-bit) floating-point value a to all elements of the return value.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_set_pd1","","Broadcast double-precision (64-bit) floating-point value a to all elements of the return value.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_set_pd","","Set packed double-precision (64-bit) floating-point elements in the return value with the supplied values.",null,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_setr_pd","","Set packed double-precision (64-bit) floating-point elements in the return value with the supplied values in reverse order.",null,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_setzero_pd","","Returns packed double-precision (64-bit) floating-point elements with all zeros.",null,{"inputs":[],"output":{"name":"__m128d"}}],[5,"_mm_movemask_pd","","Return a mask of the most significant bit of each element in `a`.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_load_pd","","Load 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from memory into the returned vector. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_load_sd","","Loads a 64-bit double-precision value to the low element of a 128-bit integer vector and clears the upper element.",null,null],[5,"_mm_loadh_pd","","Loads a double-precision value into the high-order bits of a 128-bit vector of [2 x double]. The low-order bits are copied from the low-order bits of the first operand.",null,null],[5,"_mm_loadl_pd","","Loads a double-precision value into the low-order bits of a 128-bit vector of [2 x double]. The high-order bits are copied from the high-order bits of the first operand.",null,null],[5,"_mm_stream_pd","","Stores a 128-bit floating point vector of [2 x double] to a 128-bit aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm_store_sd","","Stores the lower 64 bits of a 128-bit vector of [2 x double] to a memory location.",null,null],[5,"_mm_store_pd","","Store 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_storeu_pd","","Store 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm_store1_pd","","Store the lower double-precision (64-bit) floating-point element from `a` into 2 contiguous elements in memory. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_store_pd1","","Store the lower double-precision (64-bit) floating-point element from `a` into 2 contiguous elements in memory. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_storer_pd","","Store 2 double-precision (64-bit) floating-point elements from `a` into memory in reverse order. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_storeh_pd","","Stores the upper 64 bits of a 128-bit vector of [2 x double] to a memory location.",null,null],[5,"_mm_storel_pd","","Stores the lower 64 bits of a 128-bit vector of [2 x double] to a memory location.",null,null],[5,"_mm_load1_pd","","Load a double-precision (64-bit) floating-point element from memory into both elements of returned vector.",null,null],[5,"_mm_load_pd1","","Load a double-precision (64-bit) floating-point element from memory into both elements of returned vector.",null,null],[5,"_mm_loadr_pd","","Load 2 double-precision (64-bit) floating-point elements from memory into the returned vector in reverse order. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_loadu_pd","","Load 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from memory into the returned vector. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm_shuffle_pd","","Constructs a 128-bit floating-point vector of [2 x double] from two 128-bit vector parameters of [2 x double], using the immediate-value parameter as a specifier.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_move_sd","","Constructs a 128-bit floating-point vector of [2 x double]. The lower 64 bits are set to the lower 64 bits of the second parameter. The upper 64 bits are set to the upper 64 bits of the first parameter.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_castpd_ps","","Casts a 128-bit floating-point vector of [2 x double] into a 128-bit floating-point vector of [4 x float].",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128"}}],[5,"_mm_castpd_si128","","Casts a 128-bit floating-point vector of [2 x double] into a 128-bit integer vector.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128i"}}],[5,"_mm_castps_pd","","Casts a 128-bit floating-point vector of [4 x float] into a 128-bit floating-point vector of [2 x double].",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128d"}}],[5,"_mm_castps_si128","","Casts a 128-bit floating-point vector of [4 x float] into a 128-bit integer vector.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128i"}}],[5,"_mm_castsi128_pd","","Casts a 128-bit integer vector into a 128-bit floating-point vector of [2 x double].",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128d"}}],[5,"_mm_castsi128_ps","","Casts a 128-bit integer vector into a 128-bit floating-point vector of [4 x float].",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128"}}],[5,"_mm_undefined_pd","","Return vector of type __m128d with undefined elements.",null,{"inputs":[],"output":{"name":"__m128d"}}],[5,"_mm_undefined_si128","","Return vector of type __m128i with undefined elements.",null,{"inputs":[],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_pd","","The resulting `__m128d` element is composed by the low-order values of the two `__m128d` interleaved input elements, i.e.:",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_unpacklo_pd","","The resulting `__m128d` element is composed by the high-order values of the two `__m128d` interleaved input elements, i.e.:",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_add_si64","","Adds two signed or unsigned 64-bit integer values, returning the lower 64 bits of the sum.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_mul_su32","","Multiplies 32-bit unsigned integer values contained in the lower bits of the two 64-bit integer vectors and returns the 64-bit unsigned product.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_si64","","Subtracts signed or unsigned 64-bit integer values and writes the difference to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cvtpi32_pd","","Converts the two signed 32-bit integer elements of a 64-bit vector of [2 x i32] into two double-precision floating-point values, returned in a 128-bit vector of [2 x double].",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128d"}}],[5,"_mm_set_epi64","","Initializes both 64-bit values in a 128-bit vector of [2 x i64] with the specified 64-bit integer values.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi64","","Initializes both values in a 128-bit vector of [2 x i64] with the specified 64-bit value.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi64","","Constructs a 128-bit integer vector, initialized in reverse order with the specified 64-bit integral values.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_movepi64_pi64","","Returns the lower 64 bits of a 128-bit integer vector as a 64-bit integer.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m64"}}],[5,"_mm_movpi64_epi64","","Moves the 64-bit operand to a 128-bit integer vector, zeroing the upper bits.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtpd_pi32","","Converts the two double-precision floating-point elements of a 128-bit vector of [2 x double] into two signed 32-bit integer values, returned in a 64-bit vector of [2 x i32].",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m64"}}],[5,"_mm_cvttpd_pi32","","Converts the two double-precision floating-point elements of a 128-bit vector of [2 x double] into two signed 32-bit integer values, returned in a 64-bit vector of [2 x i32]. If the result of either conversion is inexact, the result is truncated (rounded towards zero) regardless of the current MXCSR setting.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m64"}}],[5,"_mm_addsub_ps","","Alternatively add and subtract packed single-precision (32-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_addsub_pd","","Alternatively add and subtract packed double-precision (64-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_hadd_pd","","Horizontally add adjacent pairs of double-precision (64-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_hadd_ps","","Horizontally add adjacent pairs of single-precision (32-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_hsub_pd","","Horizontally subtract adjacent pairs of double-precision (64-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_hsub_ps","","Horizontally add adjacent pairs of single-precision (32-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_lddqu_si128","","Load 128-bits of integer data from unaligned memory. This intrinsic may perform better than `_mm_loadu_si128` when the data crosses a cache line boundary.",null,null],[5,"_mm_movedup_pd","","Duplicate the low double-precision (64-bit) floating-point element from `a`.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_loaddup_pd","","Load a double-precision (64-bit) floating-point element from memory into both elements of return vector.",null,null],[5,"_mm_movehdup_ps","","Duplicate odd-indexed single-precision (32-bit) floating-point elements from `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_moveldup_ps","","Duplicate even-indexed single-precision (32-bit) floating-point elements from `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_abs_epi8","","Compute the absolute value of packed 8-bit signed integers in `a` and return the unsigned results.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_abs_epi16","","Compute the absolute value of each of the packed 16-bit signed integers in `a` and return the 16-bit unsigned integer",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_abs_epi32","","Compute the absolute value of each of the packed 32-bit signed integers in `a` and return the 32-bit unsigned integer",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_shuffle_epi8","","Shuffle bytes from `a` according to the content of `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_alignr_epi8","","Concatenate 16-byte blocks in `a` and `b` into a 32-byte temporary result, shift the result right by `n` bytes, and return the low 16 bytes.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_hadd_epi16","","Horizontally add the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hadds_epi16","","Horizontally add the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16]. Positive sums greater than 7FFFh are saturated to 7FFFh. Negative sums less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hadd_epi32","","Horizontally add the adjacent pairs of values contained in 2 packed 128-bit vectors of [4 x i32].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hsub_epi16","","Horizontally subtract the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hsubs_epi16","","Horizontally subtract the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16]. Positive differences greater than 7FFFh are saturated to 7FFFh. Negative differences less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hsub_epi32","","Horizontally subtract the adjacent pairs of values contained in 2 packed 128-bit vectors of [4 x i32].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_maddubs_epi16","","Multiply corresponding pairs of packed 8-bit unsigned integer values contained in the first source operand and packed 8-bit signed integer values contained in the second source operand, add pairs of contiguous products with signed saturation, and writes the 16-bit sums to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mulhrs_epi16","","Multiply packed 16-bit signed integer values, truncate the 32-bit product to the 18 most significant bits by right-shifting, round the truncated value by adding 1, and write bits [16:1] to the destination.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sign_epi8","","Negate packed 8-bit integers in `a` when the corresponding signed 8-bit integer in `b` is negative, and return the result. Elements in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sign_epi16","","Negate packed 16-bit integers in `a` when the corresponding signed 16-bit integer in `b` is negative, and return the results. Elements in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sign_epi32","","Negate packed 32-bit integers in `a` when the corresponding signed 32-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_abs_pi8","","Compute the absolute value of packed 8-bit integers in `a` and return the unsigned results.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_abs_pi16","","Compute the absolute value of packed 8-bit integers in `a`, and return the unsigned results.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_abs_pi32","","Compute the absolute value of packed 32-bit integers in `a`, and return the unsigned results.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_shuffle_pi8","","Shuffle packed 8-bit integers in `a` according to shuffle control mask in the corresponding 8-bit element of `b`, and return the results",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_alignr_pi8","","Concatenates the two 64-bit integer vector operands, and right-shifts the result by the number of bytes specified in the immediate operand.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_hadd_pi16","","Horizontally add the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hadd_pi32","","Horizontally add the adjacent pairs of values contained in 2 packed 64-bit vectors of [2 x i32].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hadds_pi16","","Horizontally add the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16]. Positive sums greater than 7FFFh are saturated to 7FFFh. Negative sums less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hsub_pi16","","Horizontally subtracts the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hsub_pi32","","Horizontally subtracts the adjacent pairs of values contained in 2 packed 64-bit vectors of [2 x i32].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hsubs_pi16","","Horizontally subtracts the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16]. Positive differences greater than 7FFFh are saturated to 7FFFh. Negative differences less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_maddubs_pi16","","Multiplies corresponding pairs of packed 8-bit unsigned integer values contained in the first source operand and packed 8-bit signed integer values contained in the second source operand, adds pairs of contiguous products with signed saturation, and writes the 16-bit sums to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_mulhrs_pi16","","Multiplies packed 16-bit signed integer values, truncates the 32-bit products to the 18 most significant bits by right-shifting, rounds the truncated value by adding 1, and writes bits [16:1] to the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sign_pi8","","Negate packed 8-bit integers in `a` when the corresponding signed 8-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sign_pi16","","Negate packed 16-bit integers in `a` when the corresponding signed 16-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sign_pi32","","Negate packed 32-bit integers in `a` when the corresponding signed 32-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_blendv_epi8","","Blend packed 8-bit integers from `a` and `b` using `mask`",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_blend_epi16","","Blend packed 16-bit integers from `a` and `b` using the mask `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_blendv_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using `mask`",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_blendv_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using `mask`",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_blend_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using control mask `imm2`",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_blend_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using mask `imm4`",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_extract_ps","","Extract a single-precision (32-bit) floating-point element from `a`, selected with `imm8`",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_extract_epi8","","Extract an 8-bit integer from `a`, selected with `imm8`. Returns a 32-bit integer containing the zero-extended integer data.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_extract_epi32","","Extract an 32-bit integer from `a` selected with `imm8`",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_insert_ps","","Select a single value in `a` to store at some position in `b`, Then zero elements according to `imm8`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_insert_epi8","","Return a copy of `a` with the 8-bit integer from `i` inserted at a location specified by `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_insert_epi32","","Return a copy of `a` with the 32-bit integer from `i` inserted at a location specified by `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epi8","","Compare packed 8-bit integers in `a` and `b` and return packed maximum values in dst.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return packed maximum.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epi32","","Compare packed 32-bit integers in `a` and `b`, and return packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epi8","","Compare packed 8-bit integers in `a` and `b` and return packed minimum values in dst.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return packed minimum.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epi32","","Compare packed 32-bit integers in `a` and `b`, and return packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packus_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using unsigned saturation",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi64","","Compare packed 64-bit integers in `a` and `b` for equality",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi8_epi16","","Sign extend packed 8-bit integers in `a` to packed 16-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi8_epi32","","Sign extend packed 8-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi8_epi64","","Sign extend packed 8-bit integers in the low 8 bytes of `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi16_epi32","","Sign extend packed 16-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi16_epi64","","Sign extend packed 16-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi32_epi64","","Sign extend packed 32-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu8_epi16","","Zero extend packed unsigned 8-bit integers in `a` to packed 16-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu8_epi32","","Zero extend packed unsigned 8-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu8_epi64","","Zero extend packed unsigned 8-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu16_epi32","","Zero extend packed unsigned 16-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu16_epi64","","Zero extend packed unsigned 16-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu32_epi64","","Zero extend packed unsigned 32-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_dp_pd","","Returns the dot product of two __m128d vectors.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_dp_ps","","Returns the dot product of two __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_floor_pd","","Round the packed double-precision (64-bit) floating-point elements in `a` down to an integer value, and store the results as packed double-precision floating-point elements.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_floor_ps","","Round the packed single-precision (32-bit) floating-point elements in `a` down to an integer value, and store the results as packed single-precision floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_floor_sd","","Round the lower double-precision (64-bit) floating-point element in `b` down to an integer value, store the result as a double-precision floating-point element in the lower element of the intrinsic result, and copy the upper element from `a` to the upper element of the intrinsic result.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_floor_ss","","Round the lower single-precision (32-bit) floating-point element in `b` down to an integer value, store the result as a single-precision floating-point element in the lower element of the intrinsic result, and copy the upper 3 packed elements from `a` to the upper elements of the intrinsic result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_ceil_pd","","Round the packed double-precision (64-bit) floating-point elements in `a` up to an integer value, and store the results as packed double-precision floating-point elements.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_ceil_ps","","Round the packed single-precision (32-bit) floating-point elements in `a` up to an integer value, and store the results as packed single-precision floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_ceil_sd","","Round the lower double-precision (64-bit) floating-point element in `b` up to an integer value, store the result as a double-precision floating-point element in the lower element of the intrisic result, and copy the upper element from `a` to the upper element of the intrinsic result.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_ceil_ss","","Round the lower single-precision (32-bit) floating-point element in `b` up to an integer value, store the result as a single-precision floating-point element in the lower element of the intrinsic result, and copy the upper 3 packed elements from `a` to the upper elements of the intrinsic result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_round_pd","","Round the packed double-precision (64-bit) floating-point elements in `a` using the `rounding` parameter, and store the results as packed double-precision floating-point elements. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_round_ps","","Round the packed single-precision (32-bit) floating-point elements in `a` using the `rounding` parameter, and store the results as packed single-precision floating-point elements. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_round_sd","","Round the lower double-precision (64-bit) floating-point element in `b` using the `rounding` parameter, store the result as a double-precision floating-point element in the lower element of the intrinsic result, and copy the upper element from `a` to the upper element of the intrinsic result. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_round_ss","","Round the lower single-precision (32-bit) floating-point element in `b` using the `rounding` parameter, store the result as a single-precision floating-point element in the lower element of the intrinsic result, and copy the upper 3 packed elements from `a` to the upper elements of the instrinsic result. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_minpos_epu16","","Finds the minimum unsigned 16-bit element in the 128-bit __m128i vector, returning a vector containing its value in its first position, and its index in its second position; all other elements are set to zero.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mul_epi32","","Multiply the low 32-bit integers from each packed 64-bit element in `a` and `b`, and return the signed 64-bit result.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mullo_epi32","","Multiply the packed 32-bit integers in `a` and `b`, producing intermediate 64-bit integers, and returns the lowest 32-bit, whatever they might be, reinterpreted as a signed integer. While `pmulld __m128i::splat(2), __m128i::splat(2)` returns the obvious `__m128i::splat(4)`, due to wrapping arithmetic `pmulld __m128i::splat(i32::MAX), __m128i::splat(2)` would return a negative number.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mpsadbw_epu8","","Subtracts 8-bit unsigned integer values and computes the absolute values of the differences to the corresponding bits in the destination. Then sums of the absolute differences are returned according to the bit fields in the immediate operand.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_testz_si128","","Tests whether the specified bits in a 128-bit integer vector are all zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_testc_si128","","Tests whether the specified bits in a 128-bit integer vector are all ones.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_testnzc_si128","","Tests whether the specified bits in a 128-bit integer vector are neither all zeros nor all ones.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_test_all_zeros","","Tests whether the specified bits in a 128-bit integer vector are all zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_test_all_ones","","Tests whether the specified bits in `a` 128-bit integer vector are all ones.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_test_mix_ones_zeros","","Tests whether the specified bits in a 128-bit integer vector are neither all zeros nor all ones.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrm","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return the generated mask.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpistri","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8` and return the generated index. Similar to [`_mm_cmpestri`] with the exception that [`_mm_cmpestri`] requires the lengths of `a` and `b` to be explicitly specified.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrz","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return `1` if any character in `b` was null. and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrc","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return `1` if the resulting mask was non-zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrs","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and returns `1` if any character in `a` was null, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistro","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return bit `0` of the resulting bit mask.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistra","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return `1` if `b` did not contain a null character and the resulting mask was zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrm","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return the generated mask.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpestri","","Compare packed strings `a` and `b` with lengths `la` and `lb` using the control in `imm8` and return the generated index. Similar to [`_mm_cmpistri`] with the exception that [`_mm_cmpistri`] implicitly determines the length of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrz","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if any character in `b` was null, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrc","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if the resulting mask was non-zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrs","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if any character in a was null, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestro","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return bit `0` of the resulting bit mask.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestra","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if `b` did not contain a null character and the resulting mask was zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_crc32_u8","","Starting with the initial value in `crc`, return the accumulated CRC32 value for unsigned 8-bit integer `v`.",null,{"inputs":[{"name":"u32"},{"name":"u8"}],"output":{"name":"u32"}}],[5,"_mm_crc32_u16","","Starting with the initial value in `crc`, return the accumulated CRC32 value for unsigned 16-bit integer `v`.",null,{"inputs":[{"name":"u32"},{"name":"u16"}],"output":{"name":"u32"}}],[5,"_mm_crc32_u32","","Starting with the initial value in `crc`, return the accumulated CRC32 value for unsigned 32-bit integer `v`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_cmpgt_epi64","","Compare packed 64-bit integers in `a` and `b` for greater-than, return the results.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_add_pd","","Add packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_add_ps","","Add packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_and_pd","","Compute the bitwise AND of a packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_and_ps","","Compute the bitwise AND of packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_or_pd","","Compute the bitwise OR packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_or_ps","","Compute the bitwise OR packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_shuffle_pd","","Shuffle double-precision (64-bit) floating-point elements within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_shuffle_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_andnot_pd","","Compute the bitwise NOT of packed double-precision (64-bit) floating-point elements in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_andnot_ps","","Compute the bitwise NOT of packed single-precision (32-bit) floating-point elements in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_max_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b`, and return packed maximum values",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_max_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return packed maximum values",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_min_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b`, and return packed minimum values",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_min_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return packed minimum values",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_mul_pd","","Add packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_mul_ps","","Add packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_addsub_pd","","Alternatively add and subtract packed double-precision (64-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_addsub_ps","","Alternatively add and subtract packed single-precision (32-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_sub_pd","","Subtract packed double-precision (64-bit) floating-point elements in `b` from packed elements in `a`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_sub_ps","","Subtract packed single-precision (32-bit) floating-point elements in `b` from packed elements in `a`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_div_ps","","Compute the division of each of the 8 packed 32-bit floating-point elements in `a` by the corresponding packed elements in `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_div_pd","","Compute the division of each of the 4 packed 64-bit floating-point elements in `a` by the corresponding packed elements in `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_round_pd","","Round packed double-precision (64-bit) floating point elements in `a` according to the flag `b`. The value of `b` may be as follows:",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_ceil_pd","","Round packed double-precision (64-bit) floating point elements in `a` toward positive infinity.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_floor_pd","","Round packed double-precision (64-bit) floating point elements in `a` toward negative infinity.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_round_ps","","Round packed single-precision (32-bit) floating point elements in `a` according to the flag `b`. The value of `b` may be as follows:",null,{"inputs":[{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_ceil_ps","","Round packed single-precision (32-bit) floating point elements in `a` toward positive infinity.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_floor_ps","","Round packed single-precision (32-bit) floating point elements in `a` toward negative infinity.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_sqrt_ps","","Return the square root of packed single-precision (32-bit) floating point elements in `a`.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_sqrt_pd","","Return the square root of packed double-precision (64-bit) floating point elements in `a`.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_blend_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_blend_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_blendv_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using `c` as a mask.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_blendv_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using `c` as a mask.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_dp_ps","","Conditionally multiply the packed single-precision (32-bit) floating-point elements in `a` and `b` using the high 4 bits in `imm8`, sum the four products, and conditionally return the sum  using the low 4 bits of `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_hadd_pd","","Horizontal addition of adjacent pairs in the two packed vectors of 4 64-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in even locations, while sums of elements from `b` are returned in odd locations.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_hadd_ps","","Horizontal addition of adjacent pairs in the two packed vectors of 8 32-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in locations of indices 0, 1, 4, 5; while sums of elements from `b` are locations 2, 3, 6, 7.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_hsub_pd","","Horizontal subtraction of adjacent pairs in the two packed vectors of 4 64-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in even locations, while sums of elements from `b` are returned in odd locations.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_hsub_ps","","Horizontal subtraction of adjacent pairs in the two packed vectors of 8 32-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in locations of indices 0, 1, 4, 5; while sums of elements from `b` are locations 2, 3, 6, 7.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_xor_pd","","Compute the bitwise XOR of packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_xor_ps","","Compute the bitwise XOR of packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm_cmp_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm256_cmp_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm_cmp_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_cmp_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm_cmp_sd","","Compare the lower double-precision (64-bit) floating-point element in `a` and `b` based on the comparison operand specified by `imm8`, store the result in the lower element of returned vector, and copy the upper element from `a` to the upper element of returned vector.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_cmp_ss","","Compare the lower single-precision (32-bit) floating-point element in `a` and `b` based on the comparison operand specified by `imm8`, store the result in the lower element of returned vector, and copy the upper 3 packed elements from `a` to the upper elements of returned vector.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_cvtepi32_pd","","Convert packed 32-bit integers in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256d"}}],[5,"_mm256_cvtepi32_ps","","Convert packed 32-bit integers in `a` to packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm256_cvtpd_ps","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128"}}],[5,"_mm256_cvtps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtps_pd","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256d"}}],[5,"_mm256_cvttpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128i"}}],[5,"_mm256_cvtpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128i"}}],[5,"_mm256_cvttps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256i"}}],[5,"_mm256_extractf128_ps","","Extract 128 bits (composed of 4 packed single-precision (32-bit) floating-point elements) from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_extractf128_pd","","Extract 128 bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm256_extractf128_si256","","Extract 128 bits (composed of integer data) from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm256_zeroall","","Zero the contents of all XMM or YMM registers.",null,{"inputs":[],"output":null}],[5,"_mm256_zeroupper","","Zero the upper 128 bits of all YMM registers; the lower 128-bits of the registers are unmodified.",null,{"inputs":[],"output":null}],[5,"_mm256_permutevar_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` within 128-bit lanes using the control in `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm_permutevar_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` using the control in `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128i"}],"output":{"name":"__m128"}}],[5,"_mm256_permute_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm_permute_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_permutevar_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` within 256-bit lanes using the control in `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256i"}],"output":{"name":"__m256d"}}],[5,"_mm_permutevar_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` using the control in `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128i"}],"output":{"name":"__m128d"}}],[5,"_mm256_permute_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm_permute_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm256_permute2f128_ps","","Shuffle 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_permute2f128_pd","","Shuffle 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_permute2f128_si256","","Shuffle 258-bits (composed of integer data) selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_broadcast_ss","","Broadcast a single-precision (32-bit) floating-point element from memory to all elements of the returned vector.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm_broadcast_ss","","Broadcast a single-precision (32-bit) floating-point element from memory to all elements of the returned vector.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm256_broadcast_sd","","Broadcast a double-precision (64-bit) floating-point element from memory to all elements of the returned vector.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_broadcast_ps","","Broadcast 128 bits from memory (composed of 4 packed single-precision (32-bit) floating-point elements) to all elements of the returned vector.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_broadcast_pd","","Broadcast 128 bits from memory (composed of 2 packed double-precision (64-bit) floating-point elements) to all elements of the returned vector.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_insertf128_ps","","Copy `a` to result, then insert 128 bits (composed of 4 packed single-precision (32-bit) floating-point elements) from `b` into result at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_insertf128_pd","","Copy `a` to result, then insert 128 bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `b` into result at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_insertf128_si256","","Copy `a` to result, then insert 128 bits from `b` into result at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_insert_epi8","","Copy `a` to result, and insert the 8-bit integer `i` into result at the location specified by `index`.",null,{"inputs":[{"name":"__m256i"},{"name":"i8"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_insert_epi16","","Copy `a` to result, and insert the 16-bit integer `i` into result at the location specified by `index`.",null,{"inputs":[{"name":"__m256i"},{"name":"i16"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_insert_epi32","","Copy `a` to result, and insert the 32-bit integer `i` into result at the location specified by `index`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_load_pd","","Load 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from memory into result. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_store_pd","","Store 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_load_ps","","Load 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from memory into result. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_store_ps","","Store 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from `a` into memory. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_loadu_pd","","Load 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from memory into result. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu_pd","","Store 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_loadu_ps","","Load 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from memory into result. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu_ps","","Store 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_load_si256","","Load 256-bits of integer data from memory into result. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_store_si256","","Store 256-bits of integer data from `a` into memory. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_loadu_si256","","Load 256-bits of integer data from memory into result. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu_si256","","Store 256-bits of integer data from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_maskload_pd","","Load packed double-precision (64-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm256_maskstore_pd","","Store packed double-precision (64-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm_maskload_pd","","Load packed double-precision (64-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm_maskstore_pd","","Store packed double-precision (64-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm256_maskload_ps","","Load packed single-precision (32-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm256_maskstore_ps","","Store packed single-precision (32-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm_maskload_ps","","Load packed single-precision (32-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm_maskstore_ps","","Store packed single-precision (32-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm256_movehdup_ps","","Duplicate odd-indexed single-precision (32-bit) floating-point elements from `a`, and return the results.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_moveldup_ps","","Duplicate even-indexed single-precision (32-bit) floating-point elements from `a`, and return the results.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_movedup_pd","","Duplicate even-indexed double-precision (64-bit) floating-point elements from \"a\", and return the results.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_lddqu_si256","","Load 256-bits of integer data from unaligned memory into result. This intrinsic may perform better than `_mm256_loadu_si256` when the data crosses a cache line boundary.",null,null],[5,"_mm256_stream_si256","","Moves integer data from a 256-bit integer vector to a 32-byte aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon)",null,null],[5,"_mm256_stream_pd","","Moves double-precision values from a 256-bit vector of [4 x double] to a 32-byte aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm256_stream_ps","","Moves single-precision floating point values from a 256-bit vector of [8 x float] to a 32-byte aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm256_rcp_ps","","Compute the approximate reciprocal of packed single-precision (32-bit) floating-point elements in `a`, and return the results. The maximum relative error for this approximation is less than 1.5*2^-12.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_rsqrt_ps","","Compute the approximate reciprocal square root of packed single-precision (32-bit) floating-point elements in `a`, and return the results. The maximum relative error for this approximation is less than 1.5*2^-12.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_unpackhi_pd","","Unpack and interleave double-precision (64-bit) floating-point elements from the high half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_unpackhi_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the high half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_unpacklo_pd","","Unpack and interleave double-precision (64-bit) floating-point elements from the low half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_unpacklo_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the low half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_testz_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`, and set `ZF` to 1 if the result is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, and set `CF` to 1 if the result is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_testc_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`, and set `ZF` to 1 if the result is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, and set `CF` to 1 if the result is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_testnzc_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`, and set `ZF` to 1 if the result is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, and set `CF` to 1 if the result is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_testz_pd","","Compute the bitwise AND of 256 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm256_testc_pd","","Compute the bitwise AND of 256 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm256_testnzc_pd","","Compute the bitwise AND of 256 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm_testz_pd","","Compute the bitwise AND of 128 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_testc_pd","","Compute the bitwise AND of 128 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_testnzc_pd","","Compute the bitwise AND of 128 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm256_testz_ps","","Compute the bitwise AND of 256 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm256_testc_ps","","Compute the bitwise AND of 256 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm256_testnzc_ps","","Compute the bitwise AND of 256 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm_testz_ps","","Compute the bitwise AND of 128 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_testc_ps","","Compute the bitwise AND of 128 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_testnzc_ps","","Compute the bitwise AND of 128 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm256_movemask_pd","","Set each bit of the returned mask based on the most significant bit of the corresponding packed double-precision (64-bit) floating-point element in `a`.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm256_movemask_ps","","Set each bit of the returned mask based on the most significant bit of the corresponding packed single-precision (32-bit) floating-point element in `a`.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm256_setzero_pd","","Return vector of type __m256d with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m256d"}}],[5,"_mm256_setzero_ps","","Return vector of type __m256 with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m256"}}],[5,"_mm256_setzero_si256","","Return vector of type __m256i with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m256i"}}],[5,"_mm256_set_pd","","Set packed double-precision (64-bit) floating-point elements in returned vector with the supplied values.",null,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_set_ps","","Set packed single-precision (32-bit) floating-point elements in returned vector with the supplied values.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm256_set_epi8","","Set packed 8-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m256i"}}],[5,"_mm256_set_epi16","","Set packed 16-bit integers in returned vector with the supplied values.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m256i"}}],[5,"_mm256_set_epi32","","Set packed 32-bit integers in returned vector with the supplied values.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_set_epi64x","","Set packed 64-bit integers in returned vector with the supplied values.",null,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_pd","","Set packed double-precision (64-bit) floating-point elements in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_setr_ps","","Set packed single-precision (32-bit) floating-point elements in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm256_setr_epi8","","Set packed 8-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_epi16","","Set packed 16-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_epi32","","Set packed 32-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_epi64x","","Set packed 64-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_pd","","Broadcast double-precision (64-bit) floating-point value `a` to all elements of returned vector.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_set1_ps","","Broadcast single-precision (32-bit) floating-point value `a` to all elements of returned vector.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm256_set1_epi8","","Broadcast 8-bit integer `a` to all elements of returned vector. This intrinsic may generate the `vpbroadcastb`.",null,{"inputs":[{"name":"i8"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_epi16","","Broadcast 16-bit integer `a` to all all elements of returned vector. This intrinsic may generate the `vpbroadcastw`.",null,{"inputs":[{"name":"i16"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_epi32","","Broadcast 32-bit integer `a` to all elements of returned vector. This intrinsic may generate the `vpbroadcastd`.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_epi64x","","Broadcast 64-bit integer `a` to all elements of returned vector. This intrinsic may generate the `vpbroadcastq`.",null,{"inputs":[{"name":"i64"}],"output":{"name":"__m256i"}}],[5,"_mm256_castpd_ps","","Cast vector of type __m256d to type __m256.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256"}}],[5,"_mm256_castps_pd","","Cast vector of type __m256 to type __m256d.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256d"}}],[5,"_mm256_castps_si256","","Casts vector of type __m256 to type __m256i.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256i"}}],[5,"_mm256_castsi256_ps","","Casts vector of type __m256i to type __m256.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm256_castpd_si256","","Casts vector of type __m256d to type __m256i.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256i"}}],[5,"_mm256_castsi256_pd","","Casts vector of type __m256i to type __m256d.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256d"}}],[5,"_mm256_castps256_ps128","","Casts vector of type __m256 to type __m128.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m128"}}],[5,"_mm256_castpd256_pd128","","Casts vector of type __m256d to type __m128d.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128d"}}],[5,"_mm256_castsi256_si128","","Casts vector of type __m256i to type __m128i.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m128i"}}],[5,"_mm256_castps128_ps256","","Casts vector of type __m128 to type __m256; the upper 128 bits of the result are undefined.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_castpd128_pd256","","Casts vector of type __m128d to type __m256d; the upper 128 bits of the result are undefined.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_castsi128_si256","","Casts vector of type __m128i to type __m256i; the upper 128 bits of the result are undefined.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_zextps128_ps256","","Constructs a 256-bit floating-point vector of [8 x float] from a 128-bit floating-point vector of [4 x float]. The lower 128 bits contain the value of the source vector. The upper 128 bits are set to zero.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_zextsi128_si256","","Constructs a 256-bit integer vector from a 128-bit integer vector. The lower 128 bits contain the value of the source vector. The upper 128 bits are set to zero.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_zextpd128_pd256","","Constructs a 256-bit floating-point vector of [4 x double] from a 128-bit floating-point vector of [2 x double]. The lower 128 bits contain the value of the source vector. The upper 128 bits are set to zero.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_undefined_ps","","Return vector of type `__m256` with undefined elements.",null,{"inputs":[],"output":{"name":"__m256"}}],[5,"_mm256_undefined_pd","","Return vector of type `__m256d` with undefined elements.",null,{"inputs":[],"output":{"name":"__m256d"}}],[5,"_mm256_undefined_si256","","Return vector of type __m256i with undefined elements.",null,{"inputs":[],"output":{"name":"__m256i"}}],[5,"_mm256_set_m128","","Set packed __m256 returned vector with the supplied values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_set_m128d","","Set packed __m256d returned vector with the supplied values.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_set_m128i","","Set packed __m256i returned vector with the supplied values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_m128","","Set packed __m256 returned vector with the supplied values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_setr_m128d","","Set packed __m256d returned vector with the supplied values.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_setr_m128i","","Set packed __m256i returned vector with the supplied values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_loadu2_m128","","Load two 128-bit values (composed of 4 packed single-precision (32-bit) floating-point elements) from memory, and combine them into a 256-bit value. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_loadu2_m128d","","Load two 128-bit values (composed of 2 packed double-precision (64-bit) floating-point elements) from memory, and combine them into a 256-bit value. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_loadu2_m128i","","Load two 128-bit values (composed of integer data) from memory, and combine them into a 256-bit value. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu2_m128","","Store the high and low 128-bit halves (each composed of 4 packed single-precision (32-bit) floating-point elements) from `a` into memory two different 128-bit locations. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu2_m128d","","Store the high and low 128-bit halves (each composed of 2 packed double-precision (64-bit) floating-point elements) from `a` into memory two different 128-bit locations. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu2_m128i","","Store the high and low 128-bit halves (each composed of integer data) from `a` into memory two different 128-bit locations. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_cvtss_f32","","Returns the first element of the input vector of [8 x float].",null,{"inputs":[{"name":"__m256"}],"output":{"name":"f32"}}],[5,"_mm256_abs_epi32","","Computes the absolute values of packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_abs_epi16","","Computes the absolute values of packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_abs_epi8","","Computes the absolute values of packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi64","","Add packed 64-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi32","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi16","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi8","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epi8","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epi16","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epu8","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epu16","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_alignr_epi8","","Concatenate pairs of 16-byte blocks in `a` and `b` into a 32-byte temporary result, shift the result right by `n` bytes, and return the low 16 bytes.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_and_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_andnot_si256","","Compute the bitwise NOT of 256 bits (representing integer data) in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_avg_epu16","","Average packed unsigned 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_avg_epu8","","Average packed unsigned 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_blend_epi32","","Blend packed 32-bit integers from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm256_blend_epi32","","Blend packed 32-bit integers from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_blend_epi16","","Blend packed 16-bit integers from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_blendv_epi8","","Blend packed 8-bit integers from `a` and `b` using `mask`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastb_epi8","","Broadcast the low packed 8-bit integer from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastb_epi8","","Broadcast the low packed 8-bit integer from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastd_epi32","","Broadcast the low packed 32-bit integer from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastd_epi32","","Broadcast the low packed 32-bit integer from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastq_epi64","","Broadcast the low packed 64-bit integer from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastq_epi64","","Broadcast the low packed 64-bit integer from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastsd_pd","","Broadcast the low double-precision (64-bit) floating-point element from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm256_broadcastsd_pd","","Broadcast the low double-precision (64-bit) floating-point element from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_broadcastsi128_si256","","Broadcast 128 bits of integer data from a to all 128-bit lanes in the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastss_ps","","Broadcast the low single-precision (32-bit) floating-point element from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm256_broadcastss_ps","","Broadcast the low single-precision (32-bit) floating-point element from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm_broadcastw_epi16","","Broadcast the low packed 16-bit integer from a to all elements of the 128-bit returned value",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastw_epi16","","Broadcast the low packed 16-bit integer from a to all elements of the 256-bit returned value",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi64","","Compare packed 64-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi32","","Compare packed 32-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi16","","Compare packed 16-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi8","","Compare packed 8-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi64","","Compare packed 64-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi32","","Compare packed 32-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi16","","Compare packed 16-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi8","","Compare packed 8-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi16_epi32","","Sign-extend 16-bit integers to 32-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi16_epi64","","Sign-extend 16-bit integers to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi32_epi64","","Sign-extend 32-bit integers to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi8_epi16","","Sign-extend 8-bit integers to 16-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi8_epi32","","Sign-extend 8-bit integers to 32-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi8_epi64","","Sign-extend 8-bit integers to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu16_epi32","","Zero extend packed unsigned 16-bit integers in `a` to packed 32-bit integers, and store the results in dst.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu16_epi64","","Zero-extend the lower four unsigned 16-bit integers in `a` to 64-bit integers. The upper four elements of `a` are unused.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu32_epi64","","Zero-extend unsigned 32-bit integers in `a` to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu8_epi16","","Zero-extend unsigned 8-bit integers in `a` to 16-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu8_epi32","","Zero-extend the lower eight unsigned 8-bit integers in `a` to 32-bit integers. The upper eight elements of `a` are unused.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu8_epi64","","Zero-extend the lower four unsigned 8-bit integers in `a` to 64-bit integers. The upper twelve elements of `a` are unused.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_extracti128_si256","","Extract 128 bits (of integer data) from `a` selected with `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm256_hadd_epi16","","Horizontally add adjacent pairs of 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hadd_epi32","","Horizontally add adjacent pairs of 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hadds_epi16","","Horizontally add adjacent pairs of 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hsub_epi16","","Horizontally subtract adjacent pairs of 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hsub_epi32","","Horizontally subtract adjacent pairs of 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hsubs_epi16","","Horizontally subtract adjacent pairs of 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_inserti128_si256","","Copy `a` to `dst`, then insert 128 bits (of integer data) from `b` at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_madd_epi16","","Multiply packed signed 16-bit integers in `a` and `b`, producing intermediate signed 32-bit integers. Horizontally add adjacent pairs of intermediate 32-bit integers.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_maddubs_epi16","","Vertically multiply each unsigned 8-bit integer from `a` with the corresponding signed 8-bit integer from `b`, producing intermediate signed 16-bit integers. Horizontally add adjacent pairs of intermediate signed 16-bit integers",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_maskload_epi32","","Load packed 32-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskload_epi32","","Load packed 32-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm_maskload_epi64","","Load packed 64-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskload_epi64","","Load packed 64-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm_maskstore_epi32","","Store packed 32-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskstore_epi32","","Store packed 32-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm_maskstore_epi64","","Store packed 64-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskstore_epi64","","Store packed 64-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_max_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epi32","","Compare packed 32-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epi8","","Compare packed 8-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epi32","","Compare packed 32-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epi8","","Compare packed 8-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_movemask_epi8","","Create mask from the most significant bit of each 8-bit element in `a`, return the result.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_mpsadbw_epu8","","Compute the sum of absolute differences (SADs) of quadruplets of unsigned 8-bit integers in `a` compared to those in `b`, and store the 16-bit results in dst. Eight SADs are performed for each 128-bit lane using one quadruplet from `b` and eight quadruplets from `a`. One quadruplet is selected from `b` starting at on the offset specified in `imm8`. Eight quadruplets are formed from sequential 8-bit integers selected from `a` starting at the offset specified in `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_mul_epi32","","Multiply the low 32-bit integers from each packed 64-bit element in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mul_epu32","","Multiply the low unsigned 32-bit integers from each packed 64-bit element in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mulhi_epi16","","Multiply the packed 16-bit integers in `a` and `b`, producing intermediate 32-bit integers and returning the high 16 bits of the intermediate integers.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mulhi_epu16","","Multiply the packed unsigned 16-bit integers in `a` and `b`, producing intermediate 32-bit integers and returning the high 16 bits of the intermediate integers.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mullo_epi16","","Multiply the packed 16-bit integers in `a` and `b`, producing intermediate 32-bit integers, and return the low 16 bits of the intermediate integers",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mullo_epi32","","Multiply the packed 32-bit integers in `a` and `b`, producing intermediate 64-bit integers, and return the low 16 bits of the intermediate integers",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mulhrs_epi16","","Multiply packed 16-bit integers in `a` and `b`, producing intermediate signed 32-bit integers. Truncate each intermediate integer to the 18 most significant bits, round by adding 1, and return bits [16:1]",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_or_si256","","Compute the bitwise OR of 256 bits (representing integer data) in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packs_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using signed saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packs_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using signed saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packus_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using unsigned saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packus_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using unsigned saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_permutevar8x32_epi32","","Permutes packed 32-bit integers from `a` according to the content of `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_permute4x64_epi64","","Permutes 64-bit integers from `a` using control mask `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_permute2x128_si256","","Shuffle 128-bits of integer data selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_permute4x64_pd","","Shuffle 64-bit floating-point elements in `a` across lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_permutevar8x32_ps","","Shuffle eight 32-bit foating-point elements in `a` across lanes using the corresponding 32-bit integer index in `idx`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm256_sad_epu8","","Compute the absolute differences of packed unsigned 8-bit integers in `a` and `b`, then horizontally sum each consecutive 8 differences to produce four unsigned 16-bit integers, and pack these unsigned 16-bit integers in the low 16 bits of the 64-bit return value",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_shuffle_epi8","","Shuffle bytes from `a` according to the content of `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_shuffle_epi32","","Shuffle 32-bit integers in 128-bit lanes of `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_shufflehi_epi16","","Shuffle 16-bit integers in the high 64 bits of 128-bit lanes of `a` using the control in `imm8`. The low 64 bits of 128-bit lanes of `a` are copied to the output.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_shufflelo_epi16","","Shuffle 16-bit integers in the low 64 bits of 128-bit lanes of `a` using the control in `imm8`. The high 64 bits of 128-bit lanes of `a` are copied to the output.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_sign_epi16","","Negate packed 16-bit integers in `a` when the corresponding signed 16-bit integer in `b` is negative, and return the results. Results are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sign_epi32","","Negate packed 32-bit integers in `a` when the corresponding signed 32-bit integer in `b` is negative, and return the results. Results are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sign_epi8","","Negate packed 8-bit integers in `a` when the corresponding signed 8-bit integer in `b` is negative, and return the results. Results are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sll_epi16","","Shift packed 16-bit integers in `a` left by `count` while shifting in zeros, and return the result",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sll_epi32","","Shift packed 32-bit integers in `a` left by `count` while shifting in zeros, and return the result",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sll_epi64","","Shift packed 64-bit integers in `a` left by `count` while shifting in zeros, and return the result",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_epi16","","Shift packed 16-bit integers in `a` left by `imm8` while shifting in zeros, return the results;",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_epi32","","Shift packed 32-bit integers in `a` left by `imm8` while shifting in zeros, return the results;",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_epi64","","Shift packed 64-bit integers in `a` left by `imm8` while shifting in zeros, return the results;",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_si256","","Shift 128-bit lanes in `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_bslli_epi128","","Shift 128-bit lanes in `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm_sllv_epi32","","Shift packed 32-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_sllv_epi32","","Shift packed 32-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_sllv_epi64","","Shift packed 64-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_sllv_epi64","","Shift packed 64-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sra_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sra_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srai_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srai_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm_srav_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_srav_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_si256","","Shift 128-bit lanes in `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_bsrli_epi128","","Shift 128-bit lanes in `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srl_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srl_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srl_epi64","","Shift packed 64-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in zeros",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in zeros",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_epi64","","Shift packed 64-bit integers in `a` right by `imm8` while shifting in zeros",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm_srlv_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_srlv_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_srlv_epi64","","Shift packed 64-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_srlv_epi64","","Shift packed 64-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi32","","Subtract packed 32-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi64","","Subtract packed 64-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi8","","Subtract packed 8-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epu16","","Subtract packed unsigned 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epu8","","Subtract packed unsigned 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi8","","Unpack and interleave 8-bit integers from the high half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi8","","Unpack and interleave 8-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi16","","Unpack and interleave 16-bit integers from the high half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi16","","Unpack and interleave 16-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi32","","Unpack and interleave 32-bit integers from the high half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi32","","Unpack and interleave 32-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi64","","Unpack and interleave 64-bit integers from the high half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi64","","Unpack and interleave 64-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_xor_si256","","Compute the bitwise XOR of 256 bits (representing integer data) in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_extract_epi8","","Extract an 8-bit integer from `a`, selected with `imm8`. Returns a 32-bit integer containing the zero-extended integer data.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"i8"}}],[5,"_mm256_extract_epi16","","Extract a 16-bit integer from `a`, selected with `imm8`. Returns a 32-bit integer containing the zero-extended integer data.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"i16"}}],[5,"_mm256_extract_epi32","","Extract a 32-bit integer from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm256_cvtsd_f64","","Returns the first element of the input vector of [4 x double].",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"f64"}}],[5,"_mm256_cvtsi256_si32","","Returns the first element of the input vector of [8 x i32].",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_lzcnt_u32","","Counts the leading most significant zero bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_popcnt32","","Counts the bits that are set.",null,{"inputs":[{"name":"i32"}],"output":{"name":"i32"}}],[5,"_bextr_u32","","Extracts bits in range [`start`, `start` + `length`) from `a` into the least significant bits of the result.",null,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_bextr2_u32","","Extracts bits of `a` specified by `control` into the least significant bits of the result.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_andn_u32","","Bitwise logical `AND` of inverted `a` with `b`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsi_u32","","Extract lowest set isolated bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsmsk_u32","","Get mask up to lowest set bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsr_u32","","Resets the lowest set bit of `x`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_tzcnt_u32","","Counts the number of trailing least significant zero bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_tzcnt_32","","Counts the number of trailing least significant zero bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"i32"}}],[5,"_mulx_u32","","Unsigned multiply without affecting flags.",null,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_bzhi_u32","","Zero higher bits of `a` >= `index`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_pdep_u32","","Scatter contiguous low order bits of `a` to the result at the positions specified by the `mask`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_pext_u32","","Gathers the bits of `x` specified by the `mask` into the contiguous low order bit positions of the result.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_extract_si64","","Extracts the bit range specified by `y` from the lower 64 bits of `x`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_insert_si64","","Inserts the `[length:0]` bits of `y` into `x` at `index`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_stream_sd","","Non-temporal store of `a.0` into `p`.",null,null],[5,"_mm_stream_ss","","Non-temporal store of `a.0` into `p`.",null,null],[5,"_blcfill_u32","","Clears all bits below the least significant zero bit of `x`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blci_u32","","Sets all bits of `x` to 1 except for the least significant zero bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blcic_u32","","Sets the least significant zero bit of `x` and clears all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blcmsk_u32","","Sets the least significant zero bit of `x` and clears all bits above that bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blcs_u32","","Sets the least significant zero bit of `x`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsfill_u32","","Sets all bits of `x` below the least significant one.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsic_u32","","Clears least significant bit and sets all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_t1mskc_u32","","Clears all bits below the least significant zero of `x` and sets all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_tzmsk_u32","","Sets all bits below the least significant one of `x` and clears all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_setzero_si64","","Constructs a 64-bit integer vector initialized to zero.",null,{"inputs":[],"output":{"name":"__m64"}}],[5,"_mm_add_pi8","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddb","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_add_pi16","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddw","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_add_pi32","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddd","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pi8","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddsb","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pi16","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddsw","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pu8","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddusb","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pu16","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddusw","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_pi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubb","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_pi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubw","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_pi32","","Subtract packed 32-bit integers in `b` from packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubd","","Subtract packed 32-bit integers in `b` from packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubsb","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubsw","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pu8","","Subtract packed unsigned 8-bit integers in `b` from packed unsigned 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubusb","","Subtract packed unsigned 8-bit integers in `b` from packed unsigned 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pu16","","Subtract packed unsigned 16-bit integers in `b` from packed unsigned 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubusw","","Subtract packed unsigned 16-bit integers in `b` from packed unsigned 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_packs_pi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using signed saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_packs_pi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using signed saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cmpgt_pi8","","Compares whether each element of `a` is greater than the corresponding element of `b` returning `0` for `false` and `-1` for `true`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cmpgt_pi16","","Compares whether each element of `a` is greater than the corresponding element of `b` returning `0` for `false` and `-1` for `true`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cmpgt_pi32","","Compares whether each element of `a` is greater than the corresponding element of `b` returning `0` for `false` and `-1` for `true`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpackhi_pi16","","Unpacks the upper two elements from two `i16x4` vectors and interleaves them into the result: `[a.2, b.2, a.3, b.3]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpackhi_pi8","","Unpacks the upper four elements from two `i8x8` vectors and interleaves them into the result: `[a.4, b.4, a.5, b.5, a.6, b.6, a.7, b.7]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpacklo_pi8","","Unpacks the lower four elements from two `i8x8` vectors and interleaves them into the result: `[a.0, b.0, a.1, b.1, a.2, b.2, a.3, b.3]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpacklo_pi16","","Unpacks the lower two elements from two `i16x4` vectors and interleaves them into the result: `[a.0 b.0 a.1 b.1]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpackhi_pi32","","Unpacks the upper element from two `i32x2` vectors and interleaves them into the result: `[a.1, b.1]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpacklo_pi32","","Unpacks the lower element from two `i32x2` vectors and interleaves them into the result: `[a.0, b.0]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_set_pi16","","Set packed 16-bit integers in dst with the supplied values.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m64"}}],[5,"_mm_set_pi32","","Set packed 32-bit integers in dst with the supplied values.",null,{"inputs":[{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_set_pi8","","Set packed 8-bit integers in dst with the supplied values.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m64"}}],[5,"_mm_set1_pi16","","Broadcast 16-bit integer a to all all elements of dst.",null,{"inputs":[{"name":"i16"}],"output":{"name":"__m64"}}],[5,"_mm_set1_pi32","","Broadcast 32-bit integer a to all all elements of dst.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_set1_pi8","","Broadcast 8-bit integer a to all all elements of dst.",null,{"inputs":[{"name":"i8"}],"output":{"name":"__m64"}}],[5,"_mm_setr_pi16","","Set packed 16-bit integers in dst with the supplied values in reverse order.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m64"}}],[5,"_mm_setr_pi32","","Set packed 32-bit integers in dst with the supplied values in reverse order.",null,{"inputs":[{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_setr_pi8","","Set packed 8-bit integers in dst with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m64"}}],[5,"_mm_clmulepi64_si128","","Perform a carry-less multiplication of two 64-bit polynomials over the finite field GF(2^k).",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_aesdec_si128","","Perform one round of an AES decryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesdeclast_si128","","Perform the last round of an AES decryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesenc_si128","","Perform one round of an AES encryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesenclast_si128","","Perform the last round of an AES encryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesimc_si128","","Perform the `InvMixColumns` transformation on `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aeskeygenassist_si128","","Assist in expanding the AES cipher key.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_rdrand16_step","","Read a hardware generated 16-bit random value and store the result in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u16"}],"output":{"name":"i32"}}],[5,"_rdrand32_step","","Read a hardware generated 32-bit random value and store the result in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u32"}],"output":{"name":"i32"}}],[5,"_rdseed16_step","","Read a 16-bit NIST SP800-90B and SP800-90C compliant random value and store in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u16"}],"output":{"name":"i32"}}],[5,"_rdseed32_step","","Read a 32-bit NIST SP800-90B and SP800-90C compliant random value and store in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u32"}],"output":{"name":"i32"}}],[17,"_XCR_XFEATURE_ENABLED_MASK","","`XFEATURE_ENABLED_MASK` for `XCR`",null,null],[17,"_MM_EXCEPT_INVALID","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_DENORM","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_DIV_ZERO","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_OVERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_UNDERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_INEXACT","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_MASK","","See `_MM_GET_EXCEPTION_STATE`",null,null],[17,"_MM_MASK_INVALID","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_DENORM","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_DIV_ZERO","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_OVERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_UNDERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_INEXACT","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_MASK","","See `_MM_GET_EXCEPTION_MASK`",null,null],[17,"_MM_ROUND_NEAREST","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_DOWN","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_UP","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_TOWARD_ZERO","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_MASK","","See `_MM_GET_ROUNDING_MODE`",null,null],[17,"_MM_FLUSH_ZERO_MASK","","See `_MM_GET_FLUSH_ZERO_MODE`",null,null],[17,"_MM_FLUSH_ZERO_ON","","See `_mm_setcsr`",null,null],[17,"_MM_FLUSH_ZERO_OFF","","See `_mm_setcsr`",null,null],[17,"_MM_HINT_T0","","See `_mm_prefetch`.",null,null],[17,"_MM_HINT_T1","","See `_mm_prefetch`.",null,null],[17,"_MM_HINT_T2","","See `_mm_prefetch`.",null,null],[17,"_MM_HINT_NTA","","See `_mm_prefetch`.",null,null],[17,"_MM_FROUND_TO_NEAREST_INT","","round to nearest",null,null],[17,"_MM_FROUND_TO_NEG_INF","","round down",null,null],[17,"_MM_FROUND_TO_POS_INF","","round up",null,null],[17,"_MM_FROUND_TO_ZERO","","truncate",null,null],[17,"_MM_FROUND_CUR_DIRECTION","","use MXCSR.RC; see `vendor::_MM_SET_ROUNDING_MODE`",null,null],[17,"_MM_FROUND_RAISE_EXC","","do not suppress exceptions",null,null],[17,"_MM_FROUND_NO_EXC","","suppress exceptions",null,null],[17,"_MM_FROUND_NINT","","round to nearest and do not suppress exceptions",null,null],[17,"_MM_FROUND_FLOOR","","round down and do not suppress exceptions",null,null],[17,"_MM_FROUND_CEIL","","round up and do not suppress exceptions",null,null],[17,"_MM_FROUND_TRUNC","","truncate and do not suppress exceptions",null,null],[17,"_MM_FROUND_RINT","","use MXCSR.RC and do not suppress exceptions; see `vendor::_MM_SET_ROUNDING_MODE`",null,null],[17,"_MM_FROUND_NEARBYINT","","use MXCSR.RC and suppress exceptions; see `vendor::_MM_SET_ROUNDING_MODE`",null,null],[17,"_SIDD_UBYTE_OPS","","String contains unsigned 8-bit characters (Default)",null,null],[17,"_SIDD_UWORD_OPS","","String contains unsigned 16-bit characters",null,null],[17,"_SIDD_SBYTE_OPS","","String contains signed 8-bit characters",null,null],[17,"_SIDD_SWORD_OPS","","String contains unsigned 16-bit characters",null,null],[17,"_SIDD_CMP_EQUAL_ANY","","For each character in `a`, find if it is in `b` (Default)",null,null],[17,"_SIDD_CMP_RANGES","","For each character in `a`, determine if `b[0] <= c <= b[1] or b[1] <= c <= b[2]...`",null,null],[17,"_SIDD_CMP_EQUAL_EACH","","The strings defined by `a` and `b` are equal",null,null],[17,"_SIDD_CMP_EQUAL_ORDERED","","Search for the defined substring in the target",null,null],[17,"_SIDD_POSITIVE_POLARITY","","Do not negate results (Default)",null,null],[17,"_SIDD_NEGATIVE_POLARITY","","Negate results",null,null],[17,"_SIDD_MASKED_POSITIVE_POLARITY","","Do not negate results before the end of the string",null,null],[17,"_SIDD_MASKED_NEGATIVE_POLARITY","","Negate results only before the end of the string",null,null],[17,"_SIDD_LEAST_SIGNIFICANT","","Index only: return the least significant bit (Default)",null,null],[17,"_SIDD_MOST_SIGNIFICANT","","Index only: return the most significant bit",null,null],[17,"_SIDD_BIT_MASK","","Mask only: return the bit mask",null,null],[17,"_SIDD_UNIT_MASK","","Mask only: return the byte mask",null,null],[17,"_CMP_EQ_OQ","","Equal (ordered, non-signaling)",null,null],[17,"_CMP_LT_OS","","Less-than (ordered, signaling)",null,null],[17,"_CMP_LE_OS","","Less-than-or-equal (ordered, signaling)",null,null],[17,"_CMP_UNORD_Q","","Unordered (non-signaling)",null,null],[17,"_CMP_NEQ_UQ","","Not-equal (unordered, non-signaling)",null,null],[17,"_CMP_NLT_US","","Not-less-than (unordered, signaling)",null,null],[17,"_CMP_NLE_US","","Not-less-than-or-equal (unordered, signaling)",null,null],[17,"_CMP_ORD_Q","","Ordered (non-signaling)",null,null],[17,"_CMP_EQ_UQ","","Equal (unordered, non-signaling)",null,null],[17,"_CMP_NGE_US","","Not-greater-than-or-equal (unordered, signaling)",null,null],[17,"_CMP_NGT_US","","Not-greater-than (unordered, signaling)",null,null],[17,"_CMP_FALSE_OQ","","False (ordered, non-signaling)",null,null],[17,"_CMP_NEQ_OQ","","Not-equal (ordered, non-signaling)",null,null],[17,"_CMP_GE_OS","","Greater-than-or-equal (ordered, signaling)",null,null],[17,"_CMP_GT_OS","","Greater-than (ordered, signaling)",null,null],[17,"_CMP_TRUE_UQ","","True (unordered, non-signaling)",null,null],[17,"_CMP_EQ_OS","","Equal (ordered, signaling)",null,null],[17,"_CMP_LT_OQ","","Less-than (ordered, non-signaling)",null,null],[17,"_CMP_LE_OQ","","Less-than-or-equal (ordered, non-signaling)",null,null],[17,"_CMP_UNORD_S","","Unordered (signaling)",null,null],[17,"_CMP_NEQ_US","","Not-equal (unordered, signaling)",null,null],[17,"_CMP_NLT_UQ","","Not-less-than (unordered, non-signaling)",null,null],[17,"_CMP_NLE_UQ","","Not-less-than-or-equal (unordered, non-signaling)",null,null],[17,"_CMP_ORD_S","","Ordered (signaling)",null,null],[17,"_CMP_EQ_US","","Equal (unordered, signaling)",null,null],[17,"_CMP_NGE_UQ","","Not-greater-than-or-equal (unordered, non-signaling)",null,null],[17,"_CMP_NGT_UQ","","Not-greater-than (unordered, non-signaling)",null,null],[17,"_CMP_FALSE_OS","","False (ordered, signaling)",null,null],[17,"_CMP_NEQ_OS","","Not-equal (ordered, signaling)",null,null],[17,"_CMP_GE_OQ","","Greater-than-or-equal (ordered, non-signaling)",null,null],[17,"_CMP_GT_OQ","","Greater-than (ordered, non-signaling)",null,null],[17,"_CMP_TRUE_US","","True (unordered, signaling)",null,null],[0,"x86_64","core::arch","Platform-specific intrinsics for the `x86_64` platform.",null,null],[3,"__m64","core::arch::x86_64","64-bit wide integer vector type, x86-specific",null,null],[3,"__m128i","","128-bit wide integer vector type, x86-specific",null,null],[3,"__m128","","128-bit wide set of four `f32` types, x86-specific",null,null],[3,"__m128d","","128-bit wide set of two `f64` types, x86-specific",null,null],[3,"__m256i","","256-bit wide integer vector type, x86-specific",null,null],[3,"__m256","","256-bit wide set of eight `f32` types, x86-specific",null,null],[3,"__m256d","","256-bit wide set of four `f64` types, x86-specific",null,null],[3,"CpuidResult","","Result of the `cpuid` instruction.",null,null],[12,"eax","","EAX register.",239,null],[12,"ebx","","EBX register.",239,null],[12,"ecx","","ECX register.",239,null],[12,"edx","","EDX register.",239,null],[5,"__readeflags","","Reads EFLAGS.",null,{"inputs":[],"output":{"name":"u32"}}],[5,"__writeeflags","","Write EFLAGS.",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_bswap","","Return an integer with the reversed byte order of x",null,{"inputs":[{"name":"i32"}],"output":{"name":"i32"}}],[5,"_rdtsc","","Reads the current value of the processor’s time-stamp counter.",null,{"inputs":[],"output":{"name":"i64"}}],[5,"__rdtscp","","Reads the current value of the processor’s time-stamp counter and the `IA32_TSC_AUX MSR`.",null,null],[5,"__cpuid_count","","Returns the result of the `cpuid` instruction for a given `leaf` (`EAX`) and `sub_leaf` (`ECX`).",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"cpuidresult"}}],[5,"__cpuid","","See `__cpuid_count`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"cpuidresult"}}],[5,"has_cpuid","","Does the host support the `cpuid` instruction?",null,{"inputs":[],"output":{"name":"bool"}}],[5,"__get_cpuid_max","","Returns the highest-supported `leaf` (`EAX`) and sub-leaf (`ECX`) `cpuid` values.",null,null],[5,"_xsave","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xrstor","","Perform a full or partial restore of the enabled processor states using the state information stored in memory at `mem_addr`.",null,null],[5,"_xsetbv","","Copy 64-bits from `val` to the extended control register (`XCR`) specified by `a`.",null,{"inputs":[{"name":"u32"},{"name":"u64"}],"output":null}],[5,"_xgetbv","","Reads the contents of the extended control register `XCR` specified in `xcr_no`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u64"}}],[5,"_xsaveopt","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xsavec","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xsaves","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`",null,null],[5,"_xrstors","","Perform a full or partial restore of the enabled processor states using the state information stored in memory at `mem_addr`.",null,null],[5,"_mm_add_ss","","Adds the first component of `a` and `b`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_add_ps","","Adds __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sub_ss","","Subtracts the first component of `b` from `a`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sub_ps","","Subtracts __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_mul_ss","","Multiplies the first component of `a` and `b`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_mul_ps","","Multiplies __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_div_ss","","Divides the first component of `b` by `a`, the other components are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_div_ps","","Divides __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sqrt_ss","","Return the square root of the first single-precision (32-bit) floating-point element in `a`, the other elements are unchanged.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sqrt_ps","","Return the square root of packed single-precision (32-bit) floating-point elements in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rcp_ss","","Return the approximate reciprocal of the first single-precision (32-bit) floating-point element in `a`, the other elements are unchanged.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rcp_ps","","Return the approximate reciprocal of packed single-precision (32-bit) floating-point elements in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rsqrt_ss","","Return the approximate reciprocal square root of the fist single-precision (32-bit) floating-point elements in `a`, the other elements are unchanged.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_rsqrt_ps","","Return the approximate reciprocal square root of packed single-precision (32-bit) floating-point elements in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_min_ss","","Compare the first single-precision (32-bit) floating-point element of `a` and `b`, and return the minimum value in the first element of the return value, the other elements are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_min_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return the corresponding minimum values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_max_ss","","Compare the first single-precision (32-bit) floating-point element of `a` and `b`, and return the maximum value in the first element of the return value, the other elements are copied from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_max_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return the corresponding maximum values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_and_ps","","Bitwise AND of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_andnot_ps","","Bitwise AND-NOT of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_or_ps","","Bitwise OR of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_xor_ps","","Bitwise exclusive OR of packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpeq_ss","","Compare the lowest `f32` of both inputs for equality. The lowest 32 bits of the result will be `0xffffffff` if the two inputs are equal, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmplt_ss","","Compare the lowest `f32` of both inputs for less than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is less than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmple_ss","","Compare the lowest `f32` of both inputs for less than or equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is less than or equal `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpgt_ss","","Compare the lowest `f32` of both inputs for greater than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is greater than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpge_ss","","Compare the lowest `f32` of both inputs for greater than or equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is greater than or equal `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpneq_ss","","Compare the lowest `f32` of both inputs for inequality. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not equal to `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnlt_ss","","Compare the lowest `f32` of both inputs for not-less-than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not less than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnle_ss","","Compare the lowest `f32` of both inputs for not-less-than-or-equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not less than or equal to `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpngt_ss","","Compare the lowest `f32` of both inputs for not-greater-than. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not greater than `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnge_ss","","Compare the lowest `f32` of both inputs for not-greater-than-or-equal. The lowest 32 bits of the result will be `0xffffffff` if `a.extract(0)` is not greater than or equal to `b.extract(0)`, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpord_ss","","Check if the lowest `f32` of both inputs are ordered. The lowest 32 bits of the result will be `0xffffffff` if neither of `a.extract(0)` or `b.extract(0)` is a NaN, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpunord_ss","","Check if the lowest `f32` of both inputs are unordered. The lowest 32 bits of the result will be `0xffffffff` if any of `a.extract(0)` or `b.extract(0)` is a NaN, or `0` otherwise. The upper 96 bits of the result are the upper 96 bits of `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpeq_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input elements were equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmplt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is less than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmple_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is less than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpgt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is greater than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpge_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is greater than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpneq_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input elements are not equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnlt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not less than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnle_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not less than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpngt_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not greater than the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpnge_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. The result in the output vector will be `0xffffffff` if the input element in `a` is not greater than or equal to the corresponding element in `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpord_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. Returns four floats that have one of two possible bit patterns. The element in the output vector will be `0xffffffff` if the input elements in `a` and `b` are ordered (i.e., neither of them is a NaN), or 0 otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_cmpunord_ps","","Compare each of the four floats in `a` to the corresponding element in `b`. Returns four floats that have one of two possible bit patterns. The element in the output vector will be `0xffffffff` if the input elements in `a` and `b` are unordered (i.e., at least on of them is a NaN), or 0 otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_comieq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comilt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comile_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than or equal to the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comigt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comige_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than or equal to the one from `b`, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_comineq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are not equal, or `0` otherwise.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomieq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are equal, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomilt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomile_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is less than or equal to the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomigt_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomige_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if the value from `a` is greater than or equal to the one from `b`, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_ucomineq_ss","","Compare two 32-bit floats from the low-order bits of `a` and `b`. Returns `1` if they are not equal, or `0` otherwise. This instruction will not signal an exception if either argument is a quiet NaN.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvtss_si32","","Convert the lowest 32 bit float in the input vector to a 32 bit integer.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvt_ss2si","","Alias for `_mm_cvtss_si32`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvttss_si32","","Convert the lowest 32 bit float in the input vector to a 32 bit integer with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvtt_ss2si","","Alias for `_mm_cvttss_si32`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_cvtss_f32","","Extract the lowest 32 bit float from the input vector.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"f32"}}],[5,"_mm_cvtsi32_ss","","Convert a 32 bit integer to a 32 bit float. The result vector is the input vector `a` with the lowest 32 bit float replaced by the converted integer.",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_cvt_si2ss","","Alias for `_mm_cvtsi32_ss`.",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_set_ss","","Construct a `__m128` with the lowest element set to `a` and the rest set to zero.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_set1_ps","","Construct a `__m128` with all element set to `a`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_set_ps1","","Alias for `_mm_set1_ps`",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_set_ps","","Construct a `__m128` from four floating point values highest to lowest.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_setr_ps","","Construct a `__m128` from four floating point values lowest to highest.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm_setzero_ps","","Construct a `__m128` with all elements initialized to zero.",null,{"inputs":[],"output":{"name":"__m128"}}],[5,"_mm_shuffle_ps","","Shuffle packed single-precision (32-bit) floating-point elements in `a` and `b` using `mask`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"u32"}],"output":{"name":"__m128"}}],[5,"_mm_unpackhi_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the higher half of `a` and `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_unpacklo_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the lower half of `a` and `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_movehl_ps","","Combine higher half of `a` and `b`. The highwe half of `b` occupies the lower half of result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_movelh_ps","","Combine lower half of `a` and `b`. The lower half of `b` occupies the higher half of result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_movemask_ps","","Return a mask of the most significant bit of each element in `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_loadh_pi","","Set the upper two single-precision floating-point values with 64 bits of data loaded from the address `p`; the lower two values are passed through from `a`.",null,null],[5,"_mm_loadl_pi","","Load two floats from `p` into the lower half of a `__m128`. The upper half is copied from the upper half of `a`.",null,null],[5,"_mm_load_ss","","Construct a `__m128` with the lowest element read from `p` and the other elements set to zero.",null,null],[5,"_mm_load1_ps","","Construct a `__m128` by duplicating the value read from `p` into all elements.",null,null],[5,"_mm_load_ps1","","Alias for `_mm_load1_ps`",null,null],[5,"_mm_load_ps","","Load four `f32` values from aligned memory into a `__m128`. If the pointer is not aligned to a 128-bit boundary (16 bytes) a general protection fault will be triggered (fatal program crash).",null,null],[5,"_mm_loadu_ps","","Load four `f32` values from memory into a `__m128`. There are no restrictions on memory alignment. For aligned memory `_mm_load_ps` may be faster.",null,null],[5,"_mm_loadr_ps","","Load four `f32` values from aligned memory into a `__m128` in reverse order.",null,null],[5,"_mm_storeh_pi","","Store the upper half of `a` (64 bits) into memory.",null,null],[5,"_mm_storel_pi","","Store the lower half of `a` (64 bits) into memory.",null,null],[5,"_mm_store_ss","","Store the lowest 32 bit float of `a` into memory.",null,null],[5,"_mm_store1_ps","","Store the lowest 32 bit float of `a` repeated four times into aligned memory.",null,null],[5,"_mm_store_ps1","","Alias for `_mm_store1_ps`",null,null],[5,"_mm_store_ps","","Store four 32-bit floats into aligned memory.",null,null],[5,"_mm_storeu_ps","","Store four 32-bit floats into memory. There are no restrictions on memory alignment. For aligned memory `_mm_store_ps` may be faster.",null,null],[5,"_mm_storer_ps","","Store four 32-bit floats into aligned memory in reverse order.",null,null],[5,"_mm_move_ss","","Return a `__m128` with the first component from `b` and the remaining components from `a`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_sfence","","Perform a serializing operation on all store-to-memory instructions that were issued prior to this instruction.",null,{"inputs":[],"output":null}],[5,"_mm_getcsr","","Get the unsigned 32-bit value of the MXCSR control and status register.",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_mm_setcsr","","Set the MXCSR register with the 32-bit unsigned integer value.",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_GET_EXCEPTION_MASK","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_GET_EXCEPTION_STATE","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_GET_FLUSH_ZERO_MODE","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_GET_ROUNDING_MODE","","See `_mm_setcsr`",null,{"inputs":[],"output":{"name":"u32"}}],[5,"_MM_SET_EXCEPTION_MASK","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_SET_EXCEPTION_STATE","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_SET_FLUSH_ZERO_MODE","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_MM_SET_ROUNDING_MODE","","See `_mm_setcsr`",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"_mm_prefetch","","Fetch the cache line that contains address `p` using the given `strategy`.",null,null],[5,"_mm_undefined_ps","","Return vector of type __m128 with undefined elements.",null,{"inputs":[],"output":{"name":"__m128"}}],[5,"_MM_TRANSPOSE4_PS","","Transpose the 4x4 matrix formed by 4 rows of __m128 in place.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"__m128"},{"name":"__m128"}],"output":null}],[5,"_mm_stream_ps","","Stores `a` into the memory at `mem_addr` using a non-temporal memory hint.",null,null],[5,"_mm_stream_pi","","Store 64-bits of integer data from a into memory using a non-temporal memory hint.",null,null],[5,"_mm_max_pi16","","Compares the packed 16-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pmaxsw","","Compares the packed 16-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_max_pu8","","Compares the packed 8-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pmaxub","","Compares the packed 8-bit signed integers of `a` and `b` writing the greatest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_min_pi16","","Compares the packed 16-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pminsw","","Compares the packed 16-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_min_pu8","","Compares the packed 8-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pminub","","Compares the packed 8-bit signed integers of `a` and `b` writing the smallest value into the result.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_mulhi_pu16","","Multiplies packed 16-bit unsigned integer values and writes the high-order 16 bits of each 32-bit product to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pmulhuw","","Multiplies packed 16-bit unsigned integer values and writes the high-order 16 bits of each 32-bit product to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_avg_pu8","","Computes the rounded averages of the packed unsigned 8-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pavgb","","Computes the rounded averages of the packed unsigned 8-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_avg_pu16","","Computes the rounded averages of the packed unsigned 16-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_pavgw","","Computes the rounded averages of the packed unsigned 16-bit integer values and writes the averages to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sad_pu8","","Subtracts the corresponding 8-bit unsigned integer values of the two 64-bit vector operands and computes the absolute value for each of the difference. Then sum of the 8 absolute differences is written to the bits [15:0] of the destination; the remaining bits [63:16] are cleared.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psadbw","","Subtracts the corresponding 8-bit unsigned integer values of the two 64-bit vector operands and computes the absolute value for each of the difference. Then sum of the 8 absolute differences is written to the bits [15:0] of the destination; the remaining bits [63:16] are cleared.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cvtpi32_ps","","Converts two elements of a 64-bit vector of [2 x i32] into two floating point values and writes them to the lower 64-bits of the destination. The remaining higher order elements of the destination are copied from the corresponding elements in the first operand.",null,{"inputs":[{"name":"__m128"},{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvt_pi2ps","","Converts two elements of a 64-bit vector of [2 x i32] into two floating point values and writes them to the lower 64-bits of the destination. The remaining higher order elements of the destination are copied from the corresponding elements in the first operand.",null,{"inputs":[{"name":"__m128"},{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpi8_ps","","Converts the lower 4 8-bit values of `a` into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpu8_ps","","Converts the lower 4 8-bit values of `a` into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpi16_ps","","Converts a 64-bit vector of `i16`s into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpu16_ps","","Converts a 64-bit vector of `i16`s into a 128-bit vector of 4 `f32`s.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtpi32x2_ps","","Converts the two 32-bit signed integer values from each 64-bit vector operand of [2 x i32] into a 128-bit vector of [4 x float].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m128"}}],[5,"_mm_maskmove_si64","","Conditionally copies the values from each 8-bit element in the first 64-bit integer vector operand to the specified memory location, as specified by the most significant bit in the corresponding element in the second 64-bit integer vector operand.",null,null],[5,"_m_maskmovq","","Conditionally copies the values from each 8-bit element in the first 64-bit integer vector operand to the specified memory location, as specified by the most significant bit in the corresponding element in the second 64-bit integer vector operand.",null,null],[5,"_mm_extract_pi16","","Extracts 16-bit element from a 64-bit vector of [4 x i16] and returns it, as specified by the immediate integer operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_m_pextrw","","Extracts 16-bit element from a 64-bit vector of [4 x i16] and returns it, as specified by the immediate integer operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_insert_pi16","","Copies data from the 64-bit vector of [4 x i16] to the destination, and inserts the lower 16-bits of an integer operand at the 16-bit offset specified by the immediate operand `n`.",null,{"inputs":[{"name":"__m64"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_m_pinsrw","","Copies data from the 64-bit vector of [4 x i16] to the destination, and inserts the lower 16-bits of an integer operand at the 16-bit offset specified by the immediate operand `n`.",null,{"inputs":[{"name":"__m64"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_movemask_pi8","","Takes the most significant bit from each 8-bit element in a 64-bit integer vector to create a 16-bit mask value. Zero-extends the value to 32-bit integer and writes it to the destination.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"i32"}}],[5,"_m_pmovmskb","","Takes the most significant bit from each 8-bit element in a 64-bit integer vector to create a 16-bit mask value. Zero-extends the value to 32-bit integer and writes it to the destination.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"i32"}}],[5,"_mm_shuffle_pi16","","Shuffles the 4 16-bit integers from a 64-bit integer vector to the destination, as specified by the immediate value operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_m_pshufw","","Shuffles the 4 16-bit integers from a 64-bit integer vector to the destination, as specified by the immediate value operand.",null,{"inputs":[{"name":"__m64"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_cvttps_pi32","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtt_ps2pi","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtps_pi32","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvt_ps2pi","","Convert the two lower packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtps_pi16","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 16-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_cvtps_pi8","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 8-bit integers, and returns theem in the lower 4 elements of the result.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m64"}}],[5,"_mm_pause","","Provide a hint to the processor that the code sequence is a spin-wait loop.",null,{"inputs":[],"output":null}],[5,"_mm_clflush","","Invalidate and flush the cache line that contains `p` from all levels of the cache hierarchy.",null,null],[5,"_mm_lfence","","Perform a serializing operation on all load-from-memory instructions that were issued prior to this instruction.",null,{"inputs":[],"output":null}],[5,"_mm_mfence","","Perform a serializing operation on all load-from-memory and store-to-memory instructions that were issued prior to this instruction.",null,{"inputs":[],"output":null}],[5,"_mm_add_epi8","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_epi16","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_epi32","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_epi64","","Add packed 64-bit integers in `a` and \"b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epi8","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epi16","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epu8","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_adds_epu16","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_avg_epu8","","Average packed unsigned 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_avg_epu16","","Average packed unsigned 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_madd_epi16","","Multiply and then horizontally add signed 16 bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mulhi_epi16","","Multiply the packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mulhi_epu16","","Multiply the packed unsigned 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mullo_epi16","","Multiply the packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mul_epu32","","Multiply the low unsigned 32-bit integers from each packed 64-bit element in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sad_epu8","","Sum the absolute differences of packed unsigned 8-bit integers.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi32","","Subtract packed 32-bit integers in `b` from packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sub_epi64","","Subtract packed 64-bit integers in `b` from packed 64-bit integers in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epu8","","Subtract packed unsigned 8-bit integers in `b` from packed unsigned 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_subs_epu16","","Subtract packed unsigned 16-bit integers in `b` from packed unsigned 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_si128","","Shift `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_bslli_si128","","Shift `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_bsrli_si128","","Shift `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_epi16","","Shift packed 16-bit integers in `a` left by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sll_epi16","","Shift packed 16-bit integers in `a` left by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_epi32","","Shift packed 32-bit integers in `a` left by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sll_epi32","","Shift packed 32-bit integers in `a` left by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_slli_epi64","","Shift packed 64-bit integers in `a` left by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sll_epi64","","Shift packed 64-bit integers in `a` left by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srai_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sra_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srai_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_sra_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_si128","","Shift `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srl_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srl_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_srli_epi64","","Shift packed 64-bit integers in `a` right by `imm8` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_srl_epi64","","Shift packed 64-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_and_si128","","Compute the bitwise AND of 128 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_andnot_si128","","Compute the bitwise NOT of 128 bits (representing integer data) in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_or_si128","","Compute the bitwise OR of 128 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_xor_si128","","Compute the bitwise XOR of 128 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi8","","Compare packed 8-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi16","","Compare packed 16-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi32","","Compare packed 32-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpgt_epi8","","Compare packed 8-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpgt_epi16","","Compare packed 16-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpgt_epi32","","Compare packed 32-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmplt_epi8","","Compare packed 8-bit integers in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmplt_epi16","","Compare packed 16-bit integers in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmplt_epi32","","Compare packed 32-bit integers in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi32_pd","","Convert the lower two packed 32-bit integers in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128d"}}],[5,"_mm_cvtsi32_sd","","Return `a` with its lower element replaced by `b` after converting it to an `f64`.",null,{"inputs":[{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_cvtepi32_ps","","Convert packed 32-bit integers in `a` to packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128"}}],[5,"_mm_cvtps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsi32_si128","","Return a vector whose lowest element is `a` and all higher elements are `0`.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsi128_si32","","Return the lowest element of `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_set_epi64x","","Set packed 64-bit integers with the supplied values, from highest to lowest.",null,{"inputs":[{"name":"i64"},{"name":"i64"}],"output":{"name":"__m128i"}}],[5,"_mm_set_epi32","","Set packed 32-bit integers with the supplied values.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_set_epi16","","Set packed 16-bit integers with the supplied values.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m128i"}}],[5,"_mm_set_epi8","","Set packed 8-bit integers with the supplied values.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi64x","","Broadcast 64-bit integer `a` to all elements.",null,{"inputs":[{"name":"i64"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi32","","Broadcast 32-bit integer `a` to all elements.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi16","","Broadcast 16-bit integer `a` to all elements.",null,{"inputs":[{"name":"i16"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi8","","Broadcast 8-bit integer `a` to all elements.",null,{"inputs":[{"name":"i8"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi32","","Set packed 32-bit integers with the supplied values in reverse order.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi16","","Set packed 16-bit integers with the supplied values in reverse order.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi8","","Set packed 8-bit integers with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m128i"}}],[5,"_mm_setzero_si128","","Returns a vector with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m128i"}}],[5,"_mm_loadl_epi64","","Load 64-bit integer from memory into first element of returned vector.",null,null],[5,"_mm_load_si128","","Load 128-bits of integer data from memory into a new vector.",null,null],[5,"_mm_loadu_si128","","Load 128-bits of integer data from memory into a new vector.",null,null],[5,"_mm_maskmoveu_si128","","Conditionally store 8-bit integer elements from `a` into memory using `mask`.",null,null],[5,"_mm_store_si128","","Store 128-bits of integer data from `a` into memory.",null,null],[5,"_mm_storeu_si128","","Store 128-bits of integer data from `a` into memory.",null,null],[5,"_mm_storel_epi64","","Store the lower 64-bit integer `a` to a memory location.",null,null],[5,"_mm_stream_si128","","Stores a 128-bit integer vector to a 128-bit aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm_stream_si32","","Stores a 32-bit integer value in the specified memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm_move_epi64","","Return a vector where the low element is extracted from `a` and its upper element is zero.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packs_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using signed saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packs_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using signed saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packus_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using unsigned saturation.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_extract_epi16","","Return the `imm8` element of `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_insert_epi16","","Return a new vector where the `imm8` element of `a` is replaced with `i`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_movemask_epi8","","Return a mask of the most significant bit of each element in `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_shuffle_epi32","","Shuffle 32-bit integers in `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_shufflehi_epi16","","Shuffle 16-bit integers in the high 64 bits of `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_shufflelo_epi16","","Shuffle 16-bit integers in the low 64 bits of `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi8","","Unpack and interleave 8-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi16","","Unpack and interleave 16-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi32","","Unpack and interleave 32-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_epi64","","Unpack and interleave 64-bit integers from the high half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi8","","Unpack and interleave 8-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi16","","Unpack and interleave 16-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi32","","Unpack and interleave 32-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_unpacklo_epi64","","Unpack and interleave 64-bit integers from the low half of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_add_sd","","Return a new vector with the low element of `a` replaced by the sum of the low elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_add_pd","","Add packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_div_sd","","Return a new vector with the low element of `a` replaced by the result of diving the lower element of `a` by the lower element of `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_div_pd","","Divide packed double-precision (64-bit) floating-point elements in `a` by packed elements in `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_max_sd","","Return a new vector with the low element of `a` replaced by the maximum of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_max_pd","","Return a new vector with the maximum values from corresponding elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_min_sd","","Return a new vector with the low element of `a` replaced by the minimum of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_min_pd","","Return a new vector with the minimum values from corresponding elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_mul_sd","","Return a new vector with the low element of `a` replaced by multiplying the low elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_mul_pd","","Multiply packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sqrt_sd","","Return a new vector with the low element of `a` replaced by the square root of the lower element `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sqrt_pd","","Return a new vector with the square root of each of the values in `a`.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sub_sd","","Return a new vector with the low element of `a` replaced by subtracting the low element by `b` from the low element of `a`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_sub_pd","","Subtract packed double-precision (64-bit) floating-point elements in `b` from `a`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_and_pd","","Compute the bitwise AND of packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_andnot_pd","","Compute the bitwise NOT of `a` and then AND with `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_or_pd","","Compute the bitwise OR of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_xor_pd","","Compute the bitwise OR of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpeq_sd","","Return a new vector with the low element of `a` replaced by the equality comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmplt_sd","","Return a new vector with the low element of `a` replaced by the less-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmple_sd","","Return a new vector with the low element of `a` replaced by the less-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpgt_sd","","Return a new vector with the low element of `a` replaced by the greater-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpge_sd","","Return a new vector with the low element of `a` replaced by the greater-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpord_sd","","Return a new vector with the low element of `a` replaced by the result of comparing both of the lower elements of `a` and `b` to `NaN`. If neither are equal to `NaN` then `0xFFFFFFFFFFFFFFFF` is used and `0` otherwise.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpunord_sd","","Return a new vector with the low element of `a` replaced by the result of comparing both of the lower elements of `a` and `b` to `NaN`. If either is equal to `NaN` then `0xFFFFFFFFFFFFFFFF` is used and `0` otherwise.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpneq_sd","","Return a new vector with the low element of `a` replaced by the not-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnlt_sd","","Return a new vector with the low element of `a` replaced by the not-less-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnle_sd","","Return a new vector with the low element of `a` replaced by the not-less-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpngt_sd","","Return a new vector with the low element of `a` replaced by the not-greater-than comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnge_sd","","Return a new vector with the low element of `a` replaced by the not-greater-than-or-equal comparison of the lower elements of `a` and `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpeq_pd","","Compare corresponding elements in `a` and `b` for equality.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmplt_pd","","Compare corresponding elements in `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmple_pd","","Compare corresponding elements in `a` and `b` for less-than-or-equal",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpgt_pd","","Compare corresponding elements in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpge_pd","","Compare corresponding elements in `a` and `b` for greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpord_pd","","Compare corresponding elements in `a` and `b` to see if neither is `NaN`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpunord_pd","","Compare corresponding elements in `a` and `b` to see if either is `NaN`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpneq_pd","","Compare corresponding elements in `a` and `b` for not-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnlt_pd","","Compare corresponding elements in `a` and `b` for not-less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnle_pd","","Compare corresponding elements in `a` and `b` for not-less-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpngt_pd","","Compare corresponding elements in `a` and `b` for not-greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_cmpnge_pd","","Compare corresponding elements in `a` and `b` for not-greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_comieq_sd","","Compare the lower element of `a` and `b` for equality.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comilt_sd","","Compare the lower element of `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comile_sd","","Compare the lower element of `a` and `b` for less-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comigt_sd","","Compare the lower element of `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comige_sd","","Compare the lower element of `a` and `b` for greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_comineq_sd","","Compare the lower element of `a` and `b` for not-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomieq_sd","","Compare the lower element of `a` and `b` for equality.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomilt_sd","","Compare the lower element of `a` and `b` for less-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomile_sd","","Compare the lower element of `a` and `b` for less-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomigt_sd","","Compare the lower element of `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomige_sd","","Compare the lower element of `a` and `b` for greater-than-or-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_ucomineq_sd","","Compare the lower element of `a` and `b` for not-equal.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_cvtpd_ps","","Convert packed double-precision (64-bit) floating-point elements in \"a\" to packed single-precision (32-bit) floating-point elements",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128"}}],[5,"_mm_cvtps_pd","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128d"}}],[5,"_mm_cvtpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsd_si32","","Convert the lower double-precision (64-bit) floating-point element in a to a 32-bit integer.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_cvtsd_ss","","Convert the lower double-precision (64-bit) floating-point element in `b` to a single-precision (32-bit) floating-point element, store the result in the lower element of the return value, and copy the upper element from `a` to the upper element the return value.",null,{"inputs":[{"name":"__m128"},{"name":"__m128d"}],"output":{"name":"__m128"}}],[5,"_mm_cvtsd_f64","","Return the lower double-precision (64-bit) floating-point element of \"a\".",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"f64"}}],[5,"_mm_cvtss_sd","","Convert the lower single-precision (32-bit) floating-point element in `b` to a double-precision (64-bit) floating-point element, store the result in the lower element of the return value, and copy the upper element from `a` to the upper element the return value.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128"}],"output":{"name":"__m128d"}}],[5,"_mm_cvttpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128i"}}],[5,"_mm_cvttsd_si32","","Convert the lower double-precision (64-bit) floating-point element in `a` to a 32-bit integer with truncation.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_cvttps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128i"}}],[5,"_mm_set_sd","","Copy double-precision (64-bit) floating-point element `a` to the lower element of the packed 64-bit return value.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_set1_pd","","Broadcast double-precision (64-bit) floating-point value a to all elements of the return value.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_set_pd1","","Broadcast double-precision (64-bit) floating-point value a to all elements of the return value.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_set_pd","","Set packed double-precision (64-bit) floating-point elements in the return value with the supplied values.",null,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_setr_pd","","Set packed double-precision (64-bit) floating-point elements in the return value with the supplied values in reverse order.",null,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"__m128d"}}],[5,"_mm_setzero_pd","","Returns packed double-precision (64-bit) floating-point elements with all zeros.",null,{"inputs":[],"output":{"name":"__m128d"}}],[5,"_mm_movemask_pd","","Return a mask of the most significant bit of each element in `a`.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_load_pd","","Load 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from memory into the returned vector. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_load_sd","","Loads a 64-bit double-precision value to the low element of a 128-bit integer vector and clears the upper element.",null,null],[5,"_mm_loadh_pd","","Loads a double-precision value into the high-order bits of a 128-bit vector of [2 x double]. The low-order bits are copied from the low-order bits of the first operand.",null,null],[5,"_mm_loadl_pd","","Loads a double-precision value into the low-order bits of a 128-bit vector of [2 x double]. The high-order bits are copied from the high-order bits of the first operand.",null,null],[5,"_mm_stream_pd","","Stores a 128-bit floating point vector of [2 x double] to a 128-bit aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm_store_sd","","Stores the lower 64 bits of a 128-bit vector of [2 x double] to a memory location.",null,null],[5,"_mm_store_pd","","Store 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_storeu_pd","","Store 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm_store1_pd","","Store the lower double-precision (64-bit) floating-point element from `a` into 2 contiguous elements in memory. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_store_pd1","","Store the lower double-precision (64-bit) floating-point element from `a` into 2 contiguous elements in memory. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_storer_pd","","Store 2 double-precision (64-bit) floating-point elements from `a` into memory in reverse order. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_storeh_pd","","Stores the upper 64 bits of a 128-bit vector of [2 x double] to a memory location.",null,null],[5,"_mm_storel_pd","","Stores the lower 64 bits of a 128-bit vector of [2 x double] to a memory location.",null,null],[5,"_mm_load1_pd","","Load a double-precision (64-bit) floating-point element from memory into both elements of returned vector.",null,null],[5,"_mm_load_pd1","","Load a double-precision (64-bit) floating-point element from memory into both elements of returned vector.",null,null],[5,"_mm_loadr_pd","","Load 2 double-precision (64-bit) floating-point elements from memory into the returned vector in reverse order. `mem_addr` must be aligned on a 16-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm_loadu_pd","","Load 128-bits (composed of 2 packed double-precision (64-bit) floating-point elements) from memory into the returned vector. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm_shuffle_pd","","Constructs a 128-bit floating-point vector of [2 x double] from two 128-bit vector parameters of [2 x double], using the immediate-value parameter as a specifier.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_move_sd","","Constructs a 128-bit floating-point vector of [2 x double]. The lower 64 bits are set to the lower 64 bits of the second parameter. The upper 64 bits are set to the upper 64 bits of the first parameter.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_castpd_ps","","Casts a 128-bit floating-point vector of [2 x double] into a 128-bit floating-point vector of [4 x float].",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128"}}],[5,"_mm_castpd_si128","","Casts a 128-bit floating-point vector of [2 x double] into a 128-bit integer vector.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128i"}}],[5,"_mm_castps_pd","","Casts a 128-bit floating-point vector of [4 x float] into a 128-bit floating-point vector of [2 x double].",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128d"}}],[5,"_mm_castps_si128","","Casts a 128-bit floating-point vector of [4 x float] into a 128-bit integer vector.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128i"}}],[5,"_mm_castsi128_pd","","Casts a 128-bit integer vector into a 128-bit floating-point vector of [2 x double].",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128d"}}],[5,"_mm_castsi128_ps","","Casts a 128-bit integer vector into a 128-bit floating-point vector of [4 x float].",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128"}}],[5,"_mm_undefined_pd","","Return vector of type __m128d with undefined elements.",null,{"inputs":[],"output":{"name":"__m128d"}}],[5,"_mm_undefined_si128","","Return vector of type __m128i with undefined elements.",null,{"inputs":[],"output":{"name":"__m128i"}}],[5,"_mm_unpackhi_pd","","The resulting `__m128d` element is composed by the low-order values of the two `__m128d` interleaved input elements, i.e.:",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_unpacklo_pd","","The resulting `__m128d` element is composed by the high-order values of the two `__m128d` interleaved input elements, i.e.:",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_add_si64","","Adds two signed or unsigned 64-bit integer values, returning the lower 64 bits of the sum.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_mul_su32","","Multiplies 32-bit unsigned integer values contained in the lower bits of the two 64-bit integer vectors and returns the 64-bit unsigned product.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_si64","","Subtracts signed or unsigned 64-bit integer values and writes the difference to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cvtpi32_pd","","Converts the two signed 32-bit integer elements of a 64-bit vector of [2 x i32] into two double-precision floating-point values, returned in a 128-bit vector of [2 x double].",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128d"}}],[5,"_mm_set_epi64","","Initializes both 64-bit values in a 128-bit vector of [2 x i64] with the specified 64-bit integer values.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_set1_epi64","","Initializes both values in a 128-bit vector of [2 x i64] with the specified 64-bit value.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_setr_epi64","","Constructs a 128-bit integer vector, initialized in reverse order with the specified 64-bit integral values.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_movepi64_pi64","","Returns the lower 64 bits of a 128-bit integer vector as a 64-bit integer.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m64"}}],[5,"_mm_movpi64_epi64","","Moves the 64-bit operand to a 128-bit integer vector, zeroing the upper bits.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtpd_pi32","","Converts the two double-precision floating-point elements of a 128-bit vector of [2 x double] into two signed 32-bit integer values, returned in a 64-bit vector of [2 x i32].",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m64"}}],[5,"_mm_cvttpd_pi32","","Converts the two double-precision floating-point elements of a 128-bit vector of [2 x double] into two signed 32-bit integer values, returned in a 64-bit vector of [2 x i32]. If the result of either conversion is inexact, the result is truncated (rounded towards zero) regardless of the current MXCSR setting.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m64"}}],[5,"_mm_addsub_ps","","Alternatively add and subtract packed single-precision (32-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_addsub_pd","","Alternatively add and subtract packed double-precision (64-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_hadd_pd","","Horizontally add adjacent pairs of double-precision (64-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_hadd_ps","","Horizontally add adjacent pairs of single-precision (32-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_hsub_pd","","Horizontally subtract adjacent pairs of double-precision (64-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_hsub_ps","","Horizontally add adjacent pairs of single-precision (32-bit) floating-point elements in `a` and `b`, and pack the results.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_lddqu_si128","","Load 128-bits of integer data from unaligned memory. This intrinsic may perform better than `_mm_loadu_si128` when the data crosses a cache line boundary.",null,null],[5,"_mm_movedup_pd","","Duplicate the low double-precision (64-bit) floating-point element from `a`.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_loaddup_pd","","Load a double-precision (64-bit) floating-point element from memory into both elements of return vector.",null,null],[5,"_mm_movehdup_ps","","Duplicate odd-indexed single-precision (32-bit) floating-point elements from `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_moveldup_ps","","Duplicate even-indexed single-precision (32-bit) floating-point elements from `a`.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_abs_epi8","","Compute the absolute value of packed 8-bit signed integers in `a` and return the unsigned results.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_abs_epi16","","Compute the absolute value of each of the packed 16-bit signed integers in `a` and return the 16-bit unsigned integer",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_abs_epi32","","Compute the absolute value of each of the packed 32-bit signed integers in `a` and return the 32-bit unsigned integer",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_shuffle_epi8","","Shuffle bytes from `a` according to the content of `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_alignr_epi8","","Concatenate 16-byte blocks in `a` and `b` into a 32-byte temporary result, shift the result right by `n` bytes, and return the low 16 bytes.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_hadd_epi16","","Horizontally add the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hadds_epi16","","Horizontally add the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16]. Positive sums greater than 7FFFh are saturated to 7FFFh. Negative sums less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hadd_epi32","","Horizontally add the adjacent pairs of values contained in 2 packed 128-bit vectors of [4 x i32].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hsub_epi16","","Horizontally subtract the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hsubs_epi16","","Horizontally subtract the adjacent pairs of values contained in 2 packed 128-bit vectors of [8 x i16]. Positive differences greater than 7FFFh are saturated to 7FFFh. Negative differences less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_hsub_epi32","","Horizontally subtract the adjacent pairs of values contained in 2 packed 128-bit vectors of [4 x i32].",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_maddubs_epi16","","Multiply corresponding pairs of packed 8-bit unsigned integer values contained in the first source operand and packed 8-bit signed integer values contained in the second source operand, add pairs of contiguous products with signed saturation, and writes the 16-bit sums to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mulhrs_epi16","","Multiply packed 16-bit signed integer values, truncate the 32-bit product to the 18 most significant bits by right-shifting, round the truncated value by adding 1, and write bits [16:1] to the destination.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sign_epi8","","Negate packed 8-bit integers in `a` when the corresponding signed 8-bit integer in `b` is negative, and return the result. Elements in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sign_epi16","","Negate packed 16-bit integers in `a` when the corresponding signed 16-bit integer in `b` is negative, and return the results. Elements in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_sign_epi32","","Negate packed 32-bit integers in `a` when the corresponding signed 32-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_abs_pi8","","Compute the absolute value of packed 8-bit integers in `a` and return the unsigned results.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_abs_pi16","","Compute the absolute value of packed 8-bit integers in `a`, and return the unsigned results.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_abs_pi32","","Compute the absolute value of packed 32-bit integers in `a`, and return the unsigned results.",null,{"inputs":[{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_shuffle_pi8","","Shuffle packed 8-bit integers in `a` according to shuffle control mask in the corresponding 8-bit element of `b`, and return the results",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_alignr_pi8","","Concatenates the two 64-bit integer vector operands, and right-shifts the result by the number of bytes specified in the immediate operand.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_hadd_pi16","","Horizontally add the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hadd_pi32","","Horizontally add the adjacent pairs of values contained in 2 packed 64-bit vectors of [2 x i32].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hadds_pi16","","Horizontally add the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16]. Positive sums greater than 7FFFh are saturated to 7FFFh. Negative sums less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hsub_pi16","","Horizontally subtracts the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hsub_pi32","","Horizontally subtracts the adjacent pairs of values contained in 2 packed 64-bit vectors of [2 x i32].",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_hsubs_pi16","","Horizontally subtracts the adjacent pairs of values contained in 2 packed 64-bit vectors of [4 x i16]. Positive differences greater than 7FFFh are saturated to 7FFFh. Negative differences less than 8000h are saturated to 8000h.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_maddubs_pi16","","Multiplies corresponding pairs of packed 8-bit unsigned integer values contained in the first source operand and packed 8-bit signed integer values contained in the second source operand, adds pairs of contiguous products with signed saturation, and writes the 16-bit sums to the corresponding bits in the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_mulhrs_pi16","","Multiplies packed 16-bit signed integer values, truncates the 32-bit products to the 18 most significant bits by right-shifting, rounds the truncated value by adding 1, and writes bits [16:1] to the destination.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sign_pi8","","Negate packed 8-bit integers in `a` when the corresponding signed 8-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sign_pi16","","Negate packed 16-bit integers in `a` when the corresponding signed 16-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sign_pi32","","Negate packed 32-bit integers in `a` when the corresponding signed 32-bit integer in `b` is negative, and return the results. Element in result are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_blendv_epi8","","Blend packed 8-bit integers from `a` and `b` using `mask`",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_blend_epi16","","Blend packed 16-bit integers from `a` and `b` using the mask `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_blendv_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using `mask`",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_blendv_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using `mask`",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_blend_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using control mask `imm2`",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_blend_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using mask `imm4`",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_extract_ps","","Extract a single-precision (32-bit) floating-point element from `a`, selected with `imm8`",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_extract_epi8","","Extract an 8-bit integer from `a`, selected with `imm8`. Returns a 32-bit integer containing the zero-extended integer data.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_extract_epi32","","Extract an 32-bit integer from `a` selected with `imm8`",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_insert_ps","","Select a single value in `a` to store at some position in `b`, Then zero elements according to `imm8`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_insert_epi8","","Return a copy of `a` with the 8-bit integer from `i` inserted at a location specified by `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_insert_epi32","","Return a copy of `a` with the 32-bit integer from `i` inserted at a location specified by `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epi8","","Compare packed 8-bit integers in `a` and `b` and return packed maximum values in dst.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return packed maximum.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epi32","","Compare packed 32-bit integers in `a` and `b`, and return packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_max_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return packed maximum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epi8","","Compare packed 8-bit integers in `a` and `b` and return packed minimum values in dst.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return packed minimum.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epi32","","Compare packed 32-bit integers in `a` and `b`, and return packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_min_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return packed minimum values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_packus_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using unsigned saturation",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpeq_epi64","","Compare packed 64-bit integers in `a` and `b` for equality",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi8_epi16","","Sign extend packed 8-bit integers in `a` to packed 16-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi8_epi32","","Sign extend packed 8-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi8_epi64","","Sign extend packed 8-bit integers in the low 8 bytes of `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi16_epi32","","Sign extend packed 16-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi16_epi64","","Sign extend packed 16-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepi32_epi64","","Sign extend packed 32-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu8_epi16","","Zero extend packed unsigned 8-bit integers in `a` to packed 16-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu8_epi32","","Zero extend packed unsigned 8-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu8_epi64","","Zero extend packed unsigned 8-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu16_epi32","","Zero extend packed unsigned 16-bit integers in `a` to packed 32-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu16_epi64","","Zero extend packed unsigned 16-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtepu32_epi64","","Zero extend packed unsigned 32-bit integers in `a` to packed 64-bit integers",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_dp_pd","","Returns the dot product of two __m128d vectors.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_dp_ps","","Returns the dot product of two __m128 vectors.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_floor_pd","","Round the packed double-precision (64-bit) floating-point elements in `a` down to an integer value, and store the results as packed double-precision floating-point elements.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_floor_ps","","Round the packed single-precision (32-bit) floating-point elements in `a` down to an integer value, and store the results as packed single-precision floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_floor_sd","","Round the lower double-precision (64-bit) floating-point element in `b` down to an integer value, store the result as a double-precision floating-point element in the lower element of the intrinsic result, and copy the upper element from `a` to the upper element of the intrinsic result.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_floor_ss","","Round the lower single-precision (32-bit) floating-point element in `b` down to an integer value, store the result as a single-precision floating-point element in the lower element of the intrinsic result, and copy the upper 3 packed elements from `a` to the upper elements of the intrinsic result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_ceil_pd","","Round the packed double-precision (64-bit) floating-point elements in `a` up to an integer value, and store the results as packed double-precision floating-point elements.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_ceil_ps","","Round the packed single-precision (32-bit) floating-point elements in `a` up to an integer value, and store the results as packed single-precision floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_ceil_sd","","Round the lower double-precision (64-bit) floating-point element in `b` up to an integer value, store the result as a double-precision floating-point element in the lower element of the intrisic result, and copy the upper element from `a` to the upper element of the intrinsic result.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm_ceil_ss","","Round the lower single-precision (32-bit) floating-point element in `b` up to an integer value, store the result as a single-precision floating-point element in the lower element of the intrinsic result, and copy the upper 3 packed elements from `a` to the upper elements of the intrinsic result.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm_round_pd","","Round the packed double-precision (64-bit) floating-point elements in `a` using the `rounding` parameter, and store the results as packed double-precision floating-point elements. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_round_ps","","Round the packed single-precision (32-bit) floating-point elements in `a` using the `rounding` parameter, and store the results as packed single-precision floating-point elements. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_round_sd","","Round the lower double-precision (64-bit) floating-point element in `b` using the `rounding` parameter, store the result as a double-precision floating-point element in the lower element of the intrinsic result, and copy the upper element from `a` to the upper element of the intrinsic result. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_round_ss","","Round the lower single-precision (32-bit) floating-point element in `b` using the `rounding` parameter, store the result as a single-precision floating-point element in the lower element of the intrinsic result, and copy the upper 3 packed elements from `a` to the upper elements of the instrinsic result. Rounding is done according to the rounding parameter, which can be one of:",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm_minpos_epu16","","Finds the minimum unsigned 16-bit element in the 128-bit __m128i vector, returning a vector containing its value in its first position, and its index in its second position; all other elements are set to zero.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mul_epi32","","Multiply the low 32-bit integers from each packed 64-bit element in `a` and `b`, and return the signed 64-bit result.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mullo_epi32","","Multiply the packed 32-bit integers in `a` and `b`, producing intermediate 64-bit integers, and returns the lowest 32-bit, whatever they might be, reinterpreted as a signed integer. While `pmulld __m128i::splat(2), __m128i::splat(2)` returns the obvious `__m128i::splat(4)`, due to wrapping arithmetic `pmulld __m128i::splat(i32::MAX), __m128i::splat(2)` would return a negative number.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_mpsadbw_epu8","","Subtracts 8-bit unsigned integer values and computes the absolute values of the differences to the corresponding bits in the destination. Then sums of the absolute differences are returned according to the bit fields in the immediate operand.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_testz_si128","","Tests whether the specified bits in a 128-bit integer vector are all zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_testc_si128","","Tests whether the specified bits in a 128-bit integer vector are all ones.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_testnzc_si128","","Tests whether the specified bits in a 128-bit integer vector are neither all zeros nor all ones.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_test_all_zeros","","Tests whether the specified bits in a 128-bit integer vector are all zeros.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_test_all_ones","","Tests whether the specified bits in `a` 128-bit integer vector are all ones.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_test_mix_ones_zeros","","Tests whether the specified bits in a 128-bit integer vector are neither all zeros nor all ones.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrm","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return the generated mask.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpistri","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8` and return the generated index. Similar to [`_mm_cmpestri`] with the exception that [`_mm_cmpestri`] requires the lengths of `a` and `b` to be explicitly specified.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrz","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return `1` if any character in `b` was null. and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrc","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return `1` if the resulting mask was non-zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistrs","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and returns `1` if any character in `a` was null, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistro","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return bit `0` of the resulting bit mask.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpistra","","Compare packed strings with implicit lengths in `a` and `b` using the control in `imm8`, and return `1` if `b` did not contain a null character and the resulting mask was zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrm","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return the generated mask.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_cmpestri","","Compare packed strings `a` and `b` with lengths `la` and `lb` using the control in `imm8` and return the generated index. Similar to [`_mm_cmpistri`] with the exception that [`_mm_cmpistri`] implicitly determines the length of `a` and `b`.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrz","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if any character in `b` was null, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrc","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if the resulting mask was non-zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestrs","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if any character in a was null, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestro","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return bit `0` of the resulting bit mask.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_cmpestra","","Compare packed strings in `a` and `b` with lengths `la` and `lb` using the control in `imm8`, and return `1` if `b` did not contain a null character and the resulting mask was zero, and `0` otherwise.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"},{"name":"__m128i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm_crc32_u8","","Starting with the initial value in `crc`, return the accumulated CRC32 value for unsigned 8-bit integer `v`.",null,{"inputs":[{"name":"u32"},{"name":"u8"}],"output":{"name":"u32"}}],[5,"_mm_crc32_u16","","Starting with the initial value in `crc`, return the accumulated CRC32 value for unsigned 16-bit integer `v`.",null,{"inputs":[{"name":"u32"},{"name":"u16"}],"output":{"name":"u32"}}],[5,"_mm_crc32_u32","","Starting with the initial value in `crc`, return the accumulated CRC32 value for unsigned 32-bit integer `v`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_cmpgt_epi64","","Compare packed 64-bit integers in `a` and `b` for greater-than, return the results.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_add_pd","","Add packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_add_ps","","Add packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_and_pd","","Compute the bitwise AND of a packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_and_ps","","Compute the bitwise AND of packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_or_pd","","Compute the bitwise OR packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_or_ps","","Compute the bitwise OR packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_shuffle_pd","","Shuffle double-precision (64-bit) floating-point elements within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_shuffle_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_andnot_pd","","Compute the bitwise NOT of packed double-precision (64-bit) floating-point elements in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_andnot_ps","","Compute the bitwise NOT of packed single-precision (32-bit) floating-point elements in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_max_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b`, and return packed maximum values",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_max_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return packed maximum values",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_min_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b`, and return packed minimum values",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_min_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b`, and return packed minimum values",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_mul_pd","","Add packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_mul_ps","","Add packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_addsub_pd","","Alternatively add and subtract packed double-precision (64-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_addsub_ps","","Alternatively add and subtract packed single-precision (32-bit) floating-point elements in `a` to/from packed elements in `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_sub_pd","","Subtract packed double-precision (64-bit) floating-point elements in `b` from packed elements in `a`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_sub_ps","","Subtract packed single-precision (32-bit) floating-point elements in `b` from packed elements in `a`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_div_ps","","Compute the division of each of the 8 packed 32-bit floating-point elements in `a` by the corresponding packed elements in `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_div_pd","","Compute the division of each of the 4 packed 64-bit floating-point elements in `a` by the corresponding packed elements in `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_round_pd","","Round packed double-precision (64-bit) floating point elements in `a` according to the flag `b`. The value of `b` may be as follows:",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_ceil_pd","","Round packed double-precision (64-bit) floating point elements in `a` toward positive infinity.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_floor_pd","","Round packed double-precision (64-bit) floating point elements in `a` toward negative infinity.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_round_ps","","Round packed single-precision (32-bit) floating point elements in `a` according to the flag `b`. The value of `b` may be as follows:",null,{"inputs":[{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_ceil_ps","","Round packed single-precision (32-bit) floating point elements in `a` toward positive infinity.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_floor_ps","","Round packed single-precision (32-bit) floating point elements in `a` toward negative infinity.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_sqrt_ps","","Return the square root of packed single-precision (32-bit) floating point elements in `a`.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_sqrt_pd","","Return the square root of packed double-precision (64-bit) floating point elements in `a`.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_blend_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_blend_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_blendv_pd","","Blend packed double-precision (64-bit) floating-point elements from `a` and `b` using `c` as a mask.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_blendv_ps","","Blend packed single-precision (32-bit) floating-point elements from `a` and `b` using `c` as a mask.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_dp_ps","","Conditionally multiply the packed single-precision (32-bit) floating-point elements in `a` and `b` using the high 4 bits in `imm8`, sum the four products, and conditionally return the sum  using the low 4 bits of `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_hadd_pd","","Horizontal addition of adjacent pairs in the two packed vectors of 4 64-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in even locations, while sums of elements from `b` are returned in odd locations.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_hadd_ps","","Horizontal addition of adjacent pairs in the two packed vectors of 8 32-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in locations of indices 0, 1, 4, 5; while sums of elements from `b` are locations 2, 3, 6, 7.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_hsub_pd","","Horizontal subtraction of adjacent pairs in the two packed vectors of 4 64-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in even locations, while sums of elements from `b` are returned in odd locations.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_hsub_ps","","Horizontal subtraction of adjacent pairs in the two packed vectors of 8 32-bit floating points `a` and `b`. In the result, sums of elements from `a` are returned in locations of indices 0, 1, 4, 5; while sums of elements from `b` are locations 2, 3, 6, 7.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_xor_pd","","Compute the bitwise XOR of packed double-precision (64-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_xor_ps","","Compute the bitwise XOR of packed single-precision (32-bit) floating-point elements in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm_cmp_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm256_cmp_pd","","Compare packed double-precision (64-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm_cmp_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_cmp_ps","","Compare packed single-precision (32-bit) floating-point elements in `a` and `b` based on the comparison operand specified by `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm_cmp_sd","","Compare the lower double-precision (64-bit) floating-point element in `a` and `b` based on the comparison operand specified by `imm8`, store the result in the lower element of returned vector, and copy the upper element from `a` to the upper element of returned vector.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm_cmp_ss","","Compare the lower single-precision (32-bit) floating-point element in `a` and `b` based on the comparison operand specified by `imm8`, store the result in the lower element of returned vector, and copy the upper 3 packed elements from `a` to the upper elements of returned vector.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_cvtepi32_pd","","Convert packed 32-bit integers in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256d"}}],[5,"_mm256_cvtepi32_ps","","Convert packed 32-bit integers in `a` to packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm256_cvtpd_ps","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed single-precision (32-bit) floating-point elements.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128"}}],[5,"_mm256_cvtps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtps_pd","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed double-precision (64-bit) floating-point elements.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256d"}}],[5,"_mm256_cvttpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128i"}}],[5,"_mm256_cvtpd_epi32","","Convert packed double-precision (64-bit) floating-point elements in `a` to packed 32-bit integers.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128i"}}],[5,"_mm256_cvttps_epi32","","Convert packed single-precision (32-bit) floating-point elements in `a` to packed 32-bit integers with truncation.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256i"}}],[5,"_mm256_extractf128_ps","","Extract 128 bits (composed of 4 packed single-precision (32-bit) floating-point elements) from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_extractf128_pd","","Extract 128 bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm256_extractf128_si256","","Extract 128 bits (composed of integer data) from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm256_zeroall","","Zero the contents of all XMM or YMM registers.",null,{"inputs":[],"output":null}],[5,"_mm256_zeroupper","","Zero the upper 128 bits of all YMM registers; the lower 128-bits of the registers are unmodified.",null,{"inputs":[],"output":null}],[5,"_mm256_permutevar_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` within 128-bit lanes using the control in `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm_permutevar_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` using the control in `b`.",null,{"inputs":[{"name":"__m128"},{"name":"__m128i"}],"output":{"name":"__m128"}}],[5,"_mm256_permute_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm_permute_ps","","Shuffle single-precision (32-bit) floating-point elements in `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m128"}}],[5,"_mm256_permutevar_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` within 256-bit lanes using the control in `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256i"}],"output":{"name":"__m256d"}}],[5,"_mm_permutevar_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` using the control in `b`.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128i"}],"output":{"name":"__m128d"}}],[5,"_mm256_permute_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` within 128-bit lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm_permute_pd","","Shuffle double-precision (64-bit) floating-point elements in `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m128d"}}],[5,"_mm256_permute2f128_ps","","Shuffle 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_permute2f128_pd","","Shuffle 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_permute2f128_si256","","Shuffle 258-bits (composed of integer data) selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_broadcast_ss","","Broadcast a single-precision (32-bit) floating-point element from memory to all elements of the returned vector.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm_broadcast_ss","","Broadcast a single-precision (32-bit) floating-point element from memory to all elements of the returned vector.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m128"}}],[5,"_mm256_broadcast_sd","","Broadcast a double-precision (64-bit) floating-point element from memory to all elements of the returned vector.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_broadcast_ps","","Broadcast 128 bits from memory (composed of 4 packed single-precision (32-bit) floating-point elements) to all elements of the returned vector.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_broadcast_pd","","Broadcast 128 bits from memory (composed of 2 packed double-precision (64-bit) floating-point elements) to all elements of the returned vector.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_insertf128_ps","","Copy `a` to result, then insert 128 bits (composed of 4 packed single-precision (32-bit) floating-point elements) from `b` into result at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256"},{"name":"__m128"},{"name":"i32"}],"output":{"name":"__m256"}}],[5,"_mm256_insertf128_pd","","Copy `a` to result, then insert 128 bits (composed of 2 packed double-precision (64-bit) floating-point elements) from `b` into result at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m128d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_insertf128_si256","","Copy `a` to result, then insert 128 bits from `b` into result at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_insert_epi8","","Copy `a` to result, and insert the 8-bit integer `i` into result at the location specified by `index`.",null,{"inputs":[{"name":"__m256i"},{"name":"i8"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_insert_epi16","","Copy `a` to result, and insert the 16-bit integer `i` into result at the location specified by `index`.",null,{"inputs":[{"name":"__m256i"},{"name":"i16"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_insert_epi32","","Copy `a` to result, and insert the 32-bit integer `i` into result at the location specified by `index`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_load_pd","","Load 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from memory into result. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_store_pd","","Store 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_load_ps","","Load 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from memory into result. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_store_ps","","Store 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from `a` into memory. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_loadu_pd","","Load 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from memory into result. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu_pd","","Store 256-bits (composed of 4 packed double-precision (64-bit) floating-point elements) from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_loadu_ps","","Load 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from memory into result. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu_ps","","Store 256-bits (composed of 8 packed single-precision (32-bit) floating-point elements) from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_load_si256","","Load 256-bits of integer data from memory into result. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_store_si256","","Store 256-bits of integer data from `a` into memory. `mem_addr` must be aligned on a 32-byte boundary or a general-protection exception may be generated.",null,null],[5,"_mm256_loadu_si256","","Load 256-bits of integer data from memory into result. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu_si256","","Store 256-bits of integer data from `a` into memory. `mem_addr` does not need to be aligned on any particular boundary.",null,null],[5,"_mm256_maskload_pd","","Load packed double-precision (64-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm256_maskstore_pd","","Store packed double-precision (64-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm_maskload_pd","","Load packed double-precision (64-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm_maskstore_pd","","Store packed double-precision (64-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm256_maskload_ps","","Load packed single-precision (32-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm256_maskstore_ps","","Store packed single-precision (32-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm_maskload_ps","","Load packed single-precision (32-bit) floating-point elements from memory into result using `mask` (elements are zeroed out when the high bit of the corresponding element is not set).",null,null],[5,"_mm_maskstore_ps","","Store packed single-precision (32-bit) floating-point elements from `a` into memory using `mask`.",null,null],[5,"_mm256_movehdup_ps","","Duplicate odd-indexed single-precision (32-bit) floating-point elements from `a`, and return the results.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_moveldup_ps","","Duplicate even-indexed single-precision (32-bit) floating-point elements from `a`, and return the results.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_movedup_pd","","Duplicate even-indexed double-precision (64-bit) floating-point elements from \"a\", and return the results.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_lddqu_si256","","Load 256-bits of integer data from unaligned memory into result. This intrinsic may perform better than `_mm256_loadu_si256` when the data crosses a cache line boundary.",null,null],[5,"_mm256_stream_si256","","Moves integer data from a 256-bit integer vector to a 32-byte aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon)",null,null],[5,"_mm256_stream_pd","","Moves double-precision values from a 256-bit vector of [4 x double] to a 32-byte aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm256_stream_ps","","Moves single-precision floating point values from a 256-bit vector of [8 x float] to a 32-byte aligned memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm256_rcp_ps","","Compute the approximate reciprocal of packed single-precision (32-bit) floating-point elements in `a`, and return the results. The maximum relative error for this approximation is less than 1.5*2^-12.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_rsqrt_ps","","Compute the approximate reciprocal square root of packed single-precision (32-bit) floating-point elements in `a`, and return the results. The maximum relative error for this approximation is less than 1.5*2^-12.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_unpackhi_pd","","Unpack and interleave double-precision (64-bit) floating-point elements from the high half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_unpackhi_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the high half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_unpacklo_pd","","Unpack and interleave double-precision (64-bit) floating-point elements from the low half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"__m256d"}}],[5,"_mm256_unpacklo_ps","","Unpack and interleave single-precision (32-bit) floating-point elements from the low half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"__m256"}}],[5,"_mm256_testz_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`, and set `ZF` to 1 if the result is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, and set `CF` to 1 if the result is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_testc_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`, and set `ZF` to 1 if the result is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, and set `CF` to 1 if the result is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_testnzc_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`, and set `ZF` to 1 if the result is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, and set `CF` to 1 if the result is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_testz_pd","","Compute the bitwise AND of 256 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm256_testc_pd","","Compute the bitwise AND of 256 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm256_testnzc_pd","","Compute the bitwise AND of 256 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m256d"},{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm_testz_pd","","Compute the bitwise AND of 128 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_testc_pd","","Compute the bitwise AND of 128 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm_testnzc_pd","","Compute the bitwise AND of 128 bits (representing double-precision (64-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 64-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"i32"}}],[5,"_mm256_testz_ps","","Compute the bitwise AND of 256 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm256_testc_ps","","Compute the bitwise AND of 256 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm256_testnzc_ps","","Compute the bitwise AND of 256 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 256-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m256"},{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm_testz_ps","","Compute the bitwise AND of 128 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `ZF` value.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_testc_ps","","Compute the bitwise AND of 128 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return the `CF` value.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm_testnzc_ps","","Compute the bitwise AND of 128 bits (representing single-precision (32-bit) floating-point elements) in `a` and `b`, producing an intermediate 128-bit value, and set `ZF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `ZF` to 0. Compute the bitwise NOT of `a` and then AND with `b`, producing an intermediate value, and set `CF` to 1 if the sign bit of each 32-bit element in the intermediate value is zero, otherwise set `CF` to 0. Return 1 if both the `ZF` and `CF` values are zero, otherwise return 0.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"i32"}}],[5,"_mm256_movemask_pd","","Set each bit of the returned mask based on the most significant bit of the corresponding packed double-precision (64-bit) floating-point element in `a`.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"i32"}}],[5,"_mm256_movemask_ps","","Set each bit of the returned mask based on the most significant bit of the corresponding packed single-precision (32-bit) floating-point element in `a`.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"i32"}}],[5,"_mm256_setzero_pd","","Return vector of type __m256d with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m256d"}}],[5,"_mm256_setzero_ps","","Return vector of type __m256 with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m256"}}],[5,"_mm256_setzero_si256","","Return vector of type __m256i with all elements set to zero.",null,{"inputs":[],"output":{"name":"__m256i"}}],[5,"_mm256_set_pd","","Set packed double-precision (64-bit) floating-point elements in returned vector with the supplied values.",null,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_set_ps","","Set packed single-precision (32-bit) floating-point elements in returned vector with the supplied values.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm256_set_epi8","","Set packed 8-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m256i"}}],[5,"_mm256_set_epi16","","Set packed 16-bit integers in returned vector with the supplied values.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m256i"}}],[5,"_mm256_set_epi32","","Set packed 32-bit integers in returned vector with the supplied values.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_set_epi64x","","Set packed 64-bit integers in returned vector with the supplied values.",null,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_pd","","Set packed double-precision (64-bit) floating-point elements in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_setr_ps","","Set packed single-precision (32-bit) floating-point elements in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm256_setr_epi8","","Set packed 8-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_epi16","","Set packed 16-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_epi32","","Set packed 32-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_epi64x","","Set packed 64-bit integers in returned vector with the supplied values in reverse order.",null,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_pd","","Broadcast double-precision (64-bit) floating-point value `a` to all elements of returned vector.",null,{"inputs":[{"name":"f64"}],"output":{"name":"__m256d"}}],[5,"_mm256_set1_ps","","Broadcast single-precision (32-bit) floating-point value `a` to all elements of returned vector.",null,{"inputs":[{"name":"f32"}],"output":{"name":"__m256"}}],[5,"_mm256_set1_epi8","","Broadcast 8-bit integer `a` to all elements of returned vector. This intrinsic may generate the `vpbroadcastb`.",null,{"inputs":[{"name":"i8"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_epi16","","Broadcast 16-bit integer `a` to all all elements of returned vector. This intrinsic may generate the `vpbroadcastw`.",null,{"inputs":[{"name":"i16"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_epi32","","Broadcast 32-bit integer `a` to all elements of returned vector. This intrinsic may generate the `vpbroadcastd`.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_set1_epi64x","","Broadcast 64-bit integer `a` to all elements of returned vector. This intrinsic may generate the `vpbroadcastq`.",null,{"inputs":[{"name":"i64"}],"output":{"name":"__m256i"}}],[5,"_mm256_castpd_ps","","Cast vector of type __m256d to type __m256.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256"}}],[5,"_mm256_castps_pd","","Cast vector of type __m256 to type __m256d.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256d"}}],[5,"_mm256_castps_si256","","Casts vector of type __m256 to type __m256i.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m256i"}}],[5,"_mm256_castsi256_ps","","Casts vector of type __m256i to type __m256.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm256_castpd_si256","","Casts vector of type __m256d to type __m256i.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m256i"}}],[5,"_mm256_castsi256_pd","","Casts vector of type __m256i to type __m256d.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256d"}}],[5,"_mm256_castps256_ps128","","Casts vector of type __m256 to type __m128.",null,{"inputs":[{"name":"__m256"}],"output":{"name":"__m128"}}],[5,"_mm256_castpd256_pd128","","Casts vector of type __m256d to type __m128d.",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"__m128d"}}],[5,"_mm256_castsi256_si128","","Casts vector of type __m256i to type __m128i.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m128i"}}],[5,"_mm256_castps128_ps256","","Casts vector of type __m128 to type __m256; the upper 128 bits of the result are undefined.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_castpd128_pd256","","Casts vector of type __m128d to type __m256d; the upper 128 bits of the result are undefined.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_castsi128_si256","","Casts vector of type __m128i to type __m256i; the upper 128 bits of the result are undefined.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_zextps128_ps256","","Constructs a 256-bit floating-point vector of [8 x float] from a 128-bit floating-point vector of [4 x float]. The lower 128 bits contain the value of the source vector. The upper 128 bits are set to zero.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_zextsi128_si256","","Constructs a 256-bit integer vector from a 128-bit integer vector. The lower 128 bits contain the value of the source vector. The upper 128 bits are set to zero.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_zextpd128_pd256","","Constructs a 256-bit floating-point vector of [4 x double] from a 128-bit floating-point vector of [2 x double]. The lower 128 bits contain the value of the source vector. The upper 128 bits are set to zero.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_undefined_ps","","Return vector of type `__m256` with undefined elements.",null,{"inputs":[],"output":{"name":"__m256"}}],[5,"_mm256_undefined_pd","","Return vector of type `__m256d` with undefined elements.",null,{"inputs":[],"output":{"name":"__m256d"}}],[5,"_mm256_undefined_si256","","Return vector of type __m256i with undefined elements.",null,{"inputs":[],"output":{"name":"__m256i"}}],[5,"_mm256_set_m128","","Set packed __m256 returned vector with the supplied values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_set_m128d","","Set packed __m256d returned vector with the supplied values.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_set_m128i","","Set packed __m256i returned vector with the supplied values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_setr_m128","","Set packed __m256 returned vector with the supplied values.",null,{"inputs":[{"name":"__m128"},{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm256_setr_m128d","","Set packed __m256d returned vector with the supplied values.",null,{"inputs":[{"name":"__m128d"},{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_setr_m128i","","Set packed __m256i returned vector with the supplied values.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_loadu2_m128","","Load two 128-bit values (composed of 4 packed single-precision (32-bit) floating-point elements) from memory, and combine them into a 256-bit value. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_loadu2_m128d","","Load two 128-bit values (composed of 2 packed double-precision (64-bit) floating-point elements) from memory, and combine them into a 256-bit value. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_loadu2_m128i","","Load two 128-bit values (composed of integer data) from memory, and combine them into a 256-bit value. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu2_m128","","Store the high and low 128-bit halves (each composed of 4 packed single-precision (32-bit) floating-point elements) from `a` into memory two different 128-bit locations. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu2_m128d","","Store the high and low 128-bit halves (each composed of 2 packed double-precision (64-bit) floating-point elements) from `a` into memory two different 128-bit locations. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_storeu2_m128i","","Store the high and low 128-bit halves (each composed of integer data) from `a` into memory two different 128-bit locations. `hiaddr` and `loaddr` do not need to be aligned on any particular boundary.",null,null],[5,"_mm256_cvtss_f32","","Returns the first element of the input vector of [8 x float].",null,{"inputs":[{"name":"__m256"}],"output":{"name":"f32"}}],[5,"_mm256_abs_epi32","","Computes the absolute values of packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_abs_epi16","","Computes the absolute values of packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_abs_epi8","","Computes the absolute values of packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi64","","Add packed 64-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi32","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi16","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_add_epi8","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epi8","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epi16","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epu8","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_adds_epu16","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_alignr_epi8","","Concatenate pairs of 16-byte blocks in `a` and `b` into a 32-byte temporary result, shift the result right by `n` bytes, and return the low 16 bytes.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_and_si256","","Compute the bitwise AND of 256 bits (representing integer data) in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_andnot_si256","","Compute the bitwise NOT of 256 bits (representing integer data) in `a` and then AND with `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_avg_epu16","","Average packed unsigned 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_avg_epu8","","Average packed unsigned 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_blend_epi32","","Blend packed 32-bit integers from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm256_blend_epi32","","Blend packed 32-bit integers from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_blend_epi16","","Blend packed 16-bit integers from `a` and `b` using control mask `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_blendv_epi8","","Blend packed 8-bit integers from `a` and `b` using `mask`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastb_epi8","","Broadcast the low packed 8-bit integer from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastb_epi8","","Broadcast the low packed 8-bit integer from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastd_epi32","","Broadcast the low packed 32-bit integer from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastd_epi32","","Broadcast the low packed 32-bit integer from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastq_epi64","","Broadcast the low packed 64-bit integer from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastq_epi64","","Broadcast the low packed 64-bit integer from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastsd_pd","","Broadcast the low double-precision (64-bit) floating-point element from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m128d"}}],[5,"_mm256_broadcastsd_pd","","Broadcast the low double-precision (64-bit) floating-point element from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"__m256d"}}],[5,"_mm256_broadcastsi128_si256","","Broadcast 128 bits of integer data from a to all 128-bit lanes in the 256-bit returned value.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm_broadcastss_ps","","Broadcast the low single-precision (32-bit) floating-point element from `a` to all elements of the 128-bit returned value.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m128"}}],[5,"_mm256_broadcastss_ps","","Broadcast the low single-precision (32-bit) floating-point element from `a` to all elements of the 256-bit returned value.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"__m256"}}],[5,"_mm_broadcastw_epi16","","Broadcast the low packed 16-bit integer from a to all elements of the 128-bit returned value",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_broadcastw_epi16","","Broadcast the low packed 16-bit integer from a to all elements of the 256-bit returned value",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi64","","Compare packed 64-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi32","","Compare packed 32-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi16","","Compare packed 16-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpeq_epi8","","Compare packed 8-bit integers in `a` and `b` for equality.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi64","","Compare packed 64-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi32","","Compare packed 32-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi16","","Compare packed 16-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cmpgt_epi8","","Compare packed 8-bit integers in `a` and `b` for greater-than.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi16_epi32","","Sign-extend 16-bit integers to 32-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi16_epi64","","Sign-extend 16-bit integers to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi32_epi64","","Sign-extend 32-bit integers to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi8_epi16","","Sign-extend 8-bit integers to 16-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi8_epi32","","Sign-extend 8-bit integers to 32-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepi8_epi64","","Sign-extend 8-bit integers to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu16_epi32","","Zero extend packed unsigned 16-bit integers in `a` to packed 32-bit integers, and store the results in dst.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu16_epi64","","Zero-extend the lower four unsigned 16-bit integers in `a` to 64-bit integers. The upper four elements of `a` are unused.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu32_epi64","","Zero-extend unsigned 32-bit integers in `a` to 64-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu8_epi16","","Zero-extend unsigned 8-bit integers in `a` to 16-bit integers.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu8_epi32","","Zero-extend the lower eight unsigned 8-bit integers in `a` to 32-bit integers. The upper eight elements of `a` are unused.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_cvtepu8_epi64","","Zero-extend the lower four unsigned 8-bit integers in `a` to 64-bit integers. The upper twelve elements of `a` are unused.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_extracti128_si256","","Extract 128 bits (of integer data) from `a` selected with `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm256_hadd_epi16","","Horizontally add adjacent pairs of 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hadd_epi32","","Horizontally add adjacent pairs of 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hadds_epi16","","Horizontally add adjacent pairs of 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hsub_epi16","","Horizontally subtract adjacent pairs of 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hsub_epi32","","Horizontally subtract adjacent pairs of 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_hsubs_epi16","","Horizontally subtract adjacent pairs of 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i32gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_epi32","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_ps","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_epi64","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm_mask_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8.",null,null],[5,"_mm256_mask_i64gather_pd","","Return values from `slice` at offsets determined by `offsets * scale`, where `scale` is between 1 and 8. If mask is set, load the value from `src` in that position instead.",null,null],[5,"_mm256_inserti128_si256","","Copy `a` to `dst`, then insert 128 bits (of integer data) from `b` at the location specified by `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_madd_epi16","","Multiply packed signed 16-bit integers in `a` and `b`, producing intermediate signed 32-bit integers. Horizontally add adjacent pairs of intermediate 32-bit integers.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_maddubs_epi16","","Vertically multiply each unsigned 8-bit integer from `a` with the corresponding signed 8-bit integer from `b`, producing intermediate signed 16-bit integers. Horizontally add adjacent pairs of intermediate signed 16-bit integers",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_maskload_epi32","","Load packed 32-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskload_epi32","","Load packed 32-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm_maskload_epi64","","Load packed 64-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskload_epi64","","Load packed 64-bit integers from memory pointed by `mem_addr` using `mask` (elements are zeroed out when the highest bit is not set in the corresponding element).",null,null],[5,"_mm_maskstore_epi32","","Store packed 32-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskstore_epi32","","Store packed 32-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm_maskstore_epi64","","Store packed 64-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_maskstore_epi64","","Store packed 64-bit integers from `a` into memory pointed by `mem_addr` using `mask` (elements are not stored when the highest bit is not set in the corresponding element).",null,null],[5,"_mm256_max_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epi32","","Compare packed 32-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epi8","","Compare packed 8-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_max_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed maximum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epi16","","Compare packed 16-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epi32","","Compare packed 32-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epi8","","Compare packed 8-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epu16","","Compare packed unsigned 16-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epu32","","Compare packed unsigned 32-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_min_epu8","","Compare packed unsigned 8-bit integers in `a` and `b`, and return the packed minimum values.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_movemask_epi8","","Create mask from the most significant bit of each 8-bit element in `a`, return the result.",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_mm256_mpsadbw_epu8","","Compute the sum of absolute differences (SADs) of quadruplets of unsigned 8-bit integers in `a` compared to those in `b`, and store the 16-bit results in dst. Eight SADs are performed for each 128-bit lane using one quadruplet from `b` and eight quadruplets from `a`. One quadruplet is selected from `b` starting at on the offset specified in `imm8`. Eight quadruplets are formed from sequential 8-bit integers selected from `a` starting at the offset specified in `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_mul_epi32","","Multiply the low 32-bit integers from each packed 64-bit element in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mul_epu32","","Multiply the low unsigned 32-bit integers from each packed 64-bit element in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mulhi_epi16","","Multiply the packed 16-bit integers in `a` and `b`, producing intermediate 32-bit integers and returning the high 16 bits of the intermediate integers.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mulhi_epu16","","Multiply the packed unsigned 16-bit integers in `a` and `b`, producing intermediate 32-bit integers and returning the high 16 bits of the intermediate integers.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mullo_epi16","","Multiply the packed 16-bit integers in `a` and `b`, producing intermediate 32-bit integers, and return the low 16 bits of the intermediate integers",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mullo_epi32","","Multiply the packed 32-bit integers in `a` and `b`, producing intermediate 64-bit integers, and return the low 16 bits of the intermediate integers",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_mulhrs_epi16","","Multiply packed 16-bit integers in `a` and `b`, producing intermediate signed 32-bit integers. Truncate each intermediate integer to the 18 most significant bits, round by adding 1, and return bits [16:1]",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_or_si256","","Compute the bitwise OR of 256 bits (representing integer data) in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packs_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using signed saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packs_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using signed saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packus_epi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using unsigned saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_packus_epi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using unsigned saturation",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_permutevar8x32_epi32","","Permutes packed 32-bit integers from `a` according to the content of `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_permute4x64_epi64","","Permutes 64-bit integers from `a` using control mask `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_permute2x128_si256","","Shuffle 128-bits of integer data selected by `imm8` from `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_permute4x64_pd","","Shuffle 64-bit floating-point elements in `a` across lanes using the control in `imm8`.",null,{"inputs":[{"name":"__m256d"},{"name":"i32"}],"output":{"name":"__m256d"}}],[5,"_mm256_permutevar8x32_ps","","Shuffle eight 32-bit foating-point elements in `a` across lanes using the corresponding 32-bit integer index in `idx`.",null,{"inputs":[{"name":"__m256"},{"name":"__m256i"}],"output":{"name":"__m256"}}],[5,"_mm256_sad_epu8","","Compute the absolute differences of packed unsigned 8-bit integers in `a` and `b`, then horizontally sum each consecutive 8 differences to produce four unsigned 16-bit integers, and pack these unsigned 16-bit integers in the low 16 bits of the 64-bit return value",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_shuffle_epi8","","Shuffle bytes from `a` according to the content of `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_shuffle_epi32","","Shuffle 32-bit integers in 128-bit lanes of `a` using the control in `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_shufflehi_epi16","","Shuffle 16-bit integers in the high 64 bits of 128-bit lanes of `a` using the control in `imm8`. The low 64 bits of 128-bit lanes of `a` are copied to the output.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_shufflelo_epi16","","Shuffle 16-bit integers in the low 64 bits of 128-bit lanes of `a` using the control in `imm8`. The high 64 bits of 128-bit lanes of `a` are copied to the output.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_sign_epi16","","Negate packed 16-bit integers in `a` when the corresponding signed 16-bit integer in `b` is negative, and return the results. Results are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sign_epi32","","Negate packed 32-bit integers in `a` when the corresponding signed 32-bit integer in `b` is negative, and return the results. Results are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sign_epi8","","Negate packed 8-bit integers in `a` when the corresponding signed 8-bit integer in `b` is negative, and return the results. Results are zeroed out when the corresponding element in `b` is zero.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sll_epi16","","Shift packed 16-bit integers in `a` left by `count` while shifting in zeros, and return the result",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sll_epi32","","Shift packed 32-bit integers in `a` left by `count` while shifting in zeros, and return the result",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sll_epi64","","Shift packed 64-bit integers in `a` left by `count` while shifting in zeros, and return the result",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_epi16","","Shift packed 16-bit integers in `a` left by `imm8` while shifting in zeros, return the results;",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_epi32","","Shift packed 32-bit integers in `a` left by `imm8` while shifting in zeros, return the results;",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_epi64","","Shift packed 64-bit integers in `a` left by `imm8` while shifting in zeros, return the results;",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_slli_si256","","Shift 128-bit lanes in `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_bslli_epi128","","Shift 128-bit lanes in `a` left by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm_sllv_epi32","","Shift packed 32-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_sllv_epi32","","Shift packed 32-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_sllv_epi64","","Shift packed 64-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_sllv_epi64","","Shift packed 64-bit integers in `a` left by the amount specified by the corresponding element in `count` while shifting in zeros, and return the result.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sra_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sra_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srai_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srai_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm_srav_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_srav_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in sign bits.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_si256","","Shift 128-bit lanes in `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_bsrli_epi128","","Shift 128-bit lanes in `a` right by `imm8` bytes while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srl_epi16","","Shift packed 16-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srl_epi32","","Shift packed 32-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srl_epi64","","Shift packed 64-bit integers in `a` right by `count` while shifting in zeros.",null,{"inputs":[{"name":"__m256i"},{"name":"__m128i"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_epi16","","Shift packed 16-bit integers in `a` right by `imm8` while shifting in zeros",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_epi32","","Shift packed 32-bit integers in `a` right by `imm8` while shifting in zeros",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm256_srli_epi64","","Shift packed 64-bit integers in `a` right by `imm8` while shifting in zeros",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_mm_srlv_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_srlv_epi32","","Shift packed 32-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm_srlv_epi64","","Shift packed 64-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm256_srlv_epi64","","Shift packed 64-bit integers in `a` right by the amount specified by the corresponding element in `count` while shifting in zeros,",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi32","","Subtract packed 32-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi64","","Subtract packed 64-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_sub_epi8","","Subtract packed 8-bit integers in `b` from packed 16-bit integers in `a`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epu16","","Subtract packed unsigned 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_subs_epu8","","Subtract packed unsigned 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi8","","Unpack and interleave 8-bit integers from the high half of each 128-bit lane in `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi8","","Unpack and interleave 8-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi16","","Unpack and interleave 16-bit integers from the high half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi16","","Unpack and interleave 16-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi32","","Unpack and interleave 32-bit integers from the high half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi32","","Unpack and interleave 32-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpackhi_epi64","","Unpack and interleave 64-bit integers from the high half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_unpacklo_epi64","","Unpack and interleave 64-bit integers from the low half of each 128-bit lane of `a` and `b`.",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_xor_si256","","Compute the bitwise XOR of 256 bits (representing integer data) in `a` and `b`",null,{"inputs":[{"name":"__m256i"},{"name":"__m256i"}],"output":{"name":"__m256i"}}],[5,"_mm256_extract_epi8","","Extract an 8-bit integer from `a`, selected with `imm8`. Returns a 32-bit integer containing the zero-extended integer data.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"i8"}}],[5,"_mm256_extract_epi16","","Extract a 16-bit integer from `a`, selected with `imm8`. Returns a 32-bit integer containing the zero-extended integer data.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"i16"}}],[5,"_mm256_extract_epi32","","Extract a 32-bit integer from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"i32"}}],[5,"_mm256_cvtsd_f64","","Returns the first element of the input vector of [4 x double].",null,{"inputs":[{"name":"__m256d"}],"output":{"name":"f64"}}],[5,"_mm256_cvtsi256_si32","","Returns the first element of the input vector of [8 x i32].",null,{"inputs":[{"name":"__m256i"}],"output":{"name":"i32"}}],[5,"_lzcnt_u32","","Counts the leading most significant zero bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_popcnt32","","Counts the bits that are set.",null,{"inputs":[{"name":"i32"}],"output":{"name":"i32"}}],[5,"_bextr_u32","","Extracts bits in range [`start`, `start` + `length`) from `a` into the least significant bits of the result.",null,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_bextr2_u32","","Extracts bits of `a` specified by `control` into the least significant bits of the result.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_andn_u32","","Bitwise logical `AND` of inverted `a` with `b`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsi_u32","","Extract lowest set isolated bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsmsk_u32","","Get mask up to lowest set bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsr_u32","","Resets the lowest set bit of `x`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_tzcnt_u32","","Counts the number of trailing least significant zero bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_tzcnt_32","","Counts the number of trailing least significant zero bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"i32"}}],[5,"_mulx_u32","","Unsigned multiply without affecting flags.",null,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_bzhi_u32","","Zero higher bits of `a` >= `index`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_pdep_u32","","Scatter contiguous low order bits of `a` to the result at the positions specified by the `mask`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_pext_u32","","Gathers the bits of `x` specified by the `mask` into the contiguous low order bit positions of the result.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_extract_si64","","Extracts the bit range specified by `y` from the lower 64 bits of `x`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_insert_si64","","Inserts the `[length:0]` bits of `y` into `x` at `index`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_stream_sd","","Non-temporal store of `a.0` into `p`.",null,null],[5,"_mm_stream_ss","","Non-temporal store of `a.0` into `p`.",null,null],[5,"_blcfill_u32","","Clears all bits below the least significant zero bit of `x`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blci_u32","","Sets all bits of `x` to 1 except for the least significant zero bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blcic_u32","","Sets the least significant zero bit of `x` and clears all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blcmsk_u32","","Sets the least significant zero bit of `x` and clears all bits above that bit.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blcs_u32","","Sets the least significant zero bit of `x`.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsfill_u32","","Sets all bits of `x` below the least significant one.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_blsic_u32","","Clears least significant bit and sets all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_t1mskc_u32","","Clears all bits below the least significant zero of `x` and sets all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_tzmsk_u32","","Sets all bits below the least significant one of `x` and clears all other bits.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_mm_setzero_si64","","Constructs a 64-bit integer vector initialized to zero.",null,{"inputs":[],"output":{"name":"__m64"}}],[5,"_mm_add_pi8","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddb","","Add packed 8-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_add_pi16","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddw","","Add packed 16-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_add_pi32","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddd","","Add packed 32-bit integers in `a` and `b`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pi8","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddsb","","Add packed 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pi16","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddsw","","Add packed 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pu8","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddusb","","Add packed unsigned 8-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_adds_pu16","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_paddusw","","Add packed unsigned 16-bit integers in `a` and `b` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_pi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubb","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_pi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubw","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_sub_pi32","","Subtract packed 32-bit integers in `b` from packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubd","","Subtract packed 32-bit integers in `b` from packed 32-bit integers in `a`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pi8","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubsb","","Subtract packed 8-bit integers in `b` from packed 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pi16","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubsw","","Subtract packed 16-bit integers in `b` from packed 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pu8","","Subtract packed unsigned 8-bit integers in `b` from packed unsigned 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubusb","","Subtract packed unsigned 8-bit integers in `b` from packed unsigned 8-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_subs_pu16","","Subtract packed unsigned 16-bit integers in `b` from packed unsigned 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_m_psubusw","","Subtract packed unsigned 16-bit integers in `b` from packed unsigned 16-bit integers in `a` using saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_packs_pi16","","Convert packed 16-bit integers from `a` and `b` to packed 8-bit integers using signed saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_packs_pi32","","Convert packed 32-bit integers from `a` and `b` to packed 16-bit integers using signed saturation.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cmpgt_pi8","","Compares whether each element of `a` is greater than the corresponding element of `b` returning `0` for `false` and `-1` for `true`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cmpgt_pi16","","Compares whether each element of `a` is greater than the corresponding element of `b` returning `0` for `false` and `-1` for `true`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_cmpgt_pi32","","Compares whether each element of `a` is greater than the corresponding element of `b` returning `0` for `false` and `-1` for `true`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpackhi_pi16","","Unpacks the upper two elements from two `i16x4` vectors and interleaves them into the result: `[a.2, b.2, a.3, b.3]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpackhi_pi8","","Unpacks the upper four elements from two `i8x8` vectors and interleaves them into the result: `[a.4, b.4, a.5, b.5, a.6, b.6, a.7, b.7]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpacklo_pi8","","Unpacks the lower four elements from two `i8x8` vectors and interleaves them into the result: `[a.0, b.0, a.1, b.1, a.2, b.2, a.3, b.3]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpacklo_pi16","","Unpacks the lower two elements from two `i16x4` vectors and interleaves them into the result: `[a.0 b.0 a.1 b.1]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpackhi_pi32","","Unpacks the upper element from two `i32x2` vectors and interleaves them into the result: `[a.1, b.1]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_unpacklo_pi32","","Unpacks the lower element from two `i32x2` vectors and interleaves them into the result: `[a.0, b.0]`.",null,{"inputs":[{"name":"__m64"},{"name":"__m64"}],"output":{"name":"__m64"}}],[5,"_mm_set_pi16","","Set packed 16-bit integers in dst with the supplied values.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m64"}}],[5,"_mm_set_pi32","","Set packed 32-bit integers in dst with the supplied values.",null,{"inputs":[{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_set_pi8","","Set packed 8-bit integers in dst with the supplied values.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m64"}}],[5,"_mm_set1_pi16","","Broadcast 16-bit integer a to all all elements of dst.",null,{"inputs":[{"name":"i16"}],"output":{"name":"__m64"}}],[5,"_mm_set1_pi32","","Broadcast 32-bit integer a to all all elements of dst.",null,{"inputs":[{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_set1_pi8","","Broadcast 8-bit integer a to all all elements of dst.",null,{"inputs":[{"name":"i8"}],"output":{"name":"__m64"}}],[5,"_mm_setr_pi16","","Set packed 16-bit integers in dst with the supplied values in reverse order.",null,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"__m64"}}],[5,"_mm_setr_pi32","","Set packed 32-bit integers in dst with the supplied values in reverse order.",null,{"inputs":[{"name":"i32"},{"name":"i32"}],"output":{"name":"__m64"}}],[5,"_mm_setr_pi8","","Set packed 8-bit integers in dst with the supplied values in reverse order.",null,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"__m64"}}],[5,"_mm_clmulepi64_si128","","Perform a carry-less multiplication of two 64-bit polynomials over the finite field GF(2^k).",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_aesdec_si128","","Perform one round of an AES decryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesdeclast_si128","","Perform the last round of an AES decryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesenc_si128","","Perform one round of an AES encryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesenclast_si128","","Perform the last round of an AES encryption flow on data (state) in `a`.",null,{"inputs":[{"name":"__m128i"},{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aesimc_si128","","Perform the `InvMixColumns` transformation on `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"__m128i"}}],[5,"_mm_aeskeygenassist_si128","","Assist in expanding the AES cipher key.",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_rdrand16_step","","Read a hardware generated 16-bit random value and store the result in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u16"}],"output":{"name":"i32"}}],[5,"_rdrand32_step","","Read a hardware generated 32-bit random value and store the result in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u32"}],"output":{"name":"i32"}}],[5,"_rdseed16_step","","Read a 16-bit NIST SP800-90B and SP800-90C compliant random value and store in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u16"}],"output":{"name":"i32"}}],[5,"_rdseed32_step","","Read a 32-bit NIST SP800-90B and SP800-90C compliant random value and store in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u32"}],"output":{"name":"i32"}}],[5,"_mm_cvtss_si64","","Convert the lowest 32 bit float in the input vector to a 64 bit integer.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i64"}}],[5,"_mm_cvttss_si64","","Convert the lowest 32 bit float in the input vector to a 64 bit integer with truncation.",null,{"inputs":[{"name":"__m128"}],"output":{"name":"i64"}}],[5,"_mm_cvtsi64_ss","","Convert a 64 bit integer to a 32 bit float. The result vector is the input vector `a` with the lowest 32 bit float replaced by the converted integer.",null,{"inputs":[{"name":"__m128"},{"name":"i64"}],"output":{"name":"__m128"}}],[5,"_mm_cvtsd_si64","","Convert the lower double-precision (64-bit) floating-point element in a to a 64-bit integer.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i64"}}],[5,"_mm_cvtsd_si64x","","Alias for `_mm_cvtsd_si64`",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i64"}}],[5,"_mm_cvttsd_si64","","Convert the lower double-precision (64-bit) floating-point element in `a` to a 64-bit integer with truncation.",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i64"}}],[5,"_mm_cvttsd_si64x","","Alias for `_mm_cvttsd_si64`",null,{"inputs":[{"name":"__m128d"}],"output":{"name":"i64"}}],[5,"_mm_stream_si64","","Stores a 64-bit integer value in the specified memory location. To minimize caching, the data is flagged as non-temporal (unlikely to be used again soon).",null,null],[5,"_mm_cvtsi64_si128","","Return a vector whose lowest element is `a` and all higher elements are `0`.",null,{"inputs":[{"name":"i64"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsi64x_si128","","Return a vector whose lowest element is `a` and all higher elements are `0`.",null,{"inputs":[{"name":"i64"}],"output":{"name":"__m128i"}}],[5,"_mm_cvtsi128_si64","","Return the lowest element of `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i64"}}],[5,"_mm_cvtsi128_si64x","","Return the lowest element of `a`.",null,{"inputs":[{"name":"__m128i"}],"output":{"name":"i64"}}],[5,"_mm_cvtsi64_sd","","Return `a` with its lower element replaced by `b` after converting it to an `f64`.",null,{"inputs":[{"name":"__m128d"},{"name":"i64"}],"output":{"name":"__m128d"}}],[5,"_mm_cvtsi64x_sd","","Return `a` with its lower element replaced by `b` after converting it to an `f64`.",null,{"inputs":[{"name":"__m128d"},{"name":"i64"}],"output":{"name":"__m128d"}}],[5,"_mm_extract_epi64","","Extract an 64-bit integer from `a` selected with `imm8`",null,{"inputs":[{"name":"__m128i"},{"name":"i32"}],"output":{"name":"i64"}}],[5,"_mm_insert_epi64","","Return a copy of `a` with the 64-bit integer from `i` inserted at a location specified by `imm8`.",null,{"inputs":[{"name":"__m128i"},{"name":"i64"},{"name":"i32"}],"output":{"name":"__m128i"}}],[5,"_mm_crc32_u64","","Starting with the initial value in `crc`, return the accumulated CRC32 value for unsigned 64-bit integer `v`.",null,{"inputs":[{"name":"u64"},{"name":"u64"}],"output":{"name":"u64"}}],[5,"_xsave64","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xrstor64","","Perform a full or partial restore of the enabled processor states using the state information stored in memory at `mem_addr`.",null,null],[5,"_xsaveopt64","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xsavec64","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`.",null,null],[5,"_xsaves64","","Perform a full or partial save of the enabled processor states to memory at `mem_addr`",null,null],[5,"_xrstors64","","Perform a full or partial restore of the enabled processor states using the state information stored in memory at `mem_addr`.",null,null],[5,"_lzcnt_u64","","Counts the leading most significant zero bits.",null,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[5,"_popcnt64","","Counts the bits that are set.",null,{"inputs":[{"name":"i64"}],"output":{"name":"i32"}}],[5,"_mm256_insert_epi64","","Copy `a` to result, and insert the 64-bit integer `i` into result at the location specified by `index`.",null,{"inputs":[{"name":"__m256i"},{"name":"i64"},{"name":"i32"}],"output":{"name":"__m256i"}}],[5,"_andn_u64","","Bitwise logical `AND` of inverted `a` with `b`.",null,{"inputs":[{"name":"u64"},{"name":"u64"}],"output":{"name":"u64"}}],[5,"_tzcnt_u64","","Counts the number of trailing least significant zero bits.",null,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[5,"_mm_tzcnt_64","","Counts the number of trailing least significant zero bits.",null,{"inputs":[{"name":"u64"}],"output":{"name":"i64"}}],[5,"_mm256_extract_epi64","","Extract a 64-bit integer from `a`, selected with `imm8`.",null,{"inputs":[{"name":"__m256i"},{"name":"i32"}],"output":{"name":"i64"}}],[5,"_bswap64","","Return an integer with the reversed byte order of x",null,{"inputs":[{"name":"i64"}],"output":{"name":"i64"}}],[5,"_rdrand64_step","","Read a hardware generated 64-bit random value and store the result in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u64"}],"output":{"name":"i32"}}],[5,"_rdseed64_step","","Read a 64-bit NIST SP800-90B and SP800-90C compliant random value and store in val. Return 1 if a random value was generated, and 0 otherwise.",null,{"inputs":[{"name":"u64"}],"output":{"name":"i32"}}],[17,"_XCR_XFEATURE_ENABLED_MASK","","`XFEATURE_ENABLED_MASK` for `XCR`",null,null],[17,"_MM_EXCEPT_INVALID","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_DENORM","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_DIV_ZERO","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_OVERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_UNDERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_INEXACT","","See `_mm_setcsr`",null,null],[17,"_MM_EXCEPT_MASK","","See `_MM_GET_EXCEPTION_STATE`",null,null],[17,"_MM_MASK_INVALID","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_DENORM","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_DIV_ZERO","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_OVERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_UNDERFLOW","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_INEXACT","","See `_mm_setcsr`",null,null],[17,"_MM_MASK_MASK","","See `_MM_GET_EXCEPTION_MASK`",null,null],[17,"_MM_ROUND_NEAREST","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_DOWN","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_UP","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_TOWARD_ZERO","","See `_mm_setcsr`",null,null],[17,"_MM_ROUND_MASK","","See `_MM_GET_ROUNDING_MODE`",null,null],[17,"_MM_FLUSH_ZERO_MASK","","See `_MM_GET_FLUSH_ZERO_MODE`",null,null],[17,"_MM_FLUSH_ZERO_ON","","See `_mm_setcsr`",null,null],[17,"_MM_FLUSH_ZERO_OFF","","See `_mm_setcsr`",null,null],[17,"_MM_HINT_T0","","See `_mm_prefetch`.",null,null],[17,"_MM_HINT_T1","","See `_mm_prefetch`.",null,null],[17,"_MM_HINT_T2","","See `_mm_prefetch`.",null,null],[17,"_MM_HINT_NTA","","See `_mm_prefetch`.",null,null],[17,"_MM_FROUND_TO_NEAREST_INT","","round to nearest",null,null],[17,"_MM_FROUND_TO_NEG_INF","","round down",null,null],[17,"_MM_FROUND_TO_POS_INF","","round up",null,null],[17,"_MM_FROUND_TO_ZERO","","truncate",null,null],[17,"_MM_FROUND_CUR_DIRECTION","","use MXCSR.RC; see `vendor::_MM_SET_ROUNDING_MODE`",null,null],[17,"_MM_FROUND_RAISE_EXC","","do not suppress exceptions",null,null],[17,"_MM_FROUND_NO_EXC","","suppress exceptions",null,null],[17,"_MM_FROUND_NINT","","round to nearest and do not suppress exceptions",null,null],[17,"_MM_FROUND_FLOOR","","round down and do not suppress exceptions",null,null],[17,"_MM_FROUND_CEIL","","round up and do not suppress exceptions",null,null],[17,"_MM_FROUND_TRUNC","","truncate and do not suppress exceptions",null,null],[17,"_MM_FROUND_RINT","","use MXCSR.RC and do not suppress exceptions; see `vendor::_MM_SET_ROUNDING_MODE`",null,null],[17,"_MM_FROUND_NEARBYINT","","use MXCSR.RC and suppress exceptions; see `vendor::_MM_SET_ROUNDING_MODE`",null,null],[17,"_SIDD_UBYTE_OPS","","String contains unsigned 8-bit characters (Default)",null,null],[17,"_SIDD_UWORD_OPS","","String contains unsigned 16-bit characters",null,null],[17,"_SIDD_SBYTE_OPS","","String contains signed 8-bit characters",null,null],[17,"_SIDD_SWORD_OPS","","String contains unsigned 16-bit characters",null,null],[17,"_SIDD_CMP_EQUAL_ANY","","For each character in `a`, find if it is in `b` (Default)",null,null],[17,"_SIDD_CMP_RANGES","","For each character in `a`, determine if `b[0] <= c <= b[1] or b[1] <= c <= b[2]...`",null,null],[17,"_SIDD_CMP_EQUAL_EACH","","The strings defined by `a` and `b` are equal",null,null],[17,"_SIDD_CMP_EQUAL_ORDERED","","Search for the defined substring in the target",null,null],[17,"_SIDD_POSITIVE_POLARITY","","Do not negate results (Default)",null,null],[17,"_SIDD_NEGATIVE_POLARITY","","Negate results",null,null],[17,"_SIDD_MASKED_POSITIVE_POLARITY","","Do not negate results before the end of the string",null,null],[17,"_SIDD_MASKED_NEGATIVE_POLARITY","","Negate results only before the end of the string",null,null],[17,"_SIDD_LEAST_SIGNIFICANT","","Index only: return the least significant bit (Default)",null,null],[17,"_SIDD_MOST_SIGNIFICANT","","Index only: return the most significant bit",null,null],[17,"_SIDD_BIT_MASK","","Mask only: return the bit mask",null,null],[17,"_SIDD_UNIT_MASK","","Mask only: return the byte mask",null,null],[17,"_CMP_EQ_OQ","","Equal (ordered, non-signaling)",null,null],[17,"_CMP_LT_OS","","Less-than (ordered, signaling)",null,null],[17,"_CMP_LE_OS","","Less-than-or-equal (ordered, signaling)",null,null],[17,"_CMP_UNORD_Q","","Unordered (non-signaling)",null,null],[17,"_CMP_NEQ_UQ","","Not-equal (unordered, non-signaling)",null,null],[17,"_CMP_NLT_US","","Not-less-than (unordered, signaling)",null,null],[17,"_CMP_NLE_US","","Not-less-than-or-equal (unordered, signaling)",null,null],[17,"_CMP_ORD_Q","","Ordered (non-signaling)",null,null],[17,"_CMP_EQ_UQ","","Equal (unordered, non-signaling)",null,null],[17,"_CMP_NGE_US","","Not-greater-than-or-equal (unordered, signaling)",null,null],[17,"_CMP_NGT_US","","Not-greater-than (unordered, signaling)",null,null],[17,"_CMP_FALSE_OQ","","False (ordered, non-signaling)",null,null],[17,"_CMP_NEQ_OQ","","Not-equal (ordered, non-signaling)",null,null],[17,"_CMP_GE_OS","","Greater-than-or-equal (ordered, signaling)",null,null],[17,"_CMP_GT_OS","","Greater-than (ordered, signaling)",null,null],[17,"_CMP_TRUE_UQ","","True (unordered, non-signaling)",null,null],[17,"_CMP_EQ_OS","","Equal (ordered, signaling)",null,null],[17,"_CMP_LT_OQ","","Less-than (ordered, non-signaling)",null,null],[17,"_CMP_LE_OQ","","Less-than-or-equal (ordered, non-signaling)",null,null],[17,"_CMP_UNORD_S","","Unordered (signaling)",null,null],[17,"_CMP_NEQ_US","","Not-equal (unordered, signaling)",null,null],[17,"_CMP_NLT_UQ","","Not-less-than (unordered, non-signaling)",null,null],[17,"_CMP_NLE_UQ","","Not-less-than-or-equal (unordered, non-signaling)",null,null],[17,"_CMP_ORD_S","","Ordered (signaling)",null,null],[17,"_CMP_EQ_US","","Equal (unordered, signaling)",null,null],[17,"_CMP_NGE_UQ","","Not-greater-than-or-equal (unordered, non-signaling)",null,null],[17,"_CMP_NGT_UQ","","Not-greater-than (unordered, non-signaling)",null,null],[17,"_CMP_FALSE_OS","","False (ordered, signaling)",null,null],[17,"_CMP_NEQ_OS","","Not-equal (ordered, signaling)",null,null],[17,"_CMP_GE_OQ","","Greater-than-or-equal (ordered, non-signaling)",null,null],[17,"_CMP_GT_OQ","","Greater-than (ordered, non-signaling)",null,null],[17,"_CMP_TRUE_US","","True (unordered, signaling)",null,null],[0,"arm","core::arch","Platform-specific intrinsics for the `arm` platform.",null,null],[5,"_rev_u16","core::arch::arm","Reverse the order of the bytes.",null,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[5,"_rev_u32","","Reverse the order of the bytes.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_rev_u16","","Reverse the order of the bytes.",null,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[5,"_rev_u32","","Reverse the order of the bytes.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_clz_u8","","Count Leading Zeros.",null,{"inputs":[{"name":"u8"}],"output":{"name":"u8"}}],[5,"_clz_u16","","Count Leading Zeros.",null,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[5,"_clz_u32","","Count Leading Zeros.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[0,"aarch64","core::arch","Platform-specific intrinsics for the `aarch64` platform.",null,null],[5,"_rev_u16","core::arch::aarch64","Reverse the order of the bytes.",null,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[5,"_rev_u32","","Reverse the order of the bytes.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_rev_u16","","Reverse the order of the bytes.",null,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[5,"_rev_u32","","Reverse the order of the bytes.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_clz_u8","","Count Leading Zeros.",null,{"inputs":[{"name":"u8"}],"output":{"name":"u8"}}],[5,"_clz_u16","","Count Leading Zeros.",null,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[5,"_clz_u32","","Count Leading Zeros.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_rev_u64","","Reverse the order of the bytes.",null,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[5,"_clz_u64","","Count Leading Zeros.",null,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[5,"_rbit_u64","","Reverse the bit order.",null,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[5,"_cls_u32","","Counts the leading most significant bits set.",null,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[5,"_cls_u64","","Counts the leading most significant bits set.",null,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[14,"panic","core","Entry point of thread panic, for details, see std::macros",null,null],[14,"assert_eq","","Asserts that two expressions are equal to each other (using [`PartialEq`]).",null,null],[14,"assert_ne","","Asserts that two expressions are not equal to each other (using [`PartialEq`]).",null,null],[14,"debug_assert","","Ensure that a boolean expression is `true` at runtime.",null,null],[14,"debug_assert_eq","","Asserts that two expressions are equal to each other.",null,null],[14,"debug_assert_ne","","Asserts that two expressions are not equal to each other.",null,null],[14,"try","","Helper macro for reducing boilerplate code for matching `Result` together with converting downstream errors.",null,null],[14,"write","","Write formatted data into a buffer.",null,null],[14,"writeln","","Write formatted data into a buffer, with a newline appended.",null,null],[14,"unreachable","","A utility macro for indicating unreachable code.",null,null],[14,"unimplemented","","A standardized placeholder for marking unfinished code.",null,null],[14,"compile_error","","Unconditionally causes compilation to fail with the given error message when encountered.",null,null],[14,"format_args","","The core macro for formatted string creation & output.",null,null],[14,"env","","Inspect an environment variable at compile time.",null,null],[14,"option_env","","Optionally inspect an environment variable at compile time.",null,null],[14,"concat_idents","","Concatenate identifiers into one identifier.",null,null],[14,"concat","","Concatenates literals into a static string slice.",null,null],[14,"line","","A macro which expands to the line number on which it was invoked.",null,null],[14,"column","","A macro which expands to the column number on which it was invoked.",null,null],[14,"file","","A macro which expands to the file name from which it was invoked.",null,null],[14,"stringify","","A macro which stringifies its arguments.",null,null],[14,"include_str","","Includes a utf8-encoded file as a string.",null,null],[14,"include_bytes","","Includes a file as a reference to a byte array.",null,null],[14,"module_path","","Expands to a string that represents the current module path.",null,null],[14,"cfg","","Boolean evaluation of configuration flags, at compile-time.",null,null],[14,"include","","Parse a file as an expression or an item according to the context.",null,null],[14,"assert","","Ensure that a boolean expression is `true` at runtime.",null,null],[11,"size_hint","core::iter","Returns the bounds on the remaining length of the iterator.",124,null],[11,"count","","Consumes the iterator, counting the number of iterations and returning it.",124,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","Consumes the iterator, returning the last element.",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","Returns the `n`th element of the iterator.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"step_by","","Creates an iterator starting at the same point, but stepping by the given amount at each iteration.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"stepby"}}],[11,"chain","","Takes two iterators and creates a new iterator over both in sequence.",124,{"inputs":[{"name":"self"},{"name":"u"}],"output":{"name":"chain"}}],[11,"zip","","'Zips up' two iterators into a single iterator of pairs.",124,{"inputs":[{"name":"self"},{"name":"u"}],"output":{"name":"zip"}}],[11,"map","","Takes a closure and creates an iterator which calls that closure on each element.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"map"}}],[11,"for_each","","Calls a closure on each element of an iterator.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"filter","","Creates an iterator which uses a closure to determine if an element should be yielded.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"filter"}}],[11,"filter_map","","Creates an iterator that both filters and maps.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"filtermap"}}],[11,"enumerate","","Creates an iterator which gives the current iteration count as well as the next value.",124,{"inputs":[{"name":"self"}],"output":{"name":"enumerate"}}],[11,"peekable","","Creates an iterator which can use `peek` to look at the next element of the iterator without consuming it.",124,{"inputs":[{"name":"self"}],"output":{"name":"peekable"}}],[11,"skip_while","","Creates an iterator that [`skip`]s elements based on a predicate.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"skipwhile"}}],[11,"take_while","","Creates an iterator that yields elements based on a predicate.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"takewhile"}}],[11,"skip","","Creates an iterator that skips the first `n` elements.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"skip"}}],[11,"take","","Creates an iterator that yields its first `n` elements.",124,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"take"}}],[11,"scan","","An iterator adaptor similar to [`fold`] that holds internal state and produces a new iterator.",124,{"inputs":[{"name":"self"},{"name":"st"},{"name":"f"}],"output":{"name":"scan"}}],[11,"flat_map","","Creates an iterator that works like map, but flattens nested structure.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"flatmap"}}],[11,"flatten","","Creates an iterator that flattens nested structure.",124,{"inputs":[{"name":"self"}],"output":{"name":"flatten"}}],[11,"fuse","","Creates an iterator which ends after the first [`None`].",124,{"inputs":[{"name":"self"}],"output":{"name":"fuse"}}],[11,"inspect","","Do something with each element of an iterator, passing the value on.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"inspect"}}],[11,"by_ref","","Borrows an iterator, rather than consuming it.",124,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"collect","","Transforms an iterator into a collection.",124,{"inputs":[{"name":"self"}],"output":{"name":"b"}}],[11,"partition","","Consumes an iterator, creating two collections from it.",124,null],[11,"try_fold","","An iterator method that applies a function as long as it returns successfully, producing a single, final value.",124,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"try_for_each","","An iterator method that applies a fallible function to each item in the iterator, stopping at the first error and returning that error.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","An iterator method that applies a function, producing a single, final value.",124,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"b"}}],[11,"all","","Tests if every element of the iterator matches a predicate.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"any","","Tests if any element of the iterator matches a predicate.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"find","","Searches for an element of an iterator that satisfies a predicate.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"position","","Searches for an element in an iterator, returning its index.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","Searches for an element in an iterator from the right, returning its index.",124,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"max","","Returns the maximum element of an iterator.",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"min","","Returns the minimum element of an iterator.",124,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"max_by_key","","Returns the element that gives the maximum value from the specified function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"max_by","","Returns the element that gives the maximum value with respect to the specified comparison function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"min_by_key","","Returns the element that gives the minimum value from the specified function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"min_by","","Returns the element that gives the minimum value with respect to the specified comparison function.",124,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"rev","","Reverses an iterator's direction.",124,{"inputs":[{"name":"self"}],"output":{"name":"rev"}}],[11,"unzip","","Converts an iterator of pairs into a pair of containers.",124,null],[11,"cloned","","Creates an iterator which [`clone`]s all of its elements.",124,{"inputs":[{"name":"self"}],"output":{"name":"cloned"}}],[11,"cycle","","Repeats an iterator endlessly.",124,{"inputs":[{"name":"self"}],"output":{"name":"cycle"}}],[11,"sum","","Sums the elements of an iterator.",124,{"inputs":[{"name":"self"}],"output":{"name":"s"}}],[11,"product","","Iterates over the entire iterator, multiplying all the elements",124,{"inputs":[{"name":"self"}],"output":{"name":"p"}}],[11,"cmp","","Lexicographically compares the elements of this `Iterator` with those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","Lexicographically compares the elements of this `Iterator` with those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","Determines if the elements of this `Iterator` are equal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"ne","","Determines if the elements of this `Iterator` are unequal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"lt","","Determines if the elements of this `Iterator` are lexicographically less than those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"le","","Determines if the elements of this `Iterator` are lexicographically less or equal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"gt","","Determines if the elements of this `Iterator` are lexicographically greater than those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"ge","","Determines if the elements of this `Iterator` are lexicographically greater than or equal to those of another.",124,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"try_rfold","","This is the reverse version of [`try_fold()`]: it takes elements starting from the back of the iterator.",128,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","An iterator method that reduces the iterator's elements to a single, final value, starting from the back.",128,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"b"}}],[11,"rfind","","Searches for an element of an iterator from the right that satisfies a predicate.",128,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"len","","Returns the exact number of times the iterator will iterate.",130,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns whether the iterator is empty.",130,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"sum","core::result","Takes each element in the `Iterator`: if it is an `Err`, no further elements are taken, and the `Err` is returned. Should no `Err` occur, the sum of all elements is returned.",159,{"inputs":[{"name":"i"}],"output":{"name":"result"}}],[11,"product","","Takes each element in the `Iterator`: if it is an `Err`, no further elements are taken, and the `Err` is returned. Should no `Err` occur, the product of all elements is returned.",159,{"inputs":[{"name":"i"}],"output":{"name":"result"}}],[11,"fmt","core::simd","",240,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"le","","",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"gt","","",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"ge","","",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"clone","","",240,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",240,{"inputs":[{"name":"i8"},{"name":"i8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",240,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",240,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",240,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",240,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",240,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",240,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",240,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",240,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",240,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",240,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",240,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",240,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",240,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",240,null],[11,"eq","","Lane-wise equality comparison.",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",240,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",240,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",240,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",240,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",240,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",240,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"neg","","",240,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",240,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",240,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",240,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",240,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",240,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",240,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",240,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",240,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",240,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",240,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",240,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",241,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"le","","",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"gt","","",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"ge","","",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"clone","","",241,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",241,{"inputs":[{"name":"u8"},{"name":"u8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",241,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",241,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",241,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",241,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",241,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",241,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",241,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",241,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",241,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",241,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",241,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",241,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",241,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",241,null],[11,"eq","","Lane-wise equality comparison.",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",241,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",241,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",241,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",241,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",241,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",241,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"not","","",241,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",241,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",241,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",241,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",241,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",241,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",241,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",241,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",241,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",241,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",241,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",242,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"le","","",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"gt","","",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"ge","","",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"clone","","",242,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",242,{"inputs":[{"name":"bool"},{"name":"bool"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",242,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",242,{"inputs":[{"name":"bool"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",242,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",242,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",242,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",242,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"not","","",242,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",242,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",242,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",242,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",242,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",242,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",242,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",242,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"eq","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",242,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",242,{"inputs":[],"output":{"name":"self"}}],[11,"from_bits","","",240,{"inputs":[{"name":"u8x2"}],"output":{"name":"i8x2"}}],[11,"from_bits","","",240,{"inputs":[{"name":"b8x2"}],"output":{"name":"i8x2"}}],[11,"from_bits","","",241,{"inputs":[{"name":"i8x2"}],"output":{"name":"u8x2"}}],[11,"from_bits","","",241,{"inputs":[{"name":"b8x2"}],"output":{"name":"u8x2"}}],[11,"from","","",240,{"inputs":[{"name":"f64x2"}],"output":{"name":"i8x2"}}],[11,"from","","",240,{"inputs":[{"name":"u64x2"}],"output":{"name":"i8x2"}}],[11,"from","","",240,{"inputs":[{"name":"i64x2"}],"output":{"name":"i8x2"}}],[11,"from","","",240,{"inputs":[{"name":"f32x2"}],"output":{"name":"i8x2"}}],[11,"from","","",240,{"inputs":[{"name":"u32x2"}],"output":{"name":"i8x2"}}],[11,"from","","",240,{"inputs":[{"name":"i32x2"}],"output":{"name":"i8x2"}}],[11,"from","","",240,{"inputs":[{"name":"u16x2"}],"output":{"name":"i8x2"}}],[11,"from","","",240,{"inputs":[{"name":"u8x2"}],"output":{"name":"i8x2"}}],[11,"from","","",241,{"inputs":[{"name":"f64x2"}],"output":{"name":"u8x2"}}],[11,"from","","",241,{"inputs":[{"name":"u64x2"}],"output":{"name":"u8x2"}}],[11,"from","","",241,{"inputs":[{"name":"i64x2"}],"output":{"name":"u8x2"}}],[11,"from","","",241,{"inputs":[{"name":"f32x2"}],"output":{"name":"u8x2"}}],[11,"from","","",241,{"inputs":[{"name":"u32x2"}],"output":{"name":"u8x2"}}],[11,"from","","",241,{"inputs":[{"name":"i32x2"}],"output":{"name":"u8x2"}}],[11,"from","","",241,{"inputs":[{"name":"u16x2"}],"output":{"name":"u8x2"}}],[11,"from","","",241,{"inputs":[{"name":"i8x2"}],"output":{"name":"u8x2"}}],[11,"fmt","","",243,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"le","","",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"gt","","",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"ge","","",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"clone","","",243,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",243,{"inputs":[{"name":"i16"},{"name":"i16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",243,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",243,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",243,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",243,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",243,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",243,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",243,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",243,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",243,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",243,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",243,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",243,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",243,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",243,null],[11,"eq","","Lane-wise equality comparison.",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",243,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",243,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",243,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",243,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",243,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",243,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"neg","","",243,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",243,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",243,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",243,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",243,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",243,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",243,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",243,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",243,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",243,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",243,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",243,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",244,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"le","","",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"gt","","",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"ge","","",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"clone","","",244,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",244,{"inputs":[{"name":"u16"},{"name":"u16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",244,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",244,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",244,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",244,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",244,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",244,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",244,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",244,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",244,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",244,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",244,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",244,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",244,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",244,null],[11,"eq","","Lane-wise equality comparison.",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",244,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",244,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",244,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",244,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",244,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",244,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"not","","",244,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",244,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",244,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",244,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",244,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",244,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",244,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",244,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",244,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",244,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",244,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",245,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"le","","",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"gt","","",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"ge","","",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"clone","","",245,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",245,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",245,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",245,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",245,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",245,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",245,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",245,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",245,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",245,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",245,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",245,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",245,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",245,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",245,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",245,null],[11,"eq","","Lane-wise equality comparison.",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",245,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",245,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",245,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",245,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",245,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",245,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"neg","","",245,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",245,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",245,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",245,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",245,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",245,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",245,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",245,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",245,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",245,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",245,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",245,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",246,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"le","","",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"gt","","",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"ge","","",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"clone","","",246,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",246,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",246,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",246,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",246,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",246,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",246,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",246,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",246,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",246,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",246,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",246,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",246,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",246,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",246,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",246,null],[11,"eq","","Lane-wise equality comparison.",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",246,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",246,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",246,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",246,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",246,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",246,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"not","","",246,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",246,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",246,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",246,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",246,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",246,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",246,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",246,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",246,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",246,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",246,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",247,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"le","","",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"gt","","",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"ge","","",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"clone","","",247,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",247,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",247,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",247,{"inputs":[{"name":"bool"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",247,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",247,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",247,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",247,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"not","","",247,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",247,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",247,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",247,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",247,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",247,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",247,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",247,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"eq","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",247,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",247,{"inputs":[],"output":{"name":"self"}}],[11,"from_bits","","",243,{"inputs":[{"name":"u16x2"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",243,{"inputs":[{"name":"i8x4"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",243,{"inputs":[{"name":"u8x4"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",243,{"inputs":[{"name":"b8x4"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",244,{"inputs":[{"name":"i16x2"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",244,{"inputs":[{"name":"i8x4"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",244,{"inputs":[{"name":"u8x4"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",244,{"inputs":[{"name":"b8x4"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",245,{"inputs":[{"name":"i16x2"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",245,{"inputs":[{"name":"u16x2"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",245,{"inputs":[{"name":"u8x4"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",245,{"inputs":[{"name":"b8x4"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",246,{"inputs":[{"name":"i16x2"}],"output":{"name":"u8x4"}}],[11,"from_bits","","",246,{"inputs":[{"name":"u16x2"}],"output":{"name":"u8x4"}}],[11,"from_bits","","",246,{"inputs":[{"name":"i8x4"}],"output":{"name":"u8x4"}}],[11,"from_bits","","",246,{"inputs":[{"name":"b8x4"}],"output":{"name":"u8x4"}}],[11,"from","","",243,{"inputs":[{"name":"f64x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"u64x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"i64x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"f32x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"u32x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"i32x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"u16x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"u8x2"}],"output":{"name":"i16x2"}}],[11,"from","","",243,{"inputs":[{"name":"i8x2"}],"output":{"name":"i16x2"}}],[11,"from","","",244,{"inputs":[{"name":"f64x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"u64x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"i64x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"f32x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"u32x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"i32x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"i16x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"u8x2"}],"output":{"name":"u16x2"}}],[11,"from","","",244,{"inputs":[{"name":"i8x2"}],"output":{"name":"u16x2"}}],[11,"from","","",245,{"inputs":[{"name":"f64x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"u64x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"i64x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"u32x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"i32x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"f32x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"u16x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"i16x4"}],"output":{"name":"i8x4"}}],[11,"from","","",245,{"inputs":[{"name":"u8x4"}],"output":{"name":"i8x4"}}],[11,"from","","",246,{"inputs":[{"name":"f64x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"u64x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"i64x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"u32x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"i32x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"f32x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"u16x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"i16x4"}],"output":{"name":"u8x4"}}],[11,"from","","",246,{"inputs":[{"name":"i8x4"}],"output":{"name":"u8x4"}}],[11,"fmt","","",248,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"le","","",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"gt","","",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"ge","","",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"clone","","",248,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",248,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",248,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",248,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",248,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",248,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",248,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",248,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",248,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",248,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",248,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",248,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",248,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",248,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",248,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",248,null],[11,"eq","","Lane-wise equality comparison.",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",248,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",248,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",248,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",248,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",248,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",248,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"neg","","",248,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",248,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",248,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",248,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",248,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",248,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",248,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",248,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",248,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",248,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",248,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",248,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",249,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"le","","",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"gt","","",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"ge","","",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"clone","","",249,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",249,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",249,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",249,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",249,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",249,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",249,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",249,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",249,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",249,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",249,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",249,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",249,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",249,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",249,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",249,null],[11,"eq","","Lane-wise equality comparison.",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",249,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",249,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",249,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",249,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",249,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",249,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"not","","",249,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",249,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",249,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",249,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",249,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",249,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",249,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",249,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",249,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",249,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",249,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",250,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"le","","",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"gt","","",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"ge","","",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"clone","","",250,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",250,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",250,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",250,{"inputs":[{"name":"bool"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",250,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",250,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",250,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",250,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"not","","",250,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",250,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",250,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",250,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",250,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",250,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",250,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",250,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"eq","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",250,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",250,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",251,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"le","","",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"gt","","",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"ge","","",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"clone","","",251,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",251,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",251,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",251,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",251,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",251,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",251,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",251,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",251,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",251,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",251,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",251,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",251,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",251,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",251,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",251,null],[11,"eq","","Lane-wise equality comparison.",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",251,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",251,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",251,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",251,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",251,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",251,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"neg","","",251,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",251,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",251,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",251,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",251,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",251,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",251,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",251,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",251,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",251,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",251,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",251,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",252,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"le","","",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"gt","","",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"ge","","",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"clone","","",252,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",252,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",252,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",252,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",252,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",252,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",252,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",252,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",252,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",252,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",252,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",252,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",252,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",252,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",252,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",252,null],[11,"eq","","Lane-wise equality comparison.",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",252,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",252,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",252,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",252,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",252,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",252,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"not","","",252,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",252,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",252,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",252,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",252,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",252,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",252,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",252,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",252,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",252,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",252,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",253,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"le","","",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"gt","","",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"ge","","",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"clone","","",253,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",253,{"inputs":[{"name":"i32"},{"name":"i32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",253,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",253,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",253,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",253,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",253,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",253,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",253,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",253,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",253,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",253,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",253,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",253,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",253,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",253,null],[11,"eq","","Lane-wise equality comparison.",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",253,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",253,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",253,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",253,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",253,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",253,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"neg","","",253,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",253,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",253,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",253,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",253,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",253,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",253,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",253,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",253,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",253,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",253,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",253,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",254,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"le","","",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"gt","","",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"ge","","",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"clone","","",254,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",254,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",254,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",254,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",254,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",254,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",254,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",254,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",254,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",254,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",254,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",254,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",254,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",254,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",254,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",254,null],[11,"eq","","Lane-wise equality comparison.",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",254,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",254,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",254,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",254,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",254,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",254,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"not","","",254,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",254,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",254,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",254,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",254,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",254,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",254,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",254,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",254,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",254,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",254,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",255,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"le","","",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"gt","","",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"ge","","",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"clone","","",255,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",255,{"inputs":[{"name":"f32"},{"name":"f32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",255,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",255,{"inputs":[{"name":"f32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",255,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",255,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",255,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",255,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",255,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",255,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",255,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",255,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",255,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",255,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",255,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",255,null],[11,"eq","","Lane-wise equality comparison.",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",255,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"add","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",255,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",255,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",255,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",255,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"neg","","",255,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",255,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",255,{"inputs":[],"output":{"name":"self"}}],[11,"from_bits","","",254,{"inputs":[{"name":"i32x2"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",254,{"inputs":[{"name":"f32x2"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",254,{"inputs":[{"name":"u16x4"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",254,{"inputs":[{"name":"i16x4"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",254,{"inputs":[{"name":"u8x8"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",254,{"inputs":[{"name":"i8x8"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",254,{"inputs":[{"name":"b8x8"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"u32x2"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"f32x2"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"u16x4"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"i16x4"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"u8x8"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"i8x8"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"b8x8"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",255,{"inputs":[{"name":"i32x2"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",255,{"inputs":[{"name":"u32x2"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",255,{"inputs":[{"name":"u16x4"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",255,{"inputs":[{"name":"i16x4"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",255,{"inputs":[{"name":"u8x8"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",255,{"inputs":[{"name":"i8x8"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",255,{"inputs":[{"name":"b8x8"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",252,{"inputs":[{"name":"u32x2"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",252,{"inputs":[{"name":"i32x2"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",252,{"inputs":[{"name":"i16x4"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",252,{"inputs":[{"name":"u8x8"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",252,{"inputs":[{"name":"i8x8"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",252,{"inputs":[{"name":"b8x8"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",251,{"inputs":[{"name":"u32x2"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",251,{"inputs":[{"name":"i32x2"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",251,{"inputs":[{"name":"u16x4"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",251,{"inputs":[{"name":"u8x8"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",251,{"inputs":[{"name":"i8x8"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",251,{"inputs":[{"name":"b8x8"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",249,{"inputs":[{"name":"u32x2"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",249,{"inputs":[{"name":"i32x2"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",249,{"inputs":[{"name":"u16x4"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",249,{"inputs":[{"name":"i16x4"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",249,{"inputs":[{"name":"i8x8"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",249,{"inputs":[{"name":"b8x8"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",248,{"inputs":[{"name":"u32x2"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",248,{"inputs":[{"name":"i32x2"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",248,{"inputs":[{"name":"u16x4"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",248,{"inputs":[{"name":"i16x4"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",248,{"inputs":[{"name":"u8x8"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",248,{"inputs":[{"name":"b8x8"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",255,{"inputs":[{"name":"__m64"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",254,{"inputs":[{"name":"__m64"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",253,{"inputs":[{"name":"__m64"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",252,{"inputs":[{"name":"__m64"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",251,{"inputs":[{"name":"__m64"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",249,{"inputs":[{"name":"__m64"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",248,{"inputs":[{"name":"__m64"}],"output":{"name":"i8x8"}}],[11,"from","","",255,{"inputs":[{"name":"f64x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"u64x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"i64x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"u32x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"i32x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"u16x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"i16x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"u8x2"}],"output":{"name":"f32x2"}}],[11,"from","","",255,{"inputs":[{"name":"i8x2"}],"output":{"name":"f32x2"}}],[11,"from","","",254,{"inputs":[{"name":"f64x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"u64x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"i64x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"f32x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"i32x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"u16x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"i16x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"u8x2"}],"output":{"name":"u32x2"}}],[11,"from","","",254,{"inputs":[{"name":"i8x2"}],"output":{"name":"u32x2"}}],[11,"from","","",253,{"inputs":[{"name":"f64x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"u64x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"i64x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"f32x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"u32x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"u16x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"i16x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"u8x2"}],"output":{"name":"i32x2"}}],[11,"from","","",253,{"inputs":[{"name":"i8x2"}],"output":{"name":"i32x2"}}],[11,"from","","",252,{"inputs":[{"name":"f64x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"u64x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"i64x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"f32x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"i32x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"u32x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"i16x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"u8x4"}],"output":{"name":"u16x4"}}],[11,"from","","",252,{"inputs":[{"name":"i8x4"}],"output":{"name":"u16x4"}}],[11,"from","","",251,{"inputs":[{"name":"f64x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"u64x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"i64x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"f32x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"i32x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"u32x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"u16x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"u8x4"}],"output":{"name":"i16x4"}}],[11,"from","","",251,{"inputs":[{"name":"i8x4"}],"output":{"name":"i16x4"}}],[11,"from","","",248,{"inputs":[{"name":"f64x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"u64x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"i64x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"f32x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"u32x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"i32x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"i16x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"u16x8"}],"output":{"name":"i8x8"}}],[11,"from","","",248,{"inputs":[{"name":"u8x8"}],"output":{"name":"i8x8"}}],[11,"from","","",249,{"inputs":[{"name":"f64x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"u64x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"i64x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"f32x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"u32x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"i32x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"i16x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"u16x8"}],"output":{"name":"u8x8"}}],[11,"from","","",249,{"inputs":[{"name":"i8x8"}],"output":{"name":"u8x8"}}],[11,"fmt","","",256,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"le","","",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"gt","","",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"ge","","",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"clone","","",256,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",256,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",256,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",256,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",256,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",256,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",256,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",256,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",256,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",256,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",256,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",256,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",256,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",256,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",256,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",256,null],[11,"eq","","Lane-wise equality comparison.",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",256,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"hash","","",256,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",256,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",256,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",256,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",256,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"neg","","",256,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",256,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",256,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",256,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",256,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",256,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",256,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",256,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",256,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",256,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",256,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",256,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",257,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"le","","",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"gt","","",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"ge","","",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"clone","","",257,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",257,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",257,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",257,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",257,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",257,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",257,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",257,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",257,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",257,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",257,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",257,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",257,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",257,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",257,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",257,null],[11,"eq","","Lane-wise equality comparison.",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",257,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"hash","","",257,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",257,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",257,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",257,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",257,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"not","","",257,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",257,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",257,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",257,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",257,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",257,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",257,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",257,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",257,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",257,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",257,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",258,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"le","","",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"gt","","",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"ge","","",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"clone","","",258,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",258,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",258,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",258,{"inputs":[{"name":"bool"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",258,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",258,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",258,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",258,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"not","","",258,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",258,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",258,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",258,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",258,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",258,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",258,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",258,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"eq","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",258,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",258,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",259,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"le","","",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"gt","","",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"ge","","",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"clone","","",259,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",259,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",259,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",259,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",259,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",259,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",259,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",259,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",259,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",259,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",259,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",259,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",259,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",259,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",259,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",259,null],[11,"eq","","Lane-wise equality comparison.",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",259,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",259,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",259,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",259,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",259,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",259,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"neg","","",259,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",259,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",259,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",259,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",259,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",259,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",259,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",259,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",259,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",259,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",259,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",259,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",260,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"le","","",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"gt","","",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"ge","","",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"clone","","",260,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",260,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",260,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",260,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",260,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",260,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",260,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",260,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",260,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",260,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",260,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",260,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",260,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",260,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",260,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",260,null],[11,"eq","","Lane-wise equality comparison.",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",260,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",260,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",260,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",260,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",260,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",260,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"not","","",260,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",260,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",260,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",260,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",260,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",260,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",260,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",260,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",260,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",260,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",260,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",261,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"le","","",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"gt","","",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"ge","","",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"clone","","",261,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",261,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",261,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",261,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",261,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",261,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",261,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",261,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",261,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",261,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",261,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",261,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",261,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",261,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",261,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",261,null],[11,"eq","","Lane-wise equality comparison.",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",261,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",261,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",261,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",261,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",261,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",261,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"neg","","",261,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",261,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",261,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",261,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",261,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",261,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",261,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",261,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",261,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",261,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",261,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",261,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",262,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"le","","",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"gt","","",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"ge","","",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"clone","","",262,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",262,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",262,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",262,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",262,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",262,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",262,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",262,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",262,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",262,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",262,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",262,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",262,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",262,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",262,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",262,null],[11,"eq","","Lane-wise equality comparison.",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",262,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",262,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",262,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",262,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",262,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",262,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"not","","",262,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",262,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",262,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",262,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",262,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",262,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",262,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",262,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",262,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",262,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",262,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",263,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"le","","",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"gt","","",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"ge","","",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"clone","","",263,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",263,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",263,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",263,{"inputs":[{"name":"f32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",263,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",263,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",263,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",263,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",263,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",263,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",263,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",263,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",263,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",263,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",263,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",263,null],[11,"eq","","Lane-wise equality comparison.",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",263,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"add","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",263,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",263,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",263,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",263,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"neg","","",263,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",263,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",263,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",264,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"le","","",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"gt","","",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"ge","","",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"clone","","",264,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",264,{"inputs":[{"name":"i64"},{"name":"i64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",264,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",264,{"inputs":[{"name":"i64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",264,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",264,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",264,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",264,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",264,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",264,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",264,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",264,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",264,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",264,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",264,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",264,null],[11,"eq","","Lane-wise equality comparison.",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",264,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",264,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",264,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",264,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"max","","Largest vector value.",264,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"min","","Smallest vector value.",264,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"neg","","",264,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",264,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",264,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",264,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",264,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",264,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",264,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",264,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",264,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",264,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",264,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",264,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",265,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"le","","",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"gt","","",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"ge","","",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"clone","","",265,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",265,{"inputs":[{"name":"u64"},{"name":"u64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",265,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",265,{"inputs":[{"name":"u64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",265,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",265,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",265,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",265,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",265,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",265,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",265,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",265,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",265,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",265,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",265,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",265,null],[11,"eq","","Lane-wise equality comparison.",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",265,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"hash","","",265,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",265,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",265,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"max","","Largest vector value.",265,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"min","","Smallest vector value.",265,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"not","","",265,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",265,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",265,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",265,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",265,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",265,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",265,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",265,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",265,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",265,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",265,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",266,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"le","","",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"gt","","",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"ge","","",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"clone","","",266,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",266,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",266,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",266,{"inputs":[{"name":"f64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",266,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",266,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",266,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",266,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",266,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",266,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",266,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",266,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",266,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",266,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",266,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",266,null],[11,"eq","","Lane-wise equality comparison.",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",266,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"add","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",266,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",266,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"max","","Largest vector value.",266,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"min","","Smallest vector value.",266,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"neg","","",266,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",266,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",266,{"inputs":[],"output":{"name":"self"}}],[11,"from_bits","","",265,{"inputs":[{"name":"i64x2"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"f64x2"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"u32x4"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"i32x4"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"f32x4"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"u16x8"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"i16x8"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"u8x16"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"i8x16"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"b8x16"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"u64x2"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"f64x2"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"u32x4"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"i32x4"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"f32x4"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"u16x8"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"i16x8"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"u8x16"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"i8x16"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"b8x16"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"i64x2"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"u64x2"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"u32x4"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"i32x4"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"f32x4"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"u16x8"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"i16x8"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"u8x16"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"i8x16"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"b8x16"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",262,{"inputs":[{"name":"u64x2"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"i64x2"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"f64x2"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"i32x4"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"f32x4"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"u16x8"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"i16x8"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"u8x16"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"i8x16"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"b8x16"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"u64x2"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"i64x2"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"f64x2"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"u32x4"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"f32x4"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"u16x8"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"i16x8"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"u8x16"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"i8x16"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"b8x16"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"u64x2"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"i64x2"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"f64x2"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"i32x4"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"u32x4"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"u16x8"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"i16x8"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"u8x16"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"i8x16"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"b8x16"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",260,{"inputs":[{"name":"u64x2"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"i64x2"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"f64x2"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"u32x4"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"i32x4"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"f32x4"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"i16x8"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"u8x16"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"i8x16"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"b8x16"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"u64x2"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"i64x2"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"f64x2"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"u32x4"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"i32x4"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"f32x4"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"u16x8"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"u8x16"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"i8x16"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"b8x16"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",257,{"inputs":[{"name":"u64x2"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"i64x2"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"f64x2"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"u32x4"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"i32x4"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"f32x4"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"u16x8"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"i16x8"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"i8x16"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"b8x16"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"u64x2"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"i64x2"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"f64x2"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"u32x4"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"i32x4"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"f32x4"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"u16x8"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"i16x8"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"u8x16"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"b8x16"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",266,{"inputs":[{"name":"__m128"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"__m128i"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",266,{"inputs":[{"name":"__m128d"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"__m128"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"__m128i"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",265,{"inputs":[{"name":"__m128d"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"__m128"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"__m128i"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",264,{"inputs":[{"name":"__m128d"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",263,{"inputs":[{"name":"__m128"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"__m128i"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",263,{"inputs":[{"name":"__m128d"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"__m128"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"__m128i"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",262,{"inputs":[{"name":"__m128d"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"__m128"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",261,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",260,{"inputs":[{"name":"__m128"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"__m128i"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",260,{"inputs":[{"name":"__m128d"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"__m128"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"__m128i"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",259,{"inputs":[{"name":"__m128d"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",257,{"inputs":[{"name":"__m128"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"__m128i"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",257,{"inputs":[{"name":"__m128d"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"__m128"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"__m128i"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",256,{"inputs":[{"name":"__m128d"}],"output":{"name":"i8x16"}}],[11,"from","","",266,{"inputs":[{"name":"f32x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"u64x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"i64x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"u32x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"i32x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"u16x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"i16x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"u8x2"}],"output":{"name":"f64x2"}}],[11,"from","","",266,{"inputs":[{"name":"i8x2"}],"output":{"name":"f64x2"}}],[11,"from","","",263,{"inputs":[{"name":"f64x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"u64x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"i64x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"u32x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"i32x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"u16x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"i16x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"u8x4"}],"output":{"name":"f32x4"}}],[11,"from","","",263,{"inputs":[{"name":"i8x4"}],"output":{"name":"f32x4"}}],[11,"from","","",265,{"inputs":[{"name":"f32x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"f64x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"i64x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"i32x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"u32x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"i16x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"u16x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"i8x2"}],"output":{"name":"u64x2"}}],[11,"from","","",265,{"inputs":[{"name":"u8x2"}],"output":{"name":"u64x2"}}],[11,"from","","",264,{"inputs":[{"name":"f32x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"f64x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"u64x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"i32x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"u32x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"i16x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"u16x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"i8x2"}],"output":{"name":"i64x2"}}],[11,"from","","",264,{"inputs":[{"name":"u8x2"}],"output":{"name":"i64x2"}}],[11,"from","","",262,{"inputs":[{"name":"f64x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"u64x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"i64x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"f32x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"i32x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"u16x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"i16x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"u8x4"}],"output":{"name":"u32x4"}}],[11,"from","","",262,{"inputs":[{"name":"i8x4"}],"output":{"name":"u32x4"}}],[11,"from","","",261,{"inputs":[{"name":"f64x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"u64x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"i64x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"f32x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"u32x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"u16x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"i16x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"u8x4"}],"output":{"name":"i32x4"}}],[11,"from","","",261,{"inputs":[{"name":"i8x4"}],"output":{"name":"i32x4"}}],[11,"from","","",259,{"inputs":[{"name":"f64x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"u64x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"i64x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"f32x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"u32x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"i32x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"u16x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"u8x8"}],"output":{"name":"i16x8"}}],[11,"from","","",259,{"inputs":[{"name":"i8x8"}],"output":{"name":"i16x8"}}],[11,"from","","",260,{"inputs":[{"name":"f64x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"u64x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"i64x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"f32x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"u32x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"i32x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"i16x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"u8x8"}],"output":{"name":"u16x8"}}],[11,"from","","",260,{"inputs":[{"name":"i8x8"}],"output":{"name":"u16x8"}}],[11,"fmt","","",267,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"le","","",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"gt","","",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"ge","","",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"clone","","",267,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",267,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",267,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",267,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",267,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",267,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",267,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",267,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",267,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",267,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",267,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",267,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",267,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",267,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",267,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",267,null],[11,"eq","","Lane-wise equality comparison.",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",267,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"hash","","",267,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",267,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",267,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",267,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",267,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"neg","","",267,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",267,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",267,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",267,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",267,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",267,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",267,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",267,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",267,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",267,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",267,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",267,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",268,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"le","","",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"gt","","",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"ge","","",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"clone","","",268,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",268,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",268,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",268,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",268,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",268,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",268,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",268,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",268,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",268,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",268,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",268,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",268,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",268,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",268,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",268,null],[11,"eq","","Lane-wise equality comparison.",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",268,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"hash","","",268,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",268,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",268,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",268,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",268,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"not","","",268,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",268,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",268,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",268,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",268,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",268,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",268,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",268,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",268,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",268,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",268,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",269,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"le","","",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"gt","","",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"ge","","",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"clone","","",269,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",269,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",269,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",269,{"inputs":[{"name":"bool"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",269,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",269,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",269,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",269,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"not","","",269,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",269,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",269,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",269,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",269,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",269,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",269,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",269,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"eq","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",269,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",269,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",270,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"le","","",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"gt","","",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"ge","","",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"clone","","",270,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",270,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",270,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",270,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",270,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",270,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",270,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",270,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",270,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",270,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",270,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",270,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",270,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",270,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",270,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",270,null],[11,"eq","","Lane-wise equality comparison.",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",270,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"hash","","",270,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",270,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",270,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",270,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",270,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"neg","","",270,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",270,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",270,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",270,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",270,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",270,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",270,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",270,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",270,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",270,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",270,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",270,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",271,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"le","","",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"gt","","",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"ge","","",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"clone","","",271,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",271,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",271,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",271,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",271,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",271,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",271,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",271,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",271,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",271,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",271,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",271,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",271,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",271,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",271,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",271,null],[11,"eq","","Lane-wise equality comparison.",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",271,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"hash","","",271,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",271,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",271,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",271,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",271,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"not","","",271,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",271,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",271,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",271,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",271,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",271,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",271,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",271,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",271,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",271,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",271,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",272,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"le","","",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"gt","","",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"ge","","",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"clone","","",272,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",272,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",272,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",272,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",272,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",272,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",272,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",272,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",272,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",272,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",272,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",272,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",272,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",272,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",272,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",272,null],[11,"eq","","Lane-wise equality comparison.",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",272,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",272,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",272,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",272,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",272,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",272,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"neg","","",272,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",272,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",272,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",272,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",272,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",272,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",272,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",272,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",272,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",272,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",272,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",272,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",273,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"le","","",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"gt","","",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"ge","","",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"clone","","",273,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",273,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",273,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",273,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",273,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",273,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",273,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",273,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",273,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",273,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",273,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",273,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",273,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",273,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",273,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",273,null],[11,"eq","","Lane-wise equality comparison.",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",273,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",273,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",273,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",273,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",273,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",273,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"not","","",273,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",273,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",273,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",273,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",273,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",273,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",273,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",273,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",273,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",273,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",273,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",274,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"le","","",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"gt","","",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"ge","","",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"clone","","",274,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",274,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",274,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",274,{"inputs":[{"name":"f32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",274,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",274,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",274,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",274,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",274,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",274,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",274,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",274,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",274,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",274,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",274,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",274,null],[11,"eq","","Lane-wise equality comparison.",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",274,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"add","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",274,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",274,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",274,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",274,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"neg","","",274,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",274,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",274,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",275,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"le","","",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"gt","","",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"ge","","",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"clone","","",275,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",275,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",275,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",275,{"inputs":[{"name":"i64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",275,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",275,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",275,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",275,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",275,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",275,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",275,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",275,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",275,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",275,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",275,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",275,null],[11,"eq","","Lane-wise equality comparison.",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",275,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",275,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",275,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",275,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"max","","Largest vector value.",275,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"min","","Smallest vector value.",275,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"neg","","",275,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",275,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",275,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",275,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",275,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",275,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",275,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",275,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",275,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",275,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",275,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",275,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",276,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"le","","",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"gt","","",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"ge","","",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"clone","","",276,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",276,{"inputs":[{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",276,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",276,{"inputs":[{"name":"u64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",276,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",276,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",276,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",276,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",276,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",276,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",276,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",276,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",276,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",276,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",276,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",276,null],[11,"eq","","Lane-wise equality comparison.",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",276,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"hash","","",276,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",276,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",276,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"max","","Largest vector value.",276,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"min","","Smallest vector value.",276,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"not","","",276,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",276,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",276,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",276,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",276,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",276,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",276,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",276,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",276,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",276,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",276,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",277,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"le","","",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"gt","","",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"ge","","",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"clone","","",277,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",277,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",277,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",277,{"inputs":[{"name":"f64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",277,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",277,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",277,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",277,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",277,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",277,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",277,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",277,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",277,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",277,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",277,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",277,null],[11,"eq","","Lane-wise equality comparison.",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",277,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"add","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",277,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",277,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"max","","Largest vector value.",277,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"min","","Smallest vector value.",277,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"neg","","",277,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",277,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",277,{"inputs":[],"output":{"name":"self"}}],[11,"from_bits","","",267,{"inputs":[{"name":"u64x4"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"i64x4"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"f64x4"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"u32x8"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"i32x8"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"f32x8"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"u16x16"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"i16x16"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"u8x32"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"b8x32"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"u64x4"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"i64x4"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"f64x4"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"u32x8"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"i32x8"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"f32x8"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"u16x16"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"i16x16"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"i8x32"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"b8x32"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",270,{"inputs":[{"name":"u64x4"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"i64x4"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"f64x4"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"u32x8"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"i32x8"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"f32x8"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"u16x16"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"u8x32"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"i8x32"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"b8x32"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"u64x4"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"i64x4"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"f64x4"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"u32x8"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"i32x8"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"f32x8"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"i16x16"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"u8x32"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"i8x32"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"b8x32"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",272,{"inputs":[{"name":"u64x4"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"i64x4"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"f64x4"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"u32x8"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"f32x8"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"u16x16"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"i16x16"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"u8x32"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"i8x32"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"b8x32"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"u64x4"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"i64x4"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"f64x4"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"i32x8"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"f32x8"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"u16x16"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"i16x16"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"u8x32"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"i8x32"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"b8x32"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"u64x4"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"i64x4"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"f64x4"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"i32x8"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"u32x8"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"u16x16"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"i16x16"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"u8x32"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"i8x32"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"b8x32"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",275,{"inputs":[{"name":"u64x4"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"f64x4"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"i32x8"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"u32x8"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"f32x8"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"u16x16"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"i16x16"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"u8x32"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"i8x32"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"b8x32"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"i64x4"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"f64x4"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"i32x8"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"u32x8"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"f32x8"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"u16x16"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"i16x16"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"u8x32"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"i8x32"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"b8x32"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"i64x4"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"u64x4"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"i32x8"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"u32x8"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"f32x8"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"u16x16"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"i16x16"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"u8x32"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"i8x32"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"b8x32"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"__m256"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"__m256i"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",277,{"inputs":[{"name":"__m256d"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"__m256"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"__m256i"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",276,{"inputs":[{"name":"__m256d"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"__m256"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"__m256i"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",275,{"inputs":[{"name":"__m256d"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",274,{"inputs":[{"name":"__m256"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"__m256i"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",274,{"inputs":[{"name":"__m256d"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"__m256"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"__m256i"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",273,{"inputs":[{"name":"__m256d"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"__m256"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"__m256i"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",272,{"inputs":[{"name":"__m256d"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",271,{"inputs":[{"name":"__m256"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"__m256i"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",271,{"inputs":[{"name":"__m256d"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"__m256"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"__m256i"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",270,{"inputs":[{"name":"__m256d"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",268,{"inputs":[{"name":"__m256"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"__m256i"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",268,{"inputs":[{"name":"__m256d"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"__m256"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"__m256i"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",267,{"inputs":[{"name":"__m256d"}],"output":{"name":"i8x32"}}],[11,"from","","",277,{"inputs":[{"name":"u64x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"i64x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"u32x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"i32x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"f32x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"u16x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"i16x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"u8x4"}],"output":{"name":"f64x4"}}],[11,"from","","",277,{"inputs":[{"name":"i8x4"}],"output":{"name":"f64x4"}}],[11,"from","","",275,{"inputs":[{"name":"u64x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"f64x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"u32x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"i32x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"f32x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"u16x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"i16x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"u8x4"}],"output":{"name":"i64x4"}}],[11,"from","","",275,{"inputs":[{"name":"i8x4"}],"output":{"name":"i64x4"}}],[11,"from","","",276,{"inputs":[{"name":"i64x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"f64x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"u32x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"i32x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"f32x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"u16x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"i16x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"u8x4"}],"output":{"name":"u64x4"}}],[11,"from","","",276,{"inputs":[{"name":"i8x4"}],"output":{"name":"u64x4"}}],[11,"from","","",274,{"inputs":[{"name":"u64x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"i64x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"f64x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"u32x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"i32x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"u16x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"i16x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"u8x8"}],"output":{"name":"f32x8"}}],[11,"from","","",274,{"inputs":[{"name":"i8x8"}],"output":{"name":"f32x8"}}],[11,"from","","",272,{"inputs":[{"name":"u64x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"i64x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"f64x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"u32x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"f32x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"u16x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"i16x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"u8x8"}],"output":{"name":"i32x8"}}],[11,"from","","",272,{"inputs":[{"name":"i8x8"}],"output":{"name":"i32x8"}}],[11,"from","","",273,{"inputs":[{"name":"u64x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"i64x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"f64x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"i32x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"f32x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"u16x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"i16x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"u8x8"}],"output":{"name":"u32x8"}}],[11,"from","","",273,{"inputs":[{"name":"i8x8"}],"output":{"name":"u32x8"}}],[11,"from","","",270,{"inputs":[{"name":"u32x16"}],"output":{"name":"i16x16"}}],[11,"from","","",270,{"inputs":[{"name":"i32x16"}],"output":{"name":"i16x16"}}],[11,"from","","",270,{"inputs":[{"name":"f32x16"}],"output":{"name":"i16x16"}}],[11,"from","","",270,{"inputs":[{"name":"u16x16"}],"output":{"name":"i16x16"}}],[11,"from","","",270,{"inputs":[{"name":"u8x16"}],"output":{"name":"i16x16"}}],[11,"from","","",270,{"inputs":[{"name":"i8x16"}],"output":{"name":"i16x16"}}],[11,"from","","",271,{"inputs":[{"name":"u32x16"}],"output":{"name":"u16x16"}}],[11,"from","","",271,{"inputs":[{"name":"i32x16"}],"output":{"name":"u16x16"}}],[11,"from","","",271,{"inputs":[{"name":"f32x16"}],"output":{"name":"u16x16"}}],[11,"from","","",271,{"inputs":[{"name":"i16x16"}],"output":{"name":"u16x16"}}],[11,"from","","",271,{"inputs":[{"name":"u8x16"}],"output":{"name":"u16x16"}}],[11,"from","","",271,{"inputs":[{"name":"i8x16"}],"output":{"name":"u16x16"}}],[11,"from","","",267,{"inputs":[{"name":"u16x32"}],"output":{"name":"i8x32"}}],[11,"from","","",267,{"inputs":[{"name":"i16x32"}],"output":{"name":"i8x32"}}],[11,"from","","",267,{"inputs":[{"name":"u8x32"}],"output":{"name":"i8x32"}}],[11,"from","","",268,{"inputs":[{"name":"u16x32"}],"output":{"name":"u8x32"}}],[11,"from","","",268,{"inputs":[{"name":"i16x32"}],"output":{"name":"u8x32"}}],[11,"from","","",268,{"inputs":[{"name":"i8x32"}],"output":{"name":"u8x32"}}],[11,"fmt","","",278,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"le","","",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"gt","","",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"ge","","",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"clone","","",278,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",278,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",278,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",278,{"inputs":[{"name":"i8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",278,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",278,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",278,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",278,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",278,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",278,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",278,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",278,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",278,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",278,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",278,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",278,null],[11,"eq","","Lane-wise equality comparison.",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"ne","","Lane-wise inequality comparison.",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"lt","","Lane-wise less-than comparison.",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"gt","","Lane-wise greater-than comparison.",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",278,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"hash","","",278,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",278,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",278,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",278,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",278,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"neg","","",278,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",278,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",278,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",278,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",278,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",278,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",278,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",278,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",278,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",278,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",278,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",278,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",279,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"le","","",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"gt","","",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"ge","","",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"clone","","",279,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",279,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",279,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",279,{"inputs":[{"name":"u8"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",279,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",279,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",279,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",279,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",279,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",279,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",279,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",279,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",279,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",279,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",279,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",279,null],[11,"eq","","Lane-wise equality comparison.",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"ne","","Lane-wise inequality comparison.",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"lt","","Lane-wise less-than comparison.",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"gt","","Lane-wise greater-than comparison.",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",279,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"hash","","",279,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",279,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",279,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",279,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",279,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"not","","",279,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",279,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",279,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",279,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",279,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",279,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",279,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",279,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",279,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",279,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",279,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",280,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"le","","",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"gt","","",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"ge","","",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"clone","","",280,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",280,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",280,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",280,{"inputs":[{"name":"bool"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",280,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",280,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",280,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",280,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"self"}}],[11,"not","","",280,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",280,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",280,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",280,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",280,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",280,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",280,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"ne","","Lane-wise inequality comparison.",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"lt","","Lane-wise less-than comparison.",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"gt","","Lane-wise greater-than comparison.",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",280,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"eq","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",280,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",280,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",281,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"le","","",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"gt","","",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"ge","","",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"clone","","",281,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",281,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",281,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",281,{"inputs":[{"name":"i16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",281,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",281,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",281,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",281,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",281,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",281,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",281,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",281,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",281,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",281,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",281,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",281,null],[11,"eq","","Lane-wise equality comparison.",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",281,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"hash","","",281,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",281,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",281,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",281,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",281,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"neg","","",281,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",281,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",281,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",281,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",281,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",281,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",281,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",281,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",281,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",281,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",281,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",281,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",282,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"le","","",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"gt","","",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"ge","","",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"clone","","",282,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",282,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",282,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",282,{"inputs":[{"name":"u16"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",282,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",282,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",282,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",282,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",282,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",282,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",282,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",282,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",282,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",282,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",282,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",282,null],[11,"eq","","Lane-wise equality comparison.",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",282,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"hash","","",282,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",282,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",282,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",282,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",282,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"not","","",282,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",282,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",282,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",282,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",282,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",282,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",282,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",282,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",282,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",282,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",282,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",283,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"le","","",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"gt","","",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"ge","","",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"clone","","",283,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",283,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",283,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",283,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",283,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",283,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",283,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",283,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",283,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",283,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",283,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",283,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",283,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",283,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",283,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",283,null],[11,"eq","","Lane-wise equality comparison.",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",283,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"hash","","",283,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",283,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",283,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",283,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",283,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"neg","","",283,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",283,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",283,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",283,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",283,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",283,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",283,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",283,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",283,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",283,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",283,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",283,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",284,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"le","","",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"gt","","",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"ge","","",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"clone","","",284,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",284,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",284,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",284,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",284,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",284,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",284,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",284,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",284,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",284,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",284,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",284,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",284,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",284,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",284,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",284,null],[11,"eq","","Lane-wise equality comparison.",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",284,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"hash","","",284,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",284,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",284,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",284,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",284,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"not","","",284,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",284,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",284,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",284,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",284,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",284,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",284,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",284,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",284,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",284,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",284,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"le","","",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"gt","","",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"ge","","",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"clone","","",285,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",285,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",285,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",285,{"inputs":[{"name":"f32"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",285,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",285,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",285,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",285,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",285,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",285,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",285,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",285,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",285,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",285,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",285,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",285,null],[11,"eq","","Lane-wise equality comparison.",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",285,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"add","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",285,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",285,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",285,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",285,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"neg","","",285,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",285,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",285,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",286,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"le","","",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"gt","","",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"ge","","",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"clone","","",286,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",286,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",286,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",286,{"inputs":[{"name":"i64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",286,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",286,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",286,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",286,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",286,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",286,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",286,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",286,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",286,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",286,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",286,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",286,null],[11,"eq","","Lane-wise equality comparison.",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",286,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",286,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",286,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",286,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"max","","Largest vector value.",286,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"min","","Smallest vector value.",286,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"neg","","",286,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"not","","",286,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",286,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",286,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",286,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",286,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",286,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",286,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",286,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",286,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",286,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",286,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",287,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"le","","",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"gt","","",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"ge","","",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"clone","","",287,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",287,{"inputs":[{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",287,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",287,{"inputs":[{"name":"u64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",287,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",287,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",287,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",287,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",287,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",287,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",287,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",287,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",287,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",287,null],[11,"eq","","Lane-wise equality comparison.",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",287,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"hash","","",287,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"add","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",287,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",287,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"max","","Largest vector value.",287,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"min","","Smallest vector value.",287,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"not","","",287,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bitxor","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitor","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"bitand_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitor_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"bitxor_assign","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",287,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",287,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",287,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"u8"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"i8"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"i16"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"i32"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"i64"}],"output":null}],[11,"shl","","",287,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shr","","",287,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"self"}}],[11,"shl_assign","","",287,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"shr_assign","","",287,{"inputs":[{"name":"self"},{"name":"isize"}],"output":null}],[11,"fmt","","",287,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",287,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",287,{"inputs":[],"output":{"name":"self"}}],[11,"fmt","","",288,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"partial_cmp","","",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"le","","",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"gt","","",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"ge","","",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"clone","","",288,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",288,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"self"}}],[11,"lanes","","Returns the number of vector lanes.",288,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",288,{"inputs":[{"name":"f64"}],"output":{"name":"self"}}],[11,"extract","","Extracts the value at `index`.",288,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",288,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",288,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"self"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",288,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"self"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",288,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",288,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",288,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",288,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",288,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",288,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",288,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",288,null],[11,"eq","","Lane-wise equality comparison.",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",288,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"add","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"sub","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"mul","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"div","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"rem","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"add_assign","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sub_assign","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"mul_assign","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"div_assign","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"rem_assign","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":null}],[11,"sum","","Lane-wise addition of the vector elements.",288,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",288,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"max","","Largest vector value.",288,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"min","","Smallest vector value.",288,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"neg","","",288,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"eq","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"ne","","",288,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"default","","",288,{"inputs":[],"output":{"name":"self"}}],[11,"from_bits","","",278,{"inputs":[{"name":"u64x8"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"i64x8"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"f64x8"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"u32x16"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"i32x16"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"f32x16"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"u16x32"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"i16x32"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"u8x64"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",278,{"inputs":[{"name":"b8x64"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"u64x8"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"i64x8"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"f64x8"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"u32x16"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"i32x16"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"f32x16"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"u16x32"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"i16x32"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"i8x64"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",279,{"inputs":[{"name":"b8x64"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",281,{"inputs":[{"name":"u64x8"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"i64x8"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"f64x8"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"u32x16"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"i32x16"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"f32x16"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"u16x32"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"i8x64"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"u8x64"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",281,{"inputs":[{"name":"b8x64"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"u64x8"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"i64x8"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"f64x8"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"u32x16"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"i32x16"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"f32x16"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"i16x32"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"i8x64"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"u8x64"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",282,{"inputs":[{"name":"b8x64"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",283,{"inputs":[{"name":"u64x8"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"i64x8"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"f64x8"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"u32x16"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"f32x16"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"u16x32"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"i16x32"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"i8x64"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"u8x64"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",283,{"inputs":[{"name":"b8x64"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"u64x8"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"i64x8"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"f64x8"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"i32x16"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"f32x16"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"u16x32"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"i16x32"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"i8x64"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"u8x64"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",284,{"inputs":[{"name":"b8x64"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"u64x8"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"i64x8"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"f64x8"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"u32x16"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"i32x16"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"u16x32"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"i16x32"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"i8x64"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"u8x64"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",285,{"inputs":[{"name":"b8x64"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",286,{"inputs":[{"name":"u64x8"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"f64x8"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"u32x16"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"i32x16"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"f32x16"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"u16x32"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"i16x32"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"i8x64"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"u8x64"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",286,{"inputs":[{"name":"b8x64"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"i64x8"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"f64x8"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"u32x16"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"i32x16"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"f32x16"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"u16x32"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"i16x32"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"i8x64"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"u8x64"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",287,{"inputs":[{"name":"b8x64"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"u64x8"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"i64x8"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"u32x16"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"i32x16"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"f32x16"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"u16x32"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"i16x32"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"i8x64"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"u8x64"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",288,{"inputs":[{"name":"b8x64"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"u64x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"i64x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"u32x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"i32x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"f32x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"u16x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"i16x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"u8x8"}],"output":{"name":"f64x8"}}],[11,"from","","",288,{"inputs":[{"name":"i8x8"}],"output":{"name":"f64x8"}}],[11,"from","","",286,{"inputs":[{"name":"u64x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"f64x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"u32x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"i32x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"f32x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"u16x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"i16x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"u8x8"}],"output":{"name":"i64x8"}}],[11,"from","","",286,{"inputs":[{"name":"i8x8"}],"output":{"name":"i64x8"}}],[11,"from","","",287,{"inputs":[{"name":"i64x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"f64x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"u32x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"i32x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"f32x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"u16x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"i16x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"u8x8"}],"output":{"name":"u64x8"}}],[11,"from","","",287,{"inputs":[{"name":"i8x8"}],"output":{"name":"u64x8"}}],[11,"from","","",285,{"inputs":[{"name":"u32x16"}],"output":{"name":"f32x16"}}],[11,"from","","",285,{"inputs":[{"name":"i32x16"}],"output":{"name":"f32x16"}}],[11,"from","","",285,{"inputs":[{"name":"u16x16"}],"output":{"name":"f32x16"}}],[11,"from","","",285,{"inputs":[{"name":"i16x16"}],"output":{"name":"f32x16"}}],[11,"from","","",285,{"inputs":[{"name":"u8x16"}],"output":{"name":"f32x16"}}],[11,"from","","",285,{"inputs":[{"name":"i8x16"}],"output":{"name":"f32x16"}}],[11,"from","","",283,{"inputs":[{"name":"u32x16"}],"output":{"name":"i32x16"}}],[11,"from","","",283,{"inputs":[{"name":"f32x16"}],"output":{"name":"i32x16"}}],[11,"from","","",283,{"inputs":[{"name":"u16x16"}],"output":{"name":"i32x16"}}],[11,"from","","",283,{"inputs":[{"name":"i16x16"}],"output":{"name":"i32x16"}}],[11,"from","","",283,{"inputs":[{"name":"u8x16"}],"output":{"name":"i32x16"}}],[11,"from","","",283,{"inputs":[{"name":"i8x16"}],"output":{"name":"i32x16"}}],[11,"from","","",284,{"inputs":[{"name":"i32x16"}],"output":{"name":"u32x16"}}],[11,"from","","",284,{"inputs":[{"name":"f32x16"}],"output":{"name":"u32x16"}}],[11,"from","","",284,{"inputs":[{"name":"u16x16"}],"output":{"name":"u32x16"}}],[11,"from","","",284,{"inputs":[{"name":"i16x16"}],"output":{"name":"u32x16"}}],[11,"from","","",284,{"inputs":[{"name":"u8x16"}],"output":{"name":"u32x16"}}],[11,"from","","",284,{"inputs":[{"name":"i8x16"}],"output":{"name":"u32x16"}}],[11,"from","","",281,{"inputs":[{"name":"u16x32"}],"output":{"name":"i16x32"}}],[11,"from","","",281,{"inputs":[{"name":"u8x32"}],"output":{"name":"i16x32"}}],[11,"from","","",281,{"inputs":[{"name":"i8x32"}],"output":{"name":"i16x32"}}],[11,"from","","",282,{"inputs":[{"name":"i16x32"}],"output":{"name":"u16x32"}}],[11,"from","","",282,{"inputs":[{"name":"u8x32"}],"output":{"name":"u16x32"}}],[11,"from","","",282,{"inputs":[{"name":"i8x32"}],"output":{"name":"u16x32"}}],[11,"from","","",278,{"inputs":[{"name":"u8x64"}],"output":{"name":"i8x64"}}],[11,"from","","",279,{"inputs":[{"name":"i8x64"}],"output":{"name":"u8x64"}}],[11,"clone","core::arch::x86","",239,{"inputs":[{"name":"self"}],"output":{"name":"cpuidresult"}}],[11,"cmp","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"name":"ordering"}}],[11,"eq","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"name":"bool"}}],[11,"ne","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"name":"bool"}}],[11,"le","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"name":"bool"}}],[11,"gt","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"name":"bool"}}],[11,"ge","","",239,{"inputs":[{"name":"self"},{"name":"cpuidresult"}],"output":{"name":"bool"}}],[11,"fmt","","",289,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",289,{"inputs":[{"name":"self"}],"output":{"name":"__m64"}}],[11,"fmt","","",290,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",290,{"inputs":[{"name":"self"}],"output":{"name":"__m128i"}}],[11,"fmt","","",291,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",291,{"inputs":[{"name":"self"}],"output":{"name":"__m128"}}],[11,"fmt","","",292,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",292,{"inputs":[{"name":"self"}],"output":{"name":"__m128d"}}],[11,"fmt","","",293,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",293,{"inputs":[{"name":"self"}],"output":{"name":"__m256i"}}],[11,"fmt","","",294,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",294,{"inputs":[{"name":"self"}],"output":{"name":"__m256"}}],[11,"fmt","","",295,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",295,{"inputs":[{"name":"self"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",289,{"inputs":[{"name":"u32x2"}],"output":{"name":"__m64"}}],[11,"from_bits","","",289,{"inputs":[{"name":"i32x2"}],"output":{"name":"__m64"}}],[11,"from_bits","","",289,{"inputs":[{"name":"u16x4"}],"output":{"name":"__m64"}}],[11,"from_bits","","",289,{"inputs":[{"name":"i16x4"}],"output":{"name":"__m64"}}],[11,"from_bits","","",289,{"inputs":[{"name":"u8x8"}],"output":{"name":"__m64"}}],[11,"from_bits","","",289,{"inputs":[{"name":"i8x8"}],"output":{"name":"__m64"}}],[11,"from_bits","","",289,{"inputs":[{"name":"b8x8"}],"output":{"name":"__m64"}}],[11,"from_bits","","",291,{"inputs":[{"name":"u64x2"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"i64x2"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"f64x2"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"u32x4"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"i32x4"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"f32x4"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"u16x8"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"i16x8"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"u8x16"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"i8x16"}],"output":{"name":"__m128"}}],[11,"from_bits","","",291,{"inputs":[{"name":"b8x16"}],"output":{"name":"__m128"}}],[11,"from_bits","","",290,{"inputs":[{"name":"u64x2"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"i64x2"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"f64x2"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"u32x4"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"i32x4"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"f32x4"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"u16x8"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"i16x8"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"u8x16"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"i8x16"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",290,{"inputs":[{"name":"b8x16"}],"output":{"name":"__m128i"}}],[11,"from_bits","","",292,{"inputs":[{"name":"u64x2"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"i64x2"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"f64x2"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"u32x4"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"i32x4"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"f32x4"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"u16x8"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"i16x8"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"u8x16"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"i8x16"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",292,{"inputs":[{"name":"b8x16"}],"output":{"name":"__m128d"}}],[11,"from_bits","","",294,{"inputs":[{"name":"u64x4"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"i64x4"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"f64x4"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"u32x8"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"i32x8"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"f32x8"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"u16x16"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"i16x16"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"u8x32"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"i8x32"}],"output":{"name":"__m256"}}],[11,"from_bits","","",294,{"inputs":[{"name":"b8x32"}],"output":{"name":"__m256"}}],[11,"from_bits","","",293,{"inputs":[{"name":"u64x4"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"i64x4"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"f64x4"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"u32x8"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"i32x8"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"f32x8"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"u16x16"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"i16x16"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"u8x32"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"i8x32"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",293,{"inputs":[{"name":"b8x32"}],"output":{"name":"__m256i"}}],[11,"from_bits","","",295,{"inputs":[{"name":"u64x4"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"i64x4"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"f64x4"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"u32x8"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"i32x8"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"f32x8"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"u16x16"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"i16x16"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"u8x32"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"i8x32"}],"output":{"name":"__m256d"}}],[11,"from_bits","","",295,{"inputs":[{"name":"b8x32"}],"output":{"name":"__m256d"}}]],"paths":[[3,"Wrapping"],[4,"FpCategory"],[3,"ParseFloatError"],[3,"NonZeroU8"],[3,"NonZeroU16"],[3,"NonZeroU32"],[3,"NonZeroU64"],[3,"NonZeroU128"],[3,"NonZeroUsize"],[3,"NonZeroI8"],[3,"NonZeroI16"],[3,"NonZeroI32"],[3,"NonZeroI64"],[3,"NonZeroI128"],[3,"NonZeroIsize"],[3,"TryFromIntError"],[3,"ParseIntError"],[3,"Discriminant"],[19,"ManuallyDrop"],[3,"Pin"],[8,"Zeroable"],[3,"NonZero"],[3,"Unique"],[3,"NonNull"],[3,"PhantomData"],[3,"Range"],[3,"RangeFrom"],[3,"RangeTo"],[3,"RangeInclusive"],[3,"RangeToInclusive"],[4,"Bound"],[4,"GeneratorState"],[3,"RangeFull"],[8,"Add"],[8,"Sub"],[8,"Mul"],[8,"Div"],[8,"Rem"],[8,"Neg"],[8,"AddAssign"],[8,"SubAssign"],[8,"MulAssign"],[8,"DivAssign"],[8,"RemAssign"],[8,"Not"],[8,"BitAnd"],[8,"BitOr"],[8,"BitXor"],[8,"Shl"],[8,"Shr"],[8,"BitAndAssign"],[8,"BitOrAssign"],[8,"BitXorAssign"],[8,"ShlAssign"],[8,"ShrAssign"],[8,"Deref"],[8,"DerefMut"],[8,"Drop"],[8,"Fn"],[8,"FnMut"],[8,"FnOnce"],[8,"Index"],[8,"IndexMut"],[8,"RangeBounds"],[8,"Try"],[8,"Generator"],[8,"Place"],[8,"Placer"],[8,"InPlace"],[8,"Boxed"],[8,"BoxPlace"],[3,"Reverse"],[4,"Ordering"],[8,"PartialEq"],[8,"Ord"],[8,"PartialOrd"],[8,"Clone"],[8,"Default"],[8,"AsRef"],[8,"AsMut"],[8,"Into"],[8,"From"],[8,"TryInto"],[8,"TryFrom"],[8,"Borrow"],[8,"BorrowMut"],[8,"Any"],[3,"TypeId"],[8,"FixedSizeArray"],[3,"TryFromSliceError"],[3,"EscapeDefault"],[4,"Ordering"],[3,"AtomicBool"],[3,"AtomicPtr"],[3,"AtomicI8"],[3,"AtomicU8"],[3,"AtomicI16"],[3,"AtomicU16"],[3,"AtomicI32"],[3,"AtomicU32"],[3,"AtomicI64"],[3,"AtomicU64"],[3,"AtomicIsize"],[3,"AtomicUsize"],[3,"Cell"],[3,"BorrowError"],[3,"BorrowMutError"],[3,"RefCell"],[3,"Ref"],[3,"RefMut"],[3,"UnsafeCell"],[3,"ParseCharError"],[3,"CharTryFromError"],[3,"EscapeUnicode"],[3,"EscapeDefault"],[3,"EscapeDebug"],[3,"DecodeUtf8"],[3,"InvalidSequence"],[3,"PanicInfo"],[3,"Location"],[3,"Repeat"],[3,"RepeatWith"],[3,"Empty"],[3,"Once"],[8,"Iterator"],[8,"Step"],[8,"FromIterator"],[8,"IntoIterator"],[8,"DoubleEndedIterator"],[8,"Extend"],[8,"ExactSizeIterator"],[8,"Sum"],[8,"Product"],[3,"Rev"],[3,"Cloned"],[3,"Cycle"],[3,"StepBy"],[3,"Chain"],[3,"Zip"],[3,"Map"],[3,"Filter"],[3,"FilterMap"],[3,"Enumerate"],[3,"Peekable"],[3,"SkipWhile"],[3,"TakeWhile"],[3,"Skip"],[3,"Take"],[3,"Scan"],[3,"FlatMap"],[3,"Flatten"],[3,"Fuse"],[3,"Inspect"],[4,"Option"],[3,"Iter"],[3,"IterMut"],[3,"IntoIter"],[3,"NoneError"],[3,"TraitObject"],[4,"Result"],[3,"Iter"],[3,"IterMut"],[3,"IntoIter"],[8,"SliceExt"],[8,"SliceIndex"],[3,"Iter"],[3,"IterMut"],[3,"Split"],[3,"SplitMut"],[3,"RSplit"],[3,"RSplitMut"],[3,"SplitN"],[3,"RSplitN"],[3,"SplitNMut"],[3,"RSplitNMut"],[3,"Windows"],[3,"Chunks"],[3,"ChunksMut"],[3,"ExactChunks"],[3,"ExactChunksMut"],[4,"SearchStep"],[8,"Pattern"],[8,"Searcher"],[8,"ReverseSearcher"],[3,"CharSearcher"],[3,"CharSliceSearcher"],[3,"CharPredicateSearcher"],[3,"StrSearcher"],[8,"FromStr"],[3,"ParseBoolError"],[3,"Utf8Error"],[3,"Chars"],[3,"CharIndices"],[3,"Bytes"],[3,"Split"],[3,"RSplit"],[3,"SplitTerminator"],[3,"RSplitTerminator"],[3,"SplitN"],[3,"RSplitN"],[3,"MatchIndices"],[3,"RMatchIndices"],[3,"Matches"],[3,"RMatches"],[3,"Lines"],[3,"LinesAny"],[3,"SipHasher"],[8,"Hash"],[8,"Hasher"],[8,"BuildHasher"],[3,"BuildHasherDefault"],[4,"Alignment"],[3,"DebugStruct"],[3,"DebugTuple"],[3,"DebugSet"],[3,"DebugList"],[3,"DebugMap"],[8,"Write"],[8,"Debug"],[8,"Display"],[8,"Octal"],[8,"Binary"],[8,"LowerHex"],[8,"UpperHex"],[8,"Pointer"],[8,"LowerExp"],[8,"UpperExp"],[3,"Error"],[3,"Arguments"],[3,"Formatter"],[3,"Duration"],[3,"Excess"],[4,"AllocErr"],[4,"CollectionAllocErr"],[8,"Alloc"],[3,"Layout"],[3,"CannotReallocInPlace"],[8,"FromBits"],[8,"IntoBits"],[3,"CpuidResult"],[3,"i8x2"],[3,"u8x2"],[3,"b8x2"],[3,"i16x2"],[3,"u16x2"],[3,"i8x4"],[3,"u8x4"],[3,"b8x4"],[3,"i8x8"],[3,"u8x8"],[3,"b8x8"],[3,"i16x4"],[3,"u16x4"],[3,"i32x2"],[3,"u32x2"],[3,"f32x2"],[3,"i8x16"],[3,"u8x16"],[3,"b8x16"],[3,"i16x8"],[3,"u16x8"],[3,"i32x4"],[3,"u32x4"],[3,"f32x4"],[3,"i64x2"],[3,"u64x2"],[3,"f64x2"],[3,"i8x32"],[3,"u8x32"],[3,"b8x32"],[3,"i16x16"],[3,"u16x16"],[3,"i32x8"],[3,"u32x8"],[3,"f32x8"],[3,"i64x4"],[3,"u64x4"],[3,"f64x4"],[3,"i8x64"],[3,"u8x64"],[3,"b8x64"],[3,"i16x32"],[3,"u16x32"],[3,"i32x16"],[3,"u32x16"],[3,"f32x16"],[3,"i64x8"],[3,"u64x8"],[3,"f64x8"],[3,"__m64"],[3,"__m128i"],[3,"__m128"],[3,"__m128d"],[3,"__m256i"],[3,"__m256"],[3,"__m256d"]]};
searchIndex["proc_macro"] = {"doc":"A support library for macro authors when defining new macros.","items":[[3,"Diagnostic","proc_macro","A structure representing a diagnostic message and associated children messages.",null,null],[3,"TokenStream","","The main type provided by this crate, representing an abstract stream of tokens.",null,null],[3,"LexError","","Error returned from `TokenStream::from_str`.",null,null],[3,"Span","","A region of source code, along with macro expansion information.",null,null],[3,"LineColumn","","A line-column pair representing the start or end of a `Span`.",null,null],[12,"line","","The 1-indexed line in the source file on which the span starts or ends (inclusive).",0,null],[12,"column","","The 0-indexed column (in UTF-8 characters) in the source file on which the span starts or ends (inclusive).",0,null],[3,"SourceFile","","The source file of a given `Span`.",null,null],[3,"TokenTree","","A single token or a delimited sequence of token trees (e.g. `[1, (), ..]`).",null,null],[12,"span","","The `TokenTree`'s span",1,null],[12,"kind","","Description of the `TokenTree`",1,null],[3,"Term","","An interned string.",null,null],[3,"Literal","","A literal character (`'a'`), string (`\"hello\"`), or number (`2.3`).",null,null],[3,"TokenTreeIter","","An iterator over `TokenTree`s.",null,null],[4,"Level","","An enum representing a diagnostic level.",null,null],[13,"Error","","An error.",2,null],[13,"Warning","","A warning.",2,null],[13,"Note","","A note.",2,null],[13,"Help","","A help message.",2,null],[4,"TokenNode","","Description of a `TokenTree`",null,null],[13,"Group","","A delimited tokenstream.",3,null],[13,"Term","","A unicode identifier.",3,null],[13,"Op","","A punctuation character (`+`, `,`, `$`, etc.).",3,null],[13,"Literal","","A literal character (`'a'`), string (`\"hello\"`), or number (`2.3`).",3,null],[4,"Delimiter","","Describes how a sequence of token trees is delimited.",null,null],[13,"Parenthesis","","`( ... )`",4,null],[13,"Brace","","`{ ... }`",4,null],[13,"Bracket","","`[ ... ]`",4,null],[13,"None","","An implicit delimiter, e.g. `$var`, where $var is  `...`.",4,null],[4,"Spacing","","Whether an `Op` is either followed immediately by another `Op` or followed by whitespace.",null,null],[13,"Alone","","e.g. `+` is `Alone` in `+ =`.",5,null],[13,"Joint","","e.g. `+` is `Joint` in `+=`.",5,null],[5,"quote_span","","Quote a `Span` into a `TokenStream`. This is needed to implement a custom quoter.",null,{"inputs":[{"name":"span"}],"output":{"name":"tokenstream"}}],[11,"clone","","",2,{"inputs":[{"name":"self"}],"output":{"name":"level"}}],[11,"fmt","","",2,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",6,{"inputs":[{"name":"self"}],"output":{"name":"diagnostic"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Create a new diagnostic with the given `level` and `message`.",6,{"inputs":[{"name":"level"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"spanned","","Create a new diagnostic with the given `level` and `message` pointing to the given `span`.",6,{"inputs":[{"name":"span"},{"name":"level"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"span_error","","Add a new child diagnostic message to `self` with the level identified by this methods name with the given `span` and `message`.",6,{"inputs":[{"name":"self"},{"name":"span"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"error","","Add a new child diagnostic message to `self` with the level identified by this method's name with the given `message`.",6,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"span_warning","","Add a new child diagnostic message to `self` with the level identified by this methods name with the given `span` and `message`.",6,{"inputs":[{"name":"self"},{"name":"span"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"warning","","Add a new child diagnostic message to `self` with the level identified by this method's name with the given `message`.",6,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"span_note","","Add a new child diagnostic message to `self` with the level identified by this methods name with the given `span` and `message`.",6,{"inputs":[{"name":"self"},{"name":"span"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"note","","Add a new child diagnostic message to `self` with the level identified by this method's name with the given `message`.",6,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"span_help","","Add a new child diagnostic message to `self` with the level identified by this methods name with the given `span` and `message`.",6,{"inputs":[{"name":"self"},{"name":"span"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"help","","Add a new child diagnostic message to `self` with the level identified by this method's name with the given `message`.",6,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"level","","Returns the diagnostic `level` for `self`.",6,{"inputs":[{"name":"self"}],"output":{"name":"level"}}],[11,"emit","","Emit the diagnostic.",6,{"inputs":[{"name":"self"}],"output":null}],[11,"clone","","",7,{"inputs":[{"name":"self"}],"output":{"name":"tokenstream"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from_str","","",7,{"inputs":[{"name":"str"}],"output":{"generics":["tokenstream","lexerror"],"name":"result"}}],[11,"fmt","","",7,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",7,{"inputs":[{"name":"tokentree"}],"output":{"name":"tokenstream"}}],[11,"from","","",7,{"inputs":[{"name":"tokennode"}],"output":{"name":"tokenstream"}}],[11,"from_iter","","",7,{"inputs":[{"name":"i"}],"output":{"name":"self"}}],[11,"into_iter","","",7,{"inputs":[{"name":"self"}],"output":{"name":"tokentreeiter"}}],[11,"empty","","Returns an empty `TokenStream`.",7,{"inputs":[],"output":{"name":"tokenstream"}}],[11,"is_empty","","Checks if this `TokenStream` is empty.",7,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",9,{"inputs":[{"name":"self"}],"output":{"name":"span"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",9,{"inputs":[{"name":"self"},{"name":"span"}],"output":{"name":"bool"}}],[11,"ne","","",9,{"inputs":[{"name":"self"},{"name":"span"}],"output":{"name":"bool"}}],[11,"def_site","","A span that resolves at the macro definition site.",9,{"inputs":[],"output":{"name":"span"}}],[11,"call_site","","The span of the invocation of the current procedural macro.",9,{"inputs":[],"output":{"name":"span"}}],[11,"source_file","","The original source file into which this span points.",9,{"inputs":[{"name":"self"}],"output":{"name":"sourcefile"}}],[11,"parent","","The `Span` for the tokens in the previous macro expansion from which `self` was generated from, if any.",9,{"inputs":[{"name":"self"}],"output":{"generics":["span"],"name":"option"}}],[11,"source","","The span for the origin source code that `self` was generated from. If this `Span` wasn't generated from other macro expansions then the return value is the same as `*self`.",9,{"inputs":[{"name":"self"}],"output":{"name":"span"}}],[11,"start","","Get the starting line/column in the source file for this span.",9,{"inputs":[{"name":"self"}],"output":{"name":"linecolumn"}}],[11,"end","","Get the ending line/column in the source file for this span.",9,{"inputs":[{"name":"self"}],"output":{"name":"linecolumn"}}],[11,"join","","Create a new span encompassing `self` and `other`.",9,{"inputs":[{"name":"self"},{"name":"span"}],"output":{"generics":["span"],"name":"option"}}],[11,"resolved_at","","Creates a new span with the same line/column information as `self` but that resolves symbols as though it were at `other`.",9,{"inputs":[{"name":"self"},{"name":"span"}],"output":{"name":"span"}}],[11,"located_at","","Creates a new span with the same name resolution behavior as `self` but with the line/column information of `other`.",9,{"inputs":[{"name":"self"},{"name":"span"}],"output":{"name":"span"}}],[11,"error","","Create a new `Diagnostic` with the given `message` at the span `self`.",9,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"warning","","Create a new `Diagnostic` with the given `message` at the span `self`.",9,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"note","","Create a new `Diagnostic` with the given `message` at the span `self`.",9,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"help","","Create a new `Diagnostic` with the given `message` at the span `self`.",9,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"diagnostic"}}],[11,"clone","","",0,{"inputs":[{"name":"self"}],"output":{"name":"linecolumn"}}],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",0,{"inputs":[{"name":"self"},{"name":"linecolumn"}],"output":{"name":"bool"}}],[11,"ne","","",0,{"inputs":[{"name":"self"},{"name":"linecolumn"}],"output":{"name":"bool"}}],[11,"clone","","",10,{"inputs":[{"name":"self"}],"output":{"name":"sourcefile"}}],[11,"path","","Get the path to this source file.",10,{"inputs":[{"name":"self"}],"output":{"name":"filename"}}],[11,"is_real","","Returns `true` if this source file is a real source file, and not generated by an external macro's expansion.",10,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"as_ref","","",10,{"inputs":[{"name":"self"}],"output":{"name":"filename"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",10,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","",10,{"inputs":[{"name":"self"},{"name":"filename"}],"output":{"name":"bool"}}],[11,"clone","","",1,{"inputs":[{"name":"self"}],"output":{"name":"tokentree"}}],[11,"fmt","","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",1,{"inputs":[{"name":"tokennode"}],"output":{"name":"tokentree"}}],[11,"fmt","","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",3,{"inputs":[{"name":"self"}],"output":{"name":"tokennode"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",4,{"inputs":[{"name":"self"}],"output":{"name":"delimiter"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",4,{"inputs":[{"name":"self"},{"name":"delimiter"}],"output":{"name":"bool"}}],[11,"clone","","",11,{"inputs":[{"name":"self"}],"output":{"name":"term"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"intern","","Intern a string into a `Term`.",11,{"inputs":[{"name":"str"}],"output":{"name":"term"}}],[11,"as_str","","Get a reference to the interned string.",11,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"clone","","",5,{"inputs":[{"name":"self"}],"output":{"name":"spacing"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",5,{"inputs":[{"name":"self"},{"name":"spacing"}],"output":{"name":"bool"}}],[11,"clone","","",12,{"inputs":[{"name":"self"}],"output":{"name":"literal"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"integer","","Integer literal",12,{"inputs":[{"name":"i128"}],"output":{"name":"literal"}}],[11,"u8","","Integer literal.",12,{"inputs":[{"name":"u8"}],"output":{"name":"literal"}}],[11,"i8","","Integer literal.",12,{"inputs":[{"name":"i8"}],"output":{"name":"literal"}}],[11,"u16","","Integer literal.",12,{"inputs":[{"name":"u16"}],"output":{"name":"literal"}}],[11,"i16","","Integer literal.",12,{"inputs":[{"name":"i16"}],"output":{"name":"literal"}}],[11,"u32","","Integer literal.",12,{"inputs":[{"name":"u32"}],"output":{"name":"literal"}}],[11,"i32","","Integer literal.",12,{"inputs":[{"name":"i32"}],"output":{"name":"literal"}}],[11,"u64","","Integer literal.",12,{"inputs":[{"name":"u64"}],"output":{"name":"literal"}}],[11,"i64","","Integer literal.",12,{"inputs":[{"name":"i64"}],"output":{"name":"literal"}}],[11,"usize","","Integer literal.",12,{"inputs":[{"name":"usize"}],"output":{"name":"literal"}}],[11,"isize","","Integer literal.",12,{"inputs":[{"name":"isize"}],"output":{"name":"literal"}}],[11,"float","","Floating point literal.",12,{"inputs":[{"name":"f64"}],"output":{"name":"literal"}}],[11,"f32","","Floating point literal.",12,{"inputs":[{"name":"f32"}],"output":{"name":"literal"}}],[11,"f64","","Floating point literal.",12,{"inputs":[{"name":"f64"}],"output":{"name":"literal"}}],[11,"string","","String literal.",12,{"inputs":[{"name":"str"}],"output":{"name":"literal"}}],[11,"character","","Character literal.",12,{"inputs":[{"name":"char"}],"output":{"name":"literal"}}],[11,"byte_string","","Byte string literal.",12,null],[11,"clone","","",13,{"inputs":[{"name":"self"}],"output":{"name":"tokentreeiter"}}],[11,"next","","",13,{"inputs":[{"name":"self"}],"output":{"generics":["tokentree"],"name":"option"}}],[14,"quote","","`quote!(..)` accepts arbitrary tokens and expands into a `TokenStream` describing the input. For example, `quote!(a + b)` will produce a expression, that, when evaluated, constructs the `TokenStream` `[Word(\"a\"), Op('+', Alone), Word(\"b\")]`.",null,null]],"paths":[[3,"LineColumn"],[3,"TokenTree"],[4,"Level"],[4,"TokenNode"],[4,"Delimiter"],[4,"Spacing"],[3,"Diagnostic"],[3,"TokenStream"],[3,"LexError"],[3,"Span"],[3,"SourceFile"],[3,"Term"],[3,"Literal"],[3,"TokenTreeIter"]]};
searchIndex["std"] = {"doc":"The Rust Standard Library","items":[[0,"any","std","This module implements the `Any` trait, which enables dynamic typing of any `'static` type through runtime reflection.",null,null],[8,"Any","std::any","A type to emulate dynamic typing.",null,null],[10,"get_type_id","","Gets the `TypeId` of `self`.",0,{"inputs":[{"name":"self"}],"output":{"name":"typeid"}}],[3,"TypeId","","A `TypeId` represents a globally unique identifier for a type.",null,null],[0,"cell","std","Shareable mutable containers.",null,null],[3,"Cell","std::cell","A mutable memory location.",null,null],[3,"RefCell","","A mutable memory location with dynamically checked borrow rules",null,null],[3,"BorrowError","","An error returned by `RefCell::try_borrow`.",null,null],[3,"BorrowMutError","","An error returned by `RefCell::try_borrow_mut`.",null,null],[3,"Ref","","Wraps a borrowed reference to a value in a `RefCell` box. A wrapper type for an immutably borrowed value from a `RefCell<T>`.",null,null],[3,"RefMut","","A wrapper type for a mutably borrowed value from a `RefCell<T>`.",null,null],[3,"UnsafeCell","","The core primitive for interior mutability in Rust.",null,null],[0,"clone","std","The `Clone` trait for types that cannot be 'implicitly copied'.",null,null],[8,"Clone","std::clone","A common trait for the ability to explicitly duplicate an object.",null,null],[10,"clone","","Returns a copy of the value.",1,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"clone_from","","Performs copy-assignment from `source`.",1,null],[0,"cmp","std","Functionality for ordering and comparison.",null,null],[8,"PartialEq","std::cmp","Trait for equality comparisons which are partial equivalence relations.",null,null],[10,"eq","","This method tests for `self` and `other` values to be equal, and is used by `==`.",2,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"ne","","This method tests for `!=`.",2,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[8,"Eq","","Trait for equality comparisons which are equivalence relations.",null,null],[4,"Ordering","","An `Ordering` is the result of a comparison between two values.",null,null],[13,"Less","","An ordering where a compared value is less [than another].",3,null],[13,"Equal","","An ordering where a compared value is equal [to another].",3,null],[13,"Greater","","An ordering where a compared value is greater [than another].",3,null],[3,"Reverse","","A helper struct for reverse ordering.",null,null],[12,"0","","",4,null],[8,"Ord","","Trait for types that form a total order.",null,null],[10,"cmp","","This method returns an `Ordering` between `self` and `other`.",5,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"ordering"}}],[11,"max","","Compares and returns the maximum of two values.",5,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[11,"min","","Compares and returns the minimum of two values.",5,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"self"}}],[8,"PartialOrd","","Trait for values that can be compared for a sort-order.",null,null],[10,"partial_cmp","","This method returns an ordering between `self` and `other` values if one exists.",6,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","This method tests less than (for `self` and `other`) and is used by the `<` operator.",6,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"le","","This method tests less than or equal to (for `self` and `other`) and is used by the `<=` operator.",6,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"gt","","This method tests greater than (for `self` and `other`) and is used by the `>` operator.",6,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[11,"ge","","This method tests greater than or equal to (for `self` and `other`) and is used by the `>=` operator.",6,{"inputs":[{"name":"self"},{"name":"rhs"}],"output":{"name":"bool"}}],[5,"min","","Compares and returns the minimum of two values.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"max","","Compares and returns the maximum of two values.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[0,"convert","std","Traits for conversions between types.",null,null],[8,"AsRef","std::convert","A cheap reference-to-reference conversion. Used to convert a value to a reference value within generic code.",null,null],[10,"as_ref","","Performs the conversion.",7,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[8,"AsMut","","A cheap, mutable reference-to-mutable reference conversion.",null,null],[10,"as_mut","","Performs the conversion.",8,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[8,"Into","","A conversion that consumes `self`, which may or may not be expensive. The reciprocal of [`From`][From].",null,null],[10,"into","","Performs the conversion.",9,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[8,"From","","Simple and safe type conversions in to `Self`. It is the reciprocal of `Into`.",null,null],[10,"from","","Performs the conversion.",10,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[8,"TryInto","","An attempted conversion that consumes `self`, which may or may not be expensive.",null,null],[16,"Error","","The type returned in the event of a conversion error.",11,null],[10,"try_into","","Performs the conversion.",11,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[8,"TryFrom","","Attempt to construct `Self` via a conversion.",null,null],[16,"Error","","The type returned in the event of a conversion error.",12,null],[10,"try_from","","Performs the conversion.",12,{"inputs":[{"name":"t"}],"output":{"name":"result"}}],[0,"default","std","The `Default` trait for types which may have meaningful default values.",null,null],[8,"Default","std::default","A trait for giving a type a useful default value.",null,null],[10,"default","","Returns the \"default value\" for a type.",13,{"inputs":[],"output":{"name":"self"}}],[0,"hash","std","Generic hashing support.",null,null],[8,"Hash","std::hash","A hashable type.",null,null],[10,"hash","","Feeds this value into the given [`Hasher`].",14,null],[11,"hash_slice","","Feeds a slice of this type into the given [`Hasher`].",14,null],[8,"Hasher","","A trait for hashing an arbitrary stream of bytes.",null,null],[10,"finish","","Returns the hash value for the values written so far.",15,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"write","","Writes some data into this `Hasher`.",15,null],[11,"write_u8","","Writes a single `u8` into this hasher.",15,null],[11,"write_u16","","Writes a single `u16` into this hasher.",15,null],[11,"write_u32","","Writes a single `u32` into this hasher.",15,null],[11,"write_u64","","Writes a single `u64` into this hasher.",15,null],[11,"write_u128","","Writes a single `u128` into this hasher.",15,null],[11,"write_usize","","Writes a single `usize` into this hasher.",15,null],[11,"write_i8","","Writes a single `i8` into this hasher.",15,null],[11,"write_i16","","Writes a single `i16` into this hasher.",15,null],[11,"write_i32","","Writes a single `i32` into this hasher.",15,null],[11,"write_i64","","Writes a single `i64` into this hasher.",15,null],[11,"write_i128","","Writes a single `i128` into this hasher.",15,null],[11,"write_isize","","Writes a single `isize` into this hasher.",15,null],[8,"BuildHasher","","A trait for creating instances of [`Hasher`].",null,null],[16,"Hasher","","Type of the hasher that will be created.",16,null],[10,"build_hasher","","Creates a new hasher.",16,null],[3,"BuildHasherDefault","","Used to create a default [`BuildHasher`] instance for types that implement [`Hasher`] and [`Default`].",null,null],[3,"SipHasher","","An implementation of SipHash 2-4.",null,null],[0,"intrinsics","std","rustc compiler intrinsics.",null,null],[5,"atomic_cxchg","std::intrinsics","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::SeqCst` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Acquire` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_rel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Release` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acqrel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_relaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Relaxed` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_failacq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acq_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::Acquire` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchg_acqrel_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange`][compare_exchange].",null,null],[5,"atomic_cxchgweak","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::SeqCst` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Acquire` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_rel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Release` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acqrel","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_relaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Relaxed` as both the `success` and `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_failacq","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::SeqCst` as the `success` and `Ordering::Acquire` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acq_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::Acquire` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_cxchgweak_acqrel_failrelaxed","","Stores a value if the current value is the same as the `old` value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `compare_exchange_weak` method by passing `Ordering::AcqRel` as the `success` and `Ordering::Relaxed` as the `failure` parameters. For example, [`AtomicBool::compare_exchange_weak`][cew].",null,null],[5,"atomic_load","","Loads the current value of the pointer. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `load` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::load`.",null,null],[5,"atomic_load_acq","","Loads the current value of the pointer. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `load` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::load`.",null,null],[5,"atomic_load_relaxed","","Loads the current value of the pointer. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `load` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::load`.",null,null],[5,"atomic_load_unordered","","",null,null],[5,"atomic_store","","Stores the value at the specified memory location. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `store` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::store`.",null,null],[5,"atomic_store_rel","","Stores the value at the specified memory location. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `store` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::store`.",null,null],[5,"atomic_store_relaxed","","Stores the value at the specified memory location. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `store` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::store`.",null,null],[5,"atomic_store_unordered","","",null,null],[5,"atomic_xchg","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_acq","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_rel","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_acqrel","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xchg_relaxed","","Stores the value at the specified memory location, returning the old value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `swap` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::swap`.",null,null],[5,"atomic_xadd","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_acq","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_rel","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::Release` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_acqrel","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xadd_relaxed","","Add to the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_add` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicIsize::fetch_add`.",null,null],[5,"atomic_xsub","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_acq","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_rel","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::Release` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_acqrel","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_xsub_relaxed","","Subtract from the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_sub` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicIsize::fetch_sub`.",null,null],[5,"atomic_and","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_acq","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_rel","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_acqrel","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_and_relaxed","","Bitwise and with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_and` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_and`.",null,null],[5,"atomic_nand","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_acq","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_rel","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_acqrel","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_nand_relaxed","","Bitwise nand with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic::AtomicBool` type via the `fetch_nand` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_nand`.",null,null],[5,"atomic_or","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_acq","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_rel","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_acqrel","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_or_relaxed","","Bitwise or with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_or` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_or`.",null,null],[5,"atomic_xor","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::SeqCst` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_acq","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::Acquire` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_rel","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::Release` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_acqrel","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::AcqRel` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_xor_relaxed","","Bitwise xor with the current value, returning the previous value. The stabilized version of this intrinsic is available on the `std::sync::atomic` types via the `fetch_xor` method by passing `Ordering::Relaxed` as the `order`. For example, `AtomicBool::fetch_xor`.",null,null],[5,"atomic_max","","",null,null],[5,"atomic_max_acq","","",null,null],[5,"atomic_max_rel","","",null,null],[5,"atomic_max_acqrel","","",null,null],[5,"atomic_max_relaxed","","",null,null],[5,"atomic_min","","",null,null],[5,"atomic_min_acq","","",null,null],[5,"atomic_min_rel","","",null,null],[5,"atomic_min_acqrel","","",null,null],[5,"atomic_min_relaxed","","",null,null],[5,"atomic_umin","","",null,null],[5,"atomic_umin_acq","","",null,null],[5,"atomic_umin_rel","","",null,null],[5,"atomic_umin_acqrel","","",null,null],[5,"atomic_umin_relaxed","","",null,null],[5,"atomic_umax","","",null,null],[5,"atomic_umax_acq","","",null,null],[5,"atomic_umax_rel","","",null,null],[5,"atomic_umax_acqrel","","",null,null],[5,"atomic_umax_relaxed","","",null,null],[5,"prefetch_read_data","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"prefetch_write_data","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"prefetch_read_instruction","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"prefetch_write_instruction","","The `prefetch` intrinsic is a hint to the code generator to insert a prefetch instruction if supported; otherwise, it is a noop. Prefetches have no effect on the behavior of the program but can change its performance characteristics.",null,null],[5,"atomic_fence","","",null,null],[5,"atomic_fence_acq","","",null,null],[5,"atomic_fence_rel","","",null,null],[5,"atomic_fence_acqrel","","",null,null],[5,"atomic_singlethreadfence","","A compiler-only memory barrier.",null,null],[5,"atomic_singlethreadfence_acq","","",null,null],[5,"atomic_singlethreadfence_rel","","",null,null],[5,"atomic_singlethreadfence_acqrel","","",null,null],[5,"rustc_peek","","Magic intrinsic that derives its meaning from attributes attached to the function.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"abort","","Aborts the execution of the process.",null,null],[5,"unreachable","","Tells LLVM that this point in the code is not reachable, enabling further optimizations.",null,null],[5,"assume","","Informs the optimizer that a condition is always true. If the condition is false, the behavior is undefined.",null,null],[5,"likely","","Hints to the compiler that branch condition is likely to be true. Returns the value passed to it.",null,{"inputs":[{"name":"bool"}],"output":{"name":"bool"}}],[5,"unlikely","","Hints to the compiler that branch condition is likely to be false. Returns the value passed to it.",null,{"inputs":[{"name":"bool"}],"output":{"name":"bool"}}],[5,"breakpoint","","Executes a breakpoint trap, for inspection by a debugger.",null,null],[5,"size_of","","The size of a type in bytes.",null,{"inputs":[],"output":{"name":"usize"}}],[5,"move_val_init","","Moves a value to an uninitialized memory location.",null,null],[5,"min_align_of","","",null,{"inputs":[],"output":{"name":"usize"}}],[5,"pref_align_of","","",null,{"inputs":[],"output":{"name":"usize"}}],[5,"size_of_val","","The size of the referenced value in bytes.",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"min_align_of_val","","",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"type_name","","Gets a static string slice containing the name of a type.",null,{"inputs":[],"output":{"name":"str"}}],[5,"type_id","","Gets an identifier which is globally unique to the specified type. This function will return the same value for a type regardless of whichever crate it is invoked in.",null,{"inputs":[],"output":{"name":"u64"}}],[5,"init","","Creates a value initialized to zero.",null,{"inputs":[],"output":{"name":"t"}}],[5,"uninit","","Creates an uninitialized value.",null,{"inputs":[],"output":{"name":"t"}}],[5,"transmute","","Reinterprets the bits of a value of one type as another type.",null,{"inputs":[{"name":"t"}],"output":{"name":"u"}}],[5,"needs_drop","","Returns `true` if the actual type given as `T` requires drop glue; returns `false` if the actual type provided for `T` implements `Copy`.",null,{"inputs":[],"output":{"name":"bool"}}],[5,"offset","","Calculates the offset from a pointer.",null,null],[5,"arith_offset","","Calculates the offset from a pointer, potentially wrapping.",null,null],[5,"copy_nonoverlapping","","Copies `count * size_of<T>` bytes from `src` to `dst`. The source and destination may not overlap.",null,null],[5,"copy","","Copies `count * size_of<T>` bytes from `src` to `dst`. The source and destination may overlap.",null,null],[5,"write_bytes","","Invokes memset on the specified pointer, setting `count * size_of::<T>()` bytes of memory starting at `dst` to `val`.",null,null],[5,"volatile_copy_nonoverlapping_memory","","Equivalent to the appropriate `llvm.memcpy.p0i8.0i8.*` intrinsic, with a size of `count` * `size_of::<T>()` and an alignment of `min_align_of::<T>()`",null,null],[5,"volatile_copy_memory","","Equivalent to the appropriate `llvm.memmove.p0i8.0i8.*` intrinsic, with a size of `count` * `size_of::<T>()` and an alignment of `min_align_of::<T>()`",null,null],[5,"volatile_set_memory","","Equivalent to the appropriate `llvm.memset.p0i8.*` intrinsic, with a size of `count` * `size_of::<T>()` and an alignment of `min_align_of::<T>()`.",null,null],[5,"volatile_load","","Perform a volatile load from the `src` pointer. The stabilized version of this intrinsic is `std::ptr::read_volatile`.",null,null],[5,"volatile_store","","Perform a volatile store to the `dst` pointer. The stabilized version of this intrinsic is `std::ptr::write_volatile`.",null,null],[5,"sqrtf32","","Returns the square root of an `f32`",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"sqrtf64","","Returns the square root of an `f64`",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"powif32","","Raises an `f32` to an integer power.",null,{"inputs":[{"name":"f32"},{"name":"i32"}],"output":{"name":"f32"}}],[5,"powif64","","Raises an `f64` to an integer power.",null,{"inputs":[{"name":"f64"},{"name":"i32"}],"output":{"name":"f64"}}],[5,"sinf32","","Returns the sine of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"sinf64","","Returns the sine of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"cosf32","","Returns the cosine of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"cosf64","","Returns the cosine of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"powf32","","Raises an `f32` to an `f32` power.",null,{"inputs":[{"name":"f32"},{"name":"f32"}],"output":{"name":"f32"}}],[5,"powf64","","Raises an `f64` to an `f64` power.",null,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"f64"}}],[5,"expf32","","Returns the exponential of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"expf64","","Returns the exponential of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"exp2f32","","Returns 2 raised to the power of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"exp2f64","","Returns 2 raised to the power of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"logf32","","Returns the natural logarithm of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"logf64","","Returns the natural logarithm of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"log10f32","","Returns the base 10 logarithm of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"log10f64","","Returns the base 10 logarithm of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"log2f32","","Returns the base 2 logarithm of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"log2f64","","Returns the base 2 logarithm of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"fmaf32","","Returns `a * b + c` for `f32` values.",null,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"f32"}}],[5,"fmaf64","","Returns `a * b + c` for `f64` values.",null,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"f64"}}],[5,"fabsf32","","Returns the absolute value of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"fabsf64","","Returns the absolute value of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"copysignf32","","Copies the sign from `y` to `x` for `f32` values.",null,{"inputs":[{"name":"f32"},{"name":"f32"}],"output":{"name":"f32"}}],[5,"copysignf64","","Copies the sign from `y` to `x` for `f64` values.",null,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"f64"}}],[5,"floorf32","","Returns the largest integer less than or equal to an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"floorf64","","Returns the largest integer less than or equal to an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"ceilf32","","Returns the smallest integer greater than or equal to an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"ceilf64","","Returns the smallest integer greater than or equal to an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"truncf32","","Returns the integer part of an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"truncf64","","Returns the integer part of an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"rintf32","","Returns the nearest integer to an `f32`. May raise an inexact floating-point exception if the argument is not an integer.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"rintf64","","Returns the nearest integer to an `f64`. May raise an inexact floating-point exception if the argument is not an integer.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"nearbyintf32","","Returns the nearest integer to an `f32`.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"nearbyintf64","","Returns the nearest integer to an `f64`.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"roundf32","","Returns the nearest integer to an `f32`. Rounds half-way cases away from zero.",null,{"inputs":[{"name":"f32"}],"output":{"name":"f32"}}],[5,"roundf64","","Returns the nearest integer to an `f64`. Rounds half-way cases away from zero.",null,{"inputs":[{"name":"f64"}],"output":{"name":"f64"}}],[5,"fadd_fast","","Float addition that allows optimizations based on algebraic rules. May assume inputs are finite.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"fsub_fast","","Float subtraction that allows optimizations based on algebraic rules. May assume inputs are finite.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"fmul_fast","","Float multiplication that allows optimizations based on algebraic rules. May assume inputs are finite.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"fdiv_fast","","Float division that allows optimizations based on algebraic rules. May assume inputs are finite.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"frem_fast","","Float remainder that allows optimizations based on algebraic rules. May assume inputs are finite.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"ctpop","","Returns the number of bits set in an integer type `T`",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"ctlz","","Returns the number of leading unset bits (zeroes) in an integer type `T`.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"ctlz_nonzero","","Like `ctlz`, but extra-unsafe as it returns `undef` when given an `x` with value `0`.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"cttz","","Returns the number of trailing unset bits (zeroes) in an integer type `T`.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"cttz_nonzero","","Like `cttz`, but extra-unsafe as it returns `undef` when given an `x` with value `0`.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"bswap","","Reverses the bytes in an integer type `T`.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"bitreverse","","Reverses the bits in an integer type `T`.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"add_with_overflow","","Performs checked integer addition. The stabilized versions of this intrinsic are available on the integer primitives via the `overflowing_add` method. For example, `std::u32::overflowing_add`",null,null],[5,"sub_with_overflow","","Performs checked integer subtraction The stabilized versions of this intrinsic are available on the integer primitives via the `overflowing_sub` method. For example, `std::u32::overflowing_sub`",null,null],[5,"mul_with_overflow","","Performs checked integer multiplication The stabilized versions of this intrinsic are available on the integer primitives via the `overflowing_mul` method. For example, `std::u32::overflowing_mul`",null,null],[5,"exact_div","","Performs an exact division, resulting in undefined behavior where `x % y != 0` or `y == 0` or `x == T::min_value() && y == -1`",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"unchecked_div","","Performs an unchecked division, resulting in undefined behavior where y = 0 or x = `T::min_value()` and y = -1",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"unchecked_rem","","Returns the remainder of an unchecked division, resulting in undefined behavior where y = 0 or x = `T::min_value()` and y = -1",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"unchecked_shl","","Performs an unchecked left shift, resulting in undefined behavior when y < 0 or y >= N, where N is the width of T in bits.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"unchecked_shr","","Performs an unchecked right shift, resulting in undefined behavior when y < 0 or y >= N, where N is the width of T in bits.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"overflowing_add","","Returns (a + b) mod 2N, where N is the width of T in bits. The stabilized versions of this intrinsic are available on the integer primitives via the `wrapping_add` method. For example, `std::u32::wrapping_add`",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"overflowing_sub","","Returns (a - b) mod 2N, where N is the width of T in bits. The stabilized versions of this intrinsic are available on the integer primitives via the `wrapping_sub` method. For example, `std::u32::wrapping_sub`",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"overflowing_mul","","Returns (a * b) mod 2N, where N is the width of T in bits. The stabilized versions of this intrinsic are available on the integer primitives via the `wrapping_mul` method. For example, `std::u32::wrapping_mul`",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"discriminant_value","","Returns the value of the discriminant for the variant in 'v', cast to a `u64`; if `T` has no discriminant, returns 0.",null,{"inputs":[{"name":"t"}],"output":{"name":"u64"}}],[5,"try","","Rust's \"try catch\" construct which invokes the function pointer `f` with the data pointer `data`.",null,null],[5,"align_offset","","Computes the byte offset that needs to be applied to `ptr` in order to make it aligned to `align`. If it is not possible to align `ptr`, the implementation returns `usize::max_value()`.",null,null],[5,"nontemporal_store","","Emits a `!nontemporal` store according to LLVM (see their docs). Probably will never become stable.",null,null],[5,"drop_in_place","","Executes the destructor (if any) of the pointed-to value.",null,null],[0,"iter","std","Composable external iteration.",null,null],[3,"Rev","std::iter","A double-ended iterator with the direction inverted.",null,null],[3,"Cloned","","An iterator that clones the elements of an underlying iterator.",null,null],[3,"Cycle","","An iterator that repeats endlessly.",null,null],[3,"StepBy","","An iterator for stepping iterators by a custom amount.",null,null],[3,"Chain","","An iterator that strings two iterators together.",null,null],[3,"Zip","","An iterator that iterates two other iterators simultaneously.",null,null],[3,"Map","","An iterator that maps the values of `iter` with `f`.",null,null],[3,"Filter","","An iterator that filters the elements of `iter` with `predicate`.",null,null],[3,"FilterMap","","An iterator that uses `f` to both filter and map elements from `iter`.",null,null],[3,"Enumerate","","An iterator that yields the current count and the element during iteration.",null,null],[3,"Peekable","","An iterator with a `peek()` that returns an optional reference to the next element.",null,null],[3,"SkipWhile","","An iterator that rejects elements while `predicate` is true.",null,null],[3,"TakeWhile","","An iterator that only accepts elements while `predicate` is true.",null,null],[3,"Skip","","An iterator that skips over `n` elements of `iter`.",null,null],[3,"Take","","An iterator that only iterates over the first `n` iterations of `iter`.",null,null],[3,"Scan","","An iterator to maintain state while iterating another iterator.",null,null],[3,"FlatMap","","An iterator that maps each element to an iterator, and yields the elements of the produced iterators.",null,null],[3,"Flatten","","An iterator that flattens one level of nesting in an iterator of things that can be turned into iterators.",null,null],[3,"Fuse","","An iterator that yields `None` forever after the underlying iterator yields `None` once.",null,null],[3,"Inspect","","An iterator that calls a function with a reference to each element before yielding it.",null,null],[8,"FusedIterator","","An iterator that always continues to yield `None` when exhausted.",null,null],[3,"Empty","","An iterator that yields nothing.",null,null],[3,"RepeatWith","","An iterator that repeats elements of type `A` endlessly by applying the provided closure `F: FnMut() -> A`.",null,null],[3,"Once","","An iterator that yields an element exactly once.",null,null],[5,"repeat_with","","Creates a new iterator that repeats elements of type `A` endlessly by applying the provided closure, the repeater, `F: FnMut() -> A`.",null,{"inputs":[{"name":"f"}],"output":{"name":"repeatwith"}}],[5,"repeat","","Creates a new iterator that endlessly repeats a single element.",null,{"inputs":[{"name":"t"}],"output":{"name":"repeat"}}],[8,"TrustedLen","","An iterator that reports an accurate length using size_hint.",null,null],[8,"IntoIterator","","Conversion into an `Iterator`.",null,null],[16,"Item","","The type of the elements being iterated over.",17,null],[16,"IntoIter","","Which kind of iterator are we turning this into?",17,null],[10,"into_iter","","Creates an iterator from a value.",17,null],[8,"Iterator","","An interface for dealing with iterators.",null,null],[16,"Item","","The type of the elements being iterated over.",18,null],[10,"next","","Advances the iterator and returns the next value.",18,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","Returns the bounds on the remaining length of the iterator.",18,null],[11,"count","","Consumes the iterator, counting the number of iterations and returning it.",18,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","Consumes the iterator, returning the last element.",18,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","Returns the `n`th element of the iterator.",18,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"step_by","","Creates an iterator starting at the same point, but stepping by the given amount at each iteration.",18,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"stepby"}}],[11,"chain","","Takes two iterators and creates a new iterator over both in sequence.",18,{"inputs":[{"name":"self"},{"name":"u"}],"output":{"name":"chain"}}],[11,"zip","","'Zips up' two iterators into a single iterator of pairs.",18,{"inputs":[{"name":"self"},{"name":"u"}],"output":{"name":"zip"}}],[11,"map","","Takes a closure and creates an iterator which calls that closure on each element.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"map"}}],[11,"for_each","","Calls a closure on each element of an iterator.",18,null],[11,"filter","","Creates an iterator which uses a closure to determine if an element should be yielded.",18,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"filter"}}],[11,"filter_map","","Creates an iterator that both filters and maps.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"filtermap"}}],[11,"enumerate","","Creates an iterator which gives the current iteration count as well as the next value.",18,{"inputs":[{"name":"self"}],"output":{"name":"enumerate"}}],[11,"peekable","","Creates an iterator which can use `peek` to look at the next element of the iterator without consuming it.",18,{"inputs":[{"name":"self"}],"output":{"name":"peekable"}}],[11,"skip_while","","Creates an iterator that [`skip`]s elements based on a predicate.",18,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"skipwhile"}}],[11,"take_while","","Creates an iterator that yields elements based on a predicate.",18,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"takewhile"}}],[11,"skip","","Creates an iterator that skips the first `n` elements.",18,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"skip"}}],[11,"take","","Creates an iterator that yields its first `n` elements.",18,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"take"}}],[11,"scan","","An iterator adaptor similar to [`fold`] that holds internal state and produces a new iterator.",18,{"inputs":[{"name":"self"},{"name":"st"},{"name":"f"}],"output":{"name":"scan"}}],[11,"flat_map","","Creates an iterator that works like map, but flattens nested structure.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"flatmap"}}],[11,"flatten","","Creates an iterator that flattens nested structure.",18,{"inputs":[{"name":"self"}],"output":{"name":"flatten"}}],[11,"fuse","","Creates an iterator which ends after the first [`None`].",18,{"inputs":[{"name":"self"}],"output":{"name":"fuse"}}],[11,"inspect","","Do something with each element of an iterator, passing the value on.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"inspect"}}],[11,"by_ref","","Borrows an iterator, rather than consuming it.",18,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"collect","","Transforms an iterator into a collection.",18,{"inputs":[{"name":"self"}],"output":{"name":"b"}}],[11,"partition","","Consumes an iterator, creating two collections from it.",18,null],[11,"try_fold","","An iterator method that applies a function as long as it returns successfully, producing a single, final value.",18,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"try_for_each","","An iterator method that applies a fallible function to each item in the iterator, stopping at the first error and returning that error.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","An iterator method that applies a function, producing a single, final value.",18,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"b"}}],[11,"all","","Tests if every element of the iterator matches a predicate.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"any","","Tests if any element of the iterator matches a predicate.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"find","","Searches for an element of an iterator that satisfies a predicate.",18,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"position","","Searches for an element in an iterator, returning its index.",18,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","Searches for an element in an iterator from the right, returning its index.",18,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"max","","Returns the maximum element of an iterator.",18,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"min","","Returns the minimum element of an iterator.",18,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"max_by_key","","Returns the element that gives the maximum value from the specified function.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"max_by","","Returns the element that gives the maximum value with respect to the specified comparison function.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"min_by_key","","Returns the element that gives the minimum value from the specified function.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"min_by","","Returns the element that gives the minimum value with respect to the specified comparison function.",18,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"rev","","Reverses an iterator's direction.",18,{"inputs":[{"name":"self"}],"output":{"name":"rev"}}],[11,"unzip","","Converts an iterator of pairs into a pair of containers.",18,null],[11,"cloned","","Creates an iterator which [`clone`]s all of its elements.",18,{"inputs":[{"name":"self"}],"output":{"name":"cloned"}}],[11,"cycle","","Repeats an iterator endlessly.",18,{"inputs":[{"name":"self"}],"output":{"name":"cycle"}}],[11,"sum","","Sums the elements of an iterator.",18,{"inputs":[{"name":"self"}],"output":{"name":"s"}}],[11,"product","","Iterates over the entire iterator, multiplying all the elements",18,{"inputs":[{"name":"self"}],"output":{"name":"p"}}],[11,"cmp","","Lexicographically compares the elements of this `Iterator` with those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"ordering"}}],[11,"partial_cmp","","Lexicographically compares the elements of this `Iterator` with those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","Determines if the elements of this `Iterator` are equal to those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"ne","","Determines if the elements of this `Iterator` are unequal to those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"lt","","Determines if the elements of this `Iterator` are lexicographically less than those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"le","","Determines if the elements of this `Iterator` are lexicographically less or equal to those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"gt","","Determines if the elements of this `Iterator` are lexicographically greater than those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[11,"ge","","Determines if the elements of this `Iterator` are lexicographically greater than or equal to those of another.",18,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"bool"}}],[8,"Product","","Trait to represent types that can be created by multiplying elements of an iterator.",null,null],[10,"product","","Method which takes an iterator and generates `Self` from the elements by multiplying the items.",19,{"inputs":[{"name":"i"}],"output":{"name":"self"}}],[8,"Sum","","Trait to represent types that can be created by summing up an iterator.",null,null],[10,"sum","","Method which takes an iterator and generates `Self` from the elements by \"summing up\" the items.",20,{"inputs":[{"name":"i"}],"output":{"name":"self"}}],[8,"Extend","","Extend a collection with the contents of an iterator.",null,null],[10,"extend","","Extends a collection with the contents of an iterator.",21,null],[8,"DoubleEndedIterator","","An iterator able to yield elements from both ends.",null,null],[10,"next_back","","Removes and returns an element from the end of the iterator.",22,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","This is the reverse version of [`try_fold()`]: it takes elements starting from the back of the iterator.",22,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","An iterator method that reduces the iterator's elements to a single, final value, starting from the back.",22,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"b"}}],[11,"rfind","","Searches for an element of an iterator from the right that satisfies a predicate.",22,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[5,"empty","","Creates an iterator that yields nothing.",null,{"inputs":[],"output":{"name":"empty"}}],[8,"ExactSizeIterator","","An iterator that knows its exact length.",null,null],[11,"len","","Returns the exact number of times the iterator will iterate.",23,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns whether the iterator is empty.",23,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[8,"Step","","Objects that can be stepped over in both directions.",null,null],[10,"steps_between","","Returns the number of steps between two step objects. The count is inclusive of `start` and exclusive of `end`.",24,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[10,"replace_one","","Replaces this step with `1`, returning itself",24,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"replace_zero","","Replaces this step with `0`, returning itself",24,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"add_one","","Adds one to this step, returning the result",24,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"sub_one","","Subtracts one to this step, returning the result",24,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[10,"add_usize","","Add an usize, returning None on overflow",24,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[3,"Repeat","","An iterator that repeats an element endlessly.",null,null],[8,"FromIterator","","Conversion from an `Iterator`.",null,null],[10,"from_iter","","Creates a value from an iterator.",25,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[5,"once","","Creates an iterator that yields an element exactly once.",null,{"inputs":[{"name":"t"}],"output":{"name":"once"}}],[0,"marker","std","Primitive traits and types representing basic properties of types.",null,null],[8,"Send","std::marker","Types that can be transferred across thread boundaries.",null,null],[8,"Sized","","Types with a constant size known at compile time.",null,null],[8,"Unsize","","Types that can be \"unsized\" to a dynamically-sized type.",null,null],[8,"Copy","","Types whose values can be duplicated simply by copying bits.",null,null],[8,"Sync","","Types for which it is safe to share references between threads.",null,null],[3,"PhantomData","","Zero-sized type used to mark things that \"act like\" they own a `T`.",null,null],[8,"Unpin","","Types which can be moved out of a `Pin`.",null,null],[0,"mem","std","Basic functions for dealing with memory.",null,null],[5,"forget","std::mem","Leaks a value: takes ownership and \"forgets\" about the value without running its destructor.",null,null],[5,"size_of","","Returns the size of a type in bytes.",null,{"inputs":[],"output":{"name":"usize"}}],[5,"size_of_val","","Returns the size of the pointed-to value in bytes.",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"min_align_of","","Returns the [ABI]-required minimum alignment of a type.",null,{"inputs":[],"output":{"name":"usize"}}],[5,"min_align_of_val","","Returns the [ABI]-required minimum alignment of the type of the value that `val` points to.",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"align_of","","Returns the [ABI]-required minimum alignment of a type.",null,{"inputs":[],"output":{"name":"usize"}}],[5,"align_of_val","","Returns the [ABI]-required minimum alignment of the type of the value that `val` points to.",null,{"inputs":[{"name":"t"}],"output":{"name":"usize"}}],[5,"needs_drop","","Returns whether dropping values of type `T` matters.",null,{"inputs":[],"output":{"name":"bool"}}],[5,"zeroed","","Creates a value whose bytes are all zero.",null,{"inputs":[],"output":{"name":"t"}}],[5,"uninitialized","","Bypasses Rust's normal memory-initialization checks by pretending to produce a value of type `T`, while doing nothing at all.",null,{"inputs":[],"output":{"name":"t"}}],[5,"swap","","Swaps the values at two mutable locations, without deinitializing either one.",null,null],[5,"replace","","Replaces the value at a mutable location with a new one, returning the old value, without deinitializing either one.",null,{"inputs":[{"name":"t"},{"name":"t"}],"output":{"name":"t"}}],[5,"drop","","Disposes of a value.",null,null],[5,"transmute_copy","","Interprets `src` as having type `&U`, and then reads `src` without moving the contained value.",null,{"inputs":[{"name":"t"}],"output":{"name":"u"}}],[3,"Discriminant","","Opaque type representing the discriminant of an enum.",null,null],[5,"discriminant","","Returns a value uniquely identifying the enum variant in `v`.",null,{"inputs":[{"name":"t"}],"output":{"name":"discriminant"}}],[19,"ManuallyDrop","","A wrapper to inhibit compiler from automatically calling `T`’s destructor.",null,null],[5,"unreachable","","Tells LLVM that this point in the code is not reachable, enabling further optimizations.",null,null],[3,"Pin","","A pinned reference.",null,null],[5,"transmute","","Reinterprets the bits of a value of one type as another type.",null,{"inputs":[{"name":"t"}],"output":{"name":"u"}}],[0,"ops","std","Overloadable operators.",null,null],[8,"SubAssign","std::ops","The subtraction assignment operator `-=`.",null,null],[10,"sub_assign","","Performs the `-=` operation.",26,null],[8,"Fn","","The version of the call operator that takes an immutable receiver.",null,null],[10,"call","","Performs the call operation.",27,null],[8,"FnOnce","","The version of the call operator that takes a by-value receiver.",null,null],[16,"Output","","The returned type after the call operator is used.",28,null],[10,"call_once","","Performs the call operation.",28,null],[8,"ShrAssign","","The right shift assignment operator `>>=`.",null,null],[10,"shr_assign","","Performs the `>>=` operation.",29,null],[8,"Mul","","The multiplication operator `*`.",null,null],[16,"Output","","The resulting type after applying the `*` operator.",30,null],[10,"mul","","Performs the `*` operation.",30,null],[3,"RangeTo","","A range only bounded exclusively above (`..end`).",null,null],[12,"end","","The upper bound of the range (exclusive).",31,null],[8,"Sub","","The subtraction operator `-`.",null,null],[16,"Output","","The resulting type after applying the `-` operator.",32,null],[10,"sub","","Performs the `-` operation.",32,null],[8,"MulAssign","","The multiplication assignment operator `*=`.",null,null],[10,"mul_assign","","Performs the `*=` operation.",33,null],[3,"RangeInclusive","","An range bounded inclusively below and above (`start..=end`).",null,null],[12,"start","","The lower bound of the range (inclusive).",34,null],[12,"end","","The upper bound of the range (inclusive).",34,null],[3,"RangeToInclusive","","A range only bounded inclusively above (`..=end`).",null,null],[12,"end","","The upper bound of the range (inclusive)",35,null],[8,"RangeBounds","","`RangeBounds` is implemented by Rust's built-in range types, produced by range syntax like `..`, `a..`, `..b` or `c..d`.",null,null],[10,"start","","Start index bound.",36,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[10,"end","","End index bound.",36,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[4,"GeneratorState","","The result of a generator resumption.",null,null],[13,"Yielded","","The generator suspended with a value.",37,null],[13,"Complete","","The generator completed with a return value.",37,null],[8,"Place","","Both `PLACE <- EXPR` and `box EXPR` desugar into expressions that allocate an intermediate \"place\" that holds uninitialized state.  The desugaring evaluates EXPR, and writes the result at the address returned by the `pointer` method of this trait.",null,null],[10,"pointer","","Returns the address where the input value will be written. Note that the data at this address is generally uninitialized, and thus one should use `ptr::write` for initializing it.",38,null],[8,"Rem","","The remainder operator `%`.",null,null],[16,"Output","","The resulting type after applying the `%` operator.",39,null],[10,"rem","","Performs the `%` operation.",39,null],[8,"ShlAssign","","The left shift assignment operator `<<=`.",null,null],[10,"shl_assign","","Performs the `<<=` operation.",40,null],[8,"BitOr","","The bitwise OR operator `|`.",null,null],[16,"Output","","The resulting type after applying the `|` operator.",41,null],[10,"bitor","","Performs the `|` operation.",41,null],[8,"InPlace","","Specialization of `Place` trait supporting `PLACE <- EXPR`.",null,null],[16,"Owner","","`Owner` is the type of the end value of `PLACE <- EXPR`",42,null],[10,"finalize","","Converts self into the final value, shifting deallocation/cleanup responsibilities (if any remain), over to the returned instance of `Owner` and forgetting self.",42,null],[8,"DerefMut","","Used for mutable dereferencing operations, like in `*v = 1;`.",null,null],[10,"deref_mut","","Mutably dereferences the value.",43,null],[8,"Shr","","The right shift operator `>>`.",null,null],[16,"Output","","The resulting type after applying the `>>` operator.",44,null],[10,"shr","","Performs the `>>` operation.",44,null],[8,"BitOrAssign","","The bitwise OR assignment operator `|=`.",null,null],[10,"bitor_assign","","Performs the `|=` operation.",45,null],[8,"BitAnd","","The bitwise AND operator `&`.",null,null],[16,"Output","","The resulting type after applying the `&` operator.",46,null],[10,"bitand","","Performs the `&` operation.",46,null],[8,"Drop","","Used to run some code when a value goes out of scope. This is sometimes called a 'destructor'.",null,null],[10,"drop","","Executes the destructor for this type.",47,null],[3,"Range","","A (half-open) range bounded inclusively below and exclusively above (`start..end`).",null,null],[12,"start","","The lower bound of the range (inclusive).",48,null],[12,"end","","The upper bound of the range (exclusive).",48,null],[3,"RangeFrom","","A range only bounded inclusively below (`start..`).",null,null],[12,"start","","The lower bound of the range (inclusive).",49,null],[3,"RangeFull","","An unbounded range (`..`).",null,null],[8,"AddAssign","","The addition assignment operator `+=`.",null,null],[10,"add_assign","","Performs the `+=` operation.",50,null],[8,"Index","","Used for indexing operations (`container[index]`) in immutable contexts.",null,null],[16,"Output","","The returned type after indexing.",51,null],[10,"index","","Performs the indexing (`container[index]`) operation.",51,null],[8,"IndexMut","","Used for indexing operations (`container[index]`) in mutable contexts.",null,null],[10,"index_mut","","Performs the mutable indexing (`container[index]`) operation.",52,null],[4,"Bound","","An endpoint of a range of keys.",null,null],[13,"Included","","An inclusive bound.",53,null],[13,"Excluded","","An exclusive bound.",53,null],[13,"Unbounded","","An infinite endpoint. Indicates that there is no bound in this direction.",53,null],[8,"Add","","The addition operator `+`.",null,null],[16,"Output","","The resulting type after applying the `+` operator.",54,null],[10,"add","","Performs the `+` operation.",54,null],[8,"DivAssign","","The division assignment operator `/=`.",null,null],[10,"div_assign","","Performs the `/=` operation.",55,null],[8,"Try","","A trait for customizing the behavior of the `?` operator.",null,null],[16,"Ok","","The type of this value when viewed as successful.",56,null],[16,"Error","","The type of this value when viewed as failed.",56,null],[10,"into_result","","Applies the \"?\" operator. A return of `Ok(t)` means that the execution should continue normally, and the result of `?` is the value `t`. A return of `Err(e)` means that execution should branch to the innermost enclosing `catch`, or return from the function.",56,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[10,"from_error","","Wrap an error value to construct the composite result. For example, `Result::Err(x)` and `Result::from_error(x)` are equivalent.",56,null],[10,"from_ok","","Wrap an OK value to construct the composite result. For example, `Result::Ok(x)` and `Result::from_ok(x)` are equivalent.",56,null],[8,"Deref","","Used for immutable dereferencing operations, like `*v`.",null,null],[16,"Target","","The resulting type after dereferencing.",57,null],[10,"deref","","Dereferences the value.",57,null],[8,"FnMut","","The version of the call operator that takes a mutable receiver.",null,null],[10,"call_mut","","Performs the call operation.",58,null],[8,"Div","","The division operator `/`.",null,null],[16,"Output","","The resulting type after applying the `/` operator.",59,null],[10,"div","","Performs the `/` operation.",59,null],[8,"Shl","","The left shift operator `<<`.",null,null],[16,"Output","","The resulting type after applying the `<<` operator.",60,null],[10,"shl","","Performs the `<<` operation.",60,null],[8,"Not","","The unary logical negation operator `!`.",null,null],[16,"Output","","The resulting type after applying the `!` operator.",61,null],[10,"not","","Performs the unary `!` operation.",61,null],[8,"Generator","","The trait implemented by builtin generator types.",null,null],[16,"Yield","","The type of value this generator yields.",62,null],[16,"Return","","The type of value this generator returns.",62,null],[10,"resume","","Resumes the execution of this generator.",62,{"inputs":[{"name":"self"}],"output":{"name":"generatorstate"}}],[8,"CoerceUnsized","","Trait that indicates that this is a pointer or a wrapper for one, where unsizing can be performed on the pointee.",null,null],[8,"BoxPlace","","Specialization of `Place` trait supporting `box EXPR`.",null,null],[10,"make_place","","Creates a globally fresh place.",63,{"inputs":[],"output":{"name":"self"}}],[8,"BitXor","","The bitwise XOR operator `^`.",null,null],[16,"Output","","The resulting type after applying the `^` operator.",64,null],[10,"bitxor","","Performs the `^` operation.",64,null],[8,"BitXorAssign","","The bitwise XOR assignment operator `^=`.",null,null],[10,"bitxor_assign","","Performs the `^=` operation.",65,null],[8,"Placer","","Interface to implementations of  `PLACE <- EXPR`.",null,null],[16,"Place","","`Place` is the intermediate agent guarding the uninitialized state for `Data`.",66,null],[10,"make_place","","Creates a fresh place from `self`.",66,null],[8,"RemAssign","","The remainder assignment operator `%=`.",null,null],[10,"rem_assign","","Performs the `%=` operation.",67,null],[8,"Boxed","","Core trait for the `box EXPR` form.",null,null],[16,"Data","","The kind of data that is stored in this kind of box.",68,null],[16,"Place","","The place that will negotiate the storage of the data.",68,null],[10,"finalize","","Converts filled place into final owning value, shifting deallocation/cleanup responsibilities (if any remain), over to returned instance of `Self` and forgetting `filled`.",68,null],[8,"Neg","","The unary negation operator `-`.",null,null],[16,"Output","","The resulting type after applying the `-` operator.",69,null],[10,"neg","","Performs the unary `-` operation.",69,null],[8,"BitAndAssign","","The bitwise AND assignment operator `&=`.",null,null],[10,"bitand_assign","","Performs the `&=` operation.",70,null],[0,"ptr","std","Raw, unsafe pointers, `*const T`, and `*mut T`.",null,null],[5,"drop_in_place","std::ptr","Executes the destructor (if any) of the pointed-to value.",null,null],[5,"null","","Creates a null raw pointer.",null,null],[5,"null_mut","","Creates a null mutable raw pointer.",null,null],[5,"swap","","Swaps the values at two mutable locations of the same type, without deinitializing either.",null,null],[5,"swap_nonoverlapping","","Swaps a sequence of values at two mutable locations of the same type.",null,null],[5,"replace","","Replaces the value at `dest` with `src`, returning the old value, without dropping either.",null,null],[5,"read","","Reads the value from `src` without moving it. This leaves the memory in `src` unchanged.",null,null],[5,"read_unaligned","","Reads the value from `src` without moving it. This leaves the memory in `src` unchanged.",null,null],[5,"write","","Overwrites a memory location with the given value without reading or dropping the old value.",null,null],[5,"write_unaligned","","Overwrites a memory location with the given value without reading or dropping the old value.",null,null],[5,"read_volatile","","Performs a volatile read of the value from `src` without moving it. This leaves the memory in `src` unchanged.",null,null],[5,"write_volatile","","Performs a volatile write of a memory location with the given value without reading or dropping the old value.",null,null],[5,"eq","","Compare raw pointers for equality.",null,null],[3,"Unique","","A wrapper around a raw non-null `*mut T` that indicates that the possessor of this wrapper owns the referent. Useful for building abstractions like `Box<T>`, `Vec<T>`, `String`, and `HashMap<K, V>`.",null,null],[3,"NonNull","","`*mut T` but non-zero and covariant.",null,null],[5,"copy_nonoverlapping","","Copies `count * size_of<T>` bytes from `src` to `dst`. The source and destination may not overlap.",null,null],[5,"copy","","Copies `count * size_of<T>` bytes from `src` to `dst`. The source and destination may overlap.",null,null],[5,"write_bytes","","Invokes memset on the specified pointer, setting `count * size_of::<T>()` bytes of memory starting at `dst` to `val`.",null,null],[0,"raw","std","Contains struct definitions for the layout of compiler built-in types.",null,null],[3,"TraitObject","std::raw","The representation of a trait object like `&SomeTrait`.",null,null],[12,"data","","",71,null],[12,"vtable","","",71,null],[0,"result","std","Error handling with the `Result` type.",null,null],[4,"Result","std::result","`Result` is a type that represents either success ([`Ok`]) or failure ([`Err`]).",null,null],[13,"Ok","","Contains the success value",72,null],[13,"Err","","Contains the error value",72,null],[3,"Iter","","An iterator over a reference to the [`Ok`] variant of a [`Result`].",null,null],[3,"IterMut","","An iterator over a mutable reference to the [`Ok`] variant of a [`Result`].",null,null],[3,"IntoIter","","An iterator over the value in a [`Ok`] variant of a [`Result`].",null,null],[0,"option","std","Optional values.",null,null],[4,"Option","std::option","The `Option` type. See the module level documentation for more.",null,null],[13,"None","","No value",73,null],[13,"Some","","Some value `T`",73,null],[3,"Iter","","An iterator over a reference to the [`Some`] variant of an [`Option`].",null,null],[3,"IterMut","","An iterator over a mutable reference to the [`Some`] variant of an [`Option`].",null,null],[3,"IntoIter","","An iterator over the value in [`Some`] variant of an [`Option`].",null,null],[3,"NoneError","","The error type that results from applying the try operator (`?`) to a `None` value. If you wish to allow `x?` (where `x` is an `Option<T>`) to be converted into your error type, you can implement `impl From<NoneError>` for `YourErrorType`. In that case, `x?` within a function that returns `Result<_, YourErrorType>` will translate a `None` value into an `Err` result.",null,null],[0,"isize","std","The pointer-sized signed integer type.",null,null],[17,"MIN","std::isize","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i8","std","The 8-bit signed integer type.",null,null],[17,"MIN","std::i8","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i16","std","The 16-bit signed integer type.",null,null],[17,"MIN","std::i16","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i32","std","The 32-bit signed integer type.",null,null],[17,"MIN","std::i32","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i64","std","The 64-bit signed integer type.",null,null],[17,"MIN","std::i64","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"i128","std","The 128-bit signed integer type.",null,null],[17,"MIN","std::i128","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"usize","std","The pointer-sized unsigned integer type.",null,null],[17,"MIN","std::usize","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u8","std","The 8-bit unsigned integer type.",null,null],[17,"MIN","std::u8","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u16","std","The 16-bit unsigned integer type.",null,null],[17,"MIN","std::u16","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u32","std","The 32-bit unsigned integer type.",null,null],[17,"MIN","std::u32","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"u64","std","The 64-bit unsigned integer type.",null,null],[17,"MIN","std::u64","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"boxed","std","A pointer type for heap allocation.",null,null],[17,"HEAP","std::boxed","A value that represents the heap. This is the default place that the `box` keyword allocates into when no place is supplied.",null,null],[3,"ExchangeHeapSingleton","","This the singleton type used solely for `boxed::HEAP`.",null,null],[3,"Box","","A pointer type for heap allocation.",null,null],[3,"IntermediateBox","","`IntermediateBox` represents uninitialized backing storage for `Box`.",null,null],[8,"FnBox","","`FnBox` is a version of the `FnOnce` intended for use with boxed closure objects. The idea is that where one would normally store a `Box<FnOnce()>` in a data structure, you should use `Box<FnBox()>`. The two traits behave essentially the same, except that a `FnBox` closure can only be called if it is boxed. (Note that `FnBox` may be deprecated in the future if `Box<FnOnce()>` closures become directly usable.)",null,null],[16,"Output","","",74,null],[10,"call_box","","",74,null],[3,"PinBox","","A pinned, heap allocated reference.",null,null],[0,"rc","std","Single-threaded reference-counting pointers. 'Rc' stands for 'Reference Counted'.",null,null],[3,"Rc","std::rc","A single-threaded reference-counting pointer. 'Rc' stands for 'Reference Counted'.",null,null],[3,"Weak","","`Weak` is a version of [`Rc`] that holds a non-owning reference to the managed value. The value is accessed by calling [`upgrade`] on the `Weak` pointer, which returns an [`Option`]`<`[`Rc`]`<T>>`.",null,null],[0,"borrow","std","A module for working with borrowed data.",null,null],[8,"ToOwned","std::borrow","A generalization of `Clone` to borrowed data.",null,null],[16,"Owned","","",75,null],[10,"to_owned","","Creates owned data from borrowed data, usually by cloning.",75,null],[11,"clone_into","","Uses borrowed data to replace owned data, usually by cloning.",75,null],[4,"Cow","","A clone-on-write smart pointer.",null,null],[13,"Borrowed","","Borrowed data.",76,null],[13,"Owned","","Owned data.",76,null],[8,"Borrow","","A trait for borrowing data.",null,null],[10,"borrow","","Immutably borrows from an owned value.",77,{"inputs":[{"name":"self"}],"output":{"name":"borrowed"}}],[8,"BorrowMut","","A trait for mutably borrowing data.",null,null],[10,"borrow_mut","","Mutably borrows from an owned value.",78,{"inputs":[{"name":"self"}],"output":{"name":"borrowed"}}],[0,"fmt","std","Utilities for formatting and printing `String`s.",null,null],[5,"format","std::fmt","The `format` function takes an [`Arguments`] struct and returns the resulting formatted string.",null,{"inputs":[{"name":"arguments"}],"output":{"name":"string"}}],[3,"DebugSet","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugStruct","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"Arguments","","This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.",null,null],[8,"UpperExp","","`E` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",79,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[3,"Error","","The error type which is returned from formatting a message into a stream.",null,null],[3,"DebugMap","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugTuple","","A struct to help with `fmt::Debug` implementations.",null,null],[3,"DebugList","","A struct to help with `fmt::Debug` implementations.",null,null],[8,"Debug","","`?` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",80,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Pointer","","`p` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",81,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[6,"Result","","The type returned by formatter methods.",null,null],[5,"write","","The `write` function takes an output stream, and an `Arguments` struct that can be precompiled with the `format_args!` macro.",null,{"inputs":[{"name":"write"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[8,"Display","","Format trait for an empty format, `{}`.",null,null],[10,"fmt","","Formats the value using the given formatter.",82,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Binary","","`b` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",83,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Octal","","`o` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",84,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[3,"Formatter","","A struct to represent both where to emit formatting strings to and how they should be formatted. A mutable version of this is passed to all formatting traits.",null,null],[8,"LowerHex","","`x` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",85,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"UpperHex","","`X` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",86,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[8,"Write","","A collection of methods that are required to format a message into a stream.",null,null],[10,"write_str","","Writes a slice of bytes into this writer, returning whether the write succeeded.",87,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_char","","Writes a [`char`] into this writer, returning whether the write succeeded.",87,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_fmt","","Glue for usage of the [`write!`] macro with implementors of this trait.",87,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[8,"LowerExp","","`e` formatting.",null,null],[10,"fmt","","Formats the value using the given formatter.",88,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[0,"slice","std","A dynamically-sized view into a contiguous sequence, `[T]`.",null,null],[8,"SliceConcatExt","std::slice","An extension trait for concatenating slices",null,null],[16,"Output","","The resulting type after concatenation",89,null],[10,"concat","","Flattens a slice of `T` into a single value `Self::Output`.",89,null],[10,"join","","Flattens a slice of `T` into a single value `Self::Output`, placing a given separator between each.",89,null],[10,"connect","","",89,null],[3,"RSplit","","An iterator over subslices separated by elements that match a predicate function, starting from the end of the slice.",null,null],[3,"Windows","","An iterator over overlapping subslices of length `size`.",null,null],[3,"RSplitNMut","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.",null,null],[3,"Iter","","Immutable slice iterator",null,null],[3,"RSplitMut","","An iterator over the subslices of the vector which are separated by elements that match `pred`, starting from the end of the slice.",null,null],[3,"RSplitN","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits, starting from the end of the slice.",null,null],[3,"ExactChunks","","An iterator over a slice in (non-overlapping) chunks (`chunk_size` elements at a time).",null,null],[5,"from_raw_parts_mut","","Performs the same functionality as `from_raw_parts`, except that a mutable slice is returned.",null,null],[3,"SplitNMut","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits.",null,null],[5,"from_raw_parts","","Forms a slice from a pointer and a length.",null,null],[3,"SplitN","","An iterator over subslices separated by elements that match a predicate function, limited to a given number of splits.",null,null],[8,"SliceIndex","","A helper trait used for indexing operations.",null,null],[16,"Output","","The output type returned by methods.",90,null],[10,"get","","Returns a shared reference to the output at this location, if in bounds.",90,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[10,"get_mut","","Returns a mutable reference to the output at this location, if in bounds.",90,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[10,"get_unchecked","","Returns a shared reference to the output at this location, without performing any bounds checking.",90,null],[10,"get_unchecked_mut","","Returns a mutable reference to the output at this location, without performing any bounds checking.",90,null],[10,"index","","Returns a shared reference to the output at this location, panicking if out of bounds.",90,null],[10,"index_mut","","Returns a mutable reference to the output at this location, panicking if out of bounds.",90,null],[5,"from_ref","","Converts a reference to T into a slice of length 1 (without copying).",null,null],[3,"Chunks","","An iterator over a slice in (non-overlapping) chunks (`chunk_size` elements at a time).",null,null],[3,"Split","","An iterator over subslices separated by elements that match a predicate function.",null,null],[3,"SplitMut","","An iterator over the subslices of the vector which are separated by elements that match `pred`.",null,null],[3,"ChunksMut","","An iterator over a slice in (non-overlapping) mutable chunks (`chunk_size` elements at a time). When the slice len is not evenly divided by the chunk size, the last slice of the iteration will be the remainder.",null,null],[5,"from_ref_mut","","Converts a reference to T into a slice of length 1 (without copying).",null,null],[3,"ExactChunksMut","","An iterator over a slice in (non-overlapping) mutable chunks (`chunk_size` elements at a time). When the slice len is not evenly divided by the chunk size, the last up to `chunk_size-1` elements will be omitted.",null,null],[3,"IterMut","","Mutable slice iterator.",null,null],[0,"str","std","Unicode string slices.",null,null],[3,"EncodeUtf16","std::str","An iterator of [`u16`] over the string encoded as UTF-16.",null,null],[5,"from_boxed_utf8_unchecked","","Converts a boxed slice of bytes to a boxed string slice without checking that the string contains valid UTF-8.",null,{"inputs":[{"name":"box"}],"output":{"generics":["str"],"name":"box"}}],[3,"CharIndices","","An iterator over the [`char`]s of a string slice, and their positions.",null,null],[3,"RSplit","","Created with the method [`rsplit`].",null,null],[3,"MatchIndices","","Created with the method [`match_indices`].",null,null],[3,"RMatchIndices","","Created with the method [`rmatch_indices`].",null,null],[3,"RSplitN","","Created with the method [`rsplitn`].",null,null],[0,"pattern","","The string Pattern API.",null,null],[8,"Pattern","std::str::pattern","A string pattern.",null,null],[16,"Searcher","","Associated searcher for this pattern",91,null],[10,"into_searcher","","Constructs the associated searcher from `self` and the `haystack` to search in.",91,null],[11,"is_contained_in","","Checks whether the pattern matches anywhere in the haystack",91,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_prefix_of","","Checks whether the pattern matches at the front of the haystack",91,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_suffix_of","","Checks whether the pattern matches at the back of the haystack",91,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[4,"SearchStep","","Result of calling `Searcher::next()` or `ReverseSearcher::next_back()`.",null,null],[13,"Match","","Expresses that a match of the pattern has been found at `haystack[a..b]`.",92,null],[13,"Reject","","Expresses that `haystack[a..b]` has been rejected as a possible match of the pattern.",92,null],[13,"Done","","Expresses that every byte of the haystack has been visited, ending the iteration.",92,null],[8,"Searcher","","A searcher for a string pattern.",null,null],[10,"haystack","","Getter for the underlying string to be searched in",93,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[10,"next","","Performs the next search step starting from the front.",93,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","Find the next `Match` result. See `next()`",93,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","Find the next `Reject` result. See `next()` and `next_match()`",93,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[8,"ReverseSearcher","","A reverse searcher for a string pattern.",null,null],[10,"next_back","","Performs the next search step starting from the back.",94,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","Find the next `Match` result. See `next_back()`",94,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","Find the next `Reject` result. See `next_back()`",94,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[8,"DoubleEndedSearcher","","A marker trait to express that a `ReverseSearcher` can be used for a `DoubleEndedIterator` implementation.",null,null],[3,"CharSearcher","","Associated type for `<char as Pattern<'a>>::Searcher`.",null,null],[3,"CharSliceSearcher","","Associated type for `<&[char] as Pattern<'a>>::Searcher`.",null,null],[3,"CharPredicateSearcher","","Associated type for `<F as Pattern<'a>>::Searcher`.",null,null],[3,"StrSearcher","","Associated type for `<&str as Pattern<'a>>::Searcher`.",null,null],[5,"from_utf8","std::str","Converts a slice of bytes to a string slice.",null,null],[3,"Utf8Error","","Errors which can occur when attempting to interpret a sequence of [`u8`] as a string.",null,null],[3,"RMatches","","Created with the method [`rmatches`].",null,null],[5,"from_utf8_unchecked","","Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8.",null,null],[5,"from_utf8_unchecked_mut","","Converts a slice of bytes to a string slice without checking that the string contains valid UTF-8; mutable version.",null,null],[3,"LinesAny","","Created with the method [`lines_any`].",null,null],[3,"RSplitTerminator","","Created with the method [`rsplit_terminator`].",null,null],[3,"Bytes","","An iterator over the bytes of a string slice.",null,null],[3,"ParseBoolError","","An error returned when parsing a `bool` using [`from_str`] fails",null,null],[3,"SplitWhitespace","","An iterator over the non-whitespace substrings of a string, separated by any amount of whitespace.",null,null],[3,"SplitN","","Created with the method [`splitn`].",null,null],[5,"from_utf8_mut","","Converts a mutable slice of bytes to a mutable string slice.",null,null],[3,"Split","","Created with the method [`split`].",null,null],[8,"FromStr","","A trait to abstract the idea of creating a new instance of a type from a string.",null,null],[16,"Err","","The associated error which can be returned from parsing.",95,null],[10,"from_str","","Parses a string `s` to return a value of this type.",95,{"inputs":[{"name":"str"}],"output":{"name":"result"}}],[3,"Lines","","An iterator over the lines of a string, as string slices.",null,null],[3,"SplitTerminator","","Created with the method [`split_terminator`].",null,null],[3,"Matches","","Created with the method [`matches`].",null,null],[3,"Chars","","An iterator over the [`char`]s of a string slice.",null,null],[0,"string","std","A UTF-8 encoded, growable string.",null,null],[3,"String","std::string","A UTF-8 encoded, growable string.",null,null],[3,"FromUtf8Error","","A possible error value when converting a `String` from a UTF-8 byte vector.",null,null],[3,"FromUtf16Error","","A possible error value when converting a `String` from a UTF-16 byte slice.",null,null],[4,"ParseError","","An error when parsing a `String`.",null,null],[8,"ToString","","A trait for converting a value to a `String`.",null,null],[10,"to_string","","Converts the given value to a `String`.",96,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[3,"Drain","","A draining iterator for `String`.",null,null],[0,"vec","std","A contiguous growable array type with heap-allocated contents, written `Vec<T>`.",null,null],[3,"Vec","std::vec","A contiguous growable array type, written `Vec<T>` but pronounced 'vector'.",null,null],[3,"IntoIter","","An iterator that moves out of a vector.",null,null],[3,"Drain","","A draining iterator for `Vec<T>`.",null,null],[3,"PlaceBack","","A place for insertion at the back of a `Vec`.",null,null],[3,"Splice","","A splicing iterator for `Vec`.",null,null],[3,"DrainFilter","","An iterator produced by calling `drain_filter` on Vec.",null,null],[0,"char","std","A character type.",null,null],[3,"ToLowercase","std::char","Returns an iterator that yields the lowercase equivalent of a `char`.",null,null],[3,"ToUppercase","","Returns an iterator that yields the uppercase equivalent of a `char`.",null,null],[3,"DecodeUtf16","","An iterator that decodes UTF-16 encoded code points from an iterator of `u16`s.",null,null],[3,"DecodeUtf16Error","","An error that can be returned when decoding UTF-16 code points.",null,null],[5,"decode_utf16","","Create an iterator over the UTF-16 encoded code points in `iter`, returning unpaired surrogates as `Err`s.",null,{"inputs":[{"name":"i"}],"output":{"name":"decodeutf16"}}],[17,"REPLACEMENT_CHARACTER","","`U+FFFD REPLACEMENT CHARACTER` (�) is used in Unicode to represent a decoding error.",null,null],[3,"EscapeDebug","","An iterator that yields the literal escape code of a `char`.",null,null],[3,"EscapeDefault","","An iterator that yields the literal escape code of a `char`.",null,null],[3,"ParseCharError","","An error which can be returned when parsing a char.",null,null],[3,"EscapeUnicode","","Returns an iterator that yields the hexadecimal Unicode escape of a character, as `char`s.",null,null],[3,"CharTryFromError","","The error type returned when a conversion from u32 to char fails.",null,null],[5,"decode_utf8","","Decodes an `Iterator` of bytes as UTF-8.",null,{"inputs":[{"name":"i"}],"output":{"name":"decodeutf8"}}],[3,"DecodeUtf8","","An iterator over an iterator of bytes of the characters the bytes represent as UTF-8",null,null],[17,"UNICODE_VERSION","","The version of Unicode that the Unicode parts of `CharExt` and `UnicodeStrPrelude` traits are based on.",null,null],[3,"UnicodeVersion","","Represents a Unicode Version.",null,null],[12,"major","","Major version.",97,null],[12,"minor","","Minor version.",97,null],[12,"micro","","Micro (or Update) version.",97,null],[5,"from_digit","","Converts a digit in the given radix to a `char`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"generics":["char"],"name":"option"}}],[5,"from_u32","","Converts a `u32` to a `char`.",null,{"inputs":[{"name":"u32"}],"output":{"generics":["char"],"name":"option"}}],[5,"from_u32_unchecked","","Converts a `u32` to a `char`, ignoring validity.",null,{"inputs":[{"name":"u32"}],"output":{"name":"char"}}],[17,"MAX","","The highest valid code point a `char` can have.",null,null],[0,"u128","std","The 128-bit unsigned integer type.",null,null],[17,"MIN","std::u128","The smallest value that can be represented by this integer type.",null,null],[17,"MAX","","The largest value that can be represented by this integer type.",null,null],[0,"simd","std","Platform independent SIMD vector types and operations.",null,null],[3,"f32x4","std::simd","A 128-bit vector with 4 `f32` lanes.",null,null],[3,"f64x8","","A 512-bit vector with 8 `f64` lanes.",null,null],[3,"u32x8","","A 256-bit vector with 8 `u32` lanes.",null,null],[3,"u8x8","","A 64-bit vector with 8 `u8` lanes.",null,null],[3,"i32x4","","A 128-bit vector with 4 `i32` lanes.",null,null],[3,"f32x16","","A 512-bit vector with 16 `f32` lanes.",null,null],[3,"u8x16","","A 128-bit vector with 16 `u8` lanes.",null,null],[3,"i16x16","","A 256-bit vector with 16 `i16` lanes.",null,null],[3,"i8x8","","A 64-bit vector with 8 `i8` lanes.",null,null],[3,"i8x32","","A 256-bit vector with 32 `i8` lanes.",null,null],[3,"i32x16","","A 512-bit vector with 16 `i32` lanes.",null,null],[3,"u16x2","","A 32-bit wide vector with 2 `u16` lanes.",null,null],[3,"u16x8","","A 128-bit vector with 8 `u16` lanes.",null,null],[3,"u32x16","","A 512-bit vector with 16 `u32` lanes.",null,null],[3,"i32x8","","A 256-bit vector with 8 `i32` lanes.",null,null],[3,"i16x32","","A 512-bit vector with 32 `i16` lanes.",null,null],[3,"u16x32","","A 512-bit vector with 32 `u16` lanes.",null,null],[3,"i8x4","","A 32-bit wide vector with 4 `i8` lanes.",null,null],[3,"i8x16","","A 128-bit vector with 16 `i8` lanes.",null,null],[8,"IntoBits","","Safe lossless bitwise conversion from `Self` to `T`.",null,null],[10,"into_bits","","Safe lossless bitwise transmute from `self` to `T`.",98,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[3,"b8x4","","A 32-bit wide vector with 4 `bool` lanes.",null,null],[3,"f64x2","","A 128-bit vector with 2 `f64` lanes.",null,null],[3,"u8x64","","A 512-bit vector with 64 `u8` lanes.",null,null],[8,"FromBits","","Safe lossless bitwise conversion from `T` to `Self`.",null,null],[10,"from_bits","","Safe lossless bitwise from `T` to `Self`.",99,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[3,"b8x64","","A 512-bit vector with 64 `bool` lanes.",null,null],[3,"u16x4","","A 64-bit vector with 4 `u16` lanes.",null,null],[3,"i64x2","","A 128-bit vector with 2 `u64` lanes.",null,null],[3,"u16x16","","A 256-bit vector with 16 `u16` lanes.",null,null],[3,"f32x8","","A 256-bit vector with 8 `f32` lanes.",null,null],[3,"i16x4","","A 64-bit vector with 4 `i16` lanes.",null,null],[3,"u64x8","","A 512-bit vector with 8 `u64` lanes.",null,null],[3,"i64x4","","A 256-bit vector with 4 `i64` lanes.",null,null],[3,"u32x4","","A 128-bit vector with 4 `u32` lanes.",null,null],[3,"u64x4","","A 256-bit vector with 4 `u64` lanes.",null,null],[3,"u8x2","","A 16-bit wide vector with 2 `u8` lanes.",null,null],[3,"b8x32","","A 256-bit vector with 32 `bool` lanes.",null,null],[3,"i8x2","","A 16-bit wide vector with 2 `i8` lanes.",null,null],[3,"i16x2","","A 32-bit wide vector with 2 `i16` lanes.",null,null],[3,"u32x2","","A 64-bit vector with 2 `u32` lanes.",null,null],[3,"i16x8","","A 128-bit vector with 8 `i16` lanes.",null,null],[3,"u8x32","","A 256-bit vector with 32 `u8` lanes.",null,null],[3,"i8x64","","A 512-bit vector with 64 `i8` lanes.",null,null],[3,"i64x8","","A 512-bit vector with 8 `i64` lanes.",null,null],[3,"b8x2","","A 16-bit wide vector with 2 `bool` lanes.",null,null],[3,"f32x2","","A 64-bit vector with 2 `f32` lanes.",null,null],[3,"f64x4","","A 256-bit vector with 4 `f64` lanes.",null,null],[3,"u8x4","","A 32-bit wide vector with 4 `u8` lanes.",null,null],[3,"b8x16","","A 128-bit vector with 16 `bool` lanes.",null,null],[3,"i32x2","","A 64-bit vector with 2 `i32` lanes.",null,null],[3,"b8x8","","A 64-bit vector with 8 `bool` lanes.",null,null],[3,"u64x2","","A 128-bit vector with 2 `u64` lanes.",null,null],[0,"prelude","std","The Rust Prelude.",null,null],[0,"v1","std::prelude","The first version of the prelude of The Rust Standard Library.",null,null],[0,"f32","std","This module provides constants which are specific to the implementation of the `f32` floating point data type.",null,null],[17,"RADIX","std::f32","The radix or base of the internal representation of `f32`.",null,null],[17,"MANTISSA_DIGITS","","Number of significant digits in base 2.",null,null],[17,"DIGITS","","Approximate number of significant digits in base 10.",null,null],[17,"EPSILON","","Difference between `1.0` and the next largest representable number.",null,null],[17,"MIN_EXP","","One greater than the minimum possible normal power of 2 exponent.",null,null],[17,"MAX_EXP","","Maximum possible power of 2 exponent.",null,null],[17,"MIN_10_EXP","","Minimum possible normal power of 10 exponent.",null,null],[17,"MAX_10_EXP","","Maximum possible power of 10 exponent.",null,null],[17,"NAN","","Not a Number (NaN).",null,null],[17,"INFINITY","","Infinity (∞).",null,null],[17,"NEG_INFINITY","","Negative infinity (-∞).",null,null],[17,"MIN","","Smallest finite `f32` value.",null,null],[17,"MIN_POSITIVE","","Smallest positive normal `f32` value.",null,null],[17,"MAX","","Largest finite `f32` value.",null,null],[0,"consts","","Basic mathematical constants.",null,null],[17,"PI","std::f32::consts","Archimedes' constant (π)",null,null],[17,"FRAC_PI_2","","π/2",null,null],[17,"FRAC_PI_3","","π/3",null,null],[17,"FRAC_PI_4","","π/4",null,null],[17,"FRAC_PI_6","","π/6",null,null],[17,"FRAC_PI_8","","π/8",null,null],[17,"FRAC_1_PI","","1/π",null,null],[17,"FRAC_2_PI","","2/π",null,null],[17,"FRAC_2_SQRT_PI","","2/sqrt(π)",null,null],[17,"SQRT_2","","sqrt(2)",null,null],[17,"FRAC_1_SQRT_2","","1/sqrt(2)",null,null],[17,"E","","Euler's number (e)",null,null],[17,"LOG2_E","","log2(e)",null,null],[17,"LOG10_E","","log10(e)",null,null],[17,"LN_2","","ln(2)",null,null],[17,"LN_10","","ln(10)",null,null],[0,"f64","std","This module provides constants which are specific to the implementation of the `f64` floating point data type.",null,null],[17,"RADIX","std::f64","The radix or base of the internal representation of `f64`.",null,null],[17,"MANTISSA_DIGITS","","Number of significant digits in base 2.",null,null],[17,"DIGITS","","Approximate number of significant digits in base 10.",null,null],[17,"EPSILON","","Difference between `1.0` and the next largest representable number.",null,null],[17,"MIN_EXP","","One greater than the minimum possible normal power of 2 exponent.",null,null],[17,"MAX_EXP","","Maximum possible power of 2 exponent.",null,null],[17,"MIN_10_EXP","","Minimum possible normal power of 10 exponent.",null,null],[17,"MAX_10_EXP","","Maximum possible power of 10 exponent.",null,null],[17,"NAN","","Not a Number (NaN).",null,null],[17,"INFINITY","","Infinity (∞).",null,null],[17,"NEG_INFINITY","","Negative infinity (-∞).",null,null],[17,"MIN","","Smallest finite `f64` value.",null,null],[17,"MIN_POSITIVE","","Smallest positive normal `f64` value.",null,null],[17,"MAX","","Largest finite `f64` value.",null,null],[0,"consts","","Basic mathematical constants.",null,null],[17,"PI","std::f64::consts","Archimedes' constant (π)",null,null],[17,"FRAC_PI_2","","π/2",null,null],[17,"FRAC_PI_3","","π/3",null,null],[17,"FRAC_PI_4","","π/4",null,null],[17,"FRAC_PI_6","","π/6",null,null],[17,"FRAC_PI_8","","π/8",null,null],[17,"FRAC_1_PI","","1/π",null,null],[17,"FRAC_2_PI","","2/π",null,null],[17,"FRAC_2_SQRT_PI","","2/sqrt(π)",null,null],[17,"SQRT_2","","sqrt(2)",null,null],[17,"FRAC_1_SQRT_2","","1/sqrt(2)",null,null],[17,"E","","Euler's number (e)",null,null],[17,"LOG2_E","","log2(e)",null,null],[17,"LOG10_E","","log10(e)",null,null],[17,"LN_2","","ln(2)",null,null],[17,"LN_10","","ln(10)",null,null],[0,"thread","std","Native threads.",null,null],[3,"LocalKey","std::thread","A thread local storage key which owns its contents.",null,null],[3,"AccessError","","An error returned by `LocalKey::try_with`.",null,null],[3,"Builder","","Thread factory, which can be used in order to configure the properties of a new thread.",null,null],[3,"ThreadId","","A unique identifier for a running thread.",null,null],[3,"Thread","","A handle to a thread.",null,null],[3,"JoinHandle","","An owned permission to join on a thread (block on its termination).",null,null],[5,"spawn","","Spawns a new thread, returning a [`JoinHandle`] for it.",null,{"inputs":[{"name":"f"}],"output":{"name":"joinhandle"}}],[5,"current","","Gets a handle to the thread that invokes it.",null,{"inputs":[],"output":{"name":"thread"}}],[5,"yield_now","","Cooperatively gives up a timeslice to the OS scheduler.",null,{"inputs":[],"output":null}],[5,"panicking","","Determines whether the current thread is unwinding because of panic.",null,{"inputs":[],"output":{"name":"bool"}}],[5,"sleep_ms","","Puts the current thread to sleep for the specified amount of time.",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"sleep","","Puts the current thread to sleep for the specified amount of time.",null,{"inputs":[{"name":"duration"}],"output":null}],[5,"park","","Blocks unless or until the current thread's token is made available.",null,{"inputs":[],"output":null}],[5,"park_timeout_ms","","Use [`park_timeout`].",null,{"inputs":[{"name":"u32"}],"output":null}],[5,"park_timeout","","Blocks unless or until the current thread's token is made available or the specified duration has been reached (may wake spuriously).",null,{"inputs":[{"name":"duration"}],"output":null}],[11,"fmt","","",100,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",101,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",101,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"with","","Acquires a reference to the value in this TLS key.",100,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"r"}}],[11,"try_with","","Acquires a reference to the value in this TLS key.",100,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"generics":["accesserror"],"name":"result"}}],[6,"Result","","A specialized [`Result`] type for threads.",null,null],[11,"fmt","","",102,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Generates the base configuration for spawning a thread, from which configuration methods can be chained.",102,{"inputs":[],"output":{"name":"builder"}}],[11,"name","","Names the thread-to-be. Currently the name is used for identification only in panic messages.",102,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"builder"}}],[11,"stack_size","","Sets the size of the stack (in bytes) for the new thread.",102,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"builder"}}],[11,"spawn","","Spawns a new thread by taking ownership of the `Builder`, and returns an [`io::Result`] to its [`JoinHandle`].",102,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"generics":["joinhandle"],"name":"result"}}],[11,"eq","","",103,{"inputs":[{"name":"self"},{"name":"threadid"}],"output":{"name":"bool"}}],[11,"ne","","",103,{"inputs":[{"name":"self"},{"name":"threadid"}],"output":{"name":"bool"}}],[11,"clone","","",103,{"inputs":[{"name":"self"}],"output":{"name":"threadid"}}],[11,"hash","","",103,null],[11,"fmt","","",103,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",104,{"inputs":[{"name":"self"}],"output":{"name":"thread"}}],[11,"unpark","","Atomically makes the handle's token available if it is not already.",104,{"inputs":[{"name":"self"}],"output":null}],[11,"id","","Gets the thread's unique identifier.",104,{"inputs":[{"name":"self"}],"output":{"name":"threadid"}}],[11,"name","","Gets the thread's name.",104,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"fmt","","",104,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"thread","","Extracts a handle to the underlying thread.",105,{"inputs":[{"name":"self"}],"output":{"name":"thread"}}],[11,"join","","Waits for the associated thread to finish.",105,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",105,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"ascii","std","Operations on ASCII strings and characters.",null,null],[3,"EscapeDefault","std::ascii","An iterator over the escaped version of a byte.",null,null],[5,"escape_default","","Returns an iterator that produces an escaped version of a `u8`.",null,{"inputs":[{"name":"u8"}],"output":{"name":"escapedefault"}}],[8,"AsciiExt","","Extension methods for ASCII-subset only operations.",null,null],[16,"Owned","","Container type for copied ASCII characters.",106,null],[10,"is_ascii","","Checks if the value is within the ASCII range.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"to_ascii_uppercase","","Makes a copy of the value in its ASCII upper case equivalent.",106,null],[10,"to_ascii_lowercase","","Makes a copy of the value in its ASCII lower case equivalent.",106,null],[10,"eq_ignore_ascii_case","","Checks that two values are an ASCII case-insensitive match.",106,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[10,"make_ascii_uppercase","","Converts this type to its ASCII upper case equivalent in-place.",106,{"inputs":[{"name":"self"}],"output":null}],[10,"make_ascii_lowercase","","Converts this type to its ASCII lower case equivalent in-place.",106,{"inputs":[{"name":"self"}],"output":null}],[11,"is_ascii_alphabetic","","Checks if the value is an ASCII alphabetic character: U+0041 'A' ... U+005A 'Z' or U+0061 'a' ... U+007A 'z'. For strings, true if all characters in the string are ASCII alphabetic.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_uppercase","","Checks if the value is an ASCII uppercase character: U+0041 'A' ... U+005A 'Z'. For strings, true if all characters in the string are ASCII uppercase.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_lowercase","","Checks if the value is an ASCII lowercase character: U+0061 'a' ... U+007A 'z'. For strings, true if all characters in the string are ASCII lowercase.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_alphanumeric","","Checks if the value is an ASCII alphanumeric character: U+0041 'A' ... U+005A 'Z', U+0061 'a' ... U+007A 'z', or U+0030 '0' ... U+0039 '9'. For strings, true if all characters in the string are ASCII alphanumeric.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_digit","","Checks if the value is an ASCII decimal digit: U+0030 '0' ... U+0039 '9'. For strings, true if all characters in the string are ASCII digits.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_hexdigit","","Checks if the value is an ASCII hexadecimal digit: U+0030 '0' ... U+0039 '9', U+0041 'A' ... U+0046 'F', or U+0061 'a' ... U+0066 'f'. For strings, true if all characters in the string are ASCII hex digits.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_punctuation","","Checks if the value is an ASCII punctuation character:",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_graphic","","Checks if the value is an ASCII graphic character: U+0021 '!' ... U+007E '~'. For strings, true if all characters in the string are ASCII graphic characters.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_whitespace","","Checks if the value is an ASCII whitespace character: U+0020 SPACE, U+0009 HORIZONTAL TAB, U+000A LINE FEED, U+000C FORM FEED, or U+000D CARRIAGE RETURN. For strings, true if all characters in the string are ASCII whitespace.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_control","","Checks if the value is an ASCII control character: U+0000 NUL ... U+001F UNIT SEPARATOR, or U+007F DELETE. Note that most ASCII whitespace characters are control characters, but SPACE is not.",106,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[0,"collections","std","Collection types.",null,null],[3,"BinaryHeap","std::collections","A priority queue implemented with a binary heap.",null,null],[3,"BTreeMap","","A map based on a B-Tree.",null,null],[3,"BTreeSet","","A set based on a B-Tree.",null,null],[3,"LinkedList","","A doubly-linked list with owned nodes.",null,null],[3,"VecDeque","","A double-ended queue implemented with a growable ring buffer.",null,null],[0,"binary_heap","","A priority queue implemented with a binary heap.",null,null],[3,"BinaryHeap","std::collections::binary_heap","A priority queue implemented with a binary heap.",null,null],[3,"PeekMut","","Structure wrapping a mutable reference to the greatest item on a `BinaryHeap`.",null,null],[3,"Iter","","An iterator over the elements of a `BinaryHeap`.",null,null],[3,"IntoIter","","An owning iterator over the elements of a `BinaryHeap`.",null,null],[3,"Drain","","A draining iterator over the elements of a `BinaryHeap`.",null,null],[3,"BinaryHeapPlace","","",null,null],[0,"btree_map","std::collections","A map based on a B-Tree.",null,null],[3,"Values","std::collections::btree_map","An iterator over the values of a `BTreeMap`.",null,null],[3,"Keys","","An iterator over the keys of a `BTreeMap`.",null,null],[3,"ValuesMut","","A mutable iterator over the values of a `BTreeMap`.",null,null],[3,"OccupiedEntry","","A view into an occupied entry in a `BTreeMap`. It is part of the [`Entry`] enum.",null,null],[3,"IntoIter","","An owning iterator over the entries of a `BTreeMap`.",null,null],[3,"IterMut","","A mutable iterator over the entries of a `BTreeMap`.",null,null],[3,"VacantEntry","","A view into a vacant entry in a `BTreeMap`. It is part of the [`Entry`] enum.",null,null],[3,"Range","","An iterator over a sub-range of entries in a `BTreeMap`.",null,null],[3,"BTreeMap","","A map based on a B-Tree.",null,null],[3,"RangeMut","","A mutable iterator over a sub-range of entries in a `BTreeMap`.",null,null],[4,"Entry","","A view into a single entry in a map, which may either be vacant or occupied.",null,null],[13,"Vacant","","A vacant entry.",107,null],[13,"Occupied","","An occupied entry.",107,null],[3,"Iter","","An iterator over the entries of a `BTreeMap`.",null,null],[0,"btree_set","std::collections","A set based on a B-Tree.",null,null],[3,"Intersection","std::collections::btree_set","A lazy iterator producing elements in the intersection of `BTreeSet`s.",null,null],[3,"Union","","A lazy iterator producing elements in the union of `BTreeSet`s.",null,null],[3,"Difference","","A lazy iterator producing elements in the difference of `BTreeSet`s.",null,null],[3,"IntoIter","","An owning iterator over the items of a `BTreeSet`.",null,null],[3,"Range","","An iterator over a sub-range of items in a `BTreeSet`.",null,null],[3,"SymmetricDifference","","A lazy iterator producing elements in the symmetric difference of `BTreeSet`s.",null,null],[3,"Iter","","An iterator over the items of a `BTreeSet`.",null,null],[3,"BTreeSet","","A set based on a B-Tree.",null,null],[0,"linked_list","std::collections","A doubly-linked list with owned nodes.",null,null],[3,"LinkedList","std::collections::linked_list","A doubly-linked list with owned nodes.",null,null],[3,"Iter","","An iterator over the elements of a `LinkedList`.",null,null],[3,"IterMut","","A mutable iterator over the elements of a `LinkedList`.",null,null],[3,"IntoIter","","An owning iterator over the elements of a `LinkedList`.",null,null],[3,"DrainFilter","","An iterator produced by calling `drain_filter` on LinkedList.",null,null],[3,"FrontPlace","","A place for insertion at the front of a `LinkedList`.",null,null],[3,"BackPlace","","A place for insertion at the back of a `LinkedList`.",null,null],[0,"vec_deque","std::collections","A double-ended queue implemented with a growable ring buffer.",null,null],[3,"VecDeque","std::collections::vec_deque","A double-ended queue implemented with a growable ring buffer.",null,null],[3,"Iter","","An iterator over the elements of a `VecDeque`.",null,null],[3,"IterMut","","A mutable iterator over the elements of a `VecDeque`.",null,null],[3,"IntoIter","","An owning iterator over the elements of a `VecDeque`.",null,null],[3,"Drain","","A draining iterator over the elements of a `VecDeque`.",null,null],[3,"PlaceBack","","A place for insertion at the back of a `VecDeque`.",null,null],[3,"PlaceFront","","A place for insertion at the front of a `VecDeque`.",null,null],[4,"CollectionAllocErr","std::collections","Augments `AllocErr` with a CapacityOverflow variant.",null,null],[13,"CapacityOverflow","","Error due to the computed capacity exceeding the collection's maximum (usually `isize::MAX` bytes).",108,null],[13,"AllocErr","","Error due to the allocator (see the `AllocErr` type's docs).",108,null],[3,"HashMap","","A hash map implemented with linear probing and Robin Hood bucket stealing.",null,null],[3,"HashSet","","A hash set implemented as a `HashMap` where the value is `()`.",null,null],[11,"clone","","",109,{"inputs":[{"name":"self"}],"output":{"name":"hashmap"}}],[11,"new","","Creates an empty `HashMap`.",109,{"inputs":[],"output":{"generics":["randomstate"],"name":"hashmap"}}],[11,"with_capacity","","Creates an empty `HashMap` with the specified capacity.",109,{"inputs":[{"name":"usize"}],"output":{"generics":["randomstate"],"name":"hashmap"}}],[11,"with_hasher","","Creates an empty `HashMap` which will use the given hash builder to hash keys.",109,{"inputs":[{"name":"s"}],"output":{"name":"hashmap"}}],[11,"with_capacity_and_hasher","","Creates an empty `HashMap` with the specified capacity, using `hash_builder` to hash the keys.",109,{"inputs":[{"name":"usize"},{"name":"s"}],"output":{"name":"hashmap"}}],[11,"hasher","","Returns a reference to the map's [`BuildHasher`].",109,{"inputs":[{"name":"self"}],"output":{"name":"s"}}],[11,"capacity","","Returns the number of elements the map can hold without reallocating.",109,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the `HashMap`. The collection may reserve more space to avoid frequent reallocations.",109,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"try_reserve","","Tries to reserve capacity for at least `additional` more elements to be inserted in the given `HashMap<K,V>`. The collection may reserve more space to avoid frequent reallocations.",109,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"shrink_to_fit","","Shrinks the capacity of the map as much as possible. It will drop down as much as possible while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.",109,{"inputs":[{"name":"self"}],"output":null}],[11,"shrink_to","","Shrinks the capacity of the map with a lower limit. It will drop down no lower than the supplied limit while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.",109,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"keys","","An iterator visiting all keys in arbitrary order. The iterator element type is `&'a K`.",109,{"inputs":[{"name":"self"}],"output":{"name":"keys"}}],[11,"values","","An iterator visiting all values in arbitrary order. The iterator element type is `&'a V`.",109,{"inputs":[{"name":"self"}],"output":{"name":"values"}}],[11,"values_mut","","An iterator visiting all values mutably in arbitrary order. The iterator element type is `&'a mut V`.",109,{"inputs":[{"name":"self"}],"output":{"name":"valuesmut"}}],[11,"iter","","An iterator visiting all key-value pairs in arbitrary order. The iterator element type is `(&'a K, &'a V)`.",109,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","An iterator visiting all key-value pairs in arbitrary order, with mutable references to the values. The iterator element type is `(&'a K, &'a mut V)`.",109,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"entry","","Gets the given key's corresponding entry in the map for in-place manipulation.",109,{"inputs":[{"name":"self"},{"name":"k"}],"output":{"name":"entry"}}],[11,"len","","Returns the number of elements in the map.",109,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns true if the map contains no elements.",109,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"drain","","Clears the map, returning all key-value pairs as an iterator. Keeps the allocated memory for reuse.",109,{"inputs":[{"name":"self"}],"output":{"name":"drain"}}],[11,"clear","","Clears the map, removing all key-value pairs. Keeps the allocated memory for reuse.",109,{"inputs":[{"name":"self"}],"output":null}],[11,"get","","Returns a reference to the value corresponding to the key.",109,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"get_key_value","","Returns the key-value pair corresponding to the supplied key.",109,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"contains_key","","Returns true if the map contains a value for the specified key.",109,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"get_mut","","Returns a mutable reference to the value corresponding to the key.",109,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"insert","","Inserts a key-value pair into the map.",109,{"inputs":[{"name":"self"},{"name":"k"},{"name":"v"}],"output":{"name":"option"}}],[11,"remove","","Removes a key from the map, returning the value at the key if the key was previously in the map.",109,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"remove_entry","","Removes a key from the map, returning the stored key and value if the key was previously in the map.",109,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"retain","","Retains only the elements specified by the predicate.",109,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"eq","","",109,{"inputs":[{"name":"self"},{"name":"hashmap"}],"output":{"name":"bool"}}],[11,"fmt","","",109,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Creates an empty `HashMap<K, V, S>`, with the `Default` value for the hasher.",109,{"inputs":[],"output":{"name":"hashmap"}}],[11,"index","","Returns a reference to the value corresponding to the supplied key.",109,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"v"}}],[11,"into_iter","","Creates a consuming iterator, that is, one that moves each key-value pair out of the map in arbitrary order. The map cannot be used after calling this.",109,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"from_iter","","",109,{"inputs":[{"name":"t"}],"output":{"name":"hashmap"}}],[11,"extend","","",109,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"extend","","",109,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"clone","","",110,{"inputs":[{"name":"self"}],"output":{"name":"hashset"}}],[11,"new","","Creates an empty `HashSet`.",110,{"inputs":[],"output":{"generics":["randomstate"],"name":"hashset"}}],[11,"with_capacity","","Creates an empty `HashSet` with the specified capacity.",110,{"inputs":[{"name":"usize"}],"output":{"generics":["randomstate"],"name":"hashset"}}],[11,"with_hasher","","Creates a new empty hash set which will use the given hasher to hash keys.",110,{"inputs":[{"name":"s"}],"output":{"name":"hashset"}}],[11,"with_capacity_and_hasher","","Creates an empty `HashSet` with with the specified capacity, using `hasher` to hash the keys.",110,{"inputs":[{"name":"usize"},{"name":"s"}],"output":{"name":"hashset"}}],[11,"hasher","","Returns a reference to the set's [`BuildHasher`].",110,{"inputs":[{"name":"self"}],"output":{"name":"s"}}],[11,"capacity","","Returns the number of elements the set can hold without reallocating.",110,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the `HashSet`. The collection may reserve more space to avoid frequent reallocations.",110,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shrink_to_fit","","Shrinks the capacity of the set as much as possible. It will drop down as much as possible while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.",110,{"inputs":[{"name":"self"}],"output":null}],[11,"shrink_to","","Shrinks the capacity of the set with a lower limit. It will drop down no lower than the supplied limit while maintaining the internal rules and possibly leaving some space in accordance with the resize policy.",110,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"iter","","An iterator visiting all elements in arbitrary order. The iterator element type is `&'a T`.",110,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"difference","","Visits the values representing the difference, i.e. the values that are in `self` but not in `other`.",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"difference"}}],[11,"symmetric_difference","","Visits the values representing the symmetric difference, i.e. the values that are in `self` or in `other` but not in both.",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"symmetricdifference"}}],[11,"intersection","","Visits the values representing the intersection, i.e. the values that are both in `self` and `other`.",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"intersection"}}],[11,"union","","Visits the values representing the union, i.e. all the values in `self` or `other`, without duplicates.",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"union"}}],[11,"len","","Returns the number of elements in the set.",110,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns true if the set contains no elements.",110,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"drain","","Clears the set, returning all elements in an iterator.",110,{"inputs":[{"name":"self"}],"output":{"name":"drain"}}],[11,"clear","","Clears the set, removing all values.",110,{"inputs":[{"name":"self"}],"output":null}],[11,"contains","","Returns `true` if the set contains a value.",110,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"get","","Returns a reference to the value in the set, if any, that is equal to the given value.",110,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"is_disjoint","","Returns `true` if `self` has no elements in common with `other`. This is equivalent to checking for an empty intersection.",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"bool"}}],[11,"is_subset","","Returns `true` if the set is a subset of another, i.e. `other` contains at least all the values in `self`.",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"bool"}}],[11,"is_superset","","Returns `true` if the set is a superset of another, i.e. `self` contains at least all the values in `other`.",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"bool"}}],[11,"insert","","Adds a value to the set.",110,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"replace","","Adds a value to the set, replacing the existing value, if any, that is equal to the given one. Returns the replaced value.",110,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[11,"remove","","Removes a value from the set. Returns `true` if the value was present in the set.",110,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"take","","Removes and returns the value in the set, if any, that is equal to the given one.",110,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"retain","","Retains only the elements specified by the predicate.",110,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"eq","","",110,{"inputs":[{"name":"self"},{"name":"hashset"}],"output":{"name":"bool"}}],[11,"fmt","","",110,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from_iter","","",110,{"inputs":[{"name":"i"}],"output":{"name":"hashset"}}],[11,"extend","","",110,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"extend","","",110,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"default","","Creates an empty `HashSet<T, S>` with the `Default` value for the hasher.",110,{"inputs":[],"output":{"name":"hashset"}}],[11,"into_iter","","Creates a consuming iterator, that is, one that moves each value out of the set in arbitrary order. The set cannot be used after calling this.",110,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[0,"hash_map","","A hash map implemented with linear probing and Robin Hood bucket stealing.",null,null],[3,"HashMap","std::collections::hash_map","A hash map implemented with linear probing and Robin Hood bucket stealing.",null,null],[3,"Iter","","An iterator over the entries of a `HashMap`.",null,null],[3,"IterMut","","A mutable iterator over the entries of a `HashMap`.",null,null],[3,"IntoIter","","An owning iterator over the entries of a `HashMap`.",null,null],[3,"Keys","","An iterator over the keys of a `HashMap`.",null,null],[3,"Values","","An iterator over the values of a `HashMap`.",null,null],[3,"Drain","","A draining iterator over the entries of a `HashMap`.",null,null],[3,"ValuesMut","","A mutable iterator over the values of a `HashMap`.",null,null],[3,"OccupiedEntry","","A view into an occupied entry in a `HashMap`. It is part of the [`Entry`] enum.",null,null],[3,"VacantEntry","","A view into a vacant entry in a `HashMap`. It is part of the [`Entry`] enum.",null,null],[3,"EntryPlace","","A place for insertion to a `Entry`.",null,null],[3,"RandomState","","`RandomState` is the default state for [`HashMap`] types.",null,null],[3,"DefaultHasher","","The default [`Hasher`] used by [`RandomState`].",null,null],[4,"Entry","","A view into a single entry in a map, which may either be vacant or occupied.",null,null],[13,"Occupied","","An occupied entry.",111,null],[13,"Vacant","","A vacant entry.",111,null],[0,"hash_set","std::collections","A hash set implemented as a `HashMap` where the value is `()`.",null,null],[3,"HashSet","std::collections::hash_set","A hash set implemented as a `HashMap` where the value is `()`.",null,null],[3,"Iter","","An iterator over the items of a `HashSet`.",null,null],[3,"IntoIter","","An owning iterator over the items of a `HashSet`.",null,null],[3,"Drain","","A draining iterator over the items of a `HashSet`.",null,null],[3,"Intersection","","A lazy iterator producing elements in the intersection of `HashSet`s.",null,null],[3,"Difference","","A lazy iterator producing elements in the difference of `HashSet`s.",null,null],[3,"SymmetricDifference","","A lazy iterator producing elements in the symmetric difference of `HashSet`s.",null,null],[3,"Union","","A lazy iterator producing elements in the union of `HashSet`s.",null,null],[0,"env","std","Inspection and manipulation of the process's environment.",null,null],[3,"Vars","std::env","An iterator over a snapshot of the environment variables of this process.",null,null],[3,"VarsOs","","An iterator over a snapshot of the environment variables of this process.",null,null],[3,"SplitPaths","","An iterator that splits an environment variable into paths according to platform-specific conventions.",null,null],[3,"JoinPathsError","","The error type for operations on the `PATH` variable. Possibly returned from the [`env::join_paths`] function.",null,null],[3,"Args","","An iterator over the arguments of a process, yielding a [`String`] value for each argument.",null,null],[3,"ArgsOs","","An iterator over the arguments of a process, yielding an [`OsString`] value for each argument.",null,null],[4,"VarError","","The error type for operations interacting with environment variables. Possibly returned from the [`env::var`] function.",null,null],[13,"NotPresent","","The specified environment variable was not present in the current process's environment.",112,null],[13,"NotUnicode","","The specified environment variable was found, but it did not contain valid unicode data. The found data is returned as a payload of this variant.",112,null],[5,"current_dir","","Returns the current working directory as a [`PathBuf`].",null,{"inputs":[],"output":{"generics":["pathbuf"],"name":"result"}}],[5,"set_current_dir","","Changes the current working directory to the specified path.",null,{"inputs":[{"name":"p"}],"output":{"name":"result"}}],[5,"vars","","Returns an iterator of (variable, value) pairs of strings, for all the environment variables of the current process.",null,{"inputs":[],"output":{"name":"vars"}}],[5,"vars_os","","Returns an iterator of (variable, value) pairs of OS strings, for all the environment variables of the current process.",null,{"inputs":[],"output":{"name":"varsos"}}],[5,"var","","Fetches the environment variable `key` from the current process.",null,{"inputs":[{"name":"k"}],"output":{"generics":["string","varerror"],"name":"result"}}],[5,"var_os","","Fetches the environment variable `key` from the current process, returning [`None`] if the variable isn't set.",null,{"inputs":[{"name":"k"}],"output":{"generics":["osstring"],"name":"option"}}],[5,"set_var","","Sets the environment variable `k` to the value `v` for the currently running process.",null,{"inputs":[{"name":"k"},{"name":"v"}],"output":null}],[5,"remove_var","","Removes an environment variable from the environment of the currently running process.",null,{"inputs":[{"name":"k"}],"output":null}],[5,"split_paths","","Parses input according to platform conventions for the `PATH` environment variable.",null,{"inputs":[{"name":"t"}],"output":{"name":"splitpaths"}}],[5,"join_paths","","Joins a collection of [`Path`]s appropriately for the `PATH` environment variable.",null,{"inputs":[{"name":"i"}],"output":{"generics":["osstring","joinpathserror"],"name":"result"}}],[5,"home_dir","","Returns the path of the current user's home directory if known.",null,{"inputs":[],"output":{"generics":["pathbuf"],"name":"option"}}],[5,"temp_dir","","Returns the path of a temporary directory.",null,{"inputs":[],"output":{"name":"pathbuf"}}],[5,"current_exe","","Returns the full filesystem path of the current running executable.",null,{"inputs":[],"output":{"generics":["pathbuf"],"name":"result"}}],[5,"args","","Returns the arguments which this program was started with (normally passed via the command line).",null,{"inputs":[],"output":{"name":"args"}}],[5,"args_os","","Returns the arguments which this program was started with (normally passed via the command line).",null,{"inputs":[],"output":{"name":"argsos"}}],[0,"consts","","Constants associated with the current target",null,null],[17,"ARCH","std::env::consts","A string describing the architecture of the CPU that is currently in use.",null,null],[17,"FAMILY","","The family of the operating system. Example value is `unix`.",null,null],[17,"OS","","A string describing the specific operating system in use. Example value is `linux`.",null,null],[17,"DLL_PREFIX","","Specifies the filename prefix used for shared libraries on this platform. Example value is `lib`.",null,null],[17,"DLL_SUFFIX","","Specifies the filename suffix used for shared libraries on this platform. Example value is `.so`.",null,null],[17,"DLL_EXTENSION","","Specifies the file extension used for shared libraries on this platform that goes after the dot. Example value is `so`.",null,null],[17,"EXE_SUFFIX","","Specifies the filename suffix used for executable binaries on this platform. Example value is `.exe`.",null,null],[17,"EXE_EXTENSION","","Specifies the file extension, if any, used for executable binaries on this platform. Example value is `exe`.",null,null],[11,"next","std::env","",113,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",113,null],[11,"fmt","","",113,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",114,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",114,null],[11,"fmt","","",114,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",112,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",112,{"inputs":[{"name":"self"},{"name":"varerror"}],"output":{"name":"bool"}}],[11,"ne","","",112,{"inputs":[{"name":"self"},{"name":"varerror"}],"output":{"name":"bool"}}],[11,"clone","","",112,{"inputs":[{"name":"self"}],"output":{"name":"varerror"}}],[11,"fmt","","",112,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",112,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",115,{"inputs":[{"name":"self"}],"output":{"generics":["pathbuf"],"name":"option"}}],[11,"size_hint","","",115,null],[11,"fmt","","",115,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",116,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",116,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",116,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",117,{"inputs":[{"name":"self"}],"output":{"generics":["string"],"name":"option"}}],[11,"size_hint","","",117,null],[11,"len","","",117,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",117,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_back","","",117,{"inputs":[{"name":"self"}],"output":{"generics":["string"],"name":"option"}}],[11,"fmt","","",117,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",118,{"inputs":[{"name":"self"}],"output":{"generics":["osstring"],"name":"option"}}],[11,"size_hint","","",118,null],[11,"len","","",118,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",118,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_back","","",118,{"inputs":[{"name":"self"}],"output":{"generics":["osstring"],"name":"option"}}],[11,"fmt","","",118,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"error","std","Traits for working with Errors.",null,null],[8,"Error","std::error","Base functionality for all errors in Rust.",null,null],[10,"description","","A short description of the error.",119,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","The lower-level cause of this error, if any.",119,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"e"}],"output":{"generics":["error"],"name":"box"}}],[11,"from","","",120,{"inputs":[{"name":"e"}],"output":{"generics":["error"],"name":"box"}}],[11,"from","","",120,{"inputs":[{"name":"string"}],"output":{"generics":["error"],"name":"box"}}],[11,"from","","",120,{"inputs":[{"name":"string"}],"output":{"generics":["error"],"name":"box"}}],[11,"from","","",120,{"inputs":[{"name":"str"}],"output":{"generics":["error"],"name":"box"}}],[11,"from","","",120,{"inputs":[{"name":"str"}],"output":{"generics":["error"],"name":"box"}}],[11,"from","","",120,{"inputs":[{"generics":["str"],"name":"cow"}],"output":{"generics":["error"],"name":"box"}}],[11,"from","","",120,{"inputs":[{"generics":["str"],"name":"cow"}],"output":{"generics":["error"],"name":"box"}}],[11,"description","std::str","",121,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",122,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","std::string","",123,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",124,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",125,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","std::char","",126,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",120,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"description","std::fmt","",127,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","std::cell","",128,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",129,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","std::char","",130,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",131,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"is","std::error","Returns true if the boxed type is the same as `T`",119,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"downcast_ref","","Returns some reference to the boxed value if it is of type `T`, or `None` if it isn't.",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast_mut","","Returns some mutable reference to the boxed value if it is of type `T`, or `None` if it isn't.",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is","","Forwards to the method defined on the type `Any`.",119,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"downcast_ref","","Forwards to the method defined on the type `Any`.",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast_mut","","Forwards to the method defined on the type `Any`.",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is","","Forwards to the method defined on the type `Any`.",119,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"downcast_ref","","Forwards to the method defined on the type `Any`.",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast_mut","","Forwards to the method defined on the type `Any`.",119,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast","","Attempt to downcast the box to a concrete type.",119,{"inputs":[{"name":"box"}],"output":{"generics":["box","box"],"name":"result"}}],[11,"downcast","","Attempt to downcast the box to a concrete type.",119,{"inputs":[{"name":"box"}],"output":{"generics":["box","box"],"name":"result"}}],[11,"downcast","","Attempt to downcast the box to a concrete type.",119,{"inputs":[{"name":"box"}],"output":{"generics":["box","box"],"name":"result"}}],[0,"ffi","std","Utilities related to FFI bindings.",null,null],[3,"CString","std::ffi","A type representing an owned, C-compatible, nul-terminated string with no nul bytes in the middle.",null,null],[3,"CStr","","Representation of a borrowed C string.",null,null],[3,"NulError","","An error indicating that an interior nul byte was found.",null,null],[3,"IntoStringError","","An error indicating invalid UTF-8 when converting a [`CString`] into a [`String`].",null,null],[3,"FromBytesWithNulError","","An error indicating that a nul byte was not in the expected position.",null,null],[3,"OsString","","A type that can represent owned, mutable platform-native strings, but is cheaply inter-convertible with Rust strings.",null,null],[3,"OsStr","","Borrowed reference to an OS string (see [`OsString`]).",null,null],[11,"eq","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"name":"bool"}}],[11,"ne","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"name":"bool"}}],[11,"le","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"name":"bool"}}],[11,"gt","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"name":"bool"}}],[11,"ge","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"name":"bool"}}],[11,"cmp","","",132,{"inputs":[{"name":"self"},{"name":"cstring"}],"output":{"name":"ordering"}}],[11,"hash","","",132,null],[11,"clone","","",132,{"inputs":[{"name":"self"}],"output":{"name":"cstring"}}],[11,"hash","","",133,null],[11,"clone","","",134,{"inputs":[{"name":"self"}],"output":{"name":"nulerror"}}],[11,"eq","","",134,{"inputs":[{"name":"self"},{"name":"nulerror"}],"output":{"name":"bool"}}],[11,"ne","","",134,{"inputs":[{"name":"self"},{"name":"nulerror"}],"output":{"name":"bool"}}],[11,"fmt","","",134,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",135,{"inputs":[{"name":"self"}],"output":{"name":"frombyteswithnulerror"}}],[11,"eq","","",135,{"inputs":[{"name":"self"},{"name":"frombyteswithnulerror"}],"output":{"name":"bool"}}],[11,"ne","","",135,{"inputs":[{"name":"self"},{"name":"frombyteswithnulerror"}],"output":{"name":"bool"}}],[11,"fmt","","",135,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",136,{"inputs":[{"name":"self"}],"output":{"name":"intostringerror"}}],[11,"eq","","",136,{"inputs":[{"name":"self"},{"name":"intostringerror"}],"output":{"name":"bool"}}],[11,"ne","","",136,{"inputs":[{"name":"self"},{"name":"intostringerror"}],"output":{"name":"bool"}}],[11,"fmt","","",136,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new C-compatible string from a container of bytes.",132,{"inputs":[{"name":"t"}],"output":{"generics":["cstring","nulerror"],"name":"result"}}],[11,"from_vec_unchecked","","Creates a C-compatible string by consuming a byte vector, without checking for interior 0 bytes.",132,{"inputs":[{"generics":["u8"],"name":"vec"}],"output":{"name":"cstring"}}],[11,"from_raw","","Retakes ownership of a `CString` that was transferred to C via [`into_raw`].",132,null],[11,"into_raw","","Consumes the `CString` and transfers ownership of the string to a C caller.",132,null],[11,"into_string","","Converts the `CString` into a [`String`] if it contains valid UTF-8 data.",132,{"inputs":[{"name":"self"}],"output":{"generics":["string","intostringerror"],"name":"result"}}],[11,"into_bytes","","Consumes the `CString` and returns the underlying byte buffer.",132,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"into_bytes_with_nul","","Equivalent to the [`into_bytes`] function except that the returned vector includes the trailing nul terminator.",132,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"as_bytes","","Returns the contents of this `CString` as a slice of bytes.",132,null],[11,"as_bytes_with_nul","","Equivalent to the [`as_bytes`] function except that the returned slice includes the trailing nul terminator.",132,null],[11,"as_c_str","","Extracts a [`CStr`] slice containing the entire string.",132,{"inputs":[{"name":"self"}],"output":{"name":"cstr"}}],[11,"into_boxed_c_str","","Converts this `CString` into a boxed [`CStr`].",132,{"inputs":[{"name":"self"}],"output":{"generics":["cstr"],"name":"box"}}],[11,"drop","","",132,{"inputs":[{"name":"self"}],"output":null}],[11,"deref","","",132,{"inputs":[{"name":"self"}],"output":{"name":"cstr"}}],[11,"fmt","","",132,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","std::vec","",137,{"inputs":[{"name":"cstring"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"fmt","std::ffi","",133,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Creates an empty `CString`.",132,{"inputs":[],"output":{"name":"cstring"}}],[11,"borrow","","",132,{"inputs":[{"name":"self"}],"output":{"name":"cstr"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"cstr"}],"output":{"generics":["cstr"],"name":"box"}}],[11,"from","std::ffi","",132,{"inputs":[{"generics":["cstr"],"name":"box"}],"output":{"name":"cstring"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"cstring"}],"output":{"generics":["cstr"],"name":"box"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"cstring"}],"output":{"generics":["cstr"],"name":"rc"}}],[11,"from","","",138,{"inputs":[{"name":"cstr"}],"output":{"generics":["cstr"],"name":"rc"}}],[11,"default","std::boxed","",120,{"inputs":[],"output":{"generics":["cstr"],"name":"box"}}],[11,"nul_position","std::ffi","Returns the position of the nul byte in the slice that caused [`CString::new`] to fail.",134,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"into_vec","","Consumes this error, returning the underlying vector of bytes which generated the error in the first place.",134,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"description","","",134,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"fmt","","",134,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",135,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"fmt","","",135,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"into_cstring","","Consumes this error, returning original [`CString`] which generated the error.",136,{"inputs":[{"name":"self"}],"output":{"name":"cstring"}}],[11,"utf8_error","","Access the underlying UTF-8 error that was the cause of this error.",136,{"inputs":[{"name":"self"}],"output":{"name":"utf8error"}}],[11,"description","","",136,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",136,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"fmt","","",136,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from_ptr","","Wraps a raw C string with a safe C string wrapper.",133,null],[11,"from_bytes_with_nul","","Creates a C string wrapper from a byte slice.",133,null],[11,"from_bytes_with_nul_unchecked","","Unsafely creates a C string wrapper from a byte slice.",133,null],[11,"as_ptr","","Returns the inner pointer to this C string.",133,null],[11,"to_bytes","","Converts this C string to a byte slice.",133,null],[11,"to_bytes_with_nul","","Converts this C string to a byte slice containing the trailing 0 byte.",133,null],[11,"to_str","","Yields a [`&str`] slice if the `CStr` contains valid UTF-8.",133,{"inputs":[{"name":"self"}],"output":{"generics":["str","utf8error"],"name":"result"}}],[11,"to_string_lossy","","Converts a `CStr` into a [`Cow`]`<`[`str`]`>`.",133,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"cow"}}],[11,"into_c_string","","Converts a [`Box`]`<CStr>` into a [`CString`] without copying or allocating.",133,{"inputs":[{"generics":["cstr"],"name":"box"}],"output":{"name":"cstring"}}],[11,"eq","","",133,{"inputs":[{"name":"self"},{"name":"cstr"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",133,{"inputs":[{"name":"self"},{"name":"cstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",133,{"inputs":[{"name":"self"},{"name":"cstr"}],"output":{"name":"ordering"}}],[11,"to_owned","","",133,{"inputs":[{"name":"self"}],"output":{"name":"cstring"}}],[11,"from","","",132,{"inputs":[{"name":"cstr"}],"output":{"name":"cstring"}}],[11,"index","","",132,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"cstr"}}],[11,"as_ref","","",133,{"inputs":[{"name":"self"}],"output":{"name":"cstr"}}],[11,"as_ref","","",132,{"inputs":[{"name":"self"}],"output":{"name":"cstr"}}],[11,"clone","","",139,{"inputs":[{"name":"self"}],"output":{"name":"osstring"}}],[11,"new","","Constructs a new empty `OsString`.",139,{"inputs":[],"output":{"name":"osstring"}}],[11,"as_os_str","","Converts to an [`OsStr`] slice.",139,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"into_string","","Converts the `OsString` into a [`String`] if it contains valid Unicode data.",139,{"inputs":[{"name":"self"}],"output":{"generics":["string","osstring"],"name":"result"}}],[11,"push","","Extends the string with the given [`&OsStr`] slice.",139,{"inputs":[{"name":"self"},{"name":"t"}],"output":null}],[11,"with_capacity","","Creates a new `OsString` with the given capacity.",139,{"inputs":[{"name":"usize"}],"output":{"name":"osstring"}}],[11,"clear","","Truncates the `OsString` to zero length.",139,{"inputs":[{"name":"self"}],"output":null}],[11,"capacity","","Returns the capacity this `OsString` can hold without reallocating.",139,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve","","Reserves capacity for at least `additional` more capacity to be inserted in the given `OsString`.",139,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"reserve_exact","","Reserves the minimum capacity for exactly `additional` more capacity to be inserted in the given `OsString`. Does nothing if the capacity is already sufficient.",139,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"shrink_to_fit","","Shrinks the capacity of the `OsString` to match its length.",139,{"inputs":[{"name":"self"}],"output":null}],[11,"shrink_to","","Shrinks the capacity of the `OsString` with a lower bound.",139,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"into_boxed_os_str","","Converts this `OsString` into a boxed [`OsStr`].",139,{"inputs":[{"name":"self"}],"output":{"generics":["osstr"],"name":"box"}}],[11,"from","","",139,{"inputs":[{"name":"string"}],"output":{"name":"osstring"}}],[11,"from","","",139,{"inputs":[{"name":"t"}],"output":{"name":"osstring"}}],[11,"index","","",139,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"osstr"}}],[11,"deref","","",139,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"default","","Constructs an empty `OsString`.",139,{"inputs":[],"output":{"name":"osstring"}}],[11,"fmt","","",139,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",139,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"eq","","",139,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",139,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",139,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"le","","",139,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"gt","","",139,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"ge","","",139,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",139,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",139,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"ordering"}}],[11,"hash","","",139,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"new","","Coerces into an `OsStr` slice.",140,{"inputs":[{"name":"s"}],"output":{"name":"osstr"}}],[11,"to_str","","Yields a [`&str`] slice if the `OsStr` is valid Unicode.",140,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"to_string_lossy","","Converts an `OsStr` to a [`Cow`]`<`[`str`]`>`.",140,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"cow"}}],[11,"to_os_string","","Copies the slice into an owned [`OsString`].",140,{"inputs":[{"name":"self"}],"output":{"name":"osstring"}}],[11,"is_empty","","Checks whether the `OsStr` is empty.",140,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","","Returns the length of this `OsStr`.",140,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"into_os_string","","Converts a [`Box`]`<OsStr>` into an [`OsString`] without copying or allocating.",140,{"inputs":[{"generics":["osstr"],"name":"box"}],"output":{"name":"osstring"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"osstr"}],"output":{"generics":["osstr"],"name":"box"}}],[11,"from","std::ffi","",139,{"inputs":[{"generics":["osstr"],"name":"box"}],"output":{"name":"osstring"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"osstring"}],"output":{"generics":["osstr"],"name":"box"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"osstring"}],"output":{"generics":["osstr"],"name":"rc"}}],[11,"from","","",138,{"inputs":[{"name":"osstr"}],"output":{"generics":["osstr"],"name":"rc"}}],[11,"default","std::boxed","",120,{"inputs":[],"output":{"generics":["osstr"],"name":"box"}}],[11,"eq","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"eq","","",140,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",140,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",140,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"le","","",140,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"gt","","",140,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"ge","","",140,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",140,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",140,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"ordering"}}],[11,"eq","","",139,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"eq","","",140,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",139,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",140,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",139,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",139,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",76,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"hash","","",140,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"fmt","","",140,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"borrow","","",139,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"to_owned","","",140,{"inputs":[{"name":"self"}],"output":{"name":"osstring"}}],[11,"clone_into","","",140,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":null}],[11,"as_ref","","",140,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"as_ref","","",139,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"as_ref","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[0,"fs","std","Filesystem manipulation operations.",null,null],[3,"File","std::fs","A reference to an open file on the filesystem.",null,null],[3,"Metadata","","Metadata information about a file.",null,null],[3,"ReadDir","","Iterator over the entries in a directory.",null,null],[3,"DirEntry","","Entries returned by the [`ReadDir`] iterator.",null,null],[3,"OpenOptions","","Options and flags which can be used to configure how a file is opened.",null,null],[3,"Permissions","","Representation of the various permissions on a file.",null,null],[3,"FileType","","A structure representing a type of file with accessors for each file type. It is returned by [`Metadata::file_type`] method.",null,null],[3,"DirBuilder","","A builder used to create directories in various manners.",null,null],[5,"read","","Read the entire contents of a file into a bytes vector.",null,{"inputs":[{"name":"p"}],"output":{"generics":["vec"],"name":"result"}}],[5,"read_to_string","","Read the entire contents of a file into a string.",null,{"inputs":[{"name":"p"}],"output":{"generics":["string"],"name":"result"}}],[5,"write","","Write a slice as the entire contents of a file.",null,{"inputs":[{"name":"p"},{"name":"c"}],"output":{"name":"result"}}],[5,"remove_file","","Removes a file from the filesystem.",null,{"inputs":[{"name":"p"}],"output":{"name":"result"}}],[5,"metadata","","Given a path, query the file system to get information about a file, directory, etc.",null,{"inputs":[{"name":"p"}],"output":{"generics":["metadata"],"name":"result"}}],[5,"symlink_metadata","","Query the metadata about a file without following symlinks.",null,{"inputs":[{"name":"p"}],"output":{"generics":["metadata"],"name":"result"}}],[5,"rename","","Rename a file or directory to a new name, replacing the original file if `to` already exists.",null,{"inputs":[{"name":"p"},{"name":"q"}],"output":{"name":"result"}}],[5,"copy","","Copies the contents of one file to another. This function will also copy the permission bits of the original file to the destination file.",null,{"inputs":[{"name":"p"},{"name":"q"}],"output":{"generics":["u64"],"name":"result"}}],[5,"hard_link","","Creates a new hard link on the filesystem.",null,{"inputs":[{"name":"p"},{"name":"q"}],"output":{"name":"result"}}],[5,"soft_link","","Creates a new symbolic link on the filesystem.",null,{"inputs":[{"name":"p"},{"name":"q"}],"output":{"name":"result"}}],[5,"read_link","","Reads a symbolic link, returning the file that the link points to.",null,{"inputs":[{"name":"p"}],"output":{"generics":["pathbuf"],"name":"result"}}],[5,"canonicalize","","Returns the canonical form of a path with all intermediate components normalized and symbolic links resolved.",null,{"inputs":[{"name":"p"}],"output":{"generics":["pathbuf"],"name":"result"}}],[5,"create_dir","","Creates a new, empty directory at the provided path",null,{"inputs":[{"name":"p"}],"output":{"name":"result"}}],[5,"create_dir_all","","Recursively create a directory and all of its parent components if they are missing.",null,{"inputs":[{"name":"p"}],"output":{"name":"result"}}],[5,"remove_dir","","Removes an existing, empty directory.",null,{"inputs":[{"name":"p"}],"output":{"name":"result"}}],[5,"remove_dir_all","","Removes a directory at this path, after removing all its contents. Use carefully!",null,{"inputs":[{"name":"p"}],"output":{"name":"result"}}],[5,"read_dir","","Returns an iterator over the entries within a directory.",null,{"inputs":[{"name":"p"}],"output":{"generics":["readdir"],"name":"result"}}],[5,"set_permissions","","Changes the permissions found on a file or a directory.",null,{"inputs":[{"name":"p"},{"name":"permissions"}],"output":{"name":"result"}}],[11,"clone","","",142,{"inputs":[{"name":"self"}],"output":{"name":"metadata"}}],[11,"fmt","","",143,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",144,{"inputs":[{"name":"self"}],"output":{"name":"openoptions"}}],[11,"fmt","","",144,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",145,{"inputs":[{"name":"self"}],"output":{"name":"permissions"}}],[11,"eq","","",145,{"inputs":[{"name":"self"},{"name":"permissions"}],"output":{"name":"bool"}}],[11,"ne","","",145,{"inputs":[{"name":"self"},{"name":"permissions"}],"output":{"name":"bool"}}],[11,"fmt","","",145,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",146,{"inputs":[{"name":"self"}],"output":{"name":"filetype"}}],[11,"eq","","",146,{"inputs":[{"name":"self"},{"name":"filetype"}],"output":{"name":"bool"}}],[11,"ne","","",146,{"inputs":[{"name":"self"},{"name":"filetype"}],"output":{"name":"bool"}}],[11,"hash","","",146,null],[11,"fmt","","",146,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",147,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"open","","Attempts to open a file in read-only mode.",148,{"inputs":[{"name":"p"}],"output":{"generics":["file"],"name":"result"}}],[11,"create","","Opens a file in write-only mode.",148,{"inputs":[{"name":"p"}],"output":{"generics":["file"],"name":"result"}}],[11,"sync_all","","Attempts to sync all OS-internal metadata to disk.",148,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"sync_data","","This function is similar to [`sync_all`], except that it may not synchronize file metadata to the filesystem.",148,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"set_len","","Truncates or extends the underlying file, updating the size of this file to become `size`.",148,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"result"}}],[11,"metadata","","Queries metadata about the underlying file.",148,{"inputs":[{"name":"self"}],"output":{"generics":["metadata"],"name":"result"}}],[11,"try_clone","","Create a new `File` instance that shares the same underlying file handle as the existing `File` instance. Reads, writes, and seeks will affect both `File` instances simultaneously.",148,{"inputs":[{"name":"self"}],"output":{"generics":["file"],"name":"result"}}],[11,"set_permissions","","Changes the permissions on the underlying file.",148,{"inputs":[{"name":"self"},{"name":"permissions"}],"output":{"name":"result"}}],[11,"fmt","","",148,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"read","","",148,null],[11,"initializer","","",148,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"write","","",148,null],[11,"flush","","",148,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"seek","","",148,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"generics":["u64"],"name":"result"}}],[11,"new","","Creates a blank new set of options ready for configuration.",144,{"inputs":[],"output":{"name":"openoptions"}}],[11,"read","","Sets the option for read access.",144,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"openoptions"}}],[11,"write","","Sets the option for write access.",144,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"openoptions"}}],[11,"append","","Sets the option for the append mode.",144,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"openoptions"}}],[11,"truncate","","Sets the option for truncating a previous file.",144,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"openoptions"}}],[11,"create","","Sets the option for creating a new file.",144,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"openoptions"}}],[11,"create_new","","Sets the option to always create a new file.",144,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"openoptions"}}],[11,"open","","Opens a file at `path` with the options specified by `self`.",144,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["file"],"name":"result"}}],[11,"file_type","","Returns the file type for this metadata.",142,{"inputs":[{"name":"self"}],"output":{"name":"filetype"}}],[11,"is_dir","","Returns whether this metadata is for a directory. The result is mutually exclusive to the result of [`is_file`], and will be false for symlink metadata obtained from [`symlink_metadata`].",142,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_file","","Returns whether this metadata is for a regular file. The result is mutually exclusive to the result of [`is_dir`], and will be false for symlink metadata obtained from [`symlink_metadata`].",142,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","","Returns the size of the file, in bytes, this metadata is for.",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"permissions","","Returns the permissions of the file this metadata is for.",142,{"inputs":[{"name":"self"}],"output":{"name":"permissions"}}],[11,"modified","","Returns the last modification time listed in this metadata.",142,{"inputs":[{"name":"self"}],"output":{"generics":["systemtime"],"name":"result"}}],[11,"accessed","","Returns the last access time of this metadata.",142,{"inputs":[{"name":"self"}],"output":{"generics":["systemtime"],"name":"result"}}],[11,"created","","Returns the creation time listed in this metadata.",142,{"inputs":[{"name":"self"}],"output":{"generics":["systemtime"],"name":"result"}}],[11,"fmt","","",142,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"readonly","","Returns whether these permissions describe a readonly (unwritable) file.",145,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"set_readonly","","Modifies the readonly flag for this set of permissions. If the `readonly` argument is `true`, using the resulting `Permission` will update file permissions to forbid writing. Conversely, if it's `false`, using the resulting `Permission` will update file permissions to allow writing.",145,{"inputs":[{"name":"self"},{"name":"bool"}],"output":null}],[11,"is_dir","","Test whether this file type represents a directory. The result is mutually exclusive to the results of [`is_file`] and [`is_symlink`]; only zero or one of these tests may pass.",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_file","","Test whether this file type represents a regular file. The result is  mutually exclusive to the results of [`is_dir`] and [`is_symlink`]; only zero or one of these tests may pass.",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_symlink","","Test whether this file type represents a symbolic link. The result is mutually exclusive to the results of [`is_dir`] and [`is_file`]; only zero or one of these tests may pass.",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next","","",143,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"path","","Returns the full path to the file that this entry represents.",149,{"inputs":[{"name":"self"}],"output":{"name":"pathbuf"}}],[11,"metadata","","Return the metadata for the file that this entry points at.",149,{"inputs":[{"name":"self"}],"output":{"generics":["metadata"],"name":"result"}}],[11,"file_type","","Return the file type for the file that this entry points at.",149,{"inputs":[{"name":"self"}],"output":{"generics":["filetype"],"name":"result"}}],[11,"file_name","","Returns the bare file name of this directory entry without any other leading path component.",149,{"inputs":[{"name":"self"}],"output":{"name":"osstring"}}],[11,"fmt","","",149,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new set of options with default mode/security settings for all platforms and also non-recursive.",147,{"inputs":[],"output":{"name":"dirbuilder"}}],[11,"recursive","","Indicates that directories should be created recursively, creating all parent directories. Parents that do not exist are created with the same security and permissions settings.",147,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"self"}}],[11,"create","","Create the specified directory with the options configured in this builder.",147,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"result"}}],[0,"io","std","Traits, helpers, and type definitions for core I/O functionality.",null,null],[3,"BufReader","std::io","The `BufReader` struct adds buffering to any reader.",null,null],[3,"BufWriter","","Wraps a writer and buffers its output.",null,null],[3,"LineWriter","","Wraps a writer and buffers output to it, flushing whenever a newline (`0x0a`, `'\\n'`) is detected.",null,null],[3,"IntoInnerError","","An error returned by `into_inner` which combines an error that happened while writing out the buffer, and the buffered writer object which may be used to recover from the condition.",null,null],[3,"Cursor","","A `Cursor` wraps another type and provides it with a [`Seek`] implementation.",null,null],[3,"Error","","The error type for I/O operations of the [`Read`], [`Write`], [`Seek`], and associated traits.",null,null],[3,"Sink","","A writer which will move data into the void.",null,null],[3,"Empty","","A reader which is always at EOF.",null,null],[3,"Repeat","","A reader which yields one byte over and over and over and over and over and...",null,null],[3,"Stdin","","A handle to the standard input stream of a process.",null,null],[3,"Stdout","","A handle to the global standard output stream of the current process.",null,null],[3,"Stderr","","A handle to the standard error stream of a process.",null,null],[3,"StdoutLock","","A locked reference to the `Stdout` handle.",null,null],[3,"StderrLock","","A locked reference to the `Stderr` handle.",null,null],[3,"StdinLock","","A locked reference to the `Stdin` handle.",null,null],[3,"Initializer","","A type used to conditionally initialize buffers passed to `Read` methods.",null,null],[3,"Chain","","Adaptor to chain together two readers.",null,null],[3,"Take","","Reader adaptor which limits the bytes read from an underlying reader.",null,null],[3,"Bytes","","An iterator over `u8` values of a reader.",null,null],[3,"Chars","","An iterator over the `char`s of a reader.",null,null],[3,"Split","","An iterator over the contents of an instance of `BufRead` split on a particular byte.",null,null],[3,"Lines","","An iterator over the lines of an instance of `BufRead`.",null,null],[4,"ErrorKind","","A list specifying general categories of I/O error.",null,null],[13,"NotFound","","An entity was not found, often a file.",150,null],[13,"PermissionDenied","","The operation lacked the necessary privileges to complete.",150,null],[13,"ConnectionRefused","","The connection was refused by the remote server.",150,null],[13,"ConnectionReset","","The connection was reset by the remote server.",150,null],[13,"ConnectionAborted","","The connection was aborted (terminated) by the remote server.",150,null],[13,"NotConnected","","The network operation failed because it was not connected yet.",150,null],[13,"AddrInUse","","A socket address could not be bound because the address is already in use elsewhere.",150,null],[13,"AddrNotAvailable","","A nonexistent interface was requested or the requested address was not local.",150,null],[13,"BrokenPipe","","The operation failed because a pipe was closed.",150,null],[13,"AlreadyExists","","An entity already exists, often a file.",150,null],[13,"WouldBlock","","The operation needs to block to complete, but the blocking operation was requested to not occur.",150,null],[13,"InvalidInput","","A parameter was incorrect.",150,null],[13,"InvalidData","","Data not valid for the operation were encountered.",150,null],[13,"TimedOut","","The I/O operation's timeout expired, causing it to be canceled.",150,null],[13,"WriteZero","","An error returned when an operation could not be completed because a call to [`write`] returned [`Ok(0)`].",150,null],[13,"Interrupted","","This operation was interrupted.",150,null],[13,"Other","","Any I/O error not part of this list.",150,null],[13,"UnexpectedEof","","An error returned when an operation could not be completed because an \"end of file\" was reached prematurely.",150,null],[4,"SeekFrom","","Enumeration of possible methods to seek within an I/O object.",null,null],[13,"Start","","Set the offset to the provided number of bytes.",151,null],[13,"End","","Set the offset to the size of this object plus the specified number of bytes.",151,null],[13,"Current","","Set the offset to the current position plus the specified number of bytes.",151,null],[4,"CharsError","","An enumeration of possible errors that can be generated from the `Chars` adapter.",null,null],[13,"NotUtf8","","Variant representing that the underlying stream was read successfully but it did not contain valid utf8 data.",152,null],[13,"Other","","Variant representing that an I/O error occurred.",152,null],[5,"copy","","Copies the entire contents of a reader into a writer.",null,{"inputs":[{"name":"r"},{"name":"w"}],"output":{"generics":["u64"],"name":"result"}}],[5,"sink","","Creates an instance of a writer which will successfully consume all data.",null,{"inputs":[],"output":{"name":"sink"}}],[5,"empty","","Constructs a new handle to an empty reader.",null,{"inputs":[],"output":{"name":"empty"}}],[5,"repeat","","Creates an instance of a reader that infinitely repeats one byte.",null,{"inputs":[{"name":"u8"}],"output":{"name":"repeat"}}],[5,"stdin","","Constructs a new handle to the standard input of the current process.",null,{"inputs":[],"output":{"name":"stdin"}}],[5,"stdout","","Constructs a new handle to the standard output of the current process.",null,{"inputs":[],"output":{"name":"stdout"}}],[5,"stderr","","Constructs a new handle to the standard error of the current process.",null,{"inputs":[],"output":{"name":"stderr"}}],[0,"prelude","","The I/O Prelude",null,null],[11,"new","","Creates a new `BufReader` with a default buffer capacity.",153,{"inputs":[{"name":"r"}],"output":{"name":"bufreader"}}],[11,"with_capacity","","Creates a new `BufReader` with the specified buffer capacity.",153,{"inputs":[{"name":"usize"},{"name":"r"}],"output":{"name":"bufreader"}}],[11,"get_ref","","Gets a reference to the underlying reader.",153,{"inputs":[{"name":"self"}],"output":{"name":"r"}}],[11,"get_mut","","Gets a mutable reference to the underlying reader.",153,{"inputs":[{"name":"self"}],"output":{"name":"r"}}],[11,"is_empty","","Returns `true` if there are no bytes in the internal buffer.",153,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"buffer","","Returns a reference to the internally buffered data.",153,null],[11,"into_inner","","Unwraps this `BufReader`, returning the underlying reader.",153,{"inputs":[{"name":"self"}],"output":{"name":"r"}}],[11,"seek_relative","","Seeks relative to the current position. If the new position lies within the buffer, the buffer will not be flushed, allowing for more efficient seeks. This method does not return the location of the underlying reader, so the caller must track this information themselves if it is required.",153,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"result"}}],[11,"read","","",153,null],[11,"initializer","","",153,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fill_buf","","",153,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",153,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"fmt","","",153,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"seek","","Seek to an offset, in bytes, in the underlying reader.",153,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"generics":["u64"],"name":"result"}}],[11,"fmt","","",154,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new `BufWriter` with a default buffer capacity.",155,{"inputs":[{"name":"w"}],"output":{"name":"bufwriter"}}],[11,"with_capacity","","Creates a new `BufWriter` with the specified buffer capacity.",155,{"inputs":[{"name":"usize"},{"name":"w"}],"output":{"name":"bufwriter"}}],[11,"get_ref","","Gets a reference to the underlying writer.",155,{"inputs":[{"name":"self"}],"output":{"name":"w"}}],[11,"get_mut","","Gets a mutable reference to the underlying writer.",155,{"inputs":[{"name":"self"}],"output":{"name":"w"}}],[11,"into_inner","","Unwraps this `BufWriter`, returning the underlying writer.",155,{"inputs":[{"name":"self"}],"output":{"generics":["intoinnererror"],"name":"result"}}],[11,"write","","",155,null],[11,"flush","","",155,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",155,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"seek","","Seek to the offset, in bytes, in the underlying writer.",155,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"generics":["u64"],"name":"result"}}],[11,"drop","","",155,{"inputs":[{"name":"self"}],"output":null}],[11,"error","","Returns the error which caused the call to `into_inner()` to fail.",154,{"inputs":[{"name":"self"}],"output":{"name":"error"}}],[11,"into_inner","","Returns the buffered writer instance which generated the error.",154,{"inputs":[{"name":"self"}],"output":{"name":"w"}}],[11,"from","","",156,{"inputs":[{"name":"intoinnererror"}],"output":{"name":"error"}}],[11,"description","","",154,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"fmt","","",154,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new `LineWriter`.",157,{"inputs":[{"name":"w"}],"output":{"name":"linewriter"}}],[11,"with_capacity","","Creates a new `LineWriter` with a specified capacity for the internal buffer.",157,{"inputs":[{"name":"usize"},{"name":"w"}],"output":{"name":"linewriter"}}],[11,"get_ref","","Gets a reference to the underlying writer.",157,{"inputs":[{"name":"self"}],"output":{"name":"w"}}],[11,"get_mut","","Gets a mutable reference to the underlying writer.",157,{"inputs":[{"name":"self"}],"output":{"name":"w"}}],[11,"into_inner","","Unwraps this `LineWriter`, returning the underlying writer.",157,{"inputs":[{"name":"self"}],"output":{"generics":["intoinnererror"],"name":"result"}}],[11,"write","","",157,null],[11,"flush","","",157,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",157,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",158,{"inputs":[{"name":"self"}],"output":{"name":"cursor"}}],[11,"fmt","","",158,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new cursor wrapping the provided underlying I/O object.",158,{"inputs":[{"name":"t"}],"output":{"name":"cursor"}}],[11,"into_inner","","Consumes this cursor, returning the underlying value.",158,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get_ref","","Gets a reference to the underlying value in this cursor.",158,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get_mut","","Gets a mutable reference to the underlying value in this cursor.",158,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"position","","Returns the current position of this cursor.",158,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"set_position","","Sets the position of this cursor.",158,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"seek","","",158,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"generics":["u64"],"name":"result"}}],[11,"read","","",158,null],[11,"read_exact","","",158,null],[11,"initializer","","",158,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fill_buf","","",158,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",158,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"write","","",158,null],[11,"flush","","",158,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write","","",158,null],[11,"flush","","",158,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write","","",158,null],[11,"flush","","",158,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write","","",158,null],[11,"flush","","",158,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",156,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",150,{"inputs":[{"name":"self"}],"output":{"name":"errorkind"}}],[11,"fmt","","",150,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",150,null],[11,"cmp","","",150,{"inputs":[{"name":"self"},{"name":"errorkind"}],"output":{"name":"ordering"}}],[11,"eq","","",150,{"inputs":[{"name":"self"},{"name":"errorkind"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",150,{"inputs":[{"name":"self"},{"name":"errorkind"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"from","","",156,{"inputs":[{"name":"errorkind"}],"output":{"name":"error"}}],[11,"new","","Creates a new I/O error from a known kind of error as well as an arbitrary error payload.",156,{"inputs":[{"name":"errorkind"},{"name":"e"}],"output":{"name":"error"}}],[11,"last_os_error","","Returns an error representing the last OS error which occurred.",156,{"inputs":[],"output":{"name":"error"}}],[11,"from_raw_os_error","","Creates a new instance of an `Error` from a particular OS error code.",156,{"inputs":[{"name":"i32"}],"output":{"name":"error"}}],[11,"raw_os_error","","Returns the OS error that this error represents (if any).",156,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"option"}}],[11,"get_ref","","Returns a reference to the inner error wrapped by this error (if any).",156,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"get_mut","","Returns a mutable reference to the inner error wrapped by this error (if any).",156,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"into_inner","","Consumes the `Error`, returning its inner error (if any).",156,{"inputs":[{"name":"self"}],"output":{"generics":["box"],"name":"option"}}],[11,"kind","","Returns the corresponding `ErrorKind` for this error.",156,{"inputs":[{"name":"self"}],"output":{"name":"errorkind"}}],[11,"fmt","","",156,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",156,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",156,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"read","std::boxed","",120,null],[11,"initializer","","",120,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"read_to_end","","",120,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_to_string","","",120,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_exact","","",120,null],[11,"write","","",120,null],[11,"flush","","",120,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write_all","","",120,null],[11,"write_fmt","","",120,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"seek","","",120,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"generics":["u64"],"name":"result"}}],[11,"fill_buf","","",120,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",120,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"read_until","","",120,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_line","","",120,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"write","std::vec","",137,null],[11,"write_all","","",137,null],[11,"flush","","",137,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"read","std::io","",159,null],[11,"initializer","","",159,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fill_buf","","",159,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",159,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"fmt","","",159,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"read","","",160,null],[11,"initializer","","",160,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fmt","","",160,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"write","","",161,null],[11,"flush","","",161,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",161,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"lock","","Locks this handle to the standard input stream, returning a readable guard.",162,{"inputs":[{"name":"self"}],"output":{"name":"stdinlock"}}],[11,"read_line","","Locks this handle and reads a line of input into the specified buffer.",162,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"fmt","","",162,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"read","","",162,null],[11,"initializer","","",162,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"read_to_end","","",162,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_to_string","","",162,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_exact","","",162,null],[11,"read","","",163,null],[11,"initializer","","",163,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fill_buf","","",163,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",163,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"fmt","","",163,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"lock","","Locks this handle to the standard output stream, returning a writable guard.",164,{"inputs":[{"name":"self"}],"output":{"name":"stdoutlock"}}],[11,"fmt","","",164,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"write","","",164,null],[11,"flush","","",164,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write_all","","",164,null],[11,"write_fmt","","",164,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"write","","",165,null],[11,"flush","","",165,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",165,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"lock","","Locks this handle to the standard error stream, returning a writable guard.",166,{"inputs":[{"name":"self"}],"output":{"name":"stderrlock"}}],[11,"fmt","","",166,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"write","","",166,null],[11,"flush","","",166,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write_all","","",166,null],[11,"write_fmt","","",166,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"write","","",167,null],[11,"flush","","",167,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",167,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[6,"Result","","A specialized `Result` type for I/O operations.",null,null],[8,"Read","","The `Read` trait allows for reading bytes from a source.",null,null],[10,"read","","Pull some bytes from this source into the specified buffer, returning how many bytes were read.",168,null],[11,"initializer","","Determines if this `Read`er can work with buffers of uninitialized memory.",168,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"read_to_end","","Read all bytes until EOF in this source, placing them into `buf`.",168,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_to_string","","Read all bytes until EOF in this source, appending them to `buf`.",168,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_exact","","Read the exact number of bytes required to fill `buf`.",168,null],[11,"by_ref","","Creates a \"by reference\" adaptor for this instance of `Read`.",168,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[11,"bytes","","Transforms this `Read` instance to an [`Iterator`] over its bytes.",168,{"inputs":[{"name":"self"}],"output":{"name":"bytes"}}],[11,"chars","","Transforms this `Read` instance to an [`Iterator`] over [`char`]s.",168,{"inputs":[{"name":"self"}],"output":{"name":"chars"}}],[11,"chain","","Creates an adaptor which will chain this stream with another.",168,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"chain"}}],[11,"take","","Creates an adaptor which will read at most `limit` bytes from it.",168,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"take"}}],[8,"Write","","A trait for objects which are byte-oriented sinks.",null,null],[10,"write","","Write a buffer into this object, returning how many bytes were written.",169,null],[10,"flush","","Flush this output stream, ensuring that all intermediately buffered contents reach their destination.",169,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write_all","","Attempts to write an entire buffer into this write.",169,null],[11,"write_fmt","","Writes a formatted string into this writer, returning any error encountered.",169,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"by_ref","","Creates a \"by reference\" adaptor for this instance of `Write`.",169,{"inputs":[{"name":"self"}],"output":{"name":"self"}}],[8,"Seek","","The `Seek` trait provides a cursor which can be moved within a stream of bytes.",null,null],[10,"seek","","Seek to an offset, in bytes, in a stream.",170,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"generics":["u64"],"name":"result"}}],[8,"BufRead","","A `BufRead` is a type of `Read`er which has an internal buffer, allowing it to perform extra ways of reading.",null,null],[10,"fill_buf","","Fills the internal buffer of this object, returning the buffer contents.",171,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[10,"consume","","Tells this buffer that `amt` bytes have been consumed from the buffer, so they should no longer be returned in calls to `read`.",171,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"read_until","","Read all bytes into `buf` until the delimiter `byte` or EOF is reached.",171,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_line","","Read all bytes until a newline (the 0xA byte) is reached, and append them to the provided buffer.",171,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"split","","Returns an iterator over the contents of this reader split on the byte `byte`.",171,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"split"}}],[11,"lines","","Returns an iterator over the lines of this reader.",171,{"inputs":[{"name":"self"}],"output":{"name":"lines"}}],[11,"fmt","","",172,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"zeroing","","Returns a new `Initializer` which will zero out buffers.",172,{"inputs":[],"output":{"name":"initializer"}}],[11,"nop","","Returns a new `Initializer` which will not zero out buffers.",172,{"inputs":[],"output":{"name":"initializer"}}],[11,"should_initialize","","Indicates if a buffer should be initialized.",172,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"initialize","","Initializes a buffer if necessary.",172,null],[11,"eq","","",151,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"name":"bool"}}],[11,"ne","","",151,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"name":"bool"}}],[11,"clone","","",151,{"inputs":[{"name":"self"}],"output":{"name":"seekfrom"}}],[11,"fmt","","",151,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"into_inner","","Consumes the `Chain`, returning the wrapped readers.",173,null],[11,"get_ref","","Gets references to the underlying readers in this `Chain`.",173,null],[11,"get_mut","","Gets mutable references to the underlying readers in this `Chain`.",173,null],[11,"fmt","","",173,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"read","","",173,null],[11,"initializer","","",173,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fill_buf","","",173,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",173,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"fmt","","",174,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"limit","","Returns the number of bytes that can be read before this instance will return EOF.",174,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"set_limit","","Sets the number of bytes that can be read before this instance will return EOF. This is the same as constructing a new `Take` instance, so the amount of bytes read and the previous limit value don't matter when calling this method.",174,{"inputs":[{"name":"self"},{"name":"u64"}],"output":null}],[11,"into_inner","","Consumes the `Take`, returning the wrapped reader.",174,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get_ref","","Gets a reference to the underlying reader.",174,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get_mut","","Gets a mutable reference to the underlying reader.",174,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"read","","",174,null],[11,"initializer","","",174,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fill_buf","","",174,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",174,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"fmt","","",175,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",175,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"fmt","","",176,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",152,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",176,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"description","","",152,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",152,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"fmt","","",152,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",177,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",177,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"fmt","","",178,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",178,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[0,"net","std","Networking primitives for TCP/UDP communication.",null,null],[3,"Ipv4Addr","std::net","An IPv4 address.",null,null],[3,"Ipv6Addr","","An IPv6 address.",null,null],[3,"SocketAddrV4","","An IPv4 socket address.",null,null],[3,"SocketAddrV6","","An IPv6 socket address.",null,null],[3,"TcpStream","","A TCP stream between a local and a remote socket.",null,null],[3,"TcpListener","","A TCP socket server, listening for connections.",null,null],[3,"Incoming","","An iterator that infinitely [`accept`]s connections on a [`TcpListener`].",null,null],[3,"UdpSocket","","A UDP socket.",null,null],[3,"AddrParseError","","An error which can be returned when parsing an IP address or a socket address.",null,null],[3,"LookupHost","","An iterator over `SocketAddr` values returned from a host lookup operation.",null,null],[4,"IpAddr","","An IP address, either IPv4 or IPv6.",null,null],[13,"V4","","An IPv4 address.",179,null],[13,"V6","","An IPv6 address.",179,null],[4,"Ipv6MulticastScope","","",null,null],[13,"InterfaceLocal","","",180,null],[13,"LinkLocal","","",180,null],[13,"RealmLocal","","",180,null],[13,"AdminLocal","","",180,null],[13,"SiteLocal","","",180,null],[13,"OrganizationLocal","","",180,null],[13,"Global","","",180,null],[4,"SocketAddr","","An internet socket address, either IPv4 or IPv6.",null,null],[13,"V4","","An IPv4 socket address.",181,null],[13,"V6","","An IPv6 socket address.",181,null],[4,"Shutdown","","Possible values which can be passed to the [`shutdown`] method of [`TcpStream`].",null,null],[13,"Read","","The reading portion of the [`TcpStream`] should be shut down.",182,null],[13,"Write","","The writing portion of the [`TcpStream`] should be shut down.",182,null],[13,"Both","","Both the reading and the writing portions of the [`TcpStream`] should be shut down.",182,null],[5,"lookup_host","","Resolve the host specified by `host` as a number of `SocketAddr` instances.",null,{"inputs":[{"name":"str"}],"output":{"generics":["lookuphost"],"name":"result"}}],[11,"clone","","",179,{"inputs":[{"name":"self"}],"output":{"name":"ipaddr"}}],[11,"eq","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"ne","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"fmt","","",179,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",179,null],[11,"partial_cmp","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"le","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"gt","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"ge","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"cmp","","",179,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"ordering"}}],[11,"eq","","",180,{"inputs":[{"name":"self"},{"name":"ipv6multicastscope"}],"output":{"name":"bool"}}],[11,"clone","","",180,{"inputs":[{"name":"self"}],"output":{"name":"ipv6multicastscope"}}],[11,"hash","","",180,null],[11,"fmt","","",180,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"is_unspecified","","Returns [`true`] for the special 'unspecified' address.",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_loopback","","Returns [`true`] if this is a loopback address.",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_global","","Returns [`true`] if the address appears to be globally routable.",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_multicast","","Returns [`true`] if this is a multicast address.",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_documentation","","Returns [`true`] if this address is in a range designated for documentation.",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ipv4","","Returns [`true`] if this address is an [IPv4 address], and [`false`] otherwise.",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ipv6","","Returns [`true`] if this address is an [IPv6 address], and [`false`] otherwise.",179,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"new","","Creates a new IPv4 address from four eight-bit octets.",183,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"ipv4addr"}}],[11,"localhost","","Creates a new IPv4 address with the address pointing to localhost: 127.0.0.1.",183,{"inputs":[],"output":{"name":"ipv4addr"}}],[11,"unspecified","","Creates a new IPv4 address representing an unspecified address: 0.0.0.0",183,{"inputs":[],"output":{"name":"ipv4addr"}}],[11,"octets","","Returns the four eight-bit integers that make up this address.",183,null],[11,"is_unspecified","","Returns [`true`] for the special 'unspecified' address (0.0.0.0).",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_loopback","","Returns [`true`] if this is a loopback address (127.0.0.0/8).",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_private","","Returns [`true`] if this is a private address.",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_link_local","","Returns [`true`] if the address is link-local (169.254.0.0/16).",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_global","","Returns [`true`] if the address appears to be globally routable. See [iana-ipv4-special-registry][ipv4-sr].",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_multicast","","Returns [`true`] if this is a multicast address (224.0.0.0/4).",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_broadcast","","Returns [`true`] if this is a broadcast address (255.255.255.255).",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_documentation","","Returns [`true`] if this address is in a range designated for documentation.",183,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ipv6_compatible","","Converts this address to an IPv4-compatible [IPv6 address].",183,{"inputs":[{"name":"self"}],"output":{"name":"ipv6addr"}}],[11,"to_ipv6_mapped","","Converts this address to an IPv4-mapped [IPv6 address].",183,{"inputs":[{"name":"self"}],"output":{"name":"ipv6addr"}}],[11,"fmt","","",179,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",179,{"inputs":[{"name":"ipv4addr"}],"output":{"name":"ipaddr"}}],[11,"from","","",179,{"inputs":[{"name":"ipv6addr"}],"output":{"name":"ipaddr"}}],[11,"fmt","","",183,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",183,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",183,{"inputs":[{"name":"self"}],"output":{"name":"ipv4addr"}}],[11,"eq","","",183,{"inputs":[{"name":"self"},{"name":"ipv4addr"}],"output":{"name":"bool"}}],[11,"eq","","",179,{"inputs":[{"name":"self"},{"name":"ipv4addr"}],"output":{"name":"bool"}}],[11,"eq","","",183,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"hash","","",183,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"partial_cmp","","",183,{"inputs":[{"name":"self"},{"name":"ipv4addr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",179,{"inputs":[{"name":"self"},{"name":"ipv4addr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",183,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",183,{"inputs":[{"name":"self"},{"name":"ipv4addr"}],"output":{"name":"ordering"}}],[11,"from","","Convert a host byte order `u32` into an `Ipv4Addr`.",183,{"inputs":[{"name":"u32"}],"output":{"name":"ipv4addr"}}],[11,"from","","Examples",183,null],[11,"from","","Create an `IpAddr::V4` from a four element byte array.",179,null],[11,"new","","Creates a new IPv6 address from eight 16-bit segments.",184,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"ipv6addr"}}],[11,"localhost","","Creates a new IPv6 address representing localhost: `::1`.",184,{"inputs":[],"output":{"name":"ipv6addr"}}],[11,"unspecified","","Creates a new IPv6 address representing the unspecified address: `::`",184,{"inputs":[],"output":{"name":"ipv6addr"}}],[11,"segments","","Returns the eight 16-bit segments that make up this address.",184,null],[11,"is_unspecified","","Returns [`true`] for the special 'unspecified' address (::).",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_loopback","","Returns [`true`] if this is a loopback address (::1).",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_global","","Returns [`true`] if the address appears to be globally routable.",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_unique_local","","Returns [`true`] if this is a unique local address (fc00::/7).",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_unicast_link_local","","Returns [`true`] if the address is unicast and link-local (fe80::/10).",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_unicast_site_local","","Returns [`true`] if this is a deprecated unicast site-local address (fec0::/10).",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_documentation","","Returns [`true`] if this is an address reserved for documentation (2001:db8::/32).",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_unicast_global","","Returns [`true`] if the address is a globally routable unicast address.",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"multicast_scope","","Returns the address's multicast scope if the address is multicast.",184,{"inputs":[{"name":"self"}],"output":{"generics":["ipv6multicastscope"],"name":"option"}}],[11,"is_multicast","","Returns [`true`] if this is a multicast address (ff00::/8).",184,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ipv4","","Converts this address to an [IPv4 address]. Returns [`None`] if this address is neither IPv4-compatible or IPv4-mapped.",184,{"inputs":[{"name":"self"}],"output":{"generics":["ipv4addr"],"name":"option"}}],[11,"octets","","Returns the sixteen eight-bit integers the IPv6 address consists of.",184,null],[11,"fmt","","",184,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",184,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",184,{"inputs":[{"name":"self"}],"output":{"name":"ipv6addr"}}],[11,"eq","","",184,{"inputs":[{"name":"self"},{"name":"ipv6addr"}],"output":{"name":"bool"}}],[11,"eq","","",184,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"name":"bool"}}],[11,"eq","","",179,{"inputs":[{"name":"self"},{"name":"ipv6addr"}],"output":{"name":"bool"}}],[11,"hash","","",184,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"partial_cmp","","",184,{"inputs":[{"name":"self"},{"name":"ipv6addr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",179,{"inputs":[{"name":"self"},{"name":"ipv6addr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",184,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",184,{"inputs":[{"name":"self"},{"name":"ipv6addr"}],"output":{"name":"ordering"}}],[11,"from","","",184,{"inputs":[{"name":"u128"}],"output":{"name":"ipv6addr"}}],[11,"from","","",184,null],[11,"from","","",184,null],[11,"from","","Create an `IpAddr::V6` from a sixteen element byte array.",179,null],[11,"from","","Create an `IpAddr::V6` from an eight element 16-bit array.",179,null],[11,"clone","","",181,{"inputs":[{"name":"self"}],"output":{"name":"socketaddr"}}],[11,"eq","","",181,{"inputs":[{"name":"self"},{"name":"socketaddr"}],"output":{"name":"bool"}}],[11,"ne","","",181,{"inputs":[{"name":"self"},{"name":"socketaddr"}],"output":{"name":"bool"}}],[11,"hash","","",181,null],[11,"fmt","","",181,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new socket address from an [IP address] and a port number.",181,{"inputs":[{"name":"ipaddr"},{"name":"u16"}],"output":{"name":"socketaddr"}}],[11,"ip","","Returns the IP address associated with this socket address.",181,{"inputs":[{"name":"self"}],"output":{"name":"ipaddr"}}],[11,"set_ip","","Changes the IP address associated with this socket address.",181,{"inputs":[{"name":"self"},{"name":"ipaddr"}],"output":null}],[11,"port","","Returns the port number associated with this socket address.",181,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"set_port","","Changes the port number associated with this socket address.",181,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"is_ipv4","","Returns [`true`] if the [IP address] in this `SocketAddr` is an [IPv4 address], and [`false`] otherwise.",181,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ipv6","","Returns [`true`] if the [IP address] in this `SocketAddr` is an [IPv6 address], and [`false`] otherwise.",181,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"new","","Creates a new socket address from an [IPv4 address] and a port number.",185,{"inputs":[{"name":"ipv4addr"},{"name":"u16"}],"output":{"name":"socketaddrv4"}}],[11,"ip","","Returns the IP address associated with this socket address.",185,{"inputs":[{"name":"self"}],"output":{"name":"ipv4addr"}}],[11,"set_ip","","Changes the IP address associated with this socket address.",185,{"inputs":[{"name":"self"},{"name":"ipv4addr"}],"output":null}],[11,"port","","Returns the port number associated with this socket address.",185,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"set_port","","Changes the port number associated with this socket address.",185,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"new","","Creates a new socket address from an [IPv6 address], a 16-bit port number, and the `flowinfo` and `scope_id` fields.",186,{"inputs":[{"name":"ipv6addr"},{"name":"u16"},{"name":"u32"},{"name":"u32"}],"output":{"name":"socketaddrv6"}}],[11,"ip","","Returns the IP address associated with this socket address.",186,{"inputs":[{"name":"self"}],"output":{"name":"ipv6addr"}}],[11,"set_ip","","Changes the IP address associated with this socket address.",186,{"inputs":[{"name":"self"},{"name":"ipv6addr"}],"output":null}],[11,"port","","Returns the port number associated with this socket address.",186,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"set_port","","Changes the port number associated with this socket address.",186,{"inputs":[{"name":"self"},{"name":"u16"}],"output":null}],[11,"flowinfo","","Returns the flow information associated with this address.",186,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"set_flowinfo","","Changes the flow information associated with this socket address.",186,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"scope_id","","Returns the scope ID associated with this address.",186,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"set_scope_id","","Change the scope ID associated with this socket address.",186,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"from","","",181,{"inputs":[{"name":"socketaddrv4"}],"output":{"name":"socketaddr"}}],[11,"from","","",181,{"inputs":[{"name":"socketaddrv6"}],"output":{"name":"socketaddr"}}],[11,"from","","",181,null],[11,"fmt","","",181,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",185,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",185,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",186,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",186,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",185,{"inputs":[{"name":"self"}],"output":{"name":"socketaddrv4"}}],[11,"clone","","",186,{"inputs":[{"name":"self"}],"output":{"name":"socketaddrv6"}}],[11,"eq","","",185,{"inputs":[{"name":"self"},{"name":"socketaddrv4"}],"output":{"name":"bool"}}],[11,"eq","","",186,{"inputs":[{"name":"self"},{"name":"socketaddrv6"}],"output":{"name":"bool"}}],[11,"hash","","",185,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"hash","","",186,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"to_socket_addrs","","",181,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","","",185,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","","",186,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","std::string","",141,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"fmt","std::net","",187,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"connect","","Opens a TCP connection to a remote host.",188,{"inputs":[{"name":"a"}],"output":{"generics":["tcpstream"],"name":"result"}}],[11,"connect_timeout","","Opens a TCP connection to a remote host with a timeout.",188,{"inputs":[{"name":"socketaddr"},{"name":"duration"}],"output":{"generics":["tcpstream"],"name":"result"}}],[11,"peer_addr","","Returns the socket address of the remote peer of this TCP connection.",188,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"local_addr","","Returns the socket address of the local half of this TCP connection.",188,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"shutdown","","Shuts down the read, write, or both halves of this connection.",188,{"inputs":[{"name":"self"},{"name":"shutdown"}],"output":{"name":"result"}}],[11,"try_clone","","Creates a new independently owned handle to the underlying socket.",188,{"inputs":[{"name":"self"}],"output":{"generics":["tcpstream"],"name":"result"}}],[11,"set_read_timeout","","Sets the read timeout to the timeout specified.",188,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"set_write_timeout","","Sets the write timeout to the timeout specified.",188,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"read_timeout","","Returns the read timeout of this socket.",188,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"write_timeout","","Returns the write timeout of this socket.",188,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"peek","","Receives data on the socket from the remote address to which it is connected, without removing that data from the queue. On success, returns the number of bytes peeked.",188,null],[11,"set_nodelay","","Sets the value of the `TCP_NODELAY` option on this socket.",188,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"nodelay","","Gets the value of the `TCP_NODELAY` option on this socket.",188,{"inputs":[{"name":"self"}],"output":{"generics":["bool"],"name":"result"}}],[11,"set_ttl","","Sets the value for the `IP_TTL` option on this socket.",188,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"result"}}],[11,"ttl","","Gets the value of the `IP_TTL` option for this socket.",188,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"result"}}],[11,"take_error","","Get the value of the `SO_ERROR` option on this socket.",188,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"set_nonblocking","","Moves this TCP stream into or out of nonblocking mode.",188,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"read","","",188,null],[11,"initializer","","",188,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"write","","",188,null],[11,"flush","","",188,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",188,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"bind","","Creates a new `TcpListener` which will be bound to the specified address.",189,{"inputs":[{"name":"a"}],"output":{"generics":["tcplistener"],"name":"result"}}],[11,"local_addr","","Returns the local socket address of this listener.",189,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"try_clone","","Creates a new independently owned handle to the underlying socket.",189,{"inputs":[{"name":"self"}],"output":{"generics":["tcplistener"],"name":"result"}}],[11,"accept","","Accept a new incoming connection from this listener.",189,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"incoming","","Returns an iterator over the connections being received on this listener.",189,{"inputs":[{"name":"self"}],"output":{"name":"incoming"}}],[11,"set_ttl","","Sets the value for the `IP_TTL` option on this socket.",189,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"result"}}],[11,"ttl","","Gets the value of the `IP_TTL` option for this socket.",189,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"result"}}],[11,"set_only_v6","","",189,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"only_v6","","",189,{"inputs":[{"name":"self"}],"output":{"generics":["bool"],"name":"result"}}],[11,"take_error","","Get the value of the `SO_ERROR` option on this socket.",189,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"set_nonblocking","","Moves this TCP stream into or out of nonblocking mode.",189,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"next","","",187,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"fmt","","",189,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"bind","","Creates a UDP socket from the given address.",190,{"inputs":[{"name":"a"}],"output":{"generics":["udpsocket"],"name":"result"}}],[11,"recv_from","","Receives a single datagram message on the socket. On success, returns the number of bytes read and the origin.",190,null],[11,"peek_from","","Receives a single datagram message on the socket, without removing it from the queue. On success, returns the number of bytes read and the origin.",190,null],[11,"send_to","","Sends data on the socket to the given address. On success, returns the number of bytes written.",190,null],[11,"local_addr","","Returns the socket address that this socket was created from.",190,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"try_clone","","Creates a new independently owned handle to the underlying socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["udpsocket"],"name":"result"}}],[11,"set_read_timeout","","Sets the read timeout to the timeout specified.",190,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"set_write_timeout","","Sets the write timeout to the timeout specified.",190,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"read_timeout","","Returns the read timeout of this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"write_timeout","","Returns the write timeout of this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"set_broadcast","","Sets the value of the `SO_BROADCAST` option for this socket.",190,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"broadcast","","Gets the value of the `SO_BROADCAST` option for this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["bool"],"name":"result"}}],[11,"set_multicast_loop_v4","","Sets the value of the `IP_MULTICAST_LOOP` option for this socket.",190,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"multicast_loop_v4","","Gets the value of the `IP_MULTICAST_LOOP` option for this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["bool"],"name":"result"}}],[11,"set_multicast_ttl_v4","","Sets the value of the `IP_MULTICAST_TTL` option for this socket.",190,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"result"}}],[11,"multicast_ttl_v4","","Gets the value of the `IP_MULTICAST_TTL` option for this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"result"}}],[11,"set_multicast_loop_v6","","Sets the value of the `IPV6_MULTICAST_LOOP` option for this socket.",190,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"multicast_loop_v6","","Gets the value of the `IPV6_MULTICAST_LOOP` option for this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["bool"],"name":"result"}}],[11,"set_ttl","","Sets the value for the `IP_TTL` option on this socket.",190,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"result"}}],[11,"ttl","","Gets the value of the `IP_TTL` option for this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"result"}}],[11,"join_multicast_v4","","Executes an operation of the `IP_ADD_MEMBERSHIP` type.",190,{"inputs":[{"name":"self"},{"name":"ipv4addr"},{"name":"ipv4addr"}],"output":{"name":"result"}}],[11,"join_multicast_v6","","Executes an operation of the `IPV6_ADD_MEMBERSHIP` type.",190,{"inputs":[{"name":"self"},{"name":"ipv6addr"},{"name":"u32"}],"output":{"name":"result"}}],[11,"leave_multicast_v4","","Executes an operation of the `IP_DROP_MEMBERSHIP` type.",190,{"inputs":[{"name":"self"},{"name":"ipv4addr"},{"name":"ipv4addr"}],"output":{"name":"result"}}],[11,"leave_multicast_v6","","Executes an operation of the `IPV6_DROP_MEMBERSHIP` type.",190,{"inputs":[{"name":"self"},{"name":"ipv6addr"},{"name":"u32"}],"output":{"name":"result"}}],[11,"take_error","","Get the value of the `SO_ERROR` option on this socket.",190,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"connect","","Connects this UDP socket to a remote address, allowing the `send` and `recv` syscalls to be used to send data and also applies filters to only receive data from the specified address.",190,{"inputs":[{"name":"self"},{"name":"a"}],"output":{"name":"result"}}],[11,"send","","Sends data on the socket to the remote address to which it is connected.",190,null],[11,"recv","","Receives a single datagram message on the socket from the remote address to which it is connected. On success, returns the number of bytes read.",190,null],[11,"peek","","Receives single datagram on the socket from the remote address to which it is connected, without removing the message from input queue. On success, returns the number of bytes peeked.",190,null],[11,"set_nonblocking","","Moves this UDP socket into or out of nonblocking mode.",190,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"fmt","","",190,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from_str","","",179,{"inputs":[{"name":"str"}],"output":{"generics":["ipaddr","addrparseerror"],"name":"result"}}],[11,"from_str","","",183,{"inputs":[{"name":"str"}],"output":{"generics":["ipv4addr","addrparseerror"],"name":"result"}}],[11,"from_str","","",184,{"inputs":[{"name":"str"}],"output":{"generics":["ipv6addr","addrparseerror"],"name":"result"}}],[11,"from_str","","",185,{"inputs":[{"name":"str"}],"output":{"generics":["socketaddrv4","addrparseerror"],"name":"result"}}],[11,"from_str","","",186,{"inputs":[{"name":"str"}],"output":{"generics":["socketaddrv6","addrparseerror"],"name":"result"}}],[11,"from_str","","",181,{"inputs":[{"name":"str"}],"output":{"generics":["socketaddr","addrparseerror"],"name":"result"}}],[11,"fmt","","",191,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",191,{"inputs":[{"name":"self"}],"output":{"name":"addrparseerror"}}],[11,"eq","","",191,{"inputs":[{"name":"self"},{"name":"addrparseerror"}],"output":{"name":"bool"}}],[11,"ne","","",191,{"inputs":[{"name":"self"},{"name":"addrparseerror"}],"output":{"name":"bool"}}],[11,"fmt","","",191,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",191,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[8,"ToSocketAddrs","","A trait for objects which can be converted or resolved to one or more [`SocketAddr`] values.",null,null],[16,"Iter","","Returned iterator over socket addresses which this type may correspond to.",192,null],[10,"to_socket_addrs","","Converts this object to an iterator of resolved `SocketAddr`s.",192,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"clone","","",182,{"inputs":[{"name":"self"}],"output":{"name":"shutdown"}}],[11,"eq","","",182,{"inputs":[{"name":"self"},{"name":"shutdown"}],"output":{"name":"bool"}}],[11,"fmt","","",182,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",193,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"option"}}],[11,"fmt","","",193,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"num","std","Additional functionality for numerics.",null,null],[4,"FpCategory","std::num","A classification of floating point numbers.",null,null],[13,"Nan","","\"Not a Number\", often obtained by dividing by zero.",194,null],[13,"Infinite","","Positive or negative infinity.",194,null],[13,"Zero","","Positive or negative zero.",194,null],[13,"Subnormal","","De-normalized floating point representation (less precise than `Normal`).",194,null],[13,"Normal","","A regular floating point number.",194,null],[3,"ParseIntError","","An error which can be returned when parsing an integer.",null,null],[3,"ParseFloatError","","An error which can be returned when parsing a float.",null,null],[3,"TryFromIntError","","The error type returned when a checked integral type conversion fails.",null,null],[3,"Wrapping","","Provides intentionally-wrapped arithmetic on `T`.",null,null],[12,"0","","",195,null],[3,"NonZeroU8","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI8","","An integer that is known not to equal zero.",null,null],[3,"NonZeroU16","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI16","","An integer that is known not to equal zero.",null,null],[3,"NonZeroU32","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI32","","An integer that is known not to equal zero.",null,null],[3,"NonZeroU64","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI64","","An integer that is known not to equal zero.",null,null],[3,"NonZeroU128","","An integer that is known not to equal zero.",null,null],[3,"NonZeroI128","","An integer that is known not to equal zero.",null,null],[3,"NonZeroUsize","","An integer that is known not to equal zero.",null,null],[3,"NonZeroIsize","","An integer that is known not to equal zero.",null,null],[0,"os","std","OS-specific functionality.",null,null],[0,"unix","std::os","Experimental extensions to `std` for Unix platforms.",null,null],[0,"io","std::os::unix","Unix-specific extensions to general I/O primitives",null,null],[6,"RawFd","std::os::unix::io","Raw file descriptors.",null,null],[8,"AsRawFd","","A trait to extract the raw unix file descriptor from an underlying object.",null,null],[10,"as_raw_fd","","Extracts the raw file descriptor.",196,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[8,"FromRawFd","","A trait to express the ability to construct an object from a raw file descriptor.",null,null],[10,"from_raw_fd","","Constructs a new instance of `Self` from the given raw file descriptor.",197,{"inputs":[{"name":"rawfd"}],"output":{"name":"self"}}],[8,"IntoRawFd","","A trait to express the ability to consume an object and acquire ownership of its raw file descriptor.",null,null],[10,"into_raw_fd","","Consumes this object, returning the raw underlying file descriptor.",198,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[0,"ffi","std::os::unix","Unix-specific extension to the primitives in the `std::ffi` module",null,null],[8,"OsStringExt","std::os::unix::ffi","Unix-specific extensions to `OsString`.",null,null],[10,"from_vec","","Creates an [`OsString`] from a byte vector.",199,{"inputs":[{"generics":["u8"],"name":"vec"}],"output":{"name":"self"}}],[10,"into_vec","","Yields the underlying byte vector of this [`OsString`].",199,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[8,"OsStrExt","","Unix-specific extensions to `OsStr`.",null,null],[10,"from_bytes","","Creates an [`OsStr`] from a byte slice.",200,null],[10,"as_bytes","","Gets the underlying byte view of the [`OsStr`] slice.",200,null],[0,"fs","std::os::unix","Unix-specific extensions to primitives in the `std::fs` module.",null,null],[5,"symlink","std::os::unix::fs","Creates a new symbolic link on the filesystem.",null,{"inputs":[{"name":"p"},{"name":"q"}],"output":{"name":"result"}}],[8,"FileExt","","Unix-specific extensions to [`File`].",null,null],[10,"read_at","","Reads a number of bytes starting from a given offset.",201,null],[10,"write_at","","Writes a number of bytes starting from a given offset.",201,null],[8,"PermissionsExt","","Unix-specific extensions to `Permissions`",null,null],[10,"mode","","Returns the underlying raw `st_mode` bits that contain the standard Unix permissions for this file.",202,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"set_mode","","Sets the underlying raw bits for this set of permissions.",202,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[10,"from_mode","","Creates a new instance of `Permissions` from the given set of Unix permission bits.",202,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[8,"OpenOptionsExt","","Unix-specific extensions to `OpenOptions`",null,null],[10,"mode","","Sets the mode bits that a new file will be created with.",203,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[10,"custom_flags","","Pass custom flags to the `flags` argument of `open`.",203,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"self"}}],[8,"MetadataExt","","",null,null],[10,"dev","","Returns the ID of the device containing the file.",204,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"ino","","Returns the inode number.",204,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"mode","","Returns the rights applied to this file.",204,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"nlink","","Returns the number of hard links pointing to this file.",204,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"uid","","Returns the user ID of the owner of this file.",204,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"gid","","Returns the group ID of the owner of this file.",204,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"rdev","","Returns the device ID of this file (if it is a special one).",204,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"size","","Returns the total size of this file in bytes.",204,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"atime","","Returns the time of the last access to the file.",204,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"atime_nsec","","Returns the time of the last access to the file in nanoseconds.",204,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"mtime","","Returns the time of the last modification of the file.",204,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"mtime_nsec","","Returns the time of the last modification of the file in nanoseconds.",204,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"ctime","","Returns the time of the last status change of the file.",204,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"ctime_nsec","","Returns the time of the last status change of the file in nanoseconds.",204,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"blksize","","Returns the blocksize for filesystem I/O.",204,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"blocks","","Returns the number of blocks allocated to the file, in 512-byte units.",204,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[8,"FileTypeExt","","Add support for special unix types (block/char device, fifo and socket).",null,null],[10,"is_block_device","","Returns whether this file type is a block device.",205,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"is_char_device","","Returns whether this file type is a char device.",205,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"is_fifo","","Returns whether this file type is a fifo.",205,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"is_socket","","Returns whether this file type is a socket.",205,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[8,"DirEntryExt","","Unix-specific extension methods for [`fs::DirEntry`].",null,null],[10,"ino","","Returns the underlying `d_ino` field in the contained `dirent` structure.",206,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[8,"DirBuilderExt","","An extension trait for [`fs::DirBuilder`] for unix-specific options.",null,null],[10,"mode","","Sets the mode to create new directories with. This option defaults to 0o777.",207,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[0,"process","std::os::unix","Unix-specific extensions to primitives in the `std::process` module.",null,null],[5,"parent_id","std::os::unix::process","Returns the OS-assigned process identifier associated with this process's parent.",null,{"inputs":[],"output":{"name":"u32"}}],[8,"CommandExt","","Unix-specific extensions to the `std::process::Command` builder",null,null],[10,"uid","","Sets the child process's user id. This translates to a `setuid` call in the child process. Failure in the `setuid` call will cause the spawn to fail.",208,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"command"}}],[10,"gid","","Similar to `uid`, but sets the group id of the child process. This has the same semantics as the `uid` field.",208,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"command"}}],[10,"before_exec","","Schedules a closure to be run just before the `exec` function is invoked.",208,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"command"}}],[10,"exec","","Performs all the required setup by this `Command`, followed by calling the `execvp` syscall.",208,{"inputs":[{"name":"self"}],"output":{"name":"error"}}],[8,"ExitStatusExt","","Unix-specific extensions to `std::process::ExitStatus`",null,null],[10,"from_raw","","Creates a new `ExitStatus` from the raw underlying `i32` return value of a process.",209,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[10,"signal","","If the process was terminated by a signal, returns that signal.",209,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"option"}}],[0,"raw","std::os::unix","Unix-specific primitives available on all unix platforms",null,null],[6,"uid_t","std::os::unix::raw","",null,null],[6,"gid_t","","",null,null],[6,"pid_t","","",null,null],[6,"pthread_t","","",null,null],[6,"dev_t","","",null,null],[6,"ino_t","","",null,null],[6,"mode_t","","",null,null],[6,"nlink_t","","",null,null],[6,"off_t","","",null,null],[6,"blksize_t","","",null,null],[6,"blkcnt_t","","",null,null],[6,"time_t","","",null,null],[0,"thread","std::os::unix","Unix-specific extensions to primitives in the `std::thread` module.",null,null],[6,"RawPthread","std::os::unix::thread","",null,null],[8,"JoinHandleExt","","Unix-specific extensions to `std::thread::JoinHandle`",null,null],[10,"as_pthread_t","","Extracts the raw pthread_t without taking ownership",210,{"inputs":[{"name":"self"}],"output":{"name":"rawpthread"}}],[10,"into_pthread_t","","Consumes the thread, returning the raw pthread_t",210,{"inputs":[{"name":"self"}],"output":{"name":"rawpthread"}}],[0,"net","std::os::unix","Unix-specific networking functionality",null,null],[3,"SocketAddr","std::os::unix::net","An address associated with a Unix socket.",null,null],[3,"UnixStream","","A Unix stream socket.",null,null],[3,"UnixListener","","A structure representing a Unix domain socket server.",null,null],[3,"Incoming","","An iterator over incoming connections to a [`UnixListener`].",null,null],[3,"UnixDatagram","","A Unix datagram socket.",null,null],[0,"prelude","std::os::unix","A prelude for conveniently writing platform-specific code.",null,null],[0,"windows","std::os","Platform-specific extensions to `std` for Windows.",null,null],[0,"ffi","std::os::windows","Windows-specific extensions to the primitives in the `std::ffi` module.",null,null],[3,"EncodeWide","std::os::windows::ffi","Generates a wide character sequence for potentially ill-formed UTF-16.",null,null],[8,"OsStringExt","","Windows-specific extensions to `OsString`.",null,null],[10,"from_wide","","Creates an `OsString` from a potentially ill-formed UTF-16 slice of 16-bit code units.",211,null],[8,"OsStrExt","","Windows-specific extensions to `OsStr`.",null,null],[10,"encode_wide","","Re-encodes an `OsStr` as a wide character sequence, i.e. potentially ill-formed UTF-16.",212,{"inputs":[{"name":"self"}],"output":{"name":"encodewide"}}],[0,"fs","std::os::windows","Windows-specific extensions for the primitives in the `std::fs` module.",null,null],[5,"symlink_file","std::os::windows::fs","Creates a new file symbolic link on the filesystem.",null,{"inputs":[{"name":"p"},{"name":"q"}],"output":{"name":"result"}}],[5,"symlink_dir","","Creates a new directory symlink on the filesystem.",null,{"inputs":[{"name":"p"},{"name":"q"}],"output":{"name":"result"}}],[8,"FileExt","","Windows-specific extensions to [`File`].",null,null],[10,"seek_read","","Seeks to a given position and reads a number of bytes.",213,null],[10,"seek_write","","Seeks to a given position and writes a number of bytes.",213,null],[8,"OpenOptionsExt","","Windows-specific extensions to [`OpenOptions`].",null,null],[10,"access_mode","","Overrides the `dwDesiredAccess` argument to the call to [`CreateFile`] with the specified value.",214,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[10,"share_mode","","Overrides the `dwShareMode` argument to the call to [`CreateFile`] with the specified value.",214,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[10,"custom_flags","","Sets extra flags for the `dwFileFlags` argument to the call to [`CreateFile2`] to the specified value (or combines it with `attributes` and `security_qos_flags` to set the `dwFlagsAndAttributes` for [`CreateFile`]).",214,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[10,"attributes","","Sets the `dwFileAttributes` argument to the call to [`CreateFile2`] to the specified value (or combines it with `custom_flags` and `security_qos_flags` to set the `dwFlagsAndAttributes` for [`CreateFile`]).",214,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"self"}}],[10,"security_qos_flags","","Sets the `dwSecurityQosFlags` argument to the call to [`CreateFile2`] to the specified value (or combines it with `custom_flags` and `attributes` to set the `dwFlagsAndAttributes` for [`CreateFile`]).",214,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"openoptions"}}],[8,"MetadataExt","","Extension methods for [`fs::Metadata`] to access the raw fields contained within.",null,null],[10,"file_attributes","","Returns the value of the `dwFileAttributes` field of this metadata.",215,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"creation_time","","Returns the value of the `ftCreationTime` field of this metadata.",215,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"last_access_time","","Returns the value of the `ftLastAccessTime` field of this metadata.",215,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"last_write_time","","Returns the value of the `ftLastWriteTime` field of this metadata.",215,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"file_size","","Returns the value of the `nFileSize{High,Low}` fields of this metadata.",215,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[8,"FileTypeExt","","Add support for the Windows specific fact that a symbolic link knows whether it is a file or directory.",null,null],[10,"is_symlink_dir","","Returns whether this file type is a symbolic link that is also a directory.",216,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"is_symlink_file","","Returns whether this file type is a symbolic link that is also a file.",216,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[0,"io","std::os::windows","",null,null],[6,"RawHandle","std::os::windows::io","Raw HANDLEs.",null,null],[6,"RawSocket","","Raw SOCKETs.",null,null],[8,"AsRawHandle","","Extract raw handles.",null,null],[10,"as_raw_handle","","Extracts the raw handle, without taking any ownership.",217,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[8,"FromRawHandle","","Construct I/O objects from raw handles.",null,null],[10,"from_raw_handle","","Constructs a new I/O object from the specified raw handle.",218,{"inputs":[{"name":"rawhandle"}],"output":{"name":"self"}}],[8,"IntoRawHandle","","A trait to express the ability to consume an object and acquire ownership of its raw `HANDLE`.",null,null],[10,"into_raw_handle","","Consumes this object, returning the raw underlying handle.",219,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[8,"AsRawSocket","","Extract raw sockets.",null,null],[10,"as_raw_socket","","Extracts the underlying raw socket from this object.",220,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[8,"FromRawSocket","","Create I/O objects from raw sockets.",null,null],[10,"from_raw_socket","","Creates a new I/O object from the given raw socket.",221,{"inputs":[{"name":"rawsocket"}],"output":{"name":"self"}}],[8,"IntoRawSocket","","A trait to express the ability to consume an object and acquire ownership of its raw `SOCKET`.",null,null],[10,"into_raw_socket","","Consumes this object, returning the raw underlying socket.",222,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[0,"raw","std::os::windows","Windows-specific primitives",null,null],[6,"HANDLE","std::os::windows::raw","",null,null],[6,"SOCKET","","",null,null],[0,"process","std::os::windows","Extensions to `std::process` for Windows.",null,null],[8,"ExitStatusExt","std::os::windows::process","Windows-specific extensions to `std::process::ExitStatus`",null,null],[10,"from_raw","","Creates a new `ExitStatus` from the raw underlying `u32` return value of a process.",223,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[8,"CommandExt","","Windows-specific extensions to the `std::process::Command` builder",null,null],[10,"creation_flags","","Sets the [process creation flags][1] to be passed to `CreateProcess`.",224,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"command"}}],[0,"thread","std::os::windows","Extensions to `std::thread` for Windows.",null,null],[0,"prelude","","A prelude for conveniently writing platform-specific code.",null,null],[0,"linux","std::os","Linux-specific definitions",null,null],[0,"raw","std::os::linux","Linux-specific raw type definitions",null,null],[3,"stat","std::os::linux::raw","",null,null],[12,"st_dev","","",225,null],[12,"__pad1","","",225,null],[12,"__st_ino","","",225,null],[12,"st_mode","","",225,null],[12,"st_nlink","","",225,null],[12,"st_uid","","",225,null],[12,"st_gid","","",225,null],[12,"st_rdev","","",225,null],[12,"__pad2","","",225,null],[12,"st_size","","",225,null],[12,"st_blksize","","",225,null],[12,"st_blocks","","",225,null],[12,"st_atime","","",225,null],[12,"st_atime_nsec","","",225,null],[12,"st_mtime","","",225,null],[12,"st_mtime_nsec","","",225,null],[12,"st_ctime","","",225,null],[12,"st_ctime_nsec","","",225,null],[12,"st_ino","","",225,null],[11,"clone","","",225,{"inputs":[{"name":"self"}],"output":{"name":"stat"}}],[6,"dev_t","","",null,null],[6,"mode_t","","",null,null],[6,"pthread_t","","",null,null],[6,"off_t","","",null,null],[6,"ino_t","","",null,null],[6,"nlink_t","","",null,null],[6,"blksize_t","","",null,null],[6,"blkcnt_t","","",null,null],[6,"time_t","","",null,null],[0,"fs","std::os::linux","",null,null],[8,"MetadataExt","std::os::linux::fs","OS-specific extension methods for `fs::Metadata`",null,null],[10,"as_raw_stat","","Gain a reference to the underlying `stat` structure which contains the raw information returned by the OS.",226,{"inputs":[{"name":"self"}],"output":{"name":"stat"}}],[10,"st_dev","","Returns the device ID on which this file resides.",226,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"st_ino","","Returns the inode number.",226,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"st_mode","","Returns the file type and mode.",226,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"st_nlink","","Returns the number of hard links to file.",226,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"st_uid","","Returns the user ID of the file owner.",226,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"st_gid","","Returns the group ID of the file owner.",226,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[10,"st_rdev","","Returns the device ID that this file represents. Only relevant for special file.",226,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"st_size","","Returns the size of the file (if it is a regular file or a symbolic link) in bytes.",226,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"st_atime","","Returns the last access time.",226,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"st_atime_nsec","","Returns the last access time, nano seconds part.",226,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"st_mtime","","Returns the last modification time.",226,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"st_mtime_nsec","","Returns the last modification time, nano seconds part.",226,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"st_ctime","","Returns the last status change time.",226,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"st_ctime_nsec","","Returns the last status change time, nano seconds part.",226,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[10,"st_blksize","","Returns the \"preferred\" blocksize for efficient filesystem I/O.",226,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[10,"st_blocks","","Returns the number of blocks allocated to the file, 512-byte units.",226,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"as_raw_stat","std::fs","",142,{"inputs":[{"name":"self"}],"output":{"name":"stat"}}],[11,"st_dev","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"st_ino","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"st_mode","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"st_nlink","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"st_uid","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"st_gid","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"st_rdev","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"st_size","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"st_atime","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"st_atime_nsec","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"st_mtime","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"st_mtime_nsec","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"st_ctime","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"st_ctime_nsec","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"st_blksize","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"st_blocks","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[0,"raw","std::os","Platform-specific types, as defined by C.",null,null],[4,"c_void","std::os::raw","Equivalent to C's `void` type when used as a [pointer].",null,null],[6,"c_char","","Equivalent to C's `char` type.",null,null],[6,"c_schar","","Equivalent to C's `signed char` type.",null,null],[6,"c_uchar","","Equivalent to C's `unsigned char` type.",null,null],[6,"c_short","","Equivalent to C's `signed short` (`short`) type.",null,null],[6,"c_ushort","","Equivalent to C's `unsigned short` type.",null,null],[6,"c_int","","Equivalent to C's `signed int` (`int`) type.",null,null],[6,"c_uint","","Equivalent to C's `unsigned int` type.",null,null],[6,"c_long","","Equivalent to C's `signed long` (`long`) type.",null,null],[6,"c_ulong","","Equivalent to C's `unsigned long` type.",null,null],[6,"c_longlong","","Equivalent to C's `signed long long` (`long long`) type.",null,null],[6,"c_ulonglong","","Equivalent to C's `unsigned long long` type.",null,null],[6,"c_float","","Equivalent to C's `float` type.",null,null],[6,"c_double","","Equivalent to C's `double` type.",null,null],[11,"fmt","","",227,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"panic","std","Panic support in the standard library.",null,null],[3,"PanicInfo","std::panic","A struct providing information about a panic.",null,null],[3,"Location","","A struct containing information about the location of a panic.",null,null],[3,"AssertUnwindSafe","","A simple wrapper around a type to assert that it is unwind safe.",null,null],[12,"0","","",228,null],[5,"take_hook","","Unregisters the current panic hook, returning it.",null,{"inputs":[],"output":{"generics":["fn"],"name":"box"}}],[5,"set_hook","","Registers a custom panic hook, replacing any that was previously registered.",null,{"inputs":[{"generics":["fn"],"name":"box"}],"output":null}],[5,"catch_unwind","","Invokes a closure, capturing the cause of an unwinding panic if one occurs.",null,{"inputs":[{"name":"f"}],"output":{"name":"result"}}],[5,"resume_unwind","","Triggers a panic without invoking the panic hook.",null,null],[8,"UnwindSafe","","A marker trait which represents \"panic safe\" types in Rust.",null,null],[8,"RefUnwindSafe","","A marker trait representing types where a shared reference is considered unwind safe.",null,null],[11,"deref","","",228,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",228,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"call_once","","",228,null],[11,"fmt","","",228,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"path","std","Cross-platform path manipulation.",null,null],[3,"PrefixComponent","std::path","A structure wrapping a Windows path prefix as well as its unparsed string representation.",null,null],[3,"Components","","An iterator over the [`Component`]s of a [`Path`].",null,null],[3,"Iter","","An iterator over the [`Component`]s of a [`Path`], as [`OsStr`] slices.",null,null],[3,"Ancestors","","An iterator over [`Path`] and its ancestors.",null,null],[3,"PathBuf","","An owned, mutable path (akin to [`String`]).",null,null],[3,"Path","","A slice of a path (akin to [`str`]).",null,null],[3,"StripPrefixError","","An error returned from [`Path::strip_prefix`][`strip_prefix`] if the prefix was not found.",null,null],[3,"Display","","Helper struct for safely printing paths with [`format!`] and `{}`.",null,null],[4,"Prefix","","Windows path prefixes, e.g. `C:` or `\\\\server\\share`.",null,null],[13,"Verbatim","","Verbatim prefix, e.g. `\\\\?\\cat_pics`.",229,null],[13,"VerbatimUNC","","Verbatim prefix using Windows' Uniform Naming Convention, e.g. `\\\\?\\UNC\\server\\share`.",229,null],[13,"VerbatimDisk","","Verbatim disk prefix, e.g. `\\\\?\\C:\\`.",229,null],[13,"DeviceNS","","Device namespace prefix, e.g. `\\\\.\\COM42`.",229,null],[13,"UNC","","Prefix using Windows' Uniform Naming Convention, e.g. `\\\\server\\share`.",229,null],[13,"Disk","","Prefix `C:` for the given disk drive.",229,null],[4,"Component","","A single component of a path.",null,null],[13,"Prefix","","A Windows path prefix, e.g. `C:` or `\\\\server\\share`.",230,null],[13,"RootDir","","The root directory component, appears after any prefix and before anything else.",230,null],[13,"CurDir","","A reference to the current directory, i.e. `.`.",230,null],[13,"ParentDir","","A reference to the parent directory, i.e. `..`.",230,null],[13,"Normal","","A normal component, e.g. `a` and `b` in `a/b`.",230,null],[5,"is_separator","","Determines whether the character is one of the permitted path separators for the current platform.",null,{"inputs":[{"name":"char"}],"output":{"name":"bool"}}],[17,"MAIN_SEPARATOR","","The primary separator of path components for the current platform.",null,null],[11,"clone","","",229,{"inputs":[{"name":"self"}],"output":{"name":"prefix"}}],[11,"fmt","","",229,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"hash","","",229,null],[11,"partial_cmp","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"name":"bool"}}],[11,"le","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"name":"bool"}}],[11,"gt","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"name":"bool"}}],[11,"ge","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"name":"bool"}}],[11,"cmp","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"name":"ordering"}}],[11,"eq","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"name":"bool"}}],[11,"ne","","",229,{"inputs":[{"name":"self"},{"name":"prefix"}],"output":{"name":"bool"}}],[11,"is_verbatim","","Determines if the prefix is verbatim, i.e. begins with `\\\\?\\`.",229,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"clone","","",231,{"inputs":[{"name":"self"}],"output":{"name":"prefixcomponent"}}],[11,"fmt","","",231,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"kind","","Returns the parsed prefix data.",231,{"inputs":[{"name":"self"}],"output":{"name":"prefix"}}],[11,"as_os_str","","Returns the raw [`OsStr`] slice for this prefix.",231,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"eq","","",231,{"inputs":[{"name":"self"},{"name":"prefixcomponent"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",231,{"inputs":[{"name":"self"},{"name":"prefixcomponent"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",231,{"inputs":[{"name":"self"},{"name":"prefixcomponent"}],"output":{"name":"ordering"}}],[11,"hash","","",231,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"clone","","",230,{"inputs":[{"name":"self"}],"output":{"name":"component"}}],[11,"eq","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"name":"bool"}}],[11,"ne","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"name":"bool"}}],[11,"le","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"name":"bool"}}],[11,"gt","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"name":"bool"}}],[11,"ge","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"name":"bool"}}],[11,"cmp","","",230,{"inputs":[{"name":"self"},{"name":"component"}],"output":{"name":"ordering"}}],[11,"hash","","",230,null],[11,"fmt","","",230,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"as_os_str","","Extracts the underlying [`OsStr`] slice.",230,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"as_ref","","",230,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"as_ref","","",230,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"clone","","",232,{"inputs":[{"name":"self"}],"output":{"name":"components"}}],[11,"clone","","",233,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"fmt","","",232,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"as_path","","Extracts a slice corresponding to the portion of the path remaining for iteration.",232,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","","",232,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","","",232,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"fmt","","",233,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"as_path","","Extracts a slice corresponding to the portion of the path remaining for iteration.",233,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","","",233,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","","",233,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"next","","",233,{"inputs":[{"name":"self"}],"output":{"generics":["osstr"],"name":"option"}}],[11,"next_back","","",233,{"inputs":[{"name":"self"}],"output":{"generics":["osstr"],"name":"option"}}],[11,"next","","",232,{"inputs":[{"name":"self"}],"output":{"generics":["component"],"name":"option"}}],[11,"next_back","","",232,{"inputs":[{"name":"self"}],"output":{"generics":["component"],"name":"option"}}],[11,"eq","","",232,{"inputs":[{"name":"self"},{"name":"components"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",232,{"inputs":[{"name":"self"},{"name":"components"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",232,{"inputs":[{"name":"self"},{"name":"components"}],"output":{"name":"ordering"}}],[11,"clone","","",234,{"inputs":[{"name":"self"}],"output":{"name":"ancestors"}}],[11,"fmt","","",234,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",234,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","","",235,{"inputs":[{"name":"self"}],"output":{"name":"pathbuf"}}],[11,"new","","Allocates an empty `PathBuf`.",235,{"inputs":[],"output":{"name":"pathbuf"}}],[11,"as_path","","Coerces to a [`Path`] slice.",235,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"push","","Extends `self` with `path`.",235,{"inputs":[{"name":"self"},{"name":"p"}],"output":null}],[11,"pop","","Truncates `self` to [`self.parent`].",235,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"set_file_name","","Updates [`self.file_name`] to `file_name`.",235,{"inputs":[{"name":"self"},{"name":"s"}],"output":null}],[11,"set_extension","","Updates [`self.extension`] to `extension`.",235,{"inputs":[{"name":"self"},{"name":"s"}],"output":{"name":"bool"}}],[11,"into_os_string","","Consumes the `PathBuf`, yielding its internal [`OsString`] storage.",235,{"inputs":[{"name":"self"}],"output":{"name":"osstring"}}],[11,"into_boxed_path","","Converts this `PathBuf` into a [boxed][`Box`] [`Path`].",235,{"inputs":[{"name":"self"}],"output":{"generics":["path"],"name":"box"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"path"}],"output":{"generics":["path"],"name":"box"}}],[11,"from","std::path","",235,{"inputs":[{"generics":["path"],"name":"box"}],"output":{"name":"pathbuf"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"pathbuf"}],"output":{"generics":["path"],"name":"box"}}],[11,"from","std::path","",235,{"inputs":[{"name":"t"}],"output":{"name":"pathbuf"}}],[11,"from","","",235,{"inputs":[{"name":"osstring"}],"output":{"name":"pathbuf"}}],[11,"from","std::ffi","",139,{"inputs":[{"name":"pathbuf"}],"output":{"name":"osstring"}}],[11,"from","std::path","",235,{"inputs":[{"name":"string"}],"output":{"name":"pathbuf"}}],[11,"from_iter","","",235,{"inputs":[{"name":"i"}],"output":{"name":"pathbuf"}}],[11,"extend","","",235,{"inputs":[{"name":"self"},{"name":"i"}],"output":null}],[11,"fmt","","",235,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"deref","","",235,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"borrow","","",235,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"default","","",235,{"inputs":[],"output":{"name":"self"}}],[11,"from","std::borrow","",76,{"inputs":[{"name":"path"}],"output":{"generics":["path"],"name":"cow"}}],[11,"from","","",76,{"inputs":[{"name":"pathbuf"}],"output":{"generics":["path"],"name":"cow"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"pathbuf"}],"output":{"generics":["path"],"name":"rc"}}],[11,"from","","",138,{"inputs":[{"name":"path"}],"output":{"generics":["path"],"name":"rc"}}],[11,"to_owned","std::path","",236,{"inputs":[{"name":"self"}],"output":{"name":"pathbuf"}}],[11,"clone_into","","",236,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":null}],[11,"eq","","",235,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"name":"bool"}}],[11,"hash","","",235,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"partial_cmp","","",235,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",235,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"name":"ordering"}}],[11,"as_ref","","",235,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"fmt","","",237,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",237,{"inputs":[{"name":"self"}],"output":{"name":"stripprefixerror"}}],[11,"eq","","",237,{"inputs":[{"name":"self"},{"name":"stripprefixerror"}],"output":{"name":"bool"}}],[11,"ne","","",237,{"inputs":[{"name":"self"},{"name":"stripprefixerror"}],"output":{"name":"bool"}}],[11,"new","","Directly wraps a string slice as a `Path` slice.",236,{"inputs":[{"name":"s"}],"output":{"name":"path"}}],[11,"as_os_str","","Yields the underlying [`OsStr`] slice.",236,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"to_str","","Yields a [`&str`] slice if the `Path` is valid unicode.",236,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"to_string_lossy","","Converts a `Path` to a [`Cow<str>`].",236,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"cow"}}],[11,"to_path_buf","","Converts a `Path` to an owned [`PathBuf`].",236,{"inputs":[{"name":"self"}],"output":{"name":"pathbuf"}}],[11,"is_absolute","","Returns `true` if the `Path` is absolute, i.e. if it is independent of the current directory.",236,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_relative","","Returns `true` if the `Path` is relative, i.e. not absolute.",236,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"has_root","","Returns `true` if the `Path` has a root.",236,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"parent","","Returns the `Path` without its final component, if there is one.",236,{"inputs":[{"name":"self"}],"output":{"generics":["path"],"name":"option"}}],[11,"ancestors","","Produces an iterator over `Path` and its ancestors.",236,{"inputs":[{"name":"self"}],"output":{"name":"ancestors"}}],[11,"file_name","","Returns the final component of the `Path`, if there is one.",236,{"inputs":[{"name":"self"}],"output":{"generics":["osstr"],"name":"option"}}],[11,"strip_prefix","","Returns a path that, when joined onto `base`, yields `self`.",236,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["path","stripprefixerror"],"name":"result"}}],[11,"starts_with","","Determines whether `base` is a prefix of `self`.",236,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"bool"}}],[11,"ends_with","","Determines whether `child` is a suffix of `self`.",236,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"bool"}}],[11,"file_stem","","Extracts the stem (non-extension) portion of [`self.file_name`].",236,{"inputs":[{"name":"self"}],"output":{"generics":["osstr"],"name":"option"}}],[11,"extension","","Extracts the extension of [`self.file_name`], if possible.",236,{"inputs":[{"name":"self"}],"output":{"generics":["osstr"],"name":"option"}}],[11,"join","","Creates an owned [`PathBuf`] with `path` adjoined to `self`.",236,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"pathbuf"}}],[11,"with_file_name","","Creates an owned [`PathBuf`] like `self` but with the given file name.",236,{"inputs":[{"name":"self"},{"name":"s"}],"output":{"name":"pathbuf"}}],[11,"with_extension","","Creates an owned [`PathBuf`] like `self` but with the given extension.",236,{"inputs":[{"name":"self"},{"name":"s"}],"output":{"name":"pathbuf"}}],[11,"components","","Produces an iterator over the [`Component`]s of the path.",236,{"inputs":[{"name":"self"}],"output":{"name":"components"}}],[11,"iter","","Produces an iterator over the path's components viewed as [`OsStr`] slices.",236,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"display","","Returns an object that implements [`Display`] for safely printing paths that may contain non-Unicode data.",236,{"inputs":[{"name":"self"}],"output":{"name":"display"}}],[11,"metadata","","Queries the file system to get information about a file, directory, etc.",236,{"inputs":[{"name":"self"}],"output":{"generics":["metadata"],"name":"result"}}],[11,"symlink_metadata","","Queries the metadata about a file without following symlinks.",236,{"inputs":[{"name":"self"}],"output":{"generics":["metadata"],"name":"result"}}],[11,"canonicalize","","Returns the canonical form of the path with all intermediate components normalized and symbolic links resolved.",236,{"inputs":[{"name":"self"}],"output":{"generics":["pathbuf"],"name":"result"}}],[11,"read_link","","Reads a symbolic link, returning the file that the link points to.",236,{"inputs":[{"name":"self"}],"output":{"generics":["pathbuf"],"name":"result"}}],[11,"read_dir","","Returns an iterator over the entries within a directory.",236,{"inputs":[{"name":"self"}],"output":{"generics":["readdir"],"name":"result"}}],[11,"exists","","Returns whether the path points at an existing entity.",236,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_file","","Returns whether the path exists on disk and is pointing at a regular file.",236,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_dir","","Returns whether the path exists on disk and is pointing at a directory.",236,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"into_path_buf","","Converts a [`Box<Path>`][`Box`] into a [`PathBuf`] without copying or allocating.",236,{"inputs":[{"generics":["path"],"name":"box"}],"output":{"name":"pathbuf"}}],[11,"as_ref","","",236,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"fmt","","",236,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",238,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",238,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",236,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"hash","","",236,{"inputs":[{"name":"self"},{"name":"h"}],"output":null}],[11,"partial_cmp","","",236,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"cmp","","",236,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"ordering"}}],[11,"as_ref","","",236,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","std::ffi","",140,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","std::borrow","",76,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","std::ffi","",139,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"as_ref","std::path","",235,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"eq","","",235,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"eq","","",236,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",235,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",236,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",235,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",235,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"eq","std::path","",236,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::path","",236,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",76,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"name":"bool"}}],[11,"eq","std::path","",235,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::path","",235,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",235,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::path","",235,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::path","",235,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",235,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",235,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::path","",235,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::path","",235,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::path","",235,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"pathbuf"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::path","",236,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::path","",236,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::path","",236,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",236,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",236,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::path","",236,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::path","",236,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::path","",236,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",140,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",140,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",76,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",139,{"inputs":[{"name":"self"},{"name":"path"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",140,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",76,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"eq","","",76,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"eq","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::ffi","",139,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"fmt","std::path","",237,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",237,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[0,"process","std","A module for working with processes.",null,null],[3,"Child","std::process","Representation of a running or exited child process.",null,null],[12,"stdin","","The handle for writing to the child's standard input (stdin), if it has been captured.",239,null],[12,"stdout","","The handle for reading from the child's standard output (stdout), if it has been captured.",239,null],[12,"stderr","","The handle for reading from the child's standard error (stderr), if it has been captured.",239,null],[3,"ChildStdin","","A handle to a child process's standard input (stdin).",null,null],[3,"ChildStdout","","A handle to a child process's standard output (stdout).",null,null],[3,"ChildStderr","","A handle to a child process's stderr.",null,null],[3,"Command","","A process builder, providing fine-grained control over how a new process should be spawned.",null,null],[3,"Output","","The output of a finished process.",null,null],[12,"status","","The status (exit code) of the process.",240,null],[12,"stdout","","The data that the process wrote to stdout.",240,null],[12,"stderr","","The data that the process wrote to stderr.",240,null],[3,"Stdio","","Describes what to do with a standard I/O stream for a child process when passed to the [`stdin`], [`stdout`], and [`stderr`] methods of [`Command`].",null,null],[3,"ExitStatus","","Describes the result of a process after it has terminated.",null,null],[3,"ExitCode","","This type represents the status code a process can return to its parent under normal termination.",null,null],[5,"exit","","Terminates the current process with the specified exit code.",null,null],[5,"abort","","Terminates the process in an abnormal fashion.",null,null],[5,"id","","Returns the OS-assigned process identifier associated with this process.",null,{"inputs":[],"output":{"name":"u32"}}],[8,"Termination","","A trait for implementing arbitrary return types in the `main` function.",null,null],[10,"report","","Is called to get the representation of the value as status code. This status code is returned to the operating system.",241,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"fmt","","",239,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"write","","",242,null],[11,"flush","","",242,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"fmt","","",242,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"read","","",243,null],[11,"initializer","","",243,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fmt","","",243,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"read","","",244,null],[11,"initializer","","",244,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"fmt","","",244,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Constructs a new `Command` for launching the program at path `program`, with the following default configuration:",245,{"inputs":[{"name":"s"}],"output":{"name":"command"}}],[11,"arg","","Add an argument to pass to the program.",245,{"inputs":[{"name":"self"},{"name":"s"}],"output":{"name":"command"}}],[11,"args","","Add multiple arguments to pass to the program.",245,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"command"}}],[11,"env","","Inserts or updates an environment variable mapping.",245,{"inputs":[{"name":"self"},{"name":"k"},{"name":"v"}],"output":{"name":"command"}}],[11,"envs","","Add or update multiple environment variable mappings.",245,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"command"}}],[11,"env_remove","","Removes an environment variable mapping.",245,{"inputs":[{"name":"self"},{"name":"k"}],"output":{"name":"command"}}],[11,"env_clear","","Clears the entire environment map for the child process.",245,{"inputs":[{"name":"self"}],"output":{"name":"command"}}],[11,"current_dir","","Sets the working directory for the child process.",245,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"command"}}],[11,"stdin","","Configuration for the child process's standard input (stdin) handle.",245,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"command"}}],[11,"stdout","","Configuration for the child process's standard output (stdout) handle.",245,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"command"}}],[11,"stderr","","Configuration for the child process's standard error (stderr) handle.",245,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"command"}}],[11,"spawn","","Executes the command as a child process, returning a handle to it.",245,{"inputs":[{"name":"self"}],"output":{"generics":["child"],"name":"result"}}],[11,"output","","Executes the command as a child process, waiting for it to finish and collecting all of its output.",245,{"inputs":[{"name":"self"}],"output":{"generics":["output"],"name":"result"}}],[11,"status","","Executes a command as a child process, waiting for it to finish and collecting its exit status.",245,{"inputs":[{"name":"self"}],"output":{"generics":["exitstatus"],"name":"result"}}],[11,"fmt","","Format the program and arguments of a Command for display. Any non-utf8 data is lossily converted using the utf8 replacement character.",245,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",240,{"inputs":[{"name":"self"},{"name":"output"}],"output":{"name":"bool"}}],[11,"ne","","",240,{"inputs":[{"name":"self"},{"name":"output"}],"output":{"name":"bool"}}],[11,"clone","","",240,{"inputs":[{"name":"self"}],"output":{"name":"output"}}],[11,"fmt","","",240,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"piped","","A new pipe should be arranged to connect the parent and child processes.",246,{"inputs":[],"output":{"name":"stdio"}}],[11,"inherit","","The child inherits from the corresponding parent descriptor.",246,{"inputs":[],"output":{"name":"stdio"}}],[11,"null","","This stream will be ignored. This is the equivalent of attaching the stream to `/dev/null`",246,{"inputs":[],"output":{"name":"stdio"}}],[11,"fmt","","",246,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"from","","",246,{"inputs":[{"name":"childstdin"}],"output":{"name":"stdio"}}],[11,"from","","",246,{"inputs":[{"name":"childstdout"}],"output":{"name":"stdio"}}],[11,"from","","",246,{"inputs":[{"name":"childstderr"}],"output":{"name":"stdio"}}],[11,"from","","",246,{"inputs":[{"name":"file"}],"output":{"name":"stdio"}}],[11,"eq","","",247,{"inputs":[{"name":"self"},{"name":"exitstatus"}],"output":{"name":"bool"}}],[11,"ne","","",247,{"inputs":[{"name":"self"},{"name":"exitstatus"}],"output":{"name":"bool"}}],[11,"clone","","",247,{"inputs":[{"name":"self"}],"output":{"name":"exitstatus"}}],[11,"fmt","","",247,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"success","","Was termination successful? Signal termination is not considered a success, and success is defined as a zero exit status.",247,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"code","","Returns the exit code of the process, if any.",247,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"option"}}],[11,"fmt","","",247,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",248,{"inputs":[{"name":"self"}],"output":{"name":"exitcode"}}],[11,"fmt","","",248,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[18,"SUCCESS","","The canonical ExitCode for successful termination on this platform.",248,null],[18,"FAILURE","","The canonical ExitCode for unsuccessful termination on this platform.",248,null],[11,"kill","","Forces the child to exit. This is equivalent to sending a SIGKILL on unix platforms.",239,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"id","","Returns the OS-assigned process identifier associated with this child.",239,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"wait","","Waits for the child to exit completely, returning the status that it exited with. This function will continue to have the same return value after it has been called at least once.",239,{"inputs":[{"name":"self"}],"output":{"generics":["exitstatus"],"name":"result"}}],[11,"try_wait","","Attempts to collect the exit status of the child if it has already exited.",239,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"wait_with_output","","Simultaneously waits for the child to exit and collect all remaining output on the stdout/stderr handles, returning an `Output` instance.",239,{"inputs":[{"name":"self"}],"output":{"generics":["output"],"name":"result"}}],[11,"report","std::result","",72,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"report","","",72,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"report","std::process","",248,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[0,"sync","std","Useful synchronization primitives.",null,null],[3,"Arc","std::sync","A thread-safe reference-counting pointer. 'Arc' stands for 'Atomically Reference Counted'.",null,null],[3,"Weak","","`Weak` is a version of [`Arc`] that holds a non-owning reference to the managed value. The value is accessed by calling [`upgrade`] on the `Weak` pointer, which returns an [`Option`]`<`[`Arc`]`<T>>`.",null,null],[0,"atomic","","Atomic types",null,null],[5,"spin_loop_hint","std::sync::atomic","Save power or switch hyperthreads in a busy-wait spin-loop.",null,null],[3,"AtomicBool","","A boolean type which can be safely shared between threads.",null,null],[3,"AtomicPtr","","A raw pointer type which can be safely shared between threads.",null,null],[4,"Ordering","","Atomic memory orderings",null,null],[13,"Relaxed","","No ordering constraints, only atomic operations.",249,null],[13,"Release","","When coupled with a store, all previous writes become visible to the other threads that perform a load with [`Acquire`] ordering on the same value.",249,null],[13,"Acquire","","When coupled with a load, all subsequent loads will see data written before a store with [`Release`] ordering on the same value in other threads.",249,null],[13,"AcqRel","","Has the effects of both [`Acquire`] and [`Release`] together.",249,null],[13,"SeqCst","","Like `AcqRel` with the additional guarantee that all threads see all sequentially consistent operations in the same order.",249,null],[17,"ATOMIC_BOOL_INIT","","An [`AtomicBool`] initialized to `false`.",null,null],[3,"AtomicI8","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_I8_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicU8","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_U8_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicI16","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_I16_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicU16","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_U16_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicI32","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_I32_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicU32","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_U32_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicI64","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_I64_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicU64","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_U64_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicIsize","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_ISIZE_INIT","","An atomic integer initialized to `0`.",null,null],[3,"AtomicUsize","","An integer type which can be safely shared between threads.",null,null],[17,"ATOMIC_USIZE_INIT","","An atomic integer initialized to `0`.",null,null],[5,"fence","","An atomic fence.",null,null],[5,"compiler_fence","","A compiler memory fence.",null,null],[3,"Barrier","std::sync","A barrier enables multiple threads to synchronize the beginning of some computation.",null,null],[3,"BarrierWaitResult","","A `BarrierWaitResult` is returned by [`wait`] when all threads in the [`Barrier`] have rendezvoused.",null,null],[3,"Condvar","","A Condition Variable",null,null],[3,"WaitTimeoutResult","","A type indicating whether a timed wait on a condition variable returned due to a time out or not.",null,null],[3,"Mutex","","A mutual exclusion primitive useful for protecting shared data",null,null],[3,"MutexGuard","","An RAII implementation of a \"scoped lock\" of a mutex. When this structure is dropped (falls out of scope), the lock will be unlocked.",null,null],[3,"Once","","A synchronization primitive which can be used to run a one-time global initialization. Useful for one-time initialization for FFI or related functionality. This type can only be constructed with the [`ONCE_INIT`] value.",null,null],[3,"OnceState","","State yielded to [`call_once_force`]’s closure parameter. The state can be used to query the poison status of the [`Once`].",null,null],[3,"PoisonError","","A type of error which can be returned whenever a lock is acquired.",null,null],[3,"RwLock","","A reader-writer lock",null,null],[3,"RwLockReadGuard","","RAII structure used to release the shared read access of a lock when dropped.",null,null],[3,"RwLockWriteGuard","","RAII structure used to release the exclusive write access of a lock when dropped.",null,null],[4,"TryLockError","","An enumeration of possible errors associated with a [`TryLockResult`] which can occur while trying to acquire a lock, from the [`try_lock`] method on a [`Mutex`] or the [`try_read`] and [`try_write`] methods on an [`RwLock`].",null,null],[13,"Poisoned","","The lock could not be acquired because another thread failed while holding the lock.",250,null],[13,"WouldBlock","","The lock could not be acquired at this time because the operation would otherwise block.",250,null],[0,"mpsc","","Multi-producer, single-consumer FIFO queue communication primitives.",null,null],[3,"Select","std::sync::mpsc","The \"receiver set\" of the select interface. This structure is used to manage a set of receivers which are being selected over.",null,null],[3,"Handle","","A handle to a receiver which is currently a member of a `Select` set of receivers.  This handle is used to keep the receiver in the set as well as interact with the underlying receiver.",null,null],[3,"Receiver","","The receiving half of Rust's [`channel`][] (or [`sync_channel`]) type. This half can only be owned by one thread.",null,null],[3,"Iter","","An iterator over messages on a [`Receiver`], created by [`iter`].",null,null],[3,"TryIter","","An iterator that attempts to yield all pending values for a [`Receiver`], created by [`try_iter`].",null,null],[3,"IntoIter","","An owning iterator over messages on a [`Receiver`], created by Receiver::into_iter.",null,null],[3,"Sender","","The sending-half of Rust's asynchronous [`channel`] type. This half can only be owned by one thread, but it can be cloned to send to other threads.",null,null],[3,"SyncSender","","The sending-half of Rust's synchronous [`sync_channel`] type.",null,null],[3,"SendError","","An error returned from the [`Sender::send`] or [`SyncSender::send`] function on channels.",null,null],[12,"0","","",251,null],[3,"RecvError","","An error returned from the [`recv`] function on a [`Receiver`].",null,null],[4,"TryRecvError","","This enumeration is the list of the possible reasons that [`try_recv`] could not return data when called. This can occur with both a [`channel`] and a [`sync_channel`].",null,null],[13,"Empty","","This channel is currently empty, but the Sender(s) have not yet disconnected, so data may yet become available.",252,null],[13,"Disconnected","","The channel's sending half has become disconnected, and there will never be any more data received on it.",252,null],[4,"RecvTimeoutError","","This enumeration is the list of possible errors that made [`recv_timeout`] unable to return data when called. This can occur with both a [`channel`] and a [`sync_channel`].",null,null],[13,"Timeout","","This channel is currently empty, but the Sender(s) have not yet disconnected, so data may yet become available.",253,null],[13,"Disconnected","","The channel's sending half has become disconnected, and there will never be any more data received on it.",253,null],[4,"TrySendError","","This enumeration is the list of the possible error outcomes for the [`try_send`] method.",null,null],[13,"Full","","The data could not be sent on the [`sync_channel`] because it would require that the callee block to send the data.",254,null],[13,"Disconnected","","This [`sync_channel`]'s receiving half has disconnected, so the data could not be sent. The data is returned back to the callee in this case.",254,null],[5,"channel","","Creates a new asynchronous channel, returning the sender/receiver halves. All data sent on the [`Sender`] will become available on the [`Receiver`] in the same order as it was sent, and no [`send`] will block the calling thread (this channel has an \"infinite buffer\", unlike [`sync_channel`], which will block after its buffer limit is reached). [`recv`] will block until a message is available.",null,null],[5,"sync_channel","","Creates a new synchronous, bounded channel. All data sent on the [`SyncSender`] will become available on the [`Receiver`] in the same order as it was sent. Like asynchronous [`channel`]s, the [`Receiver`] will block until a message becomes available. `sync_channel` differs greatly in the semantics of the sender, however.",null,null],[11,"new","","Creates a new selection structure. This set is initially empty.",255,{"inputs":[],"output":{"name":"select"}}],[11,"handle","","Creates a new handle into this receiver set for a new receiver. Note that this does not add the receiver to the receiver set, for that you must call the `add` method on the handle itself.",255,{"inputs":[{"name":"self"},{"name":"receiver"}],"output":{"name":"handle"}}],[11,"wait","","Waits for an event on this receiver set. The returned value is not an index, but rather an id. This id can be queried against any active `Handle` structures (each one has an `id` method). The handle with the matching `id` will have some sort of event available on it. The event could either be that data is available or the corresponding channel has been closed.",255,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"id","","Retrieves the id of this handle.",256,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"recv","","Blocks to receive a value on the underlying receiver, returning `Some` on success or `None` if the channel disconnects. This function has the same semantics as `Receiver.recv`",256,{"inputs":[{"name":"self"}],"output":{"generics":["recverror"],"name":"result"}}],[11,"add","","Adds this handle to the receiver set that the handle was created from. This method can be called multiple times, but it has no effect if `add` was called previously.",256,{"inputs":[{"name":"self"}],"output":null}],[11,"remove","","Removes this handle from the `Select` set. This method is unsafe because it has no guarantee that the `Handle` was not moved since `add` was called.",256,{"inputs":[{"name":"self"}],"output":null}],[11,"drop","","",255,{"inputs":[{"name":"self"}],"output":null}],[11,"drop","","",256,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",255,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",256,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",257,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",258,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",259,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",251,{"inputs":[{"name":"self"},{"name":"senderror"}],"output":{"name":"bool"}}],[11,"ne","","",251,{"inputs":[{"name":"self"},{"name":"senderror"}],"output":{"name":"bool"}}],[11,"clone","","",251,{"inputs":[{"name":"self"}],"output":{"name":"senderror"}}],[11,"eq","","",260,{"inputs":[{"name":"self"},{"name":"recverror"}],"output":{"name":"bool"}}],[11,"clone","","",260,{"inputs":[{"name":"self"}],"output":{"name":"recverror"}}],[11,"fmt","","",260,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",252,{"inputs":[{"name":"self"},{"name":"tryrecverror"}],"output":{"name":"bool"}}],[11,"clone","","",252,{"inputs":[{"name":"self"}],"output":{"name":"tryrecverror"}}],[11,"fmt","","",252,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",253,{"inputs":[{"name":"self"},{"name":"recvtimeouterror"}],"output":{"name":"bool"}}],[11,"clone","","",253,{"inputs":[{"name":"self"}],"output":{"name":"recvtimeouterror"}}],[11,"fmt","","",253,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",254,{"inputs":[{"name":"self"},{"name":"trysenderror"}],"output":{"name":"bool"}}],[11,"ne","","",254,{"inputs":[{"name":"self"},{"name":"trysenderror"}],"output":{"name":"bool"}}],[11,"clone","","",254,{"inputs":[{"name":"self"}],"output":{"name":"trysenderror"}}],[11,"send","","Attempts to send a value on this channel, returning it back if it could not be sent.",261,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"generics":["senderror"],"name":"result"}}],[11,"clone","","",261,{"inputs":[{"name":"self"}],"output":{"name":"sender"}}],[11,"drop","","",261,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",261,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"send","","Sends a value on this synchronous channel.",262,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"generics":["senderror"],"name":"result"}}],[11,"try_send","","Attempts to send a value on this channel without blocking.",262,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"generics":["trysenderror"],"name":"result"}}],[11,"clone","","",262,{"inputs":[{"name":"self"}],"output":{"name":"syncsender"}}],[11,"drop","","",262,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",262,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"try_recv","","Attempts to return a pending value on this receiver without blocking.",263,{"inputs":[{"name":"self"}],"output":{"generics":["tryrecverror"],"name":"result"}}],[11,"recv","","Attempts to wait for a value on this receiver, returning an error if the corresponding channel has hung up.",263,{"inputs":[{"name":"self"}],"output":{"generics":["recverror"],"name":"result"}}],[11,"recv_timeout","","Attempts to wait for a value on this receiver, returning an error if the corresponding channel has hung up, or if it waits more than `timeout`.",263,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"generics":["recvtimeouterror"],"name":"result"}}],[11,"recv_deadline","","Attempts to wait for a value on this receiver, returning an error if the corresponding channel has hung up, or if `deadline` is reached.",263,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"generics":["recvtimeouterror"],"name":"result"}}],[11,"iter","","Returns an iterator that will block waiting for messages, but never [`panic!`]. It will return [`None`] when the channel has hung up.",263,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"try_iter","","Returns an iterator that will attempt to yield all pending values. It will return `None` if there are no more pending values or if the channel has hung up. The iterator will never [`panic!`] or block the user by waiting for values.",263,{"inputs":[{"name":"self"}],"output":{"name":"tryiter"}}],[11,"next","","",257,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",258,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",259,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"into_iter","","",263,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"drop","","",263,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",263,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",251,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",251,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",251,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",251,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"fmt","","",254,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",254,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",254,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",254,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"from","","",254,{"inputs":[{"name":"senderror"}],"output":{"name":"trysenderror"}}],[11,"fmt","","",260,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",260,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",260,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"fmt","","",252,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",252,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",252,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"from","","",252,{"inputs":[{"name":"recverror"}],"output":{"name":"tryrecverror"}}],[11,"fmt","","",253,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",253,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",253,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"from","","",253,{"inputs":[{"name":"recverror"}],"output":{"name":"recvtimeouterror"}}],[11,"fmt","std::sync","",264,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new barrier that can block a given number of threads.",264,{"inputs":[{"name":"usize"}],"output":{"name":"barrier"}}],[11,"wait","","Blocks the current thread until all threads have rendezvoused here.",264,{"inputs":[{"name":"self"}],"output":{"name":"barrierwaitresult"}}],[11,"fmt","","",265,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"is_leader","","Returns whether this thread from [`wait`] is the \"leader thread\".",265,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"fmt","","",266,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",266,{"inputs":[{"name":"self"},{"name":"waittimeoutresult"}],"output":{"name":"bool"}}],[11,"ne","","",266,{"inputs":[{"name":"self"},{"name":"waittimeoutresult"}],"output":{"name":"bool"}}],[11,"clone","","",266,{"inputs":[{"name":"self"}],"output":{"name":"waittimeoutresult"}}],[11,"timed_out","","Returns whether the wait was known to have timed out.",266,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"new","","Creates a new condition variable which is ready to be waited on and notified.",267,{"inputs":[],"output":{"name":"condvar"}}],[11,"wait","","Blocks the current thread until this condition variable receives a notification.",267,{"inputs":[{"name":"self"},{"name":"mutexguard"}],"output":{"generics":["mutexguard"],"name":"lockresult"}}],[11,"wait_until","","Blocks the current thread until this condition variable receives a notification and the required condition is met. Spurious wakeups are ignored and this function will only return once the condition has been met.",267,{"inputs":[{"name":"self"},{"name":"mutexguard"},{"name":"f"}],"output":{"generics":["mutexguard"],"name":"lockresult"}}],[11,"wait_timeout_ms","","Waits on this condition variable for a notification, timing out after a specified duration.",267,{"inputs":[{"name":"self"},{"name":"mutexguard"},{"name":"u32"}],"output":{"name":"lockresult"}}],[11,"wait_timeout","","Waits on this condition variable for a notification, timing out after a specified duration.",267,{"inputs":[{"name":"self"},{"name":"mutexguard"},{"name":"duration"}],"output":{"name":"lockresult"}}],[11,"wait_timeout_until","","Waits on this condition variable for a notification, timing out after a specified duration.  Spurious wakes will not cause this function to return.",267,{"inputs":[{"name":"self"},{"name":"mutexguard"},{"name":"duration"},{"name":"f"}],"output":{"name":"lockresult"}}],[11,"notify_one","","Wakes up one blocked thread on this condvar.",267,{"inputs":[{"name":"self"}],"output":null}],[11,"notify_all","","Wakes up all blocked threads on this condvar.",267,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",267,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Creates a `Condvar` which is ready to be waited on and notified.",267,{"inputs":[],"output":{"name":"condvar"}}],[11,"drop","","",267,{"inputs":[{"name":"self"}],"output":null}],[11,"new","","Creates a new mutex in an unlocked state ready for use.",268,{"inputs":[{"name":"t"}],"output":{"name":"mutex"}}],[11,"lock","","Acquires a mutex, blocking the current thread until it is able to do so.",268,{"inputs":[{"name":"self"}],"output":{"generics":["mutexguard"],"name":"lockresult"}}],[11,"try_lock","","Attempts to acquire this lock.",268,{"inputs":[{"name":"self"}],"output":{"generics":["mutexguard"],"name":"trylockresult"}}],[11,"is_poisoned","","Determines whether the mutex is poisoned.",268,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"into_inner","","Consumes this mutex, returning the underlying data.",268,{"inputs":[{"name":"self"}],"output":{"name":"lockresult"}}],[11,"get_mut","","Returns a mutable reference to the underlying data.",268,{"inputs":[{"name":"self"}],"output":{"name":"lockresult"}}],[11,"drop","","",268,{"inputs":[{"name":"self"}],"output":null}],[11,"from","","Creates a new mutex in an unlocked state ready for use. This is equivalent to [`Mutex::new`].",268,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"default","","Creates a `Mutex<T>`, with the `Default` value for T.",268,{"inputs":[],"output":{"name":"mutex"}}],[11,"fmt","","",268,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"deref","","",269,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",269,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"drop","","",269,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",269,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",269,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",270,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new `Once` value.",271,{"inputs":[],"output":{"name":"once"}}],[11,"call_once","","Performs an initialization routine once and only once. The given closure will be executed if this is the first time `call_once` has been called, and otherwise the routine will not be invoked.",271,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"call_once_force","","Performs the same function as [`call_once`] except ignores poisoning.",271,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"fmt","","",271,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"poisoned","","Returns whether the associated [`Once`] was poisoned prior to the invocation of the closure passed to [`call_once_force`].",270,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"new","","Creates a new instance of an `RwLock<T>` which is unlocked.",272,{"inputs":[{"name":"t"}],"output":{"name":"rwlock"}}],[11,"read","","Locks this rwlock with shared read access, blocking the current thread until it can be acquired.",272,{"inputs":[{"name":"self"}],"output":{"generics":["rwlockreadguard"],"name":"lockresult"}}],[11,"try_read","","Attempts to acquire this rwlock with shared read access.",272,{"inputs":[{"name":"self"}],"output":{"generics":["rwlockreadguard"],"name":"trylockresult"}}],[11,"write","","Locks this rwlock with exclusive write access, blocking the current thread until it can be acquired.",272,{"inputs":[{"name":"self"}],"output":{"generics":["rwlockwriteguard"],"name":"lockresult"}}],[11,"try_write","","Attempts to lock this rwlock with exclusive write access.",272,{"inputs":[{"name":"self"}],"output":{"generics":["rwlockwriteguard"],"name":"trylockresult"}}],[11,"is_poisoned","","Determines whether the lock is poisoned.",272,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"into_inner","","Consumes this `RwLock`, returning the underlying data.",272,{"inputs":[{"name":"self"}],"output":{"name":"lockresult"}}],[11,"get_mut","","Returns a mutable reference to the underlying data.",272,{"inputs":[{"name":"self"}],"output":{"name":"lockresult"}}],[11,"drop","","",272,{"inputs":[{"name":"self"}],"output":null}],[11,"fmt","","",272,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"default","","Creates a new `RwLock<T>`, with the `Default` value for T.",272,{"inputs":[],"output":{"name":"rwlock"}}],[11,"from","","Creates a new instance of an `RwLock<T>` which is unlocked. This is equivalent to [`RwLock::new`].",272,{"inputs":[{"name":"t"}],"output":{"name":"self"}}],[11,"fmt","","",273,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",273,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",274,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",274,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"deref","","",273,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","","",274,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","","",274,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"drop","","",273,{"inputs":[{"name":"self"}],"output":null}],[11,"drop","","",274,{"inputs":[{"name":"self"}],"output":null}],[6,"TryLockResult","","A type alias for the result of a nonblocking locking method.",null,null],[6,"LockResult","","A type alias for the result of a lock method which can be poisoned.",null,null],[17,"ONCE_INIT","","Initialization value for static [`Once`] values.",null,null],[0,"time","std","Temporal quantification.",null,null],[3,"Duration","std::time","A `Duration` type to represent a span of time, typically used for system timeouts.",null,null],[3,"Instant","","A measurement of a monotonically nondecreasing clock. Opaque and useful only with `Duration`.",null,null],[3,"SystemTime","","A measurement of the system clock, useful for talking to external entities like the file system or other processes.",null,null],[3,"SystemTimeError","","An error returned from the `duration_since` and `elapsed` methods on `SystemTime`, used to learn how far in the opposite direction a system time lies.",null,null],[17,"UNIX_EPOCH","","An anchor in time which can be used to create new `SystemTime` instances or learn about where in time a `SystemTime` lies.",null,null],[11,"clone","","",275,{"inputs":[{"name":"self"}],"output":{"name":"instant"}}],[11,"eq","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"bool"}}],[11,"ne","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"bool"}}],[11,"le","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"bool"}}],[11,"gt","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"bool"}}],[11,"ge","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"bool"}}],[11,"cmp","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"ordering"}}],[11,"hash","","",275,null],[11,"clone","","",276,{"inputs":[{"name":"self"}],"output":{"name":"systemtime"}}],[11,"eq","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"name":"bool"}}],[11,"ne","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"name":"bool"}}],[11,"le","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"name":"bool"}}],[11,"gt","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"name":"bool"}}],[11,"ge","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"name":"bool"}}],[11,"cmp","","",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"name":"ordering"}}],[11,"hash","","",276,null],[11,"clone","","",277,{"inputs":[{"name":"self"}],"output":{"name":"systemtimeerror"}}],[11,"fmt","","",277,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"now","","Returns an instant corresponding to \"now\".",275,{"inputs":[],"output":{"name":"instant"}}],[11,"duration_since","","Returns the amount of time elapsed from another instant to this one.",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"duration"}}],[11,"elapsed","","Returns the amount of time elapsed since this instant was created.",275,{"inputs":[{"name":"self"}],"output":{"name":"duration"}}],[11,"add","","",275,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"instant"}}],[11,"add_assign","","",275,{"inputs":[{"name":"self"},{"name":"duration"}],"output":null}],[11,"sub","","",275,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"instant"}}],[11,"sub_assign","","",275,{"inputs":[{"name":"self"},{"name":"duration"}],"output":null}],[11,"sub","","",275,{"inputs":[{"name":"self"},{"name":"instant"}],"output":{"name":"duration"}}],[11,"fmt","","",275,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[18,"UNIX_EPOCH","","An anchor in time which can be used to create new `SystemTime` instances or learn about where in time a `SystemTime` lies.",276,null],[11,"now","","Returns the system time corresponding to \"now\".",276,{"inputs":[],"output":{"name":"systemtime"}}],[11,"duration_since","","Returns the amount of time elapsed from an earlier point in time.",276,{"inputs":[{"name":"self"},{"name":"systemtime"}],"output":{"generics":["duration","systemtimeerror"],"name":"result"}}],[11,"elapsed","","Returns the amount of time elapsed since this system time was created.",276,{"inputs":[{"name":"self"}],"output":{"generics":["duration","systemtimeerror"],"name":"result"}}],[11,"add","","",276,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"systemtime"}}],[11,"add_assign","","",276,{"inputs":[{"name":"self"},{"name":"duration"}],"output":null}],[11,"sub","","",276,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"systemtime"}}],[11,"sub_assign","","",276,{"inputs":[{"name":"self"},{"name":"duration"}],"output":null}],[11,"fmt","","",276,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"duration","","Returns the positive duration which represents how far forward the second system time was from the first.",277,{"inputs":[{"name":"self"}],"output":{"name":"duration"}}],[11,"description","","",277,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"fmt","","",277,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"heap","std","dox",null,null],[3,"Heap","std::heap","",null,null],[3,"System","","",null,null],[11,"fmt","std::sync","",278,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",278,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",278,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"new","","Creates a `PoisonError`.",278,{"inputs":[{"name":"t"}],"output":{"name":"poisonerror"}}],[11,"into_inner","","Consumes this error indicating that a lock is poisoned, returning the underlying guard to allow access regardless.",278,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get_ref","","Reaches into this error indicating that a lock is poisoned, returning a reference to the underlying guard to allow access regardless.",278,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get_mut","","Reaches into this error indicating that a lock is poisoned, returning a mutable reference to the underlying guard to allow access regardless.",278,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"from","","",250,{"inputs":[{"name":"poisonerror"}],"output":{"name":"trylockerror"}}],[11,"fmt","","",250,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",250,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"description","","",250,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"cause","","",250,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"option"}}],[11,"clone","std::os::windows::ffi","",279,{"inputs":[{"name":"self"}],"output":{"name":"encodewide"}}],[11,"next","","",279,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"option"}}],[11,"size_hint","","",279,null],[11,"as_raw_fd","std::fs","",148,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"from_raw_fd","","",148,{"inputs":[{"name":"rawfd"}],"output":{"name":"file"}}],[11,"into_raw_fd","","",148,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","std::io","",162,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","","",164,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","","",166,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"from_vec","std::ffi","",139,{"inputs":[{"generics":["u8"],"name":"vec"}],"output":{"name":"osstring"}}],[11,"into_vec","","",139,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"from_bytes","","",140,null],[11,"as_bytes","","",140,null],[11,"read_at","std::fs","",148,null],[11,"write_at","","",148,null],[11,"mode","","",145,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"set_mode","","",145,{"inputs":[{"name":"self"},{"name":"u32"}],"output":null}],[11,"from_mode","","",145,{"inputs":[{"name":"u32"}],"output":{"name":"permissions"}}],[11,"mode","","",144,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"openoptions"}}],[11,"custom_flags","","",144,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"openoptions"}}],[11,"dev","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"ino","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"mode","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"nlink","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"uid","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"gid","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rdev","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"size","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"atime","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"atime_nsec","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"mtime","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"mtime_nsec","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"ctime","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"ctime_nsec","","",142,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"blksize","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"blocks","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"is_block_device","","",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_char_device","","",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_fifo","","",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_socket","","",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"ino","","",149,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"mode","","",147,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"dirbuilder"}}],[11,"uid","std::process","",245,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"command"}}],[11,"gid","","",245,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"command"}}],[11,"before_exec","","",245,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"command"}}],[11,"exec","","",245,{"inputs":[{"name":"self"}],"output":{"name":"error"}}],[11,"from_raw","","",247,{"inputs":[{"name":"i32"}],"output":{"name":"self"}}],[11,"signal","","",247,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"option"}}],[11,"from_raw_fd","","",246,{"inputs":[{"name":"rawfd"}],"output":{"name":"stdio"}}],[11,"as_raw_fd","","",242,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","","",243,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","","",244,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"into_raw_fd","","",242,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"into_raw_fd","","",243,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"into_raw_fd","","",244,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_pthread_t","std::thread","",105,{"inputs":[{"name":"self"}],"output":{"name":"rawpthread"}}],[11,"into_pthread_t","","",105,{"inputs":[{"name":"self"}],"output":{"name":"rawpthread"}}],[11,"clone","std::os::unix::net","",280,{"inputs":[{"name":"self"}],"output":{"name":"socketaddr"}}],[11,"is_unnamed","","Returns true if and only if the address is unnamed.",280,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"as_pathname","","Returns the contents of this address if it is a `pathname` address.",280,{"inputs":[{"name":"self"}],"output":{"generics":["path"],"name":"option"}}],[11,"fmt","","",280,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",281,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"connect","","Connects to the socket named by `path`.",281,{"inputs":[{"name":"p"}],"output":{"generics":["unixstream"],"name":"result"}}],[11,"pair","","Creates an unnamed pair of connected sockets.",281,{"inputs":[],"output":{"name":"result"}}],[11,"try_clone","","Creates a new independently owned handle to the underlying socket.",281,{"inputs":[{"name":"self"}],"output":{"generics":["unixstream"],"name":"result"}}],[11,"local_addr","","Returns the socket address of the local half of this connection.",281,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"peer_addr","","Returns the socket address of the remote half of this connection.",281,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"set_read_timeout","","Sets the read timeout for the socket.",281,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"set_write_timeout","","Sets the write timeout for the socket.",281,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"read_timeout","","Returns the read timeout of this socket.",281,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"write_timeout","","Returns the write timeout of this socket.",281,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"set_nonblocking","","Moves the socket into or out of nonblocking mode.",281,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"take_error","","Returns the value of the `SO_ERROR` option.",281,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"shutdown","","Shuts down the read, write, or both halves of this connection.",281,{"inputs":[{"name":"self"},{"name":"shutdown"}],"output":{"name":"result"}}],[11,"read","","",281,null],[11,"initializer","","",281,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"write","","",281,null],[11,"flush","","",281,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"as_raw_fd","","",281,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"from_raw_fd","","",281,{"inputs":[{"name":"rawfd"}],"output":{"name":"unixstream"}}],[11,"into_raw_fd","","",281,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","std::net","",188,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","","",189,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"as_raw_fd","","",190,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"from_raw_fd","","",188,{"inputs":[{"name":"rawfd"}],"output":{"name":"tcpstream"}}],[11,"from_raw_fd","","",189,{"inputs":[{"name":"rawfd"}],"output":{"name":"tcplistener"}}],[11,"from_raw_fd","","",190,{"inputs":[{"name":"rawfd"}],"output":{"name":"udpsocket"}}],[11,"into_raw_fd","","",188,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"into_raw_fd","","",189,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"into_raw_fd","","",190,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"fmt","std::os::unix::net","",282,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"bind","","Creates a new `UnixListener` bound to the specified socket.",282,{"inputs":[{"name":"p"}],"output":{"generics":["unixlistener"],"name":"result"}}],[11,"accept","","Accepts a new incoming connection to this listener.",282,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"try_clone","","Creates a new independently owned handle to the underlying socket.",282,{"inputs":[{"name":"self"}],"output":{"generics":["unixlistener"],"name":"result"}}],[11,"local_addr","","Returns the local socket address of this listener.",282,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"set_nonblocking","","Moves the socket into or out of nonblocking mode.",282,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"take_error","","Returns the value of the `SO_ERROR` option.",282,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"incoming","","Returns an iterator over incoming connections.",282,{"inputs":[{"name":"self"}],"output":{"name":"incoming"}}],[11,"as_raw_fd","","",282,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"from_raw_fd","","",282,{"inputs":[{"name":"rawfd"}],"output":{"name":"unixlistener"}}],[11,"into_raw_fd","","",282,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"fmt","","",283,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",283,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"size_hint","","",283,null],[11,"fmt","","",284,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"bind","","Creates a Unix datagram socket bound to the given path.",284,{"inputs":[{"name":"p"}],"output":{"generics":["unixdatagram"],"name":"result"}}],[11,"unbound","","Creates a Unix Datagram socket which is not bound to any address.",284,{"inputs":[],"output":{"generics":["unixdatagram"],"name":"result"}}],[11,"pair","","Create an unnamed pair of connected sockets.",284,{"inputs":[],"output":{"name":"result"}}],[11,"connect","","Connects the socket to the specified address.",284,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"result"}}],[11,"try_clone","","Creates a new independently owned handle to the underlying socket.",284,{"inputs":[{"name":"self"}],"output":{"generics":["unixdatagram"],"name":"result"}}],[11,"local_addr","","Returns the address of this socket.",284,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"peer_addr","","Returns the address of this socket's peer.",284,{"inputs":[{"name":"self"}],"output":{"generics":["socketaddr"],"name":"result"}}],[11,"recv_from","","Receives data from the socket.",284,null],[11,"recv","","Receives data from the socket.",284,null],[11,"send_to","","Sends data on the socket to the specified address.",284,null],[11,"send","","Sends data on the socket to the socket's peer.",284,null],[11,"set_read_timeout","","Sets the read timeout for the socket.",284,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"set_write_timeout","","Sets the write timeout for the socket.",284,{"inputs":[{"name":"self"},{"generics":["duration"],"name":"option"}],"output":{"name":"result"}}],[11,"read_timeout","","Returns the read timeout of this socket.",284,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"write_timeout","","Returns the write timeout of this socket.",284,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"set_nonblocking","","Moves the socket into or out of nonblocking mode.",284,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"result"}}],[11,"take_error","","Returns the value of the `SO_ERROR` option.",284,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"shutdown","","Shut down the read, write, or both halves of this connection.",284,{"inputs":[{"name":"self"},{"name":"shutdown"}],"output":{"name":"result"}}],[11,"as_raw_fd","","",284,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"from_raw_fd","","",284,{"inputs":[{"name":"rawfd"}],"output":{"name":"unixdatagram"}}],[11,"into_raw_fd","","",284,{"inputs":[{"name":"self"}],"output":{"name":"rawfd"}}],[11,"from_wide","std::ffi","",139,null],[11,"encode_wide","","",140,{"inputs":[{"name":"self"}],"output":{"name":"encodewide"}}],[11,"seek_read","std::fs","",148,null],[11,"seek_write","","",148,null],[11,"access_mode","","",144,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"openoptions"}}],[11,"share_mode","","",144,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"openoptions"}}],[11,"custom_flags","","",144,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"openoptions"}}],[11,"attributes","","",144,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"openoptions"}}],[11,"security_qos_flags","","",144,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"openoptions"}}],[11,"file_attributes","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"creation_time","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"last_access_time","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"last_write_time","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"file_size","","",142,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"is_symlink_dir","","",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_symlink_file","","",146,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"as_raw_handle","","",148,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"as_raw_handle","std::io","",162,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"as_raw_handle","","",164,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"as_raw_handle","","",166,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"from_raw_handle","std::fs","",148,{"inputs":[{"name":"rawhandle"}],"output":{"name":"file"}}],[11,"into_raw_handle","","",148,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"as_raw_socket","std::net","",188,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[11,"as_raw_socket","","",189,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[11,"as_raw_socket","","",190,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[11,"from_raw_socket","","",188,{"inputs":[{"name":"rawsocket"}],"output":{"name":"tcpstream"}}],[11,"from_raw_socket","","",189,{"inputs":[{"name":"rawsocket"}],"output":{"name":"tcplistener"}}],[11,"from_raw_socket","","",190,{"inputs":[{"name":"rawsocket"}],"output":{"name":"udpsocket"}}],[11,"into_raw_socket","","",188,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[11,"into_raw_socket","","",189,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[11,"into_raw_socket","","",190,{"inputs":[{"name":"self"}],"output":{"name":"rawsocket"}}],[11,"from_raw_handle","std::process","",246,{"inputs":[{"name":"rawhandle"}],"output":{"name":"stdio"}}],[11,"as_raw_handle","","",239,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"into_raw_handle","","",239,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"as_raw_handle","","",242,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"as_raw_handle","","",243,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"as_raw_handle","","",244,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"into_raw_handle","","",242,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"into_raw_handle","","",243,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"into_raw_handle","","",244,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"from_raw","","",247,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"creation_flags","","",245,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"command"}}],[11,"as_raw_handle","std::thread","",105,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[11,"into_raw_handle","","",105,{"inputs":[{"name":"self"}],"output":{"name":"rawhandle"}}],[0,"arch","std","SIMD and vendor intrinsics module.",null,null],[0,"x86","std::arch","Platform-specific intrinsics for the `x86` platform.",null,null],[0,"x86_64","","Platform-specific intrinsics for the `x86_64` platform.",null,null],[0,"arm","","Platform-specific intrinsics for the `arm` platform.",null,null],[0,"aarch64","","Platform-specific intrinsics for the `aarch64` platform.",null,null],[14,"format","std","Creates a `String` using interpolation of runtime expressions.",null,null],[14,"vec","","Creates a [`Vec`] containing the arguments.",null,null],[14,"try","","Helper macro for reducing boilerplate code for matching `Result` together with converting downstream errors.",null,null],[14,"writeln","","Write formatted data into a buffer, with a newline appended.",null,null],[14,"write","","Write formatted data into a buffer.",null,null],[14,"unimplemented","","A standardized placeholder for marking unfinished code.",null,null],[14,"unreachable","","A utility macro for indicating unreachable code.",null,null],[14,"debug_assert_ne","","Asserts that two expressions are not equal to each other.",null,null],[14,"debug_assert_eq","","Asserts that two expressions are equal to each other.",null,null],[14,"debug_assert","","Ensure that a boolean expression is `true` at runtime.",null,null],[14,"assert_ne","","Asserts that two expressions are not equal to each other (using [`PartialEq`]).",null,null],[14,"assert_eq","","Asserts that two expressions are equal to each other (using [`PartialEq`]).",null,null],[14,"panic","","The entry point for panic of Rust threads.",null,null],[14,"print","","Macro for printing to the standard output.",null,null],[14,"println","","Macro for printing to the standard output, with a newline.",null,null],[14,"eprint","","Macro for printing to the standard error.",null,null],[14,"eprintln","","Macro for printing to the standard error, with a newline.",null,null],[14,"select","","A macro to select an event from a number of receivers.",null,null],[14,"compile_error","","Unconditionally causes compilation to fail with the given error message when encountered.",null,null],[14,"format_args","","The core macro for formatted string creation & output.",null,null],[14,"env","","Inspect an environment variable at compile time.",null,null],[14,"option_env","","Optionally inspect an environment variable at compile time.",null,null],[14,"concat_idents","","Concatenate identifiers into one identifier.",null,null],[14,"concat","","Concatenates literals into a static string slice.",null,null],[14,"line","","A macro which expands to the line number on which it was invoked.",null,null],[14,"column","","A macro which expands to the column number on which it was invoked.",null,null],[14,"file","","A macro which expands to the file name from which it was invoked.",null,null],[14,"stringify","","A macro which stringifies its arguments.",null,null],[14,"include_str","","Includes a utf8-encoded file as a string.",null,null],[14,"include_bytes","","Includes a file as a reference to a byte array.",null,null],[14,"module_path","","Expands to a string that represents the current module path.",null,null],[14,"cfg","","Boolean evaluation of configuration flags, at compile-time.",null,null],[14,"include","","Parse a file as an expression or an item according to the context.",null,null],[14,"assert","","Ensure that a boolean expression is `true` at runtime.",null,null],[14,"thread_local","","Declare a new thread local storage key of type [`std::thread::LocalKey`].",null,null],[14,"is_x86_feature_detected","","",null,null],[14,"is_arm_feature_detected","","",null,null],[14,"is_aarch64_feature_detected","","",null,null],[14,"is_powerpc64_feature_detected","","",null,null],[15,"bool","","The boolean type.",null,null],[15,"never","","The `!` type, also called \"never\".",null,null],[15,"char","","A character type.",null,null],[15,"unit","","The `()` type, sometimes called \"unit\" or \"nil\".",null,null],[15,"pointer","","Raw, unsafe pointers, `*const T`, and `*mut T`.",null,null],[15,"array","","A fixed-size array, denoted `[T; N]`, for the element type, `T`, and the non-negative compile-time constant size, `N`.",null,null],[15,"slice","","A dynamically-sized view into a contiguous sequence, `[T]`.",null,null],[15,"str","","String slices.",null,null],[15,"tuple","","A finite heterogeneous sequence, `(T, U, ..)`.",null,null],[15,"f32","","The 32-bit floating point type.",null,null],[15,"f64","","The 64-bit floating point type.",null,null],[15,"i8","","The 8-bit signed integer type.",null,null],[15,"i16","","The 16-bit signed integer type.",null,null],[15,"i32","","The 32-bit signed integer type.",null,null],[15,"i64","","The 64-bit signed integer type.",null,null],[15,"i128","","The 128-bit signed integer type.",null,null],[15,"u8","","The 8-bit unsigned integer type.",null,null],[15,"u16","","The 16-bit unsigned integer type.",null,null],[15,"u32","","The 32-bit unsigned integer type.",null,null],[15,"u64","","The 64-bit unsigned integer type.",null,null],[15,"u128","","The 128-bit unsigned integer type.",null,null],[15,"isize","","The pointer-sized signed integer type.",null,null],[15,"usize","","The pointer-sized unsigned integer type.",null,null],[15,"reference","","References, both shared and mutable.",null,null],[15,"fn","","Function pointers, like `fn(usize) -> bool`.",null,null],[11,"is","std::any","Returns `true` if the boxed type is the same as `T`.",0,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"downcast_ref","","Returns some reference to the boxed value if it is of type `T`, or `None` if it isn't.",0,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast_mut","","Returns some mutable reference to the boxed value if it is of type `T`, or `None` if it isn't.",0,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"is","","Forwards to the method defined on the type `Any`.",0,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"downcast_ref","","Forwards to the method defined on the type `Any`.",0,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"downcast_mut","","Forwards to the method defined on the type `Any`.",0,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"len","std","",285,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",285,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::iter","",286,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",286,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","","",287,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",287,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","","",288,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",288,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","std::slice","",289,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::iter","",290,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",290,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","std::slice","",291,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::char","",292,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","std::iter","",293,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","","",294,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",294,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::str","",295,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",295,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","std::slice","",296,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","","",297,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::iter","",298,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","","",299,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",299,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::char","",300,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"add","std::num","",195,null],[11,"add","std","",301,null],[11,"add","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"add","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"add","std","",301,null],[11,"add","","",304,null],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"add","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"add","std","",306,null],[11,"add","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"add","std::simd","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"f64x8"}}],[11,"add","std::time","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"duration"}}],[11,"add","std::num","",195,null],[11,"add","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"add","std","",306,null],[11,"add","","",301,null],[11,"add","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"add","std","",304,null],[11,"add","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"add","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"add","std","",314,null],[11,"add","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"add","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"add","std","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"add","","",318,null],[11,"add","","",319,null],[11,"add","","",307,null],[11,"add","","",320,null],[11,"add","std::simd","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"f64x2"}}],[11,"add","std","",322,null],[11,"add","","",307,null],[11,"add","std::simd","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"f32x2"}}],[11,"add","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"add","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"add","std","",322,null],[11,"add","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"add","std","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"add","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"add","","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"add","std","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"add","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"add","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"add","std","",320,null],[11,"add","std::num","",195,null],[11,"add","std","",329,null],[11,"add","","",332,null],[11,"add","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"add","std","",319,null],[11,"add","std::num","",195,null],[11,"add","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"add","std","",335,null],[11,"add","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"add","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"add","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"add","std","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"add","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"add","std","",320,null],[11,"add","","",332,null],[11,"add","","",318,null],[11,"add","std::num","",195,null],[11,"add","std","",329,null],[11,"add","std::num","",195,null],[11,"add","std","",335,null],[11,"add","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"add","std::num","",195,null],[11,"add","std","",314,null],[11,"add","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"add","","",317,null],[11,"add","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"add","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"add","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"add","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"add","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"add","","",339,null],[11,"add","std::num","",195,null],[11,"add","std","",317,null],[11,"add","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"add","","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"f32x8"}}],[11,"add","std","",318,null],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"add","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"add","std","",314,null],[11,"add","","",329,null],[11,"add","","",319,null],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"add","std","",304,null],[11,"add","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"add","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"add","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"f32x16"}}],[11,"add","std","",306,null],[11,"add","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"add","std::num","",195,null],[11,"add","","",195,null],[11,"add","","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"add","","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"add","std","",332,null],[11,"add","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"add","","",339,null],[11,"add","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"add","std","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"add","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"add","","",322,null],[11,"add","std::simd","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"f64x4"}}],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"add","std","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"add","std::num","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"add","std","",307,null],[11,"add","std::num","",195,null],[11,"add","std","",339,null],[11,"add","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"add","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"add","std::num","",195,null],[11,"add","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"add","std","",317,null],[11,"add","","",335,null],[11,"add","std::simd","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"f32x4"}}],[11,"add","std","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"add","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"add","","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"next","std::char","",359,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"size_hint","","",359,null],[11,"next","std::iter","",287,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",287,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",287,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",287,null],[11,"try_fold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::result","",360,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",360,null],[11,"next","std::iter","Overflow Behavior",288,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",288,null],[11,"nth","","",288,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"count","","",288,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"try_fold","","",288,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",288,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","","",361,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",361,null],[11,"try_fold","","",361,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"next","","",362,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",362,null],[11,"next","std::str","",363,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","std::slice","",364,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",364,null],[11,"count","","",364,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",364,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",364,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::iter","",294,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",294,null],[11,"try_fold","","",294,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",294,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"find","","",294,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"rposition","","",294,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next","std::str","",365,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::ops","",49,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",49,null],[11,"nth","","",49,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next","std::iter","",298,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",298,null],[11,"next","","",366,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",366,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"count","","",366,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",366,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",366,null],[11,"try_fold","","",366,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",366,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::result","",367,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",367,null],[11,"next","std::slice","",368,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",368,null],[11,"count","","",368,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",368,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",368,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::iter","",369,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",369,null],[11,"try_fold","","",369,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",369,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::slice","",370,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",370,null],[11,"next","std::iter","",286,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",286,null],[11,"try_fold","","",286,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",286,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::slice","",371,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",371,null],[11,"next","std::char","",372,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",372,null],[11,"next","std::str","",373,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","std::option","",374,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",374,null],[11,"next","std::slice","",375,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",375,null],[11,"next","std::iter","",376,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",376,null],[11,"try_fold","","",376,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"next","std::str","",377,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",377,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",377,null],[11,"last","","",377,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",378,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","std::slice","",291,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",291,null],[11,"count","","",291,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",291,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",291,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",291,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",291,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"position","","",291,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",291,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next","std::option","",379,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",379,null],[11,"next","std::iter","",380,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",380,null],[11,"try_fold","","",380,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",380,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::char","",300,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",300,null],[11,"count","","",300,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",300,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["char"],"name":"option"}}],[11,"last","","",300,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next","std::iter","",287,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",287,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",287,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",287,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",287,null],[11,"try_fold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::str","",381,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","std::slice","",382,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",382,null],[11,"next","std::iter","",383,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",383,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"try_fold","","",383,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",383,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"nth","","",383,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"find","","",383,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"last","","",383,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",383,null],[11,"next","","",384,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",384,null],[11,"next","std::slice","",289,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",289,null],[11,"count","","",289,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",289,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",289,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",289,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",289,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"position","","",289,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",289,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next","std::str","",385,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"count","","",385,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"size_hint","","",385,null],[11,"last","","",385,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next","","",386,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"size_hint","","",386,null],[11,"next","std::iter","",387,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",387,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"size_hint","","",387,null],[11,"try_fold","","",387,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"next","std::slice","",388,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",388,null],[11,"next","std::iter","",389,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",389,null],[11,"count","","",389,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"try_fold","","",389,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",389,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","","",390,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",390,null],[11,"nth","","",390,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next","std::str","",391,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","","",295,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"size_hint","","",295,null],[11,"count","","",295,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",295,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"nth","","",295,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"all","","",295,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"any","","",295,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"bool"}}],[11,"find","","",295,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"position","","",295,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rposition","","",295,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"next","std::iter","",392,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",392,null],[11,"try_fold","","",392,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",392,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::str","",393,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::iter","",299,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",299,null],[11,"try_fold","","",299,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",299,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next","std::str","",394,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"size_hint","","",394,null],[11,"next","std::ascii","",395,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"size_hint","","",395,null],[11,"next","std::str","",396,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","std::iter","",290,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",290,null],[11,"try_fold","","",290,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"r"}}],[11,"fold","","",290,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"acc"}}],[11,"next","std::slice","",297,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",297,null],[11,"count","","",297,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",297,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",297,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::iter","",397,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",397,null],[11,"nth","","",397,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next","","",398,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",398,null],[11,"try_fold","","",398,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"fold","","",398,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::char","",292,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",292,null],[11,"count","","",292,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",292,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next","std::option","",399,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",399,null],[11,"next","std::slice","",296,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",296,null],[11,"count","","",296,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",296,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",296,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::ops","",48,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",48,null],[11,"nth","","",48,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",48,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"min","","",48,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"max","","",48,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::iter","",293,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",293,null],[11,"next","std::result","",400,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",400,null],[11,"next","std::slice","",401,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",401,null],[11,"next","","",402,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",402,null],[11,"count","","",402,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",402,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",402,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",403,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",403,null],[11,"next","std::iter","",404,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",404,null],[11,"next","","",405,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"count","","",405,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",405,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",405,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",405,null],[11,"try_fold","","",405,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"fold","","",405,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next","std::str","",406,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","std::slice","",407,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",407,null],[11,"next","std","",285,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",285,null],[11,"nth","","",285,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next","std::ops","",34,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",34,null],[11,"nth","","",34,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"last","","",34,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"min","","",34,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"max","","",34,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_fold","","",34,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"next","std::str","",408,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"borrow","std","",285,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",285,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"borrow","","",409,null],[11,"fmt","std::num","",195,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",348,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",353,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",340,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",331,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",346,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",410,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",344,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",324,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",305,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",338,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",312,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",302,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",355,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",334,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",310,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",411,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",322,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",343,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",337,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",350,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",335,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",336,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",307,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",412,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",413,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",330,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",332,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",311,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",357,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",414,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",306,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",320,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",415,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",327,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",317,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",328,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",416,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",301,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",318,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",326,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",342,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",325,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",315,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",304,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",351,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",316,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",333,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",329,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",347,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",341,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",313,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",417,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",418,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",354,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",419,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",420,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",421,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",358,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",339,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",303,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"get","std::ops","",31,null],[11,"get_mut","","",31,null],[11,"get_unchecked","","",31,null],[11,"get_unchecked_mut","","",31,null],[11,"index","","",31,null],[11,"index_mut","","",31,null],[11,"get","","",422,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",422,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",422,null],[11,"get_unchecked_mut","","",422,null],[11,"index","","",422,null],[11,"index_mut","","",422,null],[11,"get","","",48,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",48,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",48,null],[11,"get_unchecked_mut","","",48,null],[11,"index","","",48,null],[11,"index_mut","","",48,null],[11,"get","","",49,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",49,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",49,null],[11,"get_unchecked_mut","","",49,null],[11,"index","","",49,null],[11,"index_mut","","",49,null],[11,"get","","",35,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",35,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",35,null],[11,"get_unchecked_mut","","",35,null],[11,"index","","",35,null],[11,"index_mut","","",35,null],[11,"get","","",31,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",31,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",31,null],[11,"get_unchecked_mut","","",31,null],[11,"index","","",31,null],[11,"index_mut","","",31,null],[11,"get","","",35,null],[11,"get_mut","","",35,null],[11,"get_unchecked","","",35,null],[11,"get_unchecked_mut","","",35,null],[11,"index","","",35,null],[11,"index_mut","","",35,null],[11,"get","std","",304,null],[11,"get_mut","","",304,null],[11,"get_unchecked","","",304,null],[11,"get_unchecked_mut","","",304,null],[11,"index","","",304,null],[11,"index_mut","","",304,null],[11,"get","std::ops","",48,null],[11,"get_mut","","",48,null],[11,"get_unchecked","","",48,null],[11,"get_unchecked_mut","","",48,null],[11,"index","","",48,null],[11,"index_mut","","",48,null],[11,"get","","",422,null],[11,"get_mut","","",422,null],[11,"get_unchecked","","",422,null],[11,"get_unchecked_mut","","",422,null],[11,"index","","",422,null],[11,"index_mut","","",422,null],[11,"get","","",49,null],[11,"get_mut","","",49,null],[11,"get_unchecked","","",49,null],[11,"get_unchecked_mut","","",49,null],[11,"index","","",49,null],[11,"index_mut","","",49,null],[11,"get","","",34,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_mut","","",34,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"option"}}],[11,"get_unchecked","","",34,null],[11,"get_unchecked_mut","","",34,null],[11,"index","","",34,null],[11,"index_mut","","",34,null],[11,"get","","",34,null],[11,"get_mut","","",34,null],[11,"get_unchecked","","",34,null],[11,"get_unchecked_mut","","",34,null],[11,"index","","",34,null],[11,"index_mut","","",34,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",424,null],[11,"hash","std::simd","",348,null],[11,"hash","std","",409,null],[11,"hash","","",423,null],[11,"hash","","",425,null],[11,"hash","","",423,null],[11,"hash","std::simd","",341,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","std::mem","",426,null],[11,"hash","std::ptr","",427,null],[11,"hash","std","",409,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","std::num","",420,null],[11,"hash","std::simd","",327,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","std::simd","",357,null],[11,"hash","std::fmt","",127,null],[11,"hash","std","",423,null],[11,"hash","std::ops","",35,null],[11,"hash","std::simd","",337,null],[11,"hash","std","",409,null],[11,"hash","","",423,null],[11,"hash","","",424,null],[11,"hash","","",423,null],[11,"hash","std::simd","",338,null],[11,"hash","std::num","",421,null],[11,"hash","std","",423,null],[11,"hash","std::ops","",48,null],[11,"hash","std::simd","",324,null],[11,"hash","std::num","",412,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",424,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",307,null],[11,"hash_slice","","",307,null],[11,"hash","","",304,null],[11,"hash_slice","","",304,null],[11,"hash","std::ops","",34,null],[11,"hash","std","",424,null],[11,"hash","std::num","",415,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","std::simd","",347,null],[11,"hash","","",354,null],[11,"hash","std","",409,null],[11,"hash","","",423,null],[11,"hash","std::ops","",31,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",409,null],[11,"hash","std::simd","",346,null],[11,"hash","std","",423,null],[11,"hash","","",285,null],[11,"hash","std::any","",428,null],[11,"hash","std","",409,null],[11,"hash","","",429,null],[11,"hash","","",423,null],[11,"hash","","",409,null],[11,"hash","std::option","",430,null],[11,"hash","std::ops","",53,null],[11,"hash","std","",409,null],[11,"hash","std::simd","",333,null],[11,"hash","","",311,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","","",409,null],[11,"hash","","",423,null],[11,"hash","std::simd","",326,null],[11,"hash","std","",431,null],[11,"hash","","",317,null],[11,"hash_slice","","",317,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","std::simd","",325,null],[11,"hash","std::time","",309,null],[11,"hash","std::simd","",342,null],[11,"hash","std","",424,null],[11,"hash","std::simd","",353,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",301,null],[11,"hash_slice","","",301,null],[11,"hash","","",409,null],[11,"hash","","",409,null],[11,"hash","std::simd","",303,null],[11,"hash","std::num","",417,null],[11,"hash","std","",423,null],[11,"hash","","",424,null],[11,"hash","std::simd","",351,null],[11,"hash","std::ops","",422,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","std::num","",419,null],[11,"hash","std","",424,null],[11,"hash","","",423,null],[11,"hash","std::simd","",310,null],[11,"hash","std","",409,null],[11,"hash","","",409,null],[11,"hash","","",423,null],[11,"hash","","",322,null],[11,"hash_slice","","",322,null],[11,"hash","std::num","",414,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",424,null],[11,"hash","","",424,null],[11,"hash","std::simd","",316,null],[11,"hash","std::num","",411,null],[11,"hash","std","",423,null],[11,"hash","","",306,null],[11,"hash_slice","","",306,null],[11,"hash","","",423,null],[11,"hash","","",409,null],[11,"hash","","",409,null],[11,"hash","","",329,null],[11,"hash_slice","","",329,null],[11,"hash","std::simd","",313,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","","",423,null],[11,"hash","","",409,null],[11,"hash","std::simd","",355,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","std::simd","",315,null],[11,"hash","std","",423,null],[11,"hash","","",424,null],[11,"hash","","",409,null],[11,"hash","std::simd","",312,null],[11,"hash","std","",318,null],[11,"hash_slice","","",318,null],[11,"hash","std::ops","",37,null],[11,"hash","std::num","",416,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","","",285,null],[11,"hash","std::simd","",331,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","std::simd","",340,null],[11,"hash","std","",432,null],[11,"hash","std::simd","",336,null],[11,"hash","","",302,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","std::simd","",305,null],[11,"hash","std::cmp","",3,null],[11,"hash","std","",423,null],[11,"hash","","",409,null],[11,"hash","","",424,null],[11,"hash","std::simd","",343,null],[11,"hash","std::result","",72,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",332,null],[11,"hash_slice","","",332,null],[11,"hash","","",339,null],[11,"hash_slice","","",339,null],[11,"hash","std::simd","",350,null],[11,"hash","std::num","",413,null],[11,"hash","std::simd","",328,null],[11,"hash","std","",409,null],[11,"hash","std::simd","",344,null],[11,"hash","","",334,null],[11,"hash","std","",433,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","std::ops","",49,null],[11,"hash","std","",434,null],[11,"hash","","",409,null],[11,"hash","std::simd","",330,null],[11,"hash","std::mem","",435,null],[11,"hash","std::num","",418,null],[11,"hash","","",195,null],[11,"hash","std","",423,null],[11,"hash","std::marker","",436,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","","",409,null],[11,"hash","std::option","",73,null],[11,"hash","std","",409,null],[11,"hash","","",409,null],[11,"hash","","",423,null],[11,"hash","std::num","",410,null],[11,"hash","std","",423,null],[11,"hash","","",423,null],[11,"hash","","",424,null],[11,"hash","","",335,null],[11,"hash_slice","","",335,null],[11,"hash","","",423,null],[11,"hash","","",423,null],[11,"hash","","",409,null],[11,"hash","","",409,null],[11,"hash","","",423,null],[11,"hash","std::cmp","",4,null],[11,"hash","std","",423,null],[11,"hash","std::simd","",358,null],[11,"hash","std","",425,null],[11,"hash","","",320,null],[11,"hash_slice","","",320,null],[11,"hash","","",409,null],[11,"resume","","",285,{"inputs":[{"name":"self"}],"output":{"name":"generatorstate"}}],[11,"index","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeto"}],"output":{"name":"str"}}],[11,"index","","",433,null],[11,"index","","",429,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"str"}}],[11,"index","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeinclusive"}],"output":{"name":"str"}}],[11,"index","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangefrom"}],"output":{"name":"str"}}],[11,"index","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangetoinclusive"}],"output":{"name":"str"}}],[11,"index","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"range"}],"output":{"name":"str"}}],[11,"clone","std::iter","",294,{"inputs":[{"name":"self"}],"output":{"name":"rev"}}],[11,"clone","std::str::pattern","",437,{"inputs":[{"name":"self"}],"output":{"name":"strsearcher"}}],[11,"clone","std::num","",414,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi128"}}],[11,"clone","","",438,{"inputs":[{"name":"self"}],"output":{"name":"parsefloaterror"}}],[11,"clone","","",439,{"inputs":[{"name":"self"}],"output":{"name":"tryfrominterror"}}],[11,"clone","std::simd","",440,{"inputs":[{"name":"self"}],"output":{"name":"b8x64"}}],[11,"clone","","",441,{"inputs":[{"name":"self"}],"output":{"name":"b8x16"}}],[11,"clone","std::num","",411,{"inputs":[{"name":"self"}],"output":{"name":"nonzerousize"}}],[11,"clone","std::simd","",349,{"inputs":[{"name":"self"}],"output":{"name":"f32x16"}}],[11,"clone","","",308,{"inputs":[{"name":"self"}],"output":{"name":"f64x8"}}],[11,"clone","","",323,{"inputs":[{"name":"self"}],"output":{"name":"f32x2"}}],[11,"clone","","",348,{"inputs":[{"name":"self"}],"output":{"name":"i8x8"}}],[11,"clone","","",316,{"inputs":[{"name":"self"}],"output":{"name":"i32x16"}}],[11,"clone","std::str","",377,{"inputs":[{"name":"self"}],"output":{"name":"charindices"}}],[11,"clone","std::simd","",315,{"inputs":[{"name":"self"}],"output":{"name":"u8x16"}}],[11,"clone","std::cmp","",3,{"inputs":[{"name":"self"}],"output":{"name":"ordering"}}],[11,"clone","std::simd","",442,{"inputs":[{"name":"self"}],"output":{"name":"b8x32"}}],[11,"clone","std::iter","",392,{"inputs":[{"name":"self"}],"output":{"name":"flatten"}}],[11,"clone","std::marker","",436,{"inputs":[{"name":"self"}],"output":{"name":"phantomdata"}}],[11,"clone","std::slice","",403,{"inputs":[{"name":"self"}],"output":{"name":"split"}}],[11,"clone","std::ops","",37,{"inputs":[{"name":"self"}],"output":{"name":"generatorstate"}}],[11,"clone","std::str","",393,{"inputs":[{"name":"self"}],"output":{"name":"rmatchindices"}}],[11,"clone","std::ops","",53,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"clone","std::str","",122,{"inputs":[{"name":"self"}],"output":{"name":"utf8error"}}],[11,"clone","","",391,{"inputs":[{"name":"self"}],"output":{"name":"rsplit"}}],[11,"clone","std::iter","",390,{"inputs":[{"name":"self"}],"output":{"name":"zip"}}],[11,"clone","std::char","",292,{"inputs":[{"name":"self"}],"output":{"name":"escapeunicode"}}],[11,"clone","std::simd","",311,{"inputs":[{"name":"self"}],"output":{"name":"i16x4"}}],[11,"clone","","",342,{"inputs":[{"name":"self"}],"output":{"name":"u16x32"}}],[11,"clone","std::fmt","",127,{"inputs":[{"name":"self"}],"output":{"name":"error"}}],[11,"clone","std::simd","",354,{"inputs":[{"name":"self"}],"output":{"name":"i16x2"}}],[11,"clone","","",326,{"inputs":[{"name":"self"}],"output":{"name":"i32x2"}}],[11,"clone","std::char","",300,{"inputs":[{"name":"self"}],"output":{"name":"escapedefault"}}],[11,"clone","std::str::pattern","",443,{"inputs":[{"name":"self"}],"output":{"name":"charslicesearcher"}}],[11,"clone","std::str","",295,{"inputs":[{"name":"self"}],"output":{"name":"bytes"}}],[11,"clone","std::char","",130,{"inputs":[{"name":"self"}],"output":{"name":"chartryfromerror"}}],[11,"clone","std::simd","",310,{"inputs":[{"name":"self"}],"output":{"name":"u32x2"}}],[11,"clone","std::iter","",387,{"inputs":[{"name":"self"}],"output":{"name":"take"}}],[11,"clone","std::simd","",351,{"inputs":[{"name":"self"}],"output":{"name":"u8x32"}}],[11,"clone","","",340,{"inputs":[{"name":"self"}],"output":{"name":"u32x8"}}],[11,"clone","std::str","",386,{"inputs":[{"name":"self"}],"output":{"name":"lines"}}],[11,"clone","std::iter","",290,{"inputs":[{"name":"self"}],"output":{"name":"map"}}],[11,"clone","std::num","",420,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou128"}}],[11,"clone","std::iter","",383,{"inputs":[{"name":"self"}],"output":{"name":"chain"}}],[11,"clone","","",293,{"inputs":[{"name":"self"}],"output":{"name":"once"}}],[11,"clone","","",298,{"inputs":[{"name":"self"}],"output":{"name":"empty"}}],[11,"clone","std::simd","",327,{"inputs":[{"name":"self"}],"output":{"name":"i64x2"}}],[11,"clone","std::num","",194,{"inputs":[{"name":"self"}],"output":{"name":"fpcategory"}}],[11,"clone","std::collections","",108,{"inputs":[{"name":"self"}],"output":{"name":"collectionallocerr"}}],[11,"clone","std::iter","",398,{"inputs":[{"name":"self"}],"output":{"name":"flatmap"}}],[11,"clone","std::simd","",312,{"inputs":[{"name":"self"}],"output":{"name":"u16x8"}}],[11,"clone","","",346,{"inputs":[{"name":"self"}],"output":{"name":"u16x4"}}],[11,"clone","std::option","",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","std::simd","",350,{"inputs":[{"name":"self"}],"output":{"name":"u32x16"}}],[11,"clone","std::iter","",380,{"inputs":[{"name":"self"}],"output":{"name":"skipwhile"}}],[11,"clone","std::mem","",435,{"inputs":[{"name":"self"}],"output":{"name":"discriminant"}}],[11,"clone","std::iter","",384,{"inputs":[{"name":"self"}],"output":{"name":"repeat"}}],[11,"clone","std::simd","",444,{"inputs":[{"name":"self"}],"output":{"name":"b8x4"}}],[11,"clone","","",347,{"inputs":[{"name":"self"}],"output":{"name":"u8x4"}}],[11,"clone","std::slice","",364,{"inputs":[{"name":"self"}],"output":{"name":"windows"}}],[11,"clone","std::iter","",287,{"inputs":[{"name":"self"}],"output":{"name":"fuse"}}],[11,"clone","std::str::pattern","",92,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"clone","std::ptr","",445,{"inputs":[{"name":"self"}],"output":{"name":"unique"}}],[11,"clone","std::raw","",71,{"inputs":[{"name":"self"}],"output":{"name":"traitobject"}}],[11,"clone","std::simd","",302,{"inputs":[{"name":"self"}],"output":{"name":"i16x32"}}],[11,"clone","","",328,{"inputs":[{"name":"self"}],"output":{"name":"u64x2"}}],[11,"clone","std::iter","",404,{"inputs":[{"name":"self"}],"output":{"name":"repeatwith"}}],[11,"clone","","",361,{"inputs":[{"name":"self"}],"output":{"name":"takewhile"}}],[11,"clone","std::str","",396,{"inputs":[{"name":"self"}],"output":{"name":"rmatches"}}],[11,"clone","std::fmt","",446,{"inputs":[{"name":"self"}],"output":{"name":"arguments"}}],[11,"clone","std::str","",408,{"inputs":[{"name":"self"}],"output":{"name":"rsplitn"}}],[11,"clone","std::iter","",288,{"inputs":[{"name":"self"}],"output":{"name":"enumerate"}}],[11,"clone","std::str","",363,{"inputs":[{"name":"self"}],"output":{"name":"splitn"}}],[11,"clone","std::mem","",426,{"inputs":[{"name":"self"}],"output":{"name":"manuallydrop"}}],[11,"clone_from","","",426,null],[11,"clone","std::simd","",330,{"inputs":[{"name":"self"}],"output":{"name":"i8x4"}}],[11,"clone","","",303,{"inputs":[{"name":"self"}],"output":{"name":"i32x8"}}],[11,"clone","std::str","",406,{"inputs":[{"name":"self"}],"output":{"name":"matches"}}],[11,"clone","","",381,{"inputs":[{"name":"self"}],"output":{"name":"splitterminator"}}],[11,"clone","std::num","",413,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou64"}}],[11,"clone","std::option","",379,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::char","",359,{"inputs":[{"name":"self"}],"output":{"name":"decodeutf8"}}],[11,"clone","std::iter","",369,{"inputs":[{"name":"self"}],"output":{"name":"filtermap"}}],[11,"clone","std::char","",131,{"inputs":[{"name":"self"}],"output":{"name":"parsecharerror"}}],[11,"clone","std::iter","",376,{"inputs":[{"name":"self"}],"output":{"name":"scan"}}],[11,"clone","std::time","",309,{"inputs":[{"name":"self"}],"output":{"name":"duration"}}],[11,"clone","std::simd","",336,{"inputs":[{"name":"self"}],"output":{"name":"i8x2"}}],[11,"clone","std::num","",421,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi8"}}],[11,"clone","std::simd","",338,{"inputs":[{"name":"self"}],"output":{"name":"i16x16"}}],[11,"clone","","",337,{"inputs":[{"name":"self"}],"output":{"name":"i16x8"}}],[11,"clone","std::iter","",389,{"inputs":[{"name":"self"}],"output":{"name":"filter"}}],[11,"clone","std::num","",418,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou8"}}],[11,"clone","std::slice","",289,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::num","",415,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroisize"}}],[11,"clone","std::simd","",344,{"inputs":[{"name":"self"}],"output":{"name":"u16x2"}}],[11,"clone","","",325,{"inputs":[{"name":"self"}],"output":{"name":"i8x64"}}],[11,"clone","","",447,{"inputs":[{"name":"self"}],"output":{"name":"b8x8"}}],[11,"clone","","",333,{"inputs":[{"name":"self"}],"output":{"name":"u16x16"}}],[11,"clone","std::num","",448,{"inputs":[{"name":"self"}],"output":{"name":"parseinterror"}}],[11,"clone","","",419,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi64"}}],[11,"clone","std::simd","",321,{"inputs":[{"name":"self"}],"output":{"name":"f64x2"}}],[11,"clone","","",356,{"inputs":[{"name":"self"}],"output":{"name":"f32x4"}}],[11,"clone","std::ops","",35,{"inputs":[{"name":"self"}],"output":{"name":"rangetoinclusive"}}],[11,"clone","std::hash","",449,{"inputs":[{"name":"self"}],"output":{"name":"siphasher"}}],[11,"clone","std::simd","",352,{"inputs":[{"name":"self"}],"output":{"name":"f64x4"}}],[11,"clone","","",450,{"inputs":[{"name":"self"}],"output":{"name":"b8x2"}}],[11,"clone","std::num","",195,{"inputs":[{"name":"self"}],"output":{"name":"wrapping"}}],[11,"clone","","",412,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou16"}}],[11,"clone","std::iter","",405,{"inputs":[{"name":"self"}],"output":{"name":"peekable"}}],[11,"clone","std::result","",72,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"clone","std::cmp","",4,{"inputs":[{"name":"self"}],"output":{"name":"reverse"}}],[11,"clone","std::iter","",362,{"inputs":[{"name":"self"}],"output":{"name":"cycle"}}],[11,"clone","std::str","",394,{"inputs":[{"name":"self"}],"output":{"name":"linesany"}}],[11,"clone","std::iter","",366,{"inputs":[{"name":"self"}],"output":{"name":"skip"}}],[11,"clone","std::slice","",382,{"inputs":[{"name":"self"}],"output":{"name":"rsplit"}}],[11,"clone","std::simd","",313,{"inputs":[{"name":"self"}],"output":{"name":"i8x16"}}],[11,"clone","std::iter","",299,{"inputs":[{"name":"self"}],"output":{"name":"cloned"}}],[11,"clone","std::simd","",345,{"inputs":[{"name":"self"}],"output":{"name":"f32x8"}}],[11,"clone","std::ops","",48,{"inputs":[{"name":"self"}],"output":{"name":"range"}}],[11,"clone","","",422,{"inputs":[{"name":"self"}],"output":{"name":"rangefull"}}],[11,"clone","","",31,{"inputs":[{"name":"self"}],"output":{"name":"rangeto"}}],[11,"clone","std::simd","",355,{"inputs":[{"name":"self"}],"output":{"name":"u64x4"}}],[11,"clone","std::any","",428,{"inputs":[{"name":"self"}],"output":{"name":"typeid"}}],[11,"clone","std::num","",410,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi16"}}],[11,"clone","std::cell","",451,{"inputs":[{"name":"self"}],"output":{"name":"cell"}}],[11,"clone","std::str::pattern","",452,{"inputs":[{"name":"self"}],"output":{"name":"charpredicatesearcher"}}],[11,"clone","std::iter","",286,{"inputs":[{"name":"self"}],"output":{"name":"inspect"}}],[11,"clone","std::ptr","",427,{"inputs":[{"name":"self"}],"output":{"name":"nonnull"}}],[11,"clone","std::str","",378,{"inputs":[{"name":"self"}],"output":{"name":"rsplitterminator"}}],[11,"clone","std::simd","",334,{"inputs":[{"name":"self"}],"output":{"name":"u8x64"}}],[11,"clone","std::str","",365,{"inputs":[{"name":"self"}],"output":{"name":"matchindices"}}],[11,"clone","std::hash","",453,{"inputs":[{"name":"self"}],"output":{"name":"buildhasherdefault"}}],[11,"clone","std::iter","",397,{"inputs":[{"name":"self"}],"output":{"name":"stepby"}}],[11,"clone","std::simd","",324,{"inputs":[{"name":"self"}],"output":{"name":"u8x8"}}],[11,"clone","","",343,{"inputs":[{"name":"self"}],"output":{"name":"u8x2"}}],[11,"clone","std::ops","",34,{"inputs":[{"name":"self"}],"output":{"name":"rangeinclusive"}}],[11,"clone","std::slice","",402,{"inputs":[{"name":"self"}],"output":{"name":"chunks"}}],[11,"clone","std::str","",373,{"inputs":[{"name":"self"}],"output":{"name":"split"}}],[11,"clone","std::result","",367,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::slice","",296,{"inputs":[{"name":"self"}],"output":{"name":"exactchunks"}}],[11,"clone","std::str","",121,{"inputs":[{"name":"self"}],"output":{"name":"parseboolerror"}}],[11,"clone","std::simd","",353,{"inputs":[{"name":"self"}],"output":{"name":"i64x8"}}],[11,"clone","std::sync::atomic","",249,{"inputs":[{"name":"self"}],"output":{"name":"ordering"}}],[11,"clone","std::ops","",49,{"inputs":[{"name":"self"}],"output":{"name":"rangefrom"}}],[11,"clone","std::simd","",305,{"inputs":[{"name":"self"}],"output":{"name":"i32x4"}}],[11,"clone","","",357,{"inputs":[{"name":"self"}],"output":{"name":"u32x4"}}],[11,"clone","std::char","",372,{"inputs":[{"name":"self"}],"output":{"name":"escapedebug"}}],[11,"clone","std::simd","",358,{"inputs":[{"name":"self"}],"output":{"name":"i64x4"}}],[11,"clone","","",331,{"inputs":[{"name":"self"}],"output":{"name":"i8x32"}}],[11,"clone","std::result","",400,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"clone","std::option","",430,{"inputs":[{"name":"self"}],"output":{"name":"noneerror"}}],[11,"clone","std::num","",416,{"inputs":[{"name":"self"}],"output":{"name":"nonzeroi32"}}],[11,"clone","std::str::pattern","",454,{"inputs":[{"name":"self"}],"output":{"name":"charsearcher"}}],[11,"clone","std::option","",374,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"clone","std::cell","Panics",455,{"inputs":[{"name":"self"}],"output":{"name":"refcell"}}],[11,"clone","std::simd","",341,{"inputs":[{"name":"self"}],"output":{"name":"u64x8"}}],[11,"clone","std::str","",385,{"inputs":[{"name":"self"}],"output":{"name":"chars"}}],[11,"clone","std::num","",417,{"inputs":[{"name":"self"}],"output":{"name":"nonzerou32"}}],[11,"mul_assign","std::time","",309,null],[11,"mul_assign","std","",307,null],[11,"mul_assign","","",339,null],[11,"mul_assign","std::simd","",358,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","","",195,null],[11,"mul_assign","","",195,null],[11,"mul_assign","","",195,null],[11,"mul_assign","std::simd","",312,null],[11,"mul_assign","","",316,null],[11,"mul_assign","std","",322,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","","",195,null],[11,"mul_assign","","",195,null],[11,"mul_assign","std","",319,null],[11,"mul_assign","std::simd","",321,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",305,null],[11,"mul_assign","std","",329,null],[11,"mul_assign","","",322,null],[11,"mul_assign","","",314,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std","",307,null],[11,"mul_assign","std::simd","",342,null],[11,"mul_assign","","",323,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",354,null],[11,"mul_assign","","",343,null],[11,"mul_assign","std","",304,null],[11,"mul_assign","std::simd","",352,null],[11,"mul_assign","std","",317,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",313,null],[11,"mul_assign","","",308,null],[11,"mul_assign","std","",320,null],[11,"mul_assign","std::simd","",325,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",331,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",327,null],[11,"mul_assign","","",348,null],[11,"mul_assign","std","",301,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",353,null],[11,"mul_assign","std","",304,null],[11,"mul_assign","std::simd","",315,null],[11,"mul_assign","","",326,null],[11,"mul_assign","std","",301,null],[11,"mul_assign","std::simd","",303,null],[11,"mul_assign","","",310,null],[11,"mul_assign","std","",317,null],[11,"mul_assign","","",332,null],[11,"mul_assign","std::simd","",302,null],[11,"mul_assign","std","",329,null],[11,"mul_assign","","",306,null],[11,"mul_assign","std::simd","",324,null],[11,"mul_assign","","",336,null],[11,"mul_assign","","",347,null],[11,"mul_assign","std","",319,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std","",335,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std","",314,null],[11,"mul_assign","std::simd","",330,null],[11,"mul_assign","","",349,null],[11,"mul_assign","","",350,null],[11,"mul_assign","","",333,null],[11,"mul_assign","","",346,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std","",318,null],[11,"mul_assign","std::simd","",357,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",345,null],[11,"mul_assign","","",338,null],[11,"mul_assign","std","",332,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","","",195,null],[11,"mul_assign","std::simd","",356,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std::simd","",355,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std","",320,null],[11,"mul_assign","","",318,null],[11,"mul_assign","std::simd","",351,null],[11,"mul_assign","std","",335,null],[11,"mul_assign","std::simd","",334,null],[11,"mul_assign","","",337,null],[11,"mul_assign","","",311,null],[11,"mul_assign","std::num","",195,null],[11,"mul_assign","std","",306,null],[11,"mul_assign","std::simd","",340,null],[11,"mul_assign","","",344,null],[11,"mul_assign","","",328,null],[11,"mul_assign","std","",339,null],[11,"mul_assign","std::simd","",341,null],[11,"mul_assign","std::num","",195,null],[11,"write_str","std::fmt","",456,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_char","","",456,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_fmt","","",456,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_str","std","",285,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_char","","",285,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_fmt","","",285,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[11,"bitor","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"bitor","std","",335,null],[11,"bitor","","",320,null],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"bitor","std","",431,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"bool"}}],[11,"bitor","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"bitor","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"bitor","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"bitor","std","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"bitor","","",322,null],[11,"bitor","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"bitor","","",195,null],[11,"bitor","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"bitor","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"bitor","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"bitor","std","",322,null],[11,"bitor","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"bitor","","",306,null],[11,"bitor","","",329,null],[11,"bitor","","",304,null],[11,"bitor","std::num","",195,null],[11,"bitor","std","",301,null],[11,"bitor","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"bitor","std","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"bitor","","",329,null],[11,"bitor","","",322,null],[11,"bitor","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"bitor","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"bitor","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"bitor","std::num","",195,null],[11,"bitor","","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"bitor","std","",335,null],[11,"bitor","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"bitor","std","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"bitor","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"bitor","std::num","",195,null],[11,"bitor","","",195,null],[11,"bitor","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"bitor","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"bitor","std","",307,null],[11,"bitor","std::num","",195,null],[11,"bitor","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"bitor","std","",306,null],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"bitor","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"bitor","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"bitor","std::num","",195,null],[11,"bitor","std","",339,null],[11,"bitor","","",317,null],[11,"bitor","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"bitor","std","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"bitor","std::simd","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"bitor","","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"bitor","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"bitor","std","",332,null],[11,"bitor","","",431,null],[11,"bitor","std::num","",195,null],[11,"bitor","std","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"bitor","","",332,null],[11,"bitor","","",329,null],[11,"bitor","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"bitor","std::num","",195,null],[11,"bitor","std","",318,null],[11,"bitor","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"bitor","std","",317,null],[11,"bitor","","",431,null],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"bitor","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"bitor","std","",306,null],[11,"bitor","std::num","",195,null],[11,"bitor","std","",301,null],[11,"bitor","","",431,null],[11,"bitor","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"bitor","","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"bitor","std","",339,null],[11,"bitor","","",307,null],[11,"bitor","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"bitor","","",317,null],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"bitor","std::simd","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"bitor","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"bitor","std","",301,null],[11,"bitor","","",335,null],[11,"bitor","","",320,null],[11,"bitor","","",320,null],[11,"bitor","std::num","",195,null],[11,"bitor","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"bitor","std::num","",195,null],[11,"bitor","std::simd","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"bitor","std","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"bitor","","",304,null],[11,"bitor","","",304,null],[11,"bitor","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"bitor","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"bitor","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"bitor","std","",332,null],[11,"bitor","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"bitor","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"bitor","std","",339,null],[11,"bitor","","",307,null],[11,"bitor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"bitor","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"bitor","","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"bitor","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"bitor","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"bitor","","",318,null],[11,"bitor","","",318,null],[11,"bitor","std::simd","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"bitor","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"bitor","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"bitor","","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"bitor","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"bitor","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"next_back","std::str::pattern","",443,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",443,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","",443,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",452,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",452,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject_back","","",452,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",437,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",437,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",454,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match_back","","",454,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std","",318,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","","",195,null],[11,"bitand_assign","std::simd","",305,null],[11,"bitand_assign","std","",306,null],[11,"bitand_assign","std::simd","",325,null],[11,"bitand_assign","","",340,null],[11,"bitand_assign","","",302,null],[11,"bitand_assign","std","",317,null],[11,"bitand_assign","std::simd","",327,null],[11,"bitand_assign","","",326,null],[11,"bitand_assign","std","",431,null],[11,"bitand_assign","","",304,null],[11,"bitand_assign","","",335,null],[11,"bitand_assign","std::simd","",331,null],[11,"bitand_assign","std","",329,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","","",195,null],[11,"bitand_assign","std::simd","",310,null],[11,"bitand_assign","","",441,null],[11,"bitand_assign","","",337,null],[11,"bitand_assign","","",313,null],[11,"bitand_assign","","",344,null],[11,"bitand_assign","std","",320,null],[11,"bitand_assign","std::simd","",357,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std","",335,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",312,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",354,null],[11,"bitand_assign","","",348,null],[11,"bitand_assign","","",330,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",342,null],[11,"bitand_assign","std","",329,null],[11,"bitand_assign","std::simd","",311,null],[11,"bitand_assign","","",350,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std","",307,null],[11,"bitand_assign","","",322,null],[11,"bitand_assign","std::simd","",328,null],[11,"bitand_assign","","",334,null],[11,"bitand_assign","std","",304,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std","",307,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std","",332,null],[11,"bitand_assign","std::simd","",355,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",358,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",303,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",447,null],[11,"bitand_assign","","",450,null],[11,"bitand_assign","","",353,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std","",317,null],[11,"bitand_assign","std::simd","",346,null],[11,"bitand_assign","std","",339,null],[11,"bitand_assign","","",306,null],[11,"bitand_assign","","",301,null],[11,"bitand_assign","std::simd","",341,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",336,null],[11,"bitand_assign","","",338,null],[11,"bitand_assign","","",324,null],[11,"bitand_assign","","",347,null],[11,"bitand_assign","std","",318,null],[11,"bitand_assign","std::simd","",440,null],[11,"bitand_assign","","",333,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std","",332,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",351,null],[11,"bitand_assign","std","",431,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",442,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","","",195,null],[11,"bitand_assign","std","",320,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",315,null],[11,"bitand_assign","std","",339,null],[11,"bitand_assign","std::simd","",343,null],[11,"bitand_assign","","",444,null],[11,"bitand_assign","std","",301,null],[11,"bitand_assign","std::num","",195,null],[11,"bitand_assign","std::simd","",316,null],[11,"bitand_assign","std","",322,null],[11,"fmt","std::num","",412,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",415,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",304,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",417,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",420,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",322,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",410,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",317,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",416,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",418,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",195,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",320,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",414,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",307,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",339,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",421,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",419,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",301,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",332,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",329,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",413,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",306,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",411,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",318,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",335,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"shl_assign","","",339,null],[11,"shl_assign","std::simd","",348,null],[11,"shl_assign","","",331,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",350,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",329,null],[11,"shl_assign","std::simd","",302,null],[11,"shl_assign","","",302,null],[11,"shl_assign","","",340,null],[11,"shl_assign","","",303,null],[11,"shl_assign","","",311,null],[11,"shl_assign","","",353,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",318,null],[11,"shl_assign","","",318,null],[11,"shl_assign","","",335,null],[11,"shl_assign","","",307,null],[11,"shl_assign","","",339,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::simd","",331,null],[11,"shl_assign","","",357,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","std::simd","",340,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",332,null],[11,"shl_assign","std::simd","",344,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","std::simd","",325,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",344,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","","",317,null],[11,"shl_assign","std::simd","",348,null],[11,"shl_assign","","",351,null],[11,"shl_assign","","",337,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",304,null],[11,"shl_assign","","",329,null],[11,"shl_assign","","",335,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::simd","",311,null],[11,"shl_assign","","",354,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","std::simd","",334,null],[11,"shl_assign","","",324,null],[11,"shl_assign","","",325,null],[11,"shl_assign","","",340,null],[11,"shl_assign","","",312,null],[11,"shl_assign","","",324,null],[11,"shl_assign","","",348,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","","",335,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",347,null],[11,"shl_assign","","",347,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",313,null],[11,"shl_assign","","",327,null],[11,"shl_assign","","",310,null],[11,"shl_assign","","",330,null],[11,"shl_assign","","",311,null],[11,"shl_assign","","",327,null],[11,"shl_assign","","",324,null],[11,"shl_assign","","",354,null],[11,"shl_assign","","",353,null],[11,"shl_assign","","",357,null],[11,"shl_assign","","",324,null],[11,"shl_assign","","",357,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",340,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",336,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",340,null],[11,"shl_assign","","",324,null],[11,"shl_assign","","",331,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",341,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",304,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",312,null],[11,"shl_assign","","",337,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",315,null],[11,"shl_assign","","",327,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","std::simd","",312,null],[11,"shl_assign","","",310,null],[11,"shl_assign","","",328,null],[11,"shl_assign","","",347,null],[11,"shl_assign","","",354,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","","",335,null],[11,"shl_assign","","",304,null],[11,"shl_assign","","",304,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::simd","",326,null],[11,"shl_assign","","",305,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","std::simd","",315,null],[11,"shl_assign","","",350,null],[11,"shl_assign","","",342,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",350,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",331,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",343,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","std::simd","",326,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",336,null],[11,"shl_assign","","",337,null],[11,"shl_assign","","",346,null],[11,"shl_assign","","",348,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::simd","",330,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",354,null],[11,"shl_assign","","",302,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","std::simd","",313,null],[11,"shl_assign","","",343,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",313,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","","",317,null],[11,"shl_assign","std::simd","",355,null],[11,"shl_assign","","",341,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",329,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","","",328,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",318,null],[11,"shl_assign","","",301,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",304,null],[11,"shl_assign","","",332,null],[11,"shl_assign","std::simd","",330,null],[11,"shl_assign","","",327,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",357,null],[11,"shl_assign","","",342,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",312,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",340,null],[11,"shl_assign","","",350,null],[11,"shl_assign","","",348,null],[11,"shl_assign","","",343,null],[11,"shl_assign","","",326,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",325,null],[11,"shl_assign","","",328,null],[11,"shl_assign","","",330,null],[11,"shl_assign","","",305,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::simd","",333,null],[11,"shl_assign","","",312,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",327,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",347,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",312,null],[11,"shl_assign","","",338,null],[11,"shl_assign","","",303,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","std::simd","",341,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",317,null],[11,"shl_assign","","",301,null],[11,"shl_assign","std::simd","",344,null],[11,"shl_assign","","",355,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","std::simd","",346,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","","",329,null],[11,"shl_assign","std::simd","",334,null],[11,"shl_assign","","",336,null],[11,"shl_assign","","",326,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",315,null],[11,"shl_assign","","",327,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",301,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","","",344,null],[11,"shl_assign","","",351,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",331,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","","",320,null],[11,"shl_assign","std::simd","",334,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",304,null],[11,"shl_assign","std::simd","",355,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::simd","",305,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::simd","",305,null],[11,"shl_assign","","",316,null],[11,"shl_assign","","",338,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","","",322,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",315,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",303,null],[11,"shl_assign","","",312,null],[11,"shl_assign","","",350,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","std::simd","",334,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",301,null],[11,"shl_assign","std::simd","",316,null],[11,"shl_assign","","",316,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","std::simd","",351,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","std::simd","",315,null],[11,"shl_assign","","",343,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",335,null],[11,"shl_assign","std::simd","",325,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","","",339,null],[11,"shl_assign","","",320,null],[11,"shl_assign","std::simd","",330,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::simd","",324,null],[11,"shl_assign","","",334,null],[11,"shl_assign","","",325,null],[11,"shl_assign","","",313,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","std::simd","",336,null],[11,"shl_assign","","",348,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",304,null],[11,"shl_assign","std::simd","",330,null],[11,"shl_assign","","",342,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","","",301,null],[11,"shl_assign","","",329,null],[11,"shl_assign","","",318,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",317,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","std::simd","",353,null],[11,"shl_assign","","",338,null],[11,"shl_assign","","",340,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",324,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","std::simd","",346,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",304,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",338,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",301,null],[11,"shl_assign","","",318,null],[11,"shl_assign","","",304,null],[11,"shl_assign","std::simd","",331,null],[11,"shl_assign","","",326,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::simd","",340,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",327,null],[11,"shl_assign","","",338,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",339,null],[11,"shl_assign","","",339,null],[11,"shl_assign","std::simd","",343,null],[11,"shl_assign","","",303,null],[11,"shl_assign","","",324,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",353,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","std::simd","",337,null],[11,"shl_assign","","",355,null],[11,"shl_assign","","",354,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",304,null],[11,"shl_assign","","",317,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",336,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","","",335,null],[11,"shl_assign","","",329,null],[11,"shl_assign","","",317,null],[11,"shl_assign","","",322,null],[11,"shl_assign","std::simd","",311,null],[11,"shl_assign","","",328,null],[11,"shl_assign","","",338,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::simd","",357,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","std::simd","",347,null],[11,"shl_assign","","",355,null],[11,"shl_assign","","",354,null],[11,"shl_assign","","",310,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",339,null],[11,"shl_assign","","",307,null],[11,"shl_assign","","",320,null],[11,"shl_assign","std::simd","",337,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",320,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",353,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",332,null],[11,"shl_assign","std::simd","",302,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",316,null],[11,"shl_assign","","",311,null],[11,"shl_assign","","",353,null],[11,"shl_assign","","",325,null],[11,"shl_assign","","",302,null],[11,"shl_assign","","",350,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",325,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",348,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",339,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","","",338,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",310,null],[11,"shl_assign","","",337,null],[11,"shl_assign","","",344,null],[11,"shl_assign","","",336,null],[11,"shl_assign","","",333,null],[11,"shl_assign","","",348,null],[11,"shl_assign","","",315,null],[11,"shl_assign","","",325,null],[11,"shl_assign","","",350,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","std::simd","",340,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",351,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",317,null],[11,"shl_assign","std::simd","",330,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",329,null],[11,"shl_assign","std::simd","",346,null],[11,"shl_assign","","",334,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",307,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::simd","",305,null],[11,"shl_assign","","",326,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",326,null],[11,"shl_assign","","",305,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","","",329,null],[11,"shl_assign","std::simd","",342,null],[11,"shl_assign","","",341,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","std::simd","",311,null],[11,"shl_assign","","",347,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","","",304,null],[11,"shl_assign","","",322,null],[11,"shl_assign","std::simd","",326,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",355,null],[11,"shl_assign","","",333,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","std::simd","",302,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","std::simd","",347,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",305,null],[11,"shl_assign","","",334,null],[11,"shl_assign","","",310,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","","",339,null],[11,"shl_assign","std::simd","",354,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","","",329,null],[11,"shl_assign","std::simd","",310,null],[11,"shl_assign","","",313,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",341,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","","",320,null],[11,"shl_assign","std::simd","",344,null],[11,"shl_assign","","",341,null],[11,"shl_assign","","",331,null],[11,"shl_assign","","",327,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",320,null],[11,"shl_assign","std::simd","",330,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",301,null],[11,"shl_assign","std::simd","",303,null],[11,"shl_assign","","",315,null],[11,"shl_assign","","",324,null],[11,"shl_assign","","",351,null],[11,"shl_assign","","",328,null],[11,"shl_assign","","",357,null],[11,"shl_assign","","",334,null],[11,"shl_assign","","",348,null],[11,"shl_assign","","",327,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",333,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",343,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","std::simd","",333,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",325,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","","",317,null],[11,"shl_assign","std::simd","",328,null],[11,"shl_assign","","",302,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",331,null],[11,"shl_assign","","",346,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",333,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",329,null],[11,"shl_assign","","",335,null],[11,"shl_assign","std::simd","",316,null],[11,"shl_assign","","",346,null],[11,"shl_assign","","",328,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","std::simd","",326,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","","",317,null],[11,"shl_assign","","",339,null],[11,"shl_assign","","",322,null],[11,"shl_assign","","",332,null],[11,"shl_assign","std::simd","",313,null],[11,"shl_assign","","",357,null],[11,"shl_assign","","",337,null],[11,"shl_assign","","",328,null],[11,"shl_assign","","",333,null],[11,"shl_assign","","",355,null],[11,"shl_assign","","",305,null],[11,"shl_assign","","",342,null],[11,"shl_assign","","",330,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",311,null],[11,"shl_assign","","",326,null],[11,"shl_assign","","",313,null],[11,"shl_assign","","",343,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","","",317,null],[11,"shl_assign","","",320,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",301,null],[11,"shl_assign","","",306,null],[11,"shl_assign","std::simd","",344,null],[11,"shl_assign","","",353,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",322,null],[11,"shl_assign","","",322,null],[11,"shl_assign","","",301,null],[11,"shl_assign","std::simd","",328,null],[11,"shl_assign","","",358,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","std::simd","",312,null],[11,"shl_assign","","",342,null],[11,"shl_assign","","",351,null],[11,"shl_assign","","",355,null],[11,"shl_assign","","",357,null],[11,"shl_assign","","",316,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","","",339,null],[11,"shl_assign","","",332,null],[11,"shl_assign","","",329,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",303,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","std::simd","",303,null],[11,"shl_assign","","",342,null],[11,"shl_assign","","",331,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","std::simd","",305,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",351,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","std::simd","",351,null],[11,"shl_assign","","",302,null],[11,"shl_assign","","",330,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","","",195,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","std::simd","",344,null],[11,"shl_assign","","",346,null],[11,"shl_assign","","",333,null],[11,"shl_assign","","",338,null],[11,"shl_assign","std","",307,null],[11,"shl_assign","std::simd","",313,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","std::simd","",316,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","std::simd","",343,null],[11,"shl_assign","","",353,null],[11,"shl_assign","","",337,null],[11,"shl_assign","","",334,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",304,null],[11,"shl_assign","std::simd","",343,null],[11,"shl_assign","","",348,null],[11,"shl_assign","","",315,null],[11,"shl_assign","","",353,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","std::simd","",324,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","","",332,null],[11,"shl_assign","std::simd","",333,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",353,null],[11,"shl_assign","","",354,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",315,null],[11,"shl_assign","","",312,null],[11,"shl_assign","","",336,null],[11,"shl_assign","","",342,null],[11,"shl_assign","","",302,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",336,null],[11,"shl_assign","","",337,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","","",320,null],[11,"shl_assign","std::simd","",311,null],[11,"shl_assign","","",310,null],[11,"shl_assign","","",333,null],[11,"shl_assign","","",347,null],[11,"shl_assign","","",347,null],[11,"shl_assign","std","",339,null],[11,"shl_assign","","",339,null],[11,"shl_assign","std::simd","",341,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","std::simd","",341,null],[11,"shl_assign","","",351,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","","",322,null],[11,"shl_assign","std::simd","",354,null],[11,"shl_assign","","",316,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",336,null],[11,"shl_assign","","",338,null],[11,"shl_assign","","",315,null],[11,"shl_assign","std","",304,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","","",331,null],[11,"shl_assign","","",311,null],[11,"shl_assign","","",328,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",336,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","std::simd","",313,null],[11,"shl_assign","","",347,null],[11,"shl_assign","std","",332,null],[11,"shl_assign","","",307,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",350,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","","",306,null],[11,"shl_assign","","",318,null],[11,"shl_assign","std::simd","",303,null],[11,"shl_assign","","",310,null],[11,"shl_assign","","",341,null],[11,"shl_assign","","",344,null],[11,"shl_assign","","",334,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::num","",195,null],[11,"shl_assign","std::simd","",316,null],[11,"shl_assign","std","",335,null],[11,"shl_assign","","",320,null],[11,"shl_assign","std::simd","",338,null],[11,"shl_assign","","",346,null],[11,"shl_assign","","",303,null],[11,"shl_assign","std","",318,null],[11,"shl_assign","","",307,null],[11,"shl_assign","","",322,null],[11,"shl_assign","std::simd","",313,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","std::simd","",311,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",310,null],[11,"shl_assign","std","",317,null],[11,"shl_assign","std::simd","",312,null],[11,"shl_assign","std","",329,null],[11,"shl_assign","std::simd","",351,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",332,null],[11,"shl_assign","std::simd","",325,null],[11,"shl_assign","std","",301,null],[11,"shl_assign","std::simd","",350,null],[11,"shl_assign","","",343,null],[11,"shl_assign","","",346,null],[11,"shl_assign","","",355,null],[11,"shl_assign","","",305,null],[11,"shl_assign","","",358,null],[11,"shl_assign","","",342,null],[11,"shl_assign","","",346,null],[11,"shl_assign","std","",306,null],[11,"shl_assign","std::simd","",341,null],[11,"shl_assign","","",316,null],[11,"shl_assign","","",342,null],[11,"shl_assign","std","",320,null],[11,"shl_assign","std::simd","",358,null],[11,"shl_assign","","",357,null],[11,"shl_assign","","",357,null],[11,"shl_assign","","",344,null],[11,"shl_assign","","",302,null],[11,"shl_assign","","",350,null],[11,"shl_assign","std","",322,null],[11,"shl_assign","","",320,null],[11,"shl_assign","","",304,null],[11,"shl_assign","std::simd","",354,null],[11,"shl_assign","","",355,null],[11,"shl_assign","","",310,null],[11,"shl_assign","","",340,null],[11,"shl_assign","","",337,null],[11,"shl_assign","","",327,null],[11,"shl_assign","","",303,null],[11,"shl_assign","std","",317,null],[11,"deref","std::cell","",457,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","std","",285,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","","",285,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","std::mem","",426,null],[11,"deref","","",458,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","std::cell","",459,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","std::mem","",426,null],[11,"deref_mut","std","",285,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","std::mem","",458,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","std::cell","",457,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"from","std::simd","",326,{"inputs":[{"name":"f32x2"}],"output":{"name":"i32x2"}}],[11,"from","","",328,{"inputs":[{"name":"u16x2"}],"output":{"name":"u64x2"}}],[11,"from","","",324,{"inputs":[{"name":"i64x8"}],"output":{"name":"u8x8"}}],[11,"from","std","",301,{"inputs":[{"name":"u16"}],"output":{"name":"u32"}}],[11,"from","std::simd","",355,{"inputs":[{"name":"f64x4"}],"output":{"name":"u64x4"}}],[11,"from","","",338,{"inputs":[{"name":"i32x16"}],"output":{"name":"i16x16"}}],[11,"from","","",358,{"inputs":[{"name":"f64x4"}],"output":{"name":"i64x4"}}],[11,"from","","",323,{"inputs":[{"name":"u16x2"}],"output":{"name":"f32x2"}}],[11,"from","","",337,{"inputs":[{"name":"i8x8"}],"output":{"name":"i16x8"}}],[11,"from","","",334,{"inputs":[{"name":"i8x64"}],"output":{"name":"u8x64"}}],[11,"from","std","",317,{"inputs":[{"name":"u8"}],"output":{"name":"i16"}}],[11,"from","std::simd","",310,{"inputs":[{"name":"i16x2"}],"output":{"name":"u32x2"}}],[11,"from","","",311,{"inputs":[{"name":"u32x4"}],"output":{"name":"i16x4"}}],[11,"from","","",321,{"inputs":[{"name":"i64x2"}],"output":{"name":"f64x2"}}],[11,"from","","",357,{"inputs":[{"name":"i16x4"}],"output":{"name":"u32x4"}}],[11,"from","","",330,{"inputs":[{"name":"i32x4"}],"output":{"name":"i8x4"}}],[11,"from","","",345,{"inputs":[{"name":"u16x8"}],"output":{"name":"f32x8"}}],[11,"from","std","",307,{"inputs":[{"name":"i8"}],"output":{"name":"i32"}}],[11,"from","std::simd","",348,{"inputs":[{"name":"u16x8"}],"output":{"name":"i8x8"}}],[11,"from","std","",319,{"inputs":[{"name":"u16"}],"output":{"name":"f32"}}],[11,"from","std::simd","",308,{"inputs":[{"name":"f32x8"}],"output":{"name":"f64x8"}}],[11,"from","","",303,{"inputs":[{"name":"i8x8"}],"output":{"name":"i32x8"}}],[11,"from","std::sync::atomic","",460,{"inputs":[{"name":"i16"}],"output":{"name":"atomici16"}}],[11,"from","std::simd","",344,{"inputs":[{"name":"i8x2"}],"output":{"name":"u16x2"}}],[11,"from","","",348,{"inputs":[{"name":"u32x8"}],"output":{"name":"i8x8"}}],[11,"from","","",352,{"inputs":[{"name":"i16x4"}],"output":{"name":"f64x4"}}],[11,"from","","",327,{"inputs":[{"name":"i32x2"}],"output":{"name":"i64x2"}}],[11,"from","std","",307,{"inputs":[{"name":"u16"}],"output":{"name":"i32"}}],[11,"from","std::simd","",311,{"inputs":[{"name":"i8x4"}],"output":{"name":"i16x4"}}],[11,"from","","",344,{"inputs":[{"name":"u32x2"}],"output":{"name":"u16x2"}}],[11,"from","","",348,{"inputs":[{"name":"u8x8"}],"output":{"name":"i8x8"}}],[11,"from","","",346,{"inputs":[{"name":"i16x4"}],"output":{"name":"u16x4"}}],[11,"from","","",336,{"inputs":[{"name":"u32x2"}],"output":{"name":"i8x2"}}],[11,"from","","",337,{"inputs":[{"name":"f32x8"}],"output":{"name":"i16x8"}}],[11,"from","","",333,{"inputs":[{"name":"i16x16"}],"output":{"name":"u16x16"}}],[11,"from","","",312,{"inputs":[{"name":"u32x8"}],"output":{"name":"u16x8"}}],[11,"from","","",303,{"inputs":[{"name":"i64x8"}],"output":{"name":"i32x8"}}],[11,"from","","",336,{"inputs":[{"name":"u64x2"}],"output":{"name":"i8x2"}}],[11,"from","","",357,{"inputs":[{"name":"u64x4"}],"output":{"name":"u32x4"}}],[11,"from","","",312,{"inputs":[{"name":"u8x8"}],"output":{"name":"u16x8"}}],[11,"from","","",356,{"inputs":[{"name":"u16x4"}],"output":{"name":"f32x4"}}],[11,"from","","",321,{"inputs":[{"name":"i16x2"}],"output":{"name":"f64x2"}}],[11,"from","","",328,{"inputs":[{"name":"i8x2"}],"output":{"name":"u64x2"}}],[11,"from","","",310,{"inputs":[{"name":"u64x2"}],"output":{"name":"u32x2"}}],[11,"from","std::sync::atomic","",461,{"inputs":[{"name":"u8"}],"output":{"name":"atomicu8"}}],[11,"from","std::simd","",330,{"inputs":[{"name":"i64x4"}],"output":{"name":"i8x4"}}],[11,"from","std","",304,{"inputs":[{"name":"u8"}],"output":{"name":"usize"}}],[11,"from","std::simd","",340,{"inputs":[{"name":"i64x8"}],"output":{"name":"u32x8"}}],[11,"from","","",349,{"inputs":[{"name":"i16x16"}],"output":{"name":"f32x16"}}],[11,"from","std","",318,{"inputs":[{"name":"u32"}],"output":{"name":"i128"}}],[11,"from","std::simd","",330,{"inputs":[{"name":"f64x4"}],"output":{"name":"i8x4"}}],[11,"from","","",324,{"inputs":[{"name":"f64x8"}],"output":{"name":"u8x8"}}],[11,"from","","",330,{"inputs":[{"name":"u16x4"}],"output":{"name":"i8x4"}}],[11,"from","","",350,{"inputs":[{"name":"i16x16"}],"output":{"name":"u32x16"}}],[11,"from","std","",307,{"inputs":[{"name":"u8"}],"output":{"name":"i32"}}],[11,"from","","",307,{"inputs":[{"name":"i16"}],"output":{"name":"i32"}}],[11,"from","std::simd","",328,{"inputs":[{"name":"f32x2"}],"output":{"name":"u64x2"}}],[11,"from","std::sync::atomic","",462,{"inputs":[{"name":"u32"}],"output":{"name":"atomicu32"}}],[11,"from","std::simd","",338,{"inputs":[{"name":"i8x16"}],"output":{"name":"i16x16"}}],[11,"from","","",356,{"inputs":[{"name":"i64x4"}],"output":{"name":"f32x4"}}],[11,"from","","",311,{"inputs":[{"name":"i32x4"}],"output":{"name":"i16x4"}}],[11,"from","","",312,{"inputs":[{"name":"f32x8"}],"output":{"name":"u16x8"}}],[11,"from","","",349,{"inputs":[{"name":"u32x16"}],"output":{"name":"f32x16"}}],[11,"from","std","",314,{"inputs":[{"name":"u16"}],"output":{"name":"f64"}}],[11,"from","std::simd","",341,{"inputs":[{"name":"u32x8"}],"output":{"name":"u64x8"}}],[11,"from","","",311,{"inputs":[{"name":"u8x4"}],"output":{"name":"i16x4"}}],[11,"from","","",355,{"inputs":[{"name":"u16x4"}],"output":{"name":"u64x4"}}],[11,"from","","",305,{"inputs":[{"name":"u16x4"}],"output":{"name":"i32x4"}}],[11,"from","","",352,{"inputs":[{"name":"f32x4"}],"output":{"name":"f64x4"}}],[11,"from","","",321,{"inputs":[{"name":"u16x2"}],"output":{"name":"f64x2"}}],[11,"from","","",340,{"inputs":[{"name":"u64x8"}],"output":{"name":"u32x8"}}],[11,"from","std","",332,{"inputs":[{"name":"i16"}],"output":{"name":"i64"}}],[11,"from","std::simd","",356,{"inputs":[{"name":"u8x4"}],"output":{"name":"f32x4"}}],[11,"from","","",312,{"inputs":[{"name":"u64x8"}],"output":{"name":"u16x8"}}],[11,"from","","",328,{"inputs":[{"name":"i64x2"}],"output":{"name":"u64x2"}}],[11,"from","","",316,{"inputs":[{"name":"i16x16"}],"output":{"name":"i32x16"}}],[11,"from","std","",432,{"inputs":[{"name":"u8"}],"output":{"name":"char"}}],[11,"from","std::simd","",326,{"inputs":[{"name":"u64x2"}],"output":{"name":"i32x2"}}],[11,"from","","",310,{"inputs":[{"name":"i64x2"}],"output":{"name":"u32x2"}}],[11,"from","","",305,{"inputs":[{"name":"u8x4"}],"output":{"name":"i32x4"}}],[11,"from","std","",339,{"inputs":[{"name":"u8"}],"output":{"name":"u128"}}],[11,"from","","",318,{"inputs":[{"name":"i16"}],"output":{"name":"i128"}}],[11,"from","std::simd","",352,{"inputs":[{"name":"u32x4"}],"output":{"name":"f64x4"}}],[11,"from","","",352,{"inputs":[{"name":"i64x4"}],"output":{"name":"f64x4"}}],[11,"from","","",333,{"inputs":[{"name":"u32x16"}],"output":{"name":"u16x16"}}],[11,"from","","",308,{"inputs":[{"name":"i16x8"}],"output":{"name":"f64x8"}}],[11,"from","","",303,{"inputs":[{"name":"f64x8"}],"output":{"name":"i32x8"}}],[11,"from","","",341,{"inputs":[{"name":"i8x8"}],"output":{"name":"u64x8"}}],[11,"from","std","",329,{"inputs":[{"name":"u8"}],"output":{"name":"u16"}}],[11,"from","std::sync::atomic","",463,{"inputs":[{"name":"i64"}],"output":{"name":"atomici64"}}],[11,"from","std::simd","",346,{"inputs":[{"name":"u64x4"}],"output":{"name":"u16x4"}}],[11,"from","","",311,{"inputs":[{"name":"i64x4"}],"output":{"name":"i16x4"}}],[11,"from","","",346,{"inputs":[{"name":"i32x4"}],"output":{"name":"u16x4"}}],[11,"from","","",340,{"inputs":[{"name":"u8x8"}],"output":{"name":"u32x8"}}],[11,"from","","",353,{"inputs":[{"name":"f64x8"}],"output":{"name":"i64x8"}}],[11,"from","std","",318,{"inputs":[{"name":"u16"}],"output":{"name":"i128"}}],[11,"from","std::simd","",338,{"inputs":[{"name":"u32x16"}],"output":{"name":"i16x16"}}],[11,"from","std","",318,{"inputs":[{"name":"i32"}],"output":{"name":"i128"}}],[11,"from","std::simd","",345,{"inputs":[{"name":"i8x8"}],"output":{"name":"f32x8"}}],[11,"from","","",337,{"inputs":[{"name":"f64x8"}],"output":{"name":"i16x8"}}],[11,"from","","",337,{"inputs":[{"name":"u8x8"}],"output":{"name":"i16x8"}}],[11,"from","","",326,{"inputs":[{"name":"i16x2"}],"output":{"name":"i32x2"}}],[11,"from","","",330,{"inputs":[{"name":"i16x4"}],"output":{"name":"i8x4"}}],[11,"from","","",353,{"inputs":[{"name":"u16x8"}],"output":{"name":"i64x8"}}],[11,"from","","",350,{"inputs":[{"name":"u8x16"}],"output":{"name":"u32x16"}}],[11,"from","","",328,{"inputs":[{"name":"i32x2"}],"output":{"name":"u64x2"}}],[11,"from","","",355,{"inputs":[{"name":"f32x4"}],"output":{"name":"u64x4"}}],[11,"from","","",350,{"inputs":[{"name":"i8x16"}],"output":{"name":"u32x16"}}],[11,"from","","",353,{"inputs":[{"name":"i16x8"}],"output":{"name":"i64x8"}}],[11,"from","","",347,{"inputs":[{"name":"u64x4"}],"output":{"name":"u8x4"}}],[11,"from","","",321,{"inputs":[{"name":"u8x2"}],"output":{"name":"f64x2"}}],[11,"from","","",344,{"inputs":[{"name":"i64x2"}],"output":{"name":"u16x2"}}],[11,"from","","",354,{"inputs":[{"name":"f32x2"}],"output":{"name":"i16x2"}}],[11,"from","","",316,{"inputs":[{"name":"i8x16"}],"output":{"name":"i32x16"}}],[11,"from","std","",317,{"inputs":[{"name":"i8"}],"output":{"name":"i16"}}],[11,"from","std::simd","",312,{"inputs":[{"name":"i8x8"}],"output":{"name":"u16x8"}}],[11,"from","","",347,{"inputs":[{"name":"i8x4"}],"output":{"name":"u8x4"}}],[11,"from","std","",314,{"inputs":[{"name":"u32"}],"output":{"name":"f64"}}],[11,"from","std::simd","",354,{"inputs":[{"name":"u16x2"}],"output":{"name":"i16x2"}}],[11,"from","","",348,{"inputs":[{"name":"i64x8"}],"output":{"name":"i8x8"}}],[11,"from","std::ptr","",427,{"inputs":[{"name":"t"}],"output":{"name":"nonnull"}}],[11,"from","std::simd","",344,{"inputs":[{"name":"i16x2"}],"output":{"name":"u16x2"}}],[11,"from","","",356,{"inputs":[{"name":"u64x4"}],"output":{"name":"f32x4"}}],[11,"from","","",321,{"inputs":[{"name":"f32x2"}],"output":{"name":"f64x2"}}],[11,"from","","",347,{"inputs":[{"name":"f32x4"}],"output":{"name":"u8x4"}}],[11,"from","","",331,{"inputs":[{"name":"u8x32"}],"output":{"name":"i8x32"}}],[11,"from","","",337,{"inputs":[{"name":"i64x8"}],"output":{"name":"i16x8"}}],[11,"from","","",336,{"inputs":[{"name":"u16x2"}],"output":{"name":"i8x2"}}],[11,"from","std","",314,{"inputs":[{"name":"i32"}],"output":{"name":"f64"}}],[11,"from","std::simd","",337,{"inputs":[{"name":"u16x8"}],"output":{"name":"i16x8"}}],[11,"from","","",356,{"inputs":[{"name":"i32x4"}],"output":{"name":"f32x4"}}],[11,"from","std","",322,{"inputs":[{"name":"i8"}],"output":{"name":"isize"}}],[11,"from","std::simd","",352,{"inputs":[{"name":"u64x4"}],"output":{"name":"f64x4"}}],[11,"from","","",354,{"inputs":[{"name":"u32x2"}],"output":{"name":"i16x2"}}],[11,"from","","",348,{"inputs":[{"name":"f32x8"}],"output":{"name":"i8x8"}}],[11,"from","","",305,{"inputs":[{"name":"f32x4"}],"output":{"name":"i32x4"}}],[11,"from","std::sync::atomic","",464,{"inputs":[{"name":"usize"}],"output":{"name":"atomicusize"}}],[11,"from","std::simd","",354,{"inputs":[{"name":"i8x2"}],"output":{"name":"i16x2"}}],[11,"from","","",308,{"inputs":[{"name":"i64x8"}],"output":{"name":"f64x8"}}],[11,"from","","",330,{"inputs":[{"name":"u8x4"}],"output":{"name":"i8x4"}}],[11,"from","","",303,{"inputs":[{"name":"u8x8"}],"output":{"name":"i32x8"}}],[11,"from","","",349,{"inputs":[{"name":"u16x16"}],"output":{"name":"f32x16"}}],[11,"from","","",305,{"inputs":[{"name":"u64x4"}],"output":{"name":"i32x4"}}],[11,"from","","",350,{"inputs":[{"name":"f32x16"}],"output":{"name":"u32x16"}}],[11,"from","","",358,{"inputs":[{"name":"u32x4"}],"output":{"name":"i64x4"}}],[11,"from","","",358,{"inputs":[{"name":"i8x4"}],"output":{"name":"i64x4"}}],[11,"from","","",355,{"inputs":[{"name":"i64x4"}],"output":{"name":"u64x4"}}],[11,"from","","",305,{"inputs":[{"name":"i16x4"}],"output":{"name":"i32x4"}}],[11,"from","","",341,{"inputs":[{"name":"u8x8"}],"output":{"name":"u64x8"}}],[11,"from","std","",314,{"inputs":[{"name":"f32"}],"output":{"name":"f64"}}],[11,"from","std::simd","",354,{"inputs":[{"name":"u64x2"}],"output":{"name":"i16x2"}}],[11,"from","std","",314,{"inputs":[{"name":"u8"}],"output":{"name":"f64"}}],[11,"from","std::simd","",321,{"inputs":[{"name":"i8x2"}],"output":{"name":"f64x2"}}],[11,"from","","",354,{"inputs":[{"name":"i32x2"}],"output":{"name":"i16x2"}}],[11,"from","std::cell","",451,{"inputs":[{"name":"t"}],"output":{"name":"cell"}}],[11,"from","std::ptr","",427,{"inputs":[{"name":"unique"}],"output":{"name":"nonnull"}}],[11,"from","std","",319,{"inputs":[{"name":"u8"}],"output":{"name":"f32"}}],[11,"from","std::simd","",358,{"inputs":[{"name":"i32x4"}],"output":{"name":"i64x4"}}],[11,"from","","",316,{"inputs":[{"name":"u8x16"}],"output":{"name":"i32x16"}}],[11,"from","","",312,{"inputs":[{"name":"f64x8"}],"output":{"name":"u16x8"}}],[11,"from","","",312,{"inputs":[{"name":"i16x8"}],"output":{"name":"u16x8"}}],[11,"from","","",345,{"inputs":[{"name":"u32x8"}],"output":{"name":"f32x8"}}],[11,"from","","",311,{"inputs":[{"name":"u16x4"}],"output":{"name":"i16x4"}}],[11,"from","","",336,{"inputs":[{"name":"i32x2"}],"output":{"name":"i8x2"}}],[11,"from","","",326,{"inputs":[{"name":"u8x2"}],"output":{"name":"i32x2"}}],[11,"from","std::sync::atomic","",465,{"inputs":[{"name":"i8"}],"output":{"name":"atomici8"}}],[11,"from","std::simd","",354,{"inputs":[{"name":"u8x2"}],"output":{"name":"i16x2"}}],[11,"from","","",355,{"inputs":[{"name":"u32x4"}],"output":{"name":"u64x4"}}],[11,"from","","",321,{"inputs":[{"name":"i32x2"}],"output":{"name":"f64x2"}}],[11,"from","","",343,{"inputs":[{"name":"u16x2"}],"output":{"name":"u8x2"}}],[11,"from","","",357,{"inputs":[{"name":"f64x4"}],"output":{"name":"u32x4"}}],[11,"from","std","",332,{"inputs":[{"name":"u32"}],"output":{"name":"i64"}}],[11,"from","std::simd","",345,{"inputs":[{"name":"u64x8"}],"output":{"name":"f32x8"}}],[11,"from","","",303,{"inputs":[{"name":"u16x8"}],"output":{"name":"i32x8"}}],[11,"from","","",338,{"inputs":[{"name":"f32x16"}],"output":{"name":"i16x16"}}],[11,"from","","",302,{"inputs":[{"name":"u16x32"}],"output":{"name":"i16x32"}}],[11,"from","","",357,{"inputs":[{"name":"f32x4"}],"output":{"name":"u32x4"}}],[11,"from","","",340,{"inputs":[{"name":"i32x8"}],"output":{"name":"u32x8"}}],[11,"from","","",354,{"inputs":[{"name":"i64x2"}],"output":{"name":"i16x2"}}],[11,"from","","",347,{"inputs":[{"name":"f64x4"}],"output":{"name":"u8x4"}}],[11,"from","","",355,{"inputs":[{"name":"u8x4"}],"output":{"name":"u64x4"}}],[11,"from","","",343,{"inputs":[{"name":"f64x2"}],"output":{"name":"u8x2"}}],[11,"from","std::num","",439,null],[11,"from","std::simd","",323,{"inputs":[{"name":"i8x2"}],"output":{"name":"f32x2"}}],[11,"from","","",348,{"inputs":[{"name":"i16x8"}],"output":{"name":"i8x8"}}],[11,"from","std","",339,{"inputs":[{"name":"u32"}],"output":{"name":"u128"}}],[11,"from","std::simd","",323,{"inputs":[{"name":"u8x2"}],"output":{"name":"f32x2"}}],[11,"from","","",327,{"inputs":[{"name":"f64x2"}],"output":{"name":"i64x2"}}],[11,"from","","",353,{"inputs":[{"name":"i32x8"}],"output":{"name":"i64x8"}}],[11,"from","","",340,{"inputs":[{"name":"i16x8"}],"output":{"name":"u32x8"}}],[11,"from","","",312,{"inputs":[{"name":"i32x8"}],"output":{"name":"u16x8"}}],[11,"from","","",345,{"inputs":[{"name":"u8x8"}],"output":{"name":"f32x8"}}],[11,"from","","",326,{"inputs":[{"name":"i64x2"}],"output":{"name":"i32x2"}}],[11,"from","","",303,{"inputs":[{"name":"f32x8"}],"output":{"name":"i32x8"}}],[11,"from","","",352,{"inputs":[{"name":"i32x4"}],"output":{"name":"f64x4"}}],[11,"from","","",347,{"inputs":[{"name":"i64x4"}],"output":{"name":"u8x4"}}],[11,"from","","",352,{"inputs":[{"name":"u8x4"}],"output":{"name":"f64x4"}}],[11,"from","std","",306,{"inputs":[{"name":"u16"}],"output":{"name":"u64"}}],[11,"from","std::simd","",302,{"inputs":[{"name":"u8x32"}],"output":{"name":"i16x32"}}],[11,"from","std","",318,{"inputs":[{"name":"i8"}],"output":{"name":"i128"}}],[11,"from","std::simd","",356,{"inputs":[{"name":"i16x4"}],"output":{"name":"f32x4"}}],[11,"from","std","",319,{"inputs":[{"name":"i8"}],"output":{"name":"f32"}}],[11,"from","","",322,{"inputs":[{"name":"i16"}],"output":{"name":"isize"}}],[11,"from","std::simd","",345,{"inputs":[{"name":"i64x8"}],"output":{"name":"f32x8"}}],[11,"from","","",308,{"inputs":[{"name":"u32x8"}],"output":{"name":"f64x8"}}],[11,"from","","",324,{"inputs":[{"name":"i16x8"}],"output":{"name":"u8x8"}}],[11,"from","","",338,{"inputs":[{"name":"u8x16"}],"output":{"name":"i16x16"}}],[11,"from","","",323,{"inputs":[{"name":"u32x2"}],"output":{"name":"f32x2"}}],[11,"from","","",324,{"inputs":[{"name":"u16x8"}],"output":{"name":"u8x8"}}],[11,"from","","",333,{"inputs":[{"name":"u8x16"}],"output":{"name":"u16x16"}}],[11,"from","","",347,{"inputs":[{"name":"u32x4"}],"output":{"name":"u8x4"}}],[11,"from","std","",301,{"inputs":[{"name":"char"}],"output":{"name":"u32"}}],[11,"from","std::simd","",352,{"inputs":[{"name":"u16x4"}],"output":{"name":"f64x4"}}],[11,"from","","",343,{"inputs":[{"name":"i64x2"}],"output":{"name":"u8x2"}}],[11,"from","","",324,{"inputs":[{"name":"i8x8"}],"output":{"name":"u8x8"}}],[11,"from","","",357,{"inputs":[{"name":"i64x4"}],"output":{"name":"u32x4"}}],[11,"from","","",338,{"inputs":[{"name":"u16x16"}],"output":{"name":"i16x16"}}],[11,"from","","",331,{"inputs":[{"name":"i16x32"}],"output":{"name":"i8x32"}}],[11,"from","std::cell","",455,{"inputs":[{"name":"t"}],"output":{"name":"refcell"}}],[11,"from","std::simd","",333,{"inputs":[{"name":"i8x16"}],"output":{"name":"u16x16"}}],[11,"from","","",355,{"inputs":[{"name":"i32x4"}],"output":{"name":"u64x4"}}],[11,"from","","",324,{"inputs":[{"name":"i32x8"}],"output":{"name":"u8x8"}}],[11,"from","","",328,{"inputs":[{"name":"u32x2"}],"output":{"name":"u64x2"}}],[11,"from","","",344,{"inputs":[{"name":"u8x2"}],"output":{"name":"u16x2"}}],[11,"from","","",353,{"inputs":[{"name":"i8x8"}],"output":{"name":"i64x8"}}],[11,"from","","",349,{"inputs":[{"name":"i8x16"}],"output":{"name":"f32x16"}}],[11,"from","","",337,{"inputs":[{"name":"i32x8"}],"output":{"name":"i16x8"}}],[11,"from","","",357,{"inputs":[{"name":"i8x4"}],"output":{"name":"u32x4"}}],[11,"from","","",308,{"inputs":[{"name":"u16x8"}],"output":{"name":"f64x8"}}],[11,"from","","",323,{"inputs":[{"name":"i16x2"}],"output":{"name":"f32x2"}}],[11,"from","","",345,{"inputs":[{"name":"i32x8"}],"output":{"name":"f32x8"}}],[11,"from","std","",322,{"inputs":[{"name":"u8"}],"output":{"name":"isize"}}],[11,"from","","",306,{"inputs":[{"name":"u32"}],"output":{"name":"u64"}}],[11,"from","std::simd","",341,{"inputs":[{"name":"i32x8"}],"output":{"name":"u64x8"}}],[11,"from","","",312,{"inputs":[{"name":"i64x8"}],"output":{"name":"u16x8"}}],[11,"from","std::sync::atomic","",466,{"inputs":[{"name":"i32"}],"output":{"name":"atomici32"}}],[11,"from","std::simd","",336,{"inputs":[{"name":"f32x2"}],"output":{"name":"i8x2"}}],[11,"from","","",336,{"inputs":[{"name":"i64x2"}],"output":{"name":"i8x2"}}],[11,"from","","",358,{"inputs":[{"name":"u64x4"}],"output":{"name":"i64x4"}}],[11,"from","std::sync::atomic","",467,null],[11,"from","std::simd","",348,{"inputs":[{"name":"f64x8"}],"output":{"name":"i8x8"}}],[11,"from","","",353,{"inputs":[{"name":"f32x8"}],"output":{"name":"i64x8"}}],[11,"from","std","",306,{"inputs":[{"name":"u8"}],"output":{"name":"u64"}}],[11,"from","std::simd","",344,{"inputs":[{"name":"f64x2"}],"output":{"name":"u16x2"}}],[11,"from","","",308,{"inputs":[{"name":"i32x8"}],"output":{"name":"f64x8"}}],[11,"from","","",323,{"inputs":[{"name":"i64x2"}],"output":{"name":"f32x2"}}],[11,"from","","",303,{"inputs":[{"name":"u64x8"}],"output":{"name":"i32x8"}}],[11,"from","std::ptr","",445,{"inputs":[{"name":"t"}],"output":{"name":"unique"}}],[11,"from","std::simd","",340,{"inputs":[{"name":"f64x8"}],"output":{"name":"u32x8"}}],[11,"from","","",341,{"inputs":[{"name":"f32x8"}],"output":{"name":"u64x8"}}],[11,"from","","",340,{"inputs":[{"name":"u16x8"}],"output":{"name":"u32x8"}}],[11,"from","","",330,{"inputs":[{"name":"u64x4"}],"output":{"name":"i8x4"}}],[11,"from","","",323,{"inputs":[{"name":"f64x2"}],"output":{"name":"f32x2"}}],[11,"from","","",344,{"inputs":[{"name":"f32x2"}],"output":{"name":"u16x2"}}],[11,"from","std::sync::atomic","",468,{"inputs":[{"name":"bool"}],"output":{"name":"atomicbool"}}],[11,"from","std::simd","",303,{"inputs":[{"name":"u32x8"}],"output":{"name":"i32x8"}}],[11,"from","","",348,{"inputs":[{"name":"i32x8"}],"output":{"name":"i8x8"}}],[11,"from","","",328,{"inputs":[{"name":"f64x2"}],"output":{"name":"u64x2"}}],[11,"from","","",348,{"inputs":[{"name":"u64x8"}],"output":{"name":"i8x8"}}],[11,"from","","",337,{"inputs":[{"name":"u32x8"}],"output":{"name":"i16x8"}}],[11,"from","","",311,{"inputs":[{"name":"f32x4"}],"output":{"name":"i16x4"}}],[11,"from","","",343,{"inputs":[{"name":"f32x2"}],"output":{"name":"u8x2"}}],[11,"from","","",310,{"inputs":[{"name":"u8x2"}],"output":{"name":"u32x2"}}],[11,"from","","",321,{"inputs":[{"name":"u64x2"}],"output":{"name":"f64x2"}}],[11,"from","std","",318,{"inputs":[{"name":"u64"}],"output":{"name":"i128"}}],[11,"from","std::simd","",341,{"inputs":[{"name":"i64x8"}],"output":{"name":"u64x8"}}],[11,"from","std::option","",73,{"inputs":[{"name":"t"}],"output":{"name":"option"}}],[11,"from","std::simd","",346,{"inputs":[{"name":"u8x4"}],"output":{"name":"u16x4"}}],[11,"from","std","",332,{"inputs":[{"name":"u8"}],"output":{"name":"i64"}}],[11,"from","std::simd","",351,{"inputs":[{"name":"i16x32"}],"output":{"name":"u8x32"}}],[11,"from","std","",319,{"inputs":[{"name":"i16"}],"output":{"name":"f32"}}],[11,"from","std::simd","",327,{"inputs":[{"name":"u32x2"}],"output":{"name":"i64x2"}}],[11,"from","","",357,{"inputs":[{"name":"u8x4"}],"output":{"name":"u32x4"}}],[11,"from","","",347,{"inputs":[{"name":"u16x4"}],"output":{"name":"u8x4"}}],[11,"from","","",346,{"inputs":[{"name":"i8x4"}],"output":{"name":"u16x4"}}],[11,"from","","",310,{"inputs":[{"name":"u16x2"}],"output":{"name":"u32x2"}}],[11,"from","std::ptr","",445,{"inputs":[{"name":"t"}],"output":{"name":"unique"}}],[11,"from","std","",318,{"inputs":[{"name":"u8"}],"output":{"name":"i128"}}],[11,"from","","",339,{"inputs":[{"name":"u64"}],"output":{"name":"u128"}}],[11,"from","std::simd","",310,{"inputs":[{"name":"i8x2"}],"output":{"name":"u32x2"}}],[11,"from","std","",332,{"inputs":[{"name":"i8"}],"output":{"name":"i64"}}],[11,"from","std::simd","",328,{"inputs":[{"name":"i16x2"}],"output":{"name":"u64x2"}}],[11,"from","std","",339,{"inputs":[{"name":"u16"}],"output":{"name":"u128"}}],[11,"from","std::simd","",356,{"inputs":[{"name":"u32x4"}],"output":{"name":"f32x4"}}],[11,"from","","",324,{"inputs":[{"name":"f32x8"}],"output":{"name":"u8x8"}}],[11,"from","","",356,{"inputs":[{"name":"i8x4"}],"output":{"name":"f32x4"}}],[11,"from","std","",314,{"inputs":[{"name":"i8"}],"output":{"name":"f64"}}],[11,"from","std::simd","",324,{"inputs":[{"name":"u32x8"}],"output":{"name":"u8x8"}}],[11,"from","","",341,{"inputs":[{"name":"f64x8"}],"output":{"name":"u64x8"}}],[11,"from","","",327,{"inputs":[{"name":"u16x2"}],"output":{"name":"i64x2"}}],[11,"from","","",351,{"inputs":[{"name":"u16x32"}],"output":{"name":"u8x32"}}],[11,"from","","",325,{"inputs":[{"name":"u8x64"}],"output":{"name":"i8x64"}}],[11,"from","std::sync::atomic","",469,{"inputs":[{"name":"u64"}],"output":{"name":"atomicu64"}}],[11,"from","std::simd","",310,{"inputs":[{"name":"f64x2"}],"output":{"name":"u32x2"}}],[11,"from","","",353,{"inputs":[{"name":"u32x8"}],"output":{"name":"i64x8"}}],[11,"from","","",316,{"inputs":[{"name":"u32x16"}],"output":{"name":"i32x16"}}],[11,"from","","",342,{"inputs":[{"name":"i16x32"}],"output":{"name":"u16x32"}}],[11,"from","","",347,{"inputs":[{"name":"i32x4"}],"output":{"name":"u8x4"}}],[11,"from","","",343,{"inputs":[{"name":"u64x2"}],"output":{"name":"u8x2"}}],[11,"from","","",355,{"inputs":[{"name":"i8x4"}],"output":{"name":"u64x4"}}],[11,"from","","",357,{"inputs":[{"name":"u16x4"}],"output":{"name":"u32x4"}}],[11,"from","","",308,{"inputs":[{"name":"u64x8"}],"output":{"name":"f64x8"}}],[11,"from","","",326,{"inputs":[{"name":"u16x2"}],"output":{"name":"i32x2"}}],[11,"from","","",323,{"inputs":[{"name":"u64x2"}],"output":{"name":"f32x2"}}],[11,"from","","",340,{"inputs":[{"name":"i8x8"}],"output":{"name":"u32x8"}}],[11,"from","","",333,{"inputs":[{"name":"i32x16"}],"output":{"name":"u16x16"}}],[11,"from","","",336,{"inputs":[{"name":"f64x2"}],"output":{"name":"i8x2"}}],[11,"from","std::collections","",108,{"inputs":[{"name":"allocerr"}],"output":{"name":"collectionallocerr"}}],[11,"from","std::simd","",346,{"inputs":[{"name":"u32x4"}],"output":{"name":"u16x4"}}],[11,"from","","",350,{"inputs":[{"name":"u16x16"}],"output":{"name":"u32x16"}}],[11,"from","","",349,{"inputs":[{"name":"i32x16"}],"output":{"name":"f32x16"}}],[11,"from","","",342,{"inputs":[{"name":"i8x32"}],"output":{"name":"u16x32"}}],[11,"from","","",327,{"inputs":[{"name":"f32x2"}],"output":{"name":"i64x2"}}],[11,"from","","",311,{"inputs":[{"name":"u64x4"}],"output":{"name":"i16x4"}}],[11,"from","","",327,{"inputs":[{"name":"i8x2"}],"output":{"name":"i64x2"}}],[11,"from","","",327,{"inputs":[{"name":"i16x2"}],"output":{"name":"i64x2"}}],[11,"from","","",349,{"inputs":[{"name":"u8x16"}],"output":{"name":"f32x16"}}],[11,"from","","",327,{"inputs":[{"name":"u8x2"}],"output":{"name":"i64x2"}}],[11,"from","","",330,{"inputs":[{"name":"f32x4"}],"output":{"name":"i8x4"}}],[11,"from","","",357,{"inputs":[{"name":"i32x4"}],"output":{"name":"u32x4"}}],[11,"from","","",305,{"inputs":[{"name":"i64x4"}],"output":{"name":"i32x4"}}],[11,"from","","",337,{"inputs":[{"name":"u64x8"}],"output":{"name":"i16x8"}}],[11,"from","","",336,{"inputs":[{"name":"u8x2"}],"output":{"name":"i8x2"}}],[11,"from","","",340,{"inputs":[{"name":"f32x8"}],"output":{"name":"u32x8"}}],[11,"from","std::cell","",470,{"inputs":[{"name":"t"}],"output":{"name":"unsafecell"}}],[11,"from","std::simd","",305,{"inputs":[{"name":"u32x4"}],"output":{"name":"i32x4"}}],[11,"from","","",343,{"inputs":[{"name":"u32x2"}],"output":{"name":"u8x2"}}],[11,"from","std::sync::atomic","",471,{"inputs":[{"name":"isize"}],"output":{"name":"atomicisize"}}],[11,"from","std::simd","",303,{"inputs":[{"name":"i16x8"}],"output":{"name":"i32x8"}}],[11,"from","","",308,{"inputs":[{"name":"u8x8"}],"output":{"name":"f64x8"}}],[11,"from","","",326,{"inputs":[{"name":"u32x2"}],"output":{"name":"i32x2"}}],[11,"from","","",346,{"inputs":[{"name":"i64x4"}],"output":{"name":"u16x4"}}],[11,"from","","",358,{"inputs":[{"name":"f32x4"}],"output":{"name":"i64x4"}}],[11,"from","","",326,{"inputs":[{"name":"f64x2"}],"output":{"name":"i32x2"}}],[11,"from","","",327,{"inputs":[{"name":"u64x2"}],"output":{"name":"i64x2"}}],[11,"from","","",351,{"inputs":[{"name":"i8x32"}],"output":{"name":"u8x32"}}],[11,"from","","",341,{"inputs":[{"name":"u16x8"}],"output":{"name":"u64x8"}}],[11,"from","","",350,{"inputs":[{"name":"i32x16"}],"output":{"name":"u32x16"}}],[11,"from","std","",304,{"inputs":[{"name":"u16"}],"output":{"name":"usize"}}],[11,"from","","",332,{"inputs":[{"name":"i32"}],"output":{"name":"i64"}}],[11,"from","std::simd","",305,{"inputs":[{"name":"f64x4"}],"output":{"name":"i32x4"}}],[11,"from","","",358,{"inputs":[{"name":"u16x4"}],"output":{"name":"i64x4"}}],[11,"from","","",343,{"inputs":[{"name":"i32x2"}],"output":{"name":"u8x2"}}],[11,"from","","",321,{"inputs":[{"name":"u32x2"}],"output":{"name":"f64x2"}}],[11,"from","","",310,{"inputs":[{"name":"i32x2"}],"output":{"name":"u32x2"}}],[11,"from","","",358,{"inputs":[{"name":"i16x4"}],"output":{"name":"i64x4"}}],[11,"from","","",353,{"inputs":[{"name":"u64x8"}],"output":{"name":"i64x8"}}],[11,"from","","",352,{"inputs":[{"name":"i8x4"}],"output":{"name":"f64x4"}}],[11,"from","","",342,{"inputs":[{"name":"u8x32"}],"output":{"name":"u16x32"}}],[11,"from","","",344,{"inputs":[{"name":"u64x2"}],"output":{"name":"u16x2"}}],[11,"from","","",328,{"inputs":[{"name":"u8x2"}],"output":{"name":"u64x2"}}],[11,"from","std::ptr","",445,{"inputs":[{"name":"nonnull"}],"output":{"name":"unique"}}],[11,"from","std::simd","",308,{"inputs":[{"name":"i8x8"}],"output":{"name":"f64x8"}}],[11,"from","","",323,{"inputs":[{"name":"i32x2"}],"output":{"name":"f32x2"}}],[11,"from","std::sync::atomic","",472,{"inputs":[{"name":"u16"}],"output":{"name":"atomicu16"}}],[11,"from","std::simd","",326,{"inputs":[{"name":"i8x2"}],"output":{"name":"i32x2"}}],[11,"from","std","",301,{"inputs":[{"name":"u8"}],"output":{"name":"u32"}}],[11,"from","","",314,{"inputs":[{"name":"i16"}],"output":{"name":"f64"}}],[11,"from","std::simd","",302,{"inputs":[{"name":"i8x32"}],"output":{"name":"i16x32"}}],[11,"from","","",346,{"inputs":[{"name":"f32x4"}],"output":{"name":"u16x4"}}],[11,"from","","",353,{"inputs":[{"name":"u8x8"}],"output":{"name":"i64x8"}}],[11,"from","","",316,{"inputs":[{"name":"u16x16"}],"output":{"name":"i32x16"}}],[11,"from","","",316,{"inputs":[{"name":"f32x16"}],"output":{"name":"i32x16"}}],[11,"from","std","",332,{"inputs":[{"name":"u16"}],"output":{"name":"i64"}}],[11,"from","std::simd","",346,{"inputs":[{"name":"f64x4"}],"output":{"name":"u16x4"}}],[11,"from","","",345,{"inputs":[{"name":"f64x8"}],"output":{"name":"f32x8"}}],[11,"from","","",356,{"inputs":[{"name":"f64x4"}],"output":{"name":"f32x4"}}],[11,"from","","",355,{"inputs":[{"name":"i16x4"}],"output":{"name":"u64x4"}}],[11,"from","","",344,{"inputs":[{"name":"i32x2"}],"output":{"name":"u16x2"}}],[11,"from","std::ptr","",427,{"inputs":[{"name":"t"}],"output":{"name":"nonnull"}}],[11,"from","std::simd","",333,{"inputs":[{"name":"f32x16"}],"output":{"name":"u16x16"}}],[11,"from","","",341,{"inputs":[{"name":"i16x8"}],"output":{"name":"u64x8"}}],[11,"from","","",311,{"inputs":[{"name":"f64x4"}],"output":{"name":"i16x4"}}],[11,"from","","",305,{"inputs":[{"name":"i8x4"}],"output":{"name":"i32x4"}}],[11,"from","","",343,{"inputs":[{"name":"i8x2"}],"output":{"name":"u8x2"}}],[11,"from","","",345,{"inputs":[{"name":"i16x8"}],"output":{"name":"f32x8"}}],[11,"from","","",331,{"inputs":[{"name":"u16x32"}],"output":{"name":"i8x32"}}],[11,"from","","",354,{"inputs":[{"name":"f64x2"}],"output":{"name":"i16x2"}}],[11,"from","std","",318,{"inputs":[{"name":"i64"}],"output":{"name":"i128"}}],[11,"from","std::simd","",358,{"inputs":[{"name":"u8x4"}],"output":{"name":"i64x4"}}],[11,"from","","",330,{"inputs":[{"name":"u32x4"}],"output":{"name":"i8x4"}}],[11,"from","","",347,{"inputs":[{"name":"i16x4"}],"output":{"name":"u8x4"}}],[11,"from","","",324,{"inputs":[{"name":"u64x8"}],"output":{"name":"u8x8"}}],[11,"from","","",310,{"inputs":[{"name":"f32x2"}],"output":{"name":"u32x2"}}],[11,"into_searcher","std","",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"strsearcher"}}],[11,"is_prefix_of","","Checks whether the pattern matches at the front of the haystack",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_suffix_of","","Checks whether the pattern matches at the back of the haystack",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"into_searcher","","",432,null],[11,"is_contained_in","","",432,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_prefix_of","","",432,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_suffix_of","","",432,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"into_searcher","","",433,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"charslicesearcher"}}],[11,"is_contained_in","","",433,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_prefix_of","","",433,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"is_suffix_of","","",433,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"bool"}}],[11,"ne","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"bool"}}],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::num","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"ne","","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",424,null],[11,"ne","","",424,null],[11,"eq","std::ops","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"ne","","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"eq","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"ne","","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"ne","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"bool"}}],[11,"ne","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"bool"}}],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","std::ops","",34,{"inputs":[{"name":"self"},{"name":"rangeinclusive"}],"output":{"name":"bool"}}],[11,"ne","","",34,{"inputs":[{"name":"self"},{"name":"rangeinclusive"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"ne","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"ne","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"eq","","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"bool"}}],[11,"ne","","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"bool"}}],[11,"eq","std::num","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"ne","","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"ne","","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"ne","","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"ne","","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"eq","std::cell","",451,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"eq","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"ne","","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"eq","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"ne","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","std::str::pattern","",92,{"inputs":[{"name":"self"},{"name":"searchstep"}],"output":{"name":"bool"}}],[11,"ne","","",92,{"inputs":[{"name":"self"},{"name":"searchstep"}],"output":{"name":"bool"}}],[11,"eq","std::num","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"ne","","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"ne","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"ne","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"ne","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"ne","","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"ne","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"bool"}}],[11,"ne","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"bool"}}],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"ne","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"eq","","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"ne","","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"bool"}}],[11,"ne","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"bool"}}],[11,"eq","std::result","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"ne","","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"ne","","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::ptr","",427,{"inputs":[{"name":"self"},{"name":"nonnull"}],"output":{"name":"bool"}}],[11,"eq","std","",424,null],[11,"ne","","",424,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"ne","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"bool"}}],[11,"ne","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"bool"}}],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::cmp","",3,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",424,null],[11,"ne","","",424,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"ne","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"ne","","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"eq","","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"ne","","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"ne","","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"ne","","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::cmp","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"ne","","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"ne","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"ne","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::char","",131,{"inputs":[{"name":"self"},{"name":"parsecharerror"}],"output":{"name":"bool"}}],[11,"ne","","",131,{"inputs":[{"name":"self"},{"name":"parsecharerror"}],"output":{"name":"bool"}}],[11,"eq","std::simd","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"ne","","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","std::num","",448,{"inputs":[{"name":"self"},{"name":"parseinterror"}],"output":{"name":"bool"}}],[11,"ne","","",448,{"inputs":[{"name":"self"},{"name":"parseinterror"}],"output":{"name":"bool"}}],[11,"eq","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"ne","","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",423,null],[11,"eq","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"ne","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"eq","std::num","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"ne","","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"ne","","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::time","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"ne","","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"eq","std::char","",130,{"inputs":[{"name":"self"},{"name":"chartryfromerror"}],"output":{"name":"bool"}}],[11,"ne","","",130,{"inputs":[{"name":"self"},{"name":"chartryfromerror"}],"output":{"name":"bool"}}],[11,"eq","std","",425,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"ne","","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"ne","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",434,null],[11,"ne","","",434,null],[11,"eq","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"ne","","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"eq","std","",424,null],[11,"ne","","",424,null],[11,"eq","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"bool"}}],[11,"ne","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"bool"}}],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",424,null],[11,"ne","","",424,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::num","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"ne","","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"eq","std::fmt","",127,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",423,null],[11,"eq","std::num","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"ne","","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"ne","","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",424,null],[11,"ne","","",424,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",424,null],[11,"ne","","",424,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",425,null],[11,"eq","std::str","",122,{"inputs":[{"name":"self"},{"name":"utf8error"}],"output":{"name":"bool"}}],[11,"ne","","",122,{"inputs":[{"name":"self"},{"name":"utf8error"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"ne","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::num","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"ne","","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","std::ops","",422,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",473,null],[11,"eq","","",424,null],[11,"ne","","",424,null],[11,"eq","std::simd","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"ne","","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"eq","std::num","",194,{"inputs":[{"name":"self"},{"name":"fpcategory"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"ne","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","std::num","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"ne","","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"eq","std","",424,null],[11,"ne","","",424,null],[11,"eq","std::marker","",436,{"inputs":[{"name":"self"},{"name":"phantomdata"}],"output":{"name":"bool"}}],[11,"eq","std::simd","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"ne","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"ne","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"eq","std::ops","",48,{"inputs":[{"name":"self"},{"name":"range"}],"output":{"name":"bool"}}],[11,"ne","","",48,{"inputs":[{"name":"self"},{"name":"range"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"ne","","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"ne","","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"eq","std::any","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"ne","","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"ne","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"eq","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"bool"}}],[11,"ne","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"bool"}}],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"ne","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"eq","std","",424,null],[11,"ne","","",424,null],[11,"eq","std::ops","",35,{"inputs":[{"name":"self"},{"name":"rangetoinclusive"}],"output":{"name":"bool"}}],[11,"ne","","",35,{"inputs":[{"name":"self"},{"name":"rangetoinclusive"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"ne","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","std::collections","",108,{"inputs":[{"name":"self"},{"name":"collectionallocerr"}],"output":{"name":"bool"}}],[11,"ne","","",108,{"inputs":[{"name":"self"},{"name":"collectionallocerr"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::ops","",53,{"inputs":[{"name":"self"},{"name":"bound"}],"output":{"name":"bool"}}],[11,"ne","","",53,{"inputs":[{"name":"self"},{"name":"bound"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::num","",438,{"inputs":[{"name":"self"},{"name":"parsefloaterror"}],"output":{"name":"bool"}}],[11,"ne","","",438,{"inputs":[{"name":"self"},{"name":"parsefloaterror"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"ne","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",431,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"bool"}}],[11,"ne","","",431,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"bool"}}],[11,"eq","std::option","",430,{"inputs":[{"name":"self"},{"name":"noneerror"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","std::num","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"ne","","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"ne","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"bool"}}],[11,"ne","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"bool"}}],[11,"eq","std::num","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"ne","","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","std::simd","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"ne","","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"eq","std::ops","",49,{"inputs":[{"name":"self"},{"name":"rangefrom"}],"output":{"name":"bool"}}],[11,"ne","","",49,{"inputs":[{"name":"self"},{"name":"rangefrom"}],"output":{"name":"bool"}}],[11,"eq","std::num","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"ne","","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"eq","std::ops","",31,{"inputs":[{"name":"self"},{"name":"rangeto"}],"output":{"name":"bool"}}],[11,"ne","","",31,{"inputs":[{"name":"self"},{"name":"rangeto"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"ne","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::mem","",435,{"inputs":[{"name":"self"},{"name":"discriminant"}],"output":{"name":"bool"}}],[11,"eq","std::simd","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"ne","","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"eq","std","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"bool"}}],[11,"ne","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"bool"}}],[11,"eq","std::num","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"ne","","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::num","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"ne","","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::option","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"ne","","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"ne","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"eq","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"ne","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"bool"}}],[11,"ne","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"bool"}}],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"bool"}}],[11,"ne","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"bool"}}],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","std::mem","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"name":"bool"}}],[11,"ne","","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"name":"bool"}}],[11,"eq","std","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","std::str","",121,{"inputs":[{"name":"self"},{"name":"parseboolerror"}],"output":{"name":"bool"}}],[11,"ne","","",121,{"inputs":[{"name":"self"},{"name":"parseboolerror"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"bool"}}],[11,"ne","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"bool"}}],[11,"eq","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"ne","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"eq","std","",423,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",423,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"ne","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"eq","std::cell","Panics",455,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"eq","std","",433,null],[11,"ne","","",433,null],[11,"eq","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"ne","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"eq","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"ne","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"eq","std","",424,null],[11,"ne","","",424,null],[11,"eq","","",424,null],[11,"ne","","",424,null],[11,"eq","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"bool"}}],[11,"ne","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"bool"}}],[11,"eq","","",409,null],[11,"ne","","",409,null],[11,"eq","","",433,null],[11,"ne","","",433,null],[11,"cmp","","",423,null],[11,"cmp","std::num","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",424,null],[11,"cmp","std::ptr","",427,{"inputs":[{"name":"self"},{"name":"nonnull"}],"output":{"name":"ordering"}}],[11,"cmp","std","",409,null],[11,"cmp","std::num","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",424,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","std::marker","",436,{"inputs":[{"name":"self"},{"name":"phantomdata"}],"output":{"name":"ordering"}}],[11,"cmp","std","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",424,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",424,null],[11,"cmp","","",424,null],[11,"cmp","std::num","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"ordering"}}],[11,"cmp","std::cell","",451,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"ordering"}}],[11,"cmp","std::num","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"ordering"}}],[11,"cmp","","",409,null],[11,"cmp","","",285,{"inputs":[{"name":"self"},{"name":"a"}],"output":{"name":"ordering"}}],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","std::ops","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",424,null],[11,"cmp","","",423,null],[11,"cmp","std::cmp","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"ordering"}}],[11,"cmp","std::result","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"ordering"}}],[11,"cmp","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"ordering"}}],[11,"cmp","","",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"ordering"}}],[11,"cmp","","",424,null],[11,"cmp","","",409,null],[11,"cmp","std::num","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"ordering"}}],[11,"cmp","","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"ordering"}}],[11,"cmp","std","",409,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",433,null],[11,"cmp","","",425,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","std::num","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",424,null],[11,"cmp","","",423,null],[11,"cmp","","",424,null],[11,"cmp","","",409,null],[11,"cmp","std::num","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","std::num","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",423,null],[11,"cmp","std::num","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",425,null],[11,"cmp","std::option","",430,{"inputs":[{"name":"self"},{"name":"noneerror"}],"output":{"name":"ordering"}}],[11,"cmp","std","",409,null],[11,"cmp","","",409,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","std::time","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","std::cell","Panics",455,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",285,{"inputs":[{"name":"self"},{"name":"a"}],"output":{"name":"ordering"}}],[11,"cmp","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","std::cmp","",3,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"ordering"}}],[11,"cmp","std","",409,null],[11,"cmp","std::fmt","",127,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","std::mem","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"name":"ordering"}}],[11,"cmp","std","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"ordering"}}],[11,"cmp","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",424,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","std::num","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",409,null],[11,"cmp","","",434,null],[11,"cmp","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",473,null],[11,"cmp","","",423,null],[11,"cmp","std::num","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"ordering"}}],[11,"cmp","std::num","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"ordering"}}],[11,"cmp","std","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"ordering"}}],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",424,null],[11,"cmp","","",409,null],[11,"cmp","std::any","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"ordering"}}],[11,"cmp","std","",423,null],[11,"cmp","","",424,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",423,null],[11,"cmp","","",423,null],[11,"cmp","","",409,null],[11,"cmp","","",431,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"ordering"}}],[11,"cmp","","",423,null],[11,"cmp","std::option","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"ordering"}}],[11,"partial_cmp","std::num","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"le","","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"gt","","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"ge","","",195,{"inputs":[{"name":"self"},{"name":"wrapping"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"le","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"gt","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"ge","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::time","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"le","","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"gt","","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"ge","","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",433,null],[11,"partial_cmp","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"le","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"gt","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"ge","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"le","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"gt","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"ge","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"le","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"gt","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"ge","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::num","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"le","","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"gt","","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"ge","","",420,{"inputs":[{"name":"self"},{"name":"nonzerou128"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"le","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"gt","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"ge","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"le","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"gt","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"ge","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::ptr","",427,{"inputs":[{"name":"self"},{"name":"nonnull"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"le","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"gt","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"ge","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::result","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"le","","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"gt","","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"ge","","",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"le","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"gt","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"ge","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::num","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"le","","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"gt","","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"ge","","",411,{"inputs":[{"name":"self"},{"name":"nonzerousize"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"le","","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"gt","","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"ge","","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"le","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"gt","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"ge","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",434,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"bool"}}],[11,"le","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"bool"}}],[11,"ge","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"bool"}}],[11,"gt","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"le","","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"gt","","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"ge","","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"le","","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"gt","","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"ge","","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::cell","Panics",455,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","Panics",455,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"le","","Panics",455,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"gt","","Panics",455,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"ge","","Panics",455,{"inputs":[{"name":"self"},{"name":"refcell"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"le","","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"gt","","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"ge","","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"bool"}}],[11,"le","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"bool"}}],[11,"ge","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"bool"}}],[11,"gt","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"bool"}}],[11,"le","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"bool"}}],[11,"ge","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"bool"}}],[11,"gt","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"le","","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"gt","","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"ge","","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::mem","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"name":"bool"}}],[11,"le","","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"name":"bool"}}],[11,"gt","","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"name":"bool"}}],[11,"ge","","",426,{"inputs":[{"name":"self"},{"name":"manuallydrop"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"le","","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"gt","","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"ge","","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"le","","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"gt","","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"ge","","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"le","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"gt","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"ge","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"le","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"gt","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"ge","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"le","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"ge","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"gt","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"bool"}}],[11,"le","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"bool"}}],[11,"ge","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"bool"}}],[11,"gt","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::marker","",436,{"inputs":[{"name":"self"},{"name":"phantomdata"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"le","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"gt","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"ge","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::num","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"le","","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"gt","","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"ge","","",419,{"inputs":[{"name":"self"},{"name":"nonzeroi64"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::ops","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"le","","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"gt","","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"ge","","",37,{"inputs":[{"name":"self"},{"name":"generatorstate"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"bool"}}],[11,"le","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"bool"}}],[11,"ge","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"bool"}}],[11,"gt","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::num","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"le","","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"gt","","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"ge","","",412,{"inputs":[{"name":"self"},{"name":"nonzerou16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",473,null],[11,"partial_cmp","std::num","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"le","","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"gt","","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"ge","","",415,{"inputs":[{"name":"self"},{"name":"nonzeroisize"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::option","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"le","","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"gt","","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"ge","","",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::num","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"le","","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"gt","","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"ge","","",416,{"inputs":[{"name":"self"},{"name":"nonzeroi32"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::option","",430,{"inputs":[{"name":"self"},{"name":"noneerror"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"le","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"gt","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"ge","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"bool"}}],[11,"le","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"bool"}}],[11,"ge","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"bool"}}],[11,"gt","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"le","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"gt","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"ge","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::num","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"le","","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"gt","","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"ge","","",413,{"inputs":[{"name":"self"},{"name":"nonzerou64"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"le","","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"gt","","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"ge","","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"le","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"gt","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"ge","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"le","","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"gt","","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"ge","","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"le","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"gt","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"ge","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::num","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"le","","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"gt","","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"ge","","",410,{"inputs":[{"name":"self"},{"name":"nonzeroi16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::cmp","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"le","","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"ge","","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"gt","","",4,{"inputs":[{"name":"self"},{"name":"reverse"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::any","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"le","","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"gt","","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"ge","","",428,{"inputs":[{"name":"self"},{"name":"typeid"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"bool"}}],[11,"le","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"bool"}}],[11,"ge","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"bool"}}],[11,"gt","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"le","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"gt","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"ge","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"le","","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"gt","","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"ge","","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"le","","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"gt","","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"ge","","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"le","","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"gt","","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"ge","","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"bool"}}],[11,"le","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"bool"}}],[11,"ge","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"bool"}}],[11,"gt","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",431,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::num","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"le","","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"gt","","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"ge","","",418,{"inputs":[{"name":"self"},{"name":"nonzerou8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"le","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"gt","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"ge","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"bool"}}],[11,"le","","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"bool"}}],[11,"ge","","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"bool"}}],[11,"gt","","",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"le","","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"gt","","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"ge","","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"le","","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"gt","","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"ge","","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"le","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"ge","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"gt","","",285,{"inputs":[{"name":"self"},{"name":"b"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"le","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"gt","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"ge","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"le","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"gt","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"ge","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"le","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"gt","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"ge","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"le","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"gt","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"ge","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::cell","",451,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",451,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"le","","",451,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"gt","","",451,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"ge","","",451,{"inputs":[{"name":"self"},{"name":"cell"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"le","","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"gt","","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"ge","","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"le","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"gt","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"ge","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"le","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"ge","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"gt","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"le","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"gt","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"ge","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","std::simd","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"le","","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"gt","","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"ge","","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::num","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"le","","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"gt","","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"ge","","",414,{"inputs":[{"name":"self"},{"name":"nonzeroi128"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"le","","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"gt","","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"ge","","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"bool"}}],[11,"le","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"bool"}}],[11,"ge","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"bool"}}],[11,"gt","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"le","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"gt","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"ge","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::num","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"le","","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"gt","","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"ge","","",421,{"inputs":[{"name":"self"},{"name":"nonzeroi8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"bool"}}],[11,"le","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"bool"}}],[11,"ge","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"bool"}}],[11,"gt","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::cmp","",3,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"bool"}}],[11,"le","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"bool"}}],[11,"ge","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"bool"}}],[11,"gt","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"bool"}}],[11,"le","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"bool"}}],[11,"ge","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"bool"}}],[11,"gt","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::simd","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"le","","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"gt","","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"ge","","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"le","","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"gt","","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"ge","","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",425,null],[11,"lt","","",425,null],[11,"le","","",425,null],[11,"gt","","",425,null],[11,"ge","","",425,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",425,null],[11,"lt","","",425,null],[11,"le","","",425,null],[11,"gt","","",425,null],[11,"ge","","",425,null],[11,"partial_cmp","std::fmt","",127,{"inputs":[{"name":"self"},{"name":"error"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std","",423,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"le","","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"gt","","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"ge","","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","std::simd","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"le","","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"gt","","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"ge","","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"le","","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"gt","","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"ge","","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"bool"}}],[11,"le","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"bool"}}],[11,"ge","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"bool"}}],[11,"gt","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",409,null],[11,"lt","","",409,null],[11,"le","","",409,null],[11,"ge","","",409,null],[11,"gt","","",409,null],[11,"partial_cmp","","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"le","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"gt","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"ge","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::num","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"le","","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"gt","","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"ge","","",417,{"inputs":[{"name":"self"},{"name":"nonzerou32"}],"output":{"name":"bool"}}],[11,"partial_cmp","std","",424,null],[11,"lt","","",424,null],[11,"le","","",424,null],[11,"ge","","",424,null],[11,"gt","","",424,null],[11,"partial_cmp","","",423,null],[11,"partial_cmp","std::simd","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"le","","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"gt","","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"ge","","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"bool"}}],[11,"fmt","std","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",301,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",306,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",320,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",332,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",420,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",413,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",415,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",411,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",410,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",419,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",195,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",416,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",339,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",412,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",421,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",317,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",329,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",417,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",418,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",322,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",304,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",307,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",335,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",414,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",318,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"div","","",301,null],[11,"div","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"div","","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"f32x4"}}],[11,"div","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"div","","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"div","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"div","std","",318,null],[11,"div","","",322,null],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"div","std","",322,null],[11,"div","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"div","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"div","std","",304,null],[11,"div","std::num","",195,null],[11,"div","std::simd","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"f32x2"}}],[11,"div","std","",301,null],[11,"div","std::simd","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"f32x8"}}],[11,"div","std","",339,null],[11,"div","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"div","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"div","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"div","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"div","std","",301,null],[11,"div","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"div","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"div","std","",335,null],[11,"div","","",319,null],[11,"div","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"div","","",317,null],[11,"div","","",339,null],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"div","","",195,null],[11,"div","std","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"div","std::num","",195,null],[11,"div","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"div","std","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"div","","",339,null],[11,"div","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"div","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"div","std","",335,null],[11,"div","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"div","std::num","",195,null],[11,"div","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"div","std","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"div","","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"div","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"div","std","",307,null],[11,"div","","",318,null],[11,"div","std::num","",195,null],[11,"div","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"div","std","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"div","","",307,null],[11,"div","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"div","","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"f64x2"}}],[11,"div","std","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"div","std::num","",195,null],[11,"div","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"div","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"div","std::num","",195,null],[11,"div","std","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"div","std::simd","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"f32x16"}}],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"div","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"div","std","",314,null],[11,"div","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"div","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"div","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"div","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"div","std","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"div","","",329,null],[11,"div","std::time","",309,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"duration"}}],[11,"div","std","",314,null],[11,"div","","",320,null],[11,"div","","",319,null],[11,"div","","",317,null],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"div","std","",332,null],[11,"div","","",318,null],[11,"div","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"div","","",317,null],[11,"div","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"div","","",322,null],[11,"div","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"div","std","",320,null],[11,"div","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"div","std","",335,null],[11,"div","","",304,null],[11,"div","","",307,null],[11,"div","","",332,null],[11,"div","std::num","",195,null],[11,"div","","",195,null],[11,"div","","",195,null],[11,"div","std","",306,null],[11,"div","std::num","",195,null],[11,"div","std","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"div","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"div","std::num","",195,null],[11,"div","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"div","","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"f64x8"}}],[11,"div","std","",329,null],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"div","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"div","","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"f64x4"}}],[11,"div","std","",332,null],[11,"div","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"div","std","",329,null],[11,"div","","",306,null],[11,"div","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"div","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"div","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"div","std","",304,null],[11,"div","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"div","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"div","std","",306,null],[11,"div","","",314,null],[11,"div","","",319,null],[11,"div","","",320,null],[11,"div","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"div","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"bitand","std::num","",195,null],[11,"bitand","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"bitand","","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"bitand","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"bitand","std","",339,null],[11,"bitand","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"bitand","std::num","",195,null],[11,"bitand","","",195,null],[11,"bitand","std","",306,null],[11,"bitand","","",317,null],[11,"bitand","","",332,null],[11,"bitand","","",335,null],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"bitand","std","",320,null],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"bitand","std","",307,null],[11,"bitand","","",304,null],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"bitand","","",195,null],[11,"bitand","","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"bitand","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"bitand","std","",306,null],[11,"bitand","","",431,null],[11,"bitand","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"bitand","","",317,null],[11,"bitand","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"bitand","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"bitand","std::num","",195,null],[11,"bitand","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"bitand","std","",304,null],[11,"bitand","","",332,null],[11,"bitand","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"bitand","std","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"bitand","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"bitand","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"bitand","std","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"bitand","std::num","",195,null],[11,"bitand","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"bitand","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"bitand","std::num","",195,null],[11,"bitand","std","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"bitand","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"bitand","std","",306,null],[11,"bitand","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"bitand","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"bitand","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"bitand","std","",301,null],[11,"bitand","std::num","",195,null],[11,"bitand","std","",320,null],[11,"bitand","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"bitand","std::num","",195,null],[11,"bitand","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"bitand","std","",335,null],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"bitand","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"bitand","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"bitand","std","",301,null],[11,"bitand","","",322,null],[11,"bitand","std::num","",195,null],[11,"bitand","std","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"bitand","std","",307,null],[11,"bitand","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"bitand","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"bitand","std","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"bitand","","",332,null],[11,"bitand","","",339,null],[11,"bitand","","",329,null],[11,"bitand","","",335,null],[11,"bitand","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"bitand","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"bitand","std","",317,null],[11,"bitand","std::simd","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"bitand","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"bitand","","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"bitand","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"bitand","std","",431,null],[11,"bitand","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"bitand","","",431,null],[11,"bitand","","",431,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"bool"}}],[11,"bitand","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"bitand","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"bitand","std","",301,null],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"bitand","","",195,null],[11,"bitand","std","",318,null],[11,"bitand","std::simd","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"bitand","std","",322,null],[11,"bitand","","",339,null],[11,"bitand","std::simd","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"bitand","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"bitand","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"bitand","std::num","",195,null],[11,"bitand","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"bitand","std","",329,null],[11,"bitand","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"bitand","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"bitand","std","",318,null],[11,"bitand","","",318,null],[11,"bitand","","",307,null],[11,"bitand","","",322,null],[11,"bitand","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"bitand","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"bitand","std","",320,null],[11,"bitand","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"bitand","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"bitand","std","",329,null],[11,"bitand","","",304,null],[11,"bitand","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"bitand","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"bitand","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"bitand","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"bitand","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"bitand","","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"fmt","std::num","",412,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",129,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",304,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::fmt","",127,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",431,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",417,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",307,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",130,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",438,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",332,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",292,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",372,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",421,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",121,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",320,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",319,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",439,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",318,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",195,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",314,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",301,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",335,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",131,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",418,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",413,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",339,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",411,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",473,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::panic","",474,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",415,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",322,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",416,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::fmt","",446,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::panic","",475,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",300,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",419,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",459,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",329,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",457,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",448,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",122,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",420,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",429,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",128,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",414,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::mem","",458,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",317,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",432,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",306,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",410,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"into_iter","std","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","std::result","Returns a consuming iterator over the possibly contained value.",72,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"into_iter","std","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",433,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",433,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","std::option","Returns a consuming iterator over the possibly contained value.",73,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"into_iter","std","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"into_iter","","",409,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"write","std::hash","",449,null],[11,"finish","","",449,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"finish","std","",285,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"write","","",285,null],[11,"write_u8","","",285,null],[11,"write_u16","","",285,null],[11,"write_u32","","",285,null],[11,"write_u64","","",285,null],[11,"write_u128","","",285,null],[11,"write_usize","","",285,null],[11,"write_i8","","",285,null],[11,"write_i16","","",285,null],[11,"write_i32","","",285,null],[11,"write_i64","","",285,null],[11,"write_i128","","",285,null],[11,"write_isize","","",285,null],[11,"index_mut","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeinclusive"}],"output":{"name":"str"}}],[11,"index_mut","","",429,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"str"}}],[11,"index_mut","","",433,null],[11,"index_mut","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangefrom"}],"output":{"name":"str"}}],[11,"index_mut","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"range"}],"output":{"name":"str"}}],[11,"index_mut","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangetoinclusive"}],"output":{"name":"str"}}],[11,"index_mut","","",429,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeto"}],"output":{"name":"str"}}],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",285,{"inputs":[{"name":"self"}],"output":{"name":"u"}}],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",433,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"as_mut","","",409,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",335,null],[11,"add_assign","std::simd","",302,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",356,null],[11,"add_assign","","",344,null],[11,"add_assign","","",349,null],[11,"add_assign","","",337,null],[11,"add_assign","std","",307,null],[11,"add_assign","std::simd","",308,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",339,null],[11,"add_assign","","",335,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","","",195,null],[11,"add_assign","std::simd","",346,null],[11,"add_assign","","",345,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","","",195,null],[11,"add_assign","","",195,null],[11,"add_assign","std::simd","",341,null],[11,"add_assign","","",333,null],[11,"add_assign","","",310,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::time","",309,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",326,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",301,null],[11,"add_assign","std::simd","",321,null],[11,"add_assign","std","",319,null],[11,"add_assign","std::simd","",348,null],[11,"add_assign","std","",301,null],[11,"add_assign","","",317,null],[11,"add_assign","","",307,null],[11,"add_assign","","",329,null],[11,"add_assign","","",318,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",322,null],[11,"add_assign","std::simd","",353,null],[11,"add_assign","std","",306,null],[11,"add_assign","std::simd","",323,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",320,null],[11,"add_assign","std::simd","",334,null],[11,"add_assign","","",336,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",328,null],[11,"add_assign","","",313,null],[11,"add_assign","std","",306,null],[11,"add_assign","","",314,null],[11,"add_assign","std::simd","",312,null],[11,"add_assign","","",303,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",347,null],[11,"add_assign","","",350,null],[11,"add_assign","std","",317,null],[11,"add_assign","std::simd","",316,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",314,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",332,null],[11,"add_assign","std::simd","",305,null],[11,"add_assign","","",331,null],[11,"add_assign","std","",322,null],[11,"add_assign","std::simd","",355,null],[11,"add_assign","std","",329,null],[11,"add_assign","std::simd","",351,null],[11,"add_assign","","",343,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",311,null],[11,"add_assign","","",342,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",315,null],[11,"add_assign","std","",318,null],[11,"add_assign","std::simd","",327,null],[11,"add_assign","","",357,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",339,null],[11,"add_assign","std::simd","",340,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",304,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std","",332,null],[11,"add_assign","std::simd","",324,null],[11,"add_assign","","",338,null],[11,"add_assign","std","",320,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",352,null],[11,"add_assign","std","",319,null],[11,"add_assign","std::simd","",330,null],[11,"add_assign","std","",304,null],[11,"add_assign","std::simd","",358,null],[11,"add_assign","","",325,null],[11,"add_assign","std::num","",195,null],[11,"add_assign","std::simd","",354,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std","",332,null],[11,"div_assign","std::simd","",341,null],[11,"div_assign","std","",317,null],[11,"div_assign","std::simd","",321,null],[11,"div_assign","","",343,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std::simd","",336,null],[11,"div_assign","","",353,null],[11,"div_assign","std","",320,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","","",195,null],[11,"div_assign","std::simd","",331,null],[11,"div_assign","std","",332,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","","",195,null],[11,"div_assign","std::simd","",308,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","","",195,null],[11,"div_assign","std","",322,null],[11,"div_assign","","",329,null],[11,"div_assign","std::simd","",344,null],[11,"div_assign","","",305,null],[11,"div_assign","std","",306,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std::simd","",334,null],[11,"div_assign","","",323,null],[11,"div_assign","","",324,null],[11,"div_assign","std","",335,null],[11,"div_assign","std::simd","",328,null],[11,"div_assign","","",354,null],[11,"div_assign","std","",314,null],[11,"div_assign","","",335,null],[11,"div_assign","std::simd","",302,null],[11,"div_assign","","",313,null],[11,"div_assign","std","",320,null],[11,"div_assign","std::simd","",312,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","","",195,null],[11,"div_assign","std","",318,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std::simd","",316,null],[11,"div_assign","std","",322,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std::simd","",342,null],[11,"div_assign","std","",318,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std","",301,null],[11,"div_assign","","",301,null],[11,"div_assign","std::simd","",327,null],[11,"div_assign","","",330,null],[11,"div_assign","","",350,null],[11,"div_assign","std","",314,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std::simd","",340,null],[11,"div_assign","std","",317,null],[11,"div_assign","std::simd","",325,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","","",195,null],[11,"div_assign","std","",339,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std::simd","",345,null],[11,"div_assign","","",352,null],[11,"div_assign","","",356,null],[11,"div_assign","","",310,null],[11,"div_assign","","",315,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std","",319,null],[11,"div_assign","std::simd","",333,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std","",339,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std::simd","",303,null],[11,"div_assign","std","",319,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","std","",307,null],[11,"div_assign","std::simd","",337,null],[11,"div_assign","","",338,null],[11,"div_assign","","",357,null],[11,"div_assign","","",349,null],[11,"div_assign","","",358,null],[11,"div_assign","","",355,null],[11,"div_assign","","",311,null],[11,"div_assign","","",351,null],[11,"div_assign","std::num","",195,null],[11,"div_assign","","",195,null],[11,"div_assign","std::simd","",347,null],[11,"div_assign","","",346,null],[11,"div_assign","std","",329,null],[11,"div_assign","","",304,null],[11,"div_assign","","",304,null],[11,"div_assign","std::simd","",326,null],[11,"div_assign","","",348,null],[11,"div_assign","std","",306,null],[11,"div_assign","","",307,null],[11,"div_assign","std::time","",309,null],[11,"try_from","std","",320,{"inputs":[{"name":"i128"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",307,{"inputs":[{"name":"u128"}],"output":{"generics":["i32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",307,{"inputs":[{"name":"i64"}],"output":{"generics":["i32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",335,{"inputs":[{"name":"i64"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",317,{"inputs":[{"name":"i128"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",332,{"inputs":[{"name":"u64"}],"output":{"generics":["i64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",318,{"inputs":[{"name":"u128"}],"output":{"generics":["i128","tryfrominterror"],"name":"result"}}],[11,"try_from","","",301,{"inputs":[{"name":"i16"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",306,{"inputs":[{"name":"isize"}],"output":{"generics":["u64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",307,{"inputs":[{"name":"u32"}],"output":{"generics":["i32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",317,{"inputs":[{"name":"u64"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"u64"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"u16"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",304,{"inputs":[{"name":"i64"}],"output":{"generics":["usize","tryfrominterror"],"name":"result"}}],[11,"try_from","","",335,{"inputs":[{"name":"u8"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",306,{"inputs":[{"name":"i32"}],"output":{"generics":["u64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"usize"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",301,{"inputs":[{"name":"u128"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"i8"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",335,{"inputs":[{"name":"isize"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",335,{"inputs":[{"name":"u16"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"i32"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",320,{"inputs":[{"name":"u32"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"u32"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",332,{"inputs":[{"name":"i128"}],"output":{"generics":["i64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",301,{"inputs":[{"name":"i128"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",317,{"inputs":[{"name":"u16"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",304,{"inputs":[{"name":"i32"}],"output":{"generics":["usize","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",339,{"inputs":[{"name":"i16"}],"output":{"generics":["u128","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",339,{"inputs":[{"name":"i8"}],"output":{"generics":["u128","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",432,{"inputs":[{"name":"u32"}],"output":{"generics":["char"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",339,{"inputs":[{"name":"isize"}],"output":{"generics":["u128","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"u128"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",301,{"inputs":[{"name":"i8"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",339,{"inputs":[{"name":"i32"}],"output":{"generics":["u128","tryfrominterror"],"name":"result"}}],[11,"try_from","","",301,{"inputs":[{"name":"i32"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",306,{"inputs":[{"name":"u128"}],"output":{"generics":["u64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"u128"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",306,{"inputs":[{"name":"i128"}],"output":{"generics":["u64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"u64"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",306,{"inputs":[{"name":"i8"}],"output":{"generics":["u64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"i16"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",335,{"inputs":[{"name":"i32"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",335,{"inputs":[{"name":"u64"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",304,{"inputs":[{"name":"i16"}],"output":{"generics":["usize","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",322,{"inputs":[{"name":"usize"}],"output":{"generics":["isize","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",317,{"inputs":[{"name":"u32"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",317,{"inputs":[{"name":"i32"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",317,{"inputs":[{"name":"usize"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"i8"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"i32"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",304,{"inputs":[{"name":"isize"}],"output":{"generics":["usize","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",301,{"inputs":[{"name":"i64"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",317,{"inputs":[{"name":"u128"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",335,{"inputs":[{"name":"u128"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",339,{"inputs":[{"name":"i64"}],"output":{"generics":["u128","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",329,{"inputs":[{"name":"i128"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"isize"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"isize"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",332,{"inputs":[{"name":"u128"}],"output":{"generics":["i64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",301,{"inputs":[{"name":"isize"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",306,{"inputs":[{"name":"i64"}],"output":{"generics":["u64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",317,{"inputs":[{"name":"i64"}],"output":{"generics":["i16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",304,{"inputs":[{"name":"i128"}],"output":{"generics":["usize","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",335,{"inputs":[{"name":"u32"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",307,{"inputs":[{"name":"u64"}],"output":{"generics":["i32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",335,{"inputs":[{"name":"i128"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",335,{"inputs":[{"name":"i16"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",320,{"inputs":[{"name":"i64"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",335,{"inputs":[{"name":"usize"}],"output":{"generics":["i8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",329,{"inputs":[{"name":"i64"}],"output":{"generics":["u16","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",301,{"inputs":[{"name":"u64"}],"output":{"generics":["u32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",307,{"inputs":[{"name":"i128"}],"output":{"generics":["i32","tryfrominterror"],"name":"result"}}],[11,"try_from","","",306,{"inputs":[{"name":"i16"}],"output":{"generics":["u64","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",304,{"inputs":[{"name":"i8"}],"output":{"generics":["usize","tryfrominterror"],"name":"result"}}],[11,"try_from","","",320,{"inputs":[{"name":"i16"}],"output":{"generics":["u8","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"try_from","","",409,null],[11,"try_from","","",339,{"inputs":[{"name":"i128"}],"output":{"generics":["u128","tryfrominterror"],"name":"result"}}],[11,"try_from","","",409,null],[11,"from_bits","std::simd","",353,{"inputs":[{"name":"u64x8"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",305,{"inputs":[{"name":"__m128i"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",308,{"inputs":[{"name":"u32x16"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",315,{"inputs":[{"name":"f64x2"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",350,{"inputs":[{"name":"f64x8"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",355,{"inputs":[{"name":"__m256"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",350,{"inputs":[{"name":"u16x32"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",321,{"inputs":[{"name":"u32x4"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",352,{"inputs":[{"name":"b8x32"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",316,{"inputs":[{"name":"u16x32"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",338,{"inputs":[{"name":"u8x32"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",321,{"inputs":[{"name":"__m128d"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",333,{"inputs":[{"name":"u64x4"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",331,{"inputs":[{"name":"u8x32"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",349,{"inputs":[{"name":"i64x8"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",355,{"inputs":[{"name":"b8x32"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",357,{"inputs":[{"name":"__m128d"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",331,{"inputs":[{"name":"f32x8"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",350,{"inputs":[{"name":"u64x8"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",355,{"inputs":[{"name":"u16x16"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",350,{"inputs":[{"name":"i16x32"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",337,{"inputs":[{"name":"__m128i"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",333,{"inputs":[{"name":"u32x8"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",344,{"inputs":[{"name":"i16x2"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",333,{"inputs":[{"name":"__m256"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",348,{"inputs":[{"name":"u8x8"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",352,{"inputs":[{"name":"i64x4"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",331,{"inputs":[{"name":"u16x16"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",312,{"inputs":[{"name":"i32x4"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",303,{"inputs":[{"name":"u16x16"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",327,{"inputs":[{"name":"u8x16"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",308,{"inputs":[{"name":"f32x16"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",337,{"inputs":[{"name":"i64x2"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",356,{"inputs":[{"name":"__m128"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",352,{"inputs":[{"name":"u8x32"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",340,{"inputs":[{"name":"u64x4"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",327,{"inputs":[{"name":"u32x4"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",341,{"inputs":[{"name":"i32x16"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",341,{"inputs":[{"name":"u8x64"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",341,{"inputs":[{"name":"b8x64"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",352,{"inputs":[{"name":"i32x8"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",312,{"inputs":[{"name":"i8x16"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",312,{"inputs":[{"name":"f32x4"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",338,{"inputs":[{"name":"b8x32"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",350,{"inputs":[{"name":"i64x8"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",313,{"inputs":[{"name":"i16x8"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",338,{"inputs":[{"name":"f32x8"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",349,{"inputs":[{"name":"u32x16"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",342,{"inputs":[{"name":"i8x64"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",352,{"inputs":[{"name":"__m256d"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",308,{"inputs":[{"name":"u16x32"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",328,{"inputs":[{"name":"i32x4"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",312,{"inputs":[{"name":"i16x8"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"i64x4"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",345,{"inputs":[{"name":"__m256i"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",353,{"inputs":[{"name":"f32x16"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",302,{"inputs":[{"name":"b8x64"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",337,{"inputs":[{"name":"u64x2"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",353,{"inputs":[{"name":"i32x16"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",312,{"inputs":[{"name":"u64x2"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"__m256i"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",340,{"inputs":[{"name":"f64x4"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",343,{"inputs":[{"name":"b8x2"}],"output":{"name":"u8x2"}}],[11,"from_bits","","",323,{"inputs":[{"name":"i32x2"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",345,{"inputs":[{"name":"f64x4"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",316,{"inputs":[{"name":"i8x64"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",343,{"inputs":[{"name":"i8x2"}],"output":{"name":"u8x2"}}],[11,"from_bits","","",302,{"inputs":[{"name":"u32x16"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",352,{"inputs":[{"name":"f32x8"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",328,{"inputs":[{"name":"__m128"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",356,{"inputs":[{"name":"u16x8"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",338,{"inputs":[{"name":"__m256"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",324,{"inputs":[{"name":"i16x4"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"__m256d"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",315,{"inputs":[{"name":"__m128"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",313,{"inputs":[{"name":"f32x4"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",358,{"inputs":[{"name":"u8x32"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",328,{"inputs":[{"name":"f32x4"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",328,{"inputs":[{"name":"__m128d"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",302,{"inputs":[{"name":"i64x8"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",337,{"inputs":[{"name":"b8x16"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",340,{"inputs":[{"name":"f32x8"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",355,{"inputs":[{"name":"__m256i"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",355,{"inputs":[{"name":"u32x8"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",340,{"inputs":[{"name":"u8x32"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",327,{"inputs":[{"name":"u16x8"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",352,{"inputs":[{"name":"i16x16"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",334,{"inputs":[{"name":"u16x32"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",308,{"inputs":[{"name":"u64x8"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",331,{"inputs":[{"name":"__m256"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",313,{"inputs":[{"name":"f64x2"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",310,{"inputs":[{"name":"i16x4"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",328,{"inputs":[{"name":"f64x2"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",326,{"inputs":[{"name":"u16x4"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",324,{"inputs":[{"name":"i8x8"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",356,{"inputs":[{"name":"i8x16"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",315,{"inputs":[{"name":"i8x16"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",302,{"inputs":[{"name":"u64x8"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",312,{"inputs":[{"name":"__m128d"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",333,{"inputs":[{"name":"i16x16"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",323,{"inputs":[{"name":"i16x4"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",325,{"inputs":[{"name":"u32x16"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",303,{"inputs":[{"name":"f64x4"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",338,{"inputs":[{"name":"u64x4"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",327,{"inputs":[{"name":"i8x16"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",349,{"inputs":[{"name":"u64x8"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",337,{"inputs":[{"name":"__m128"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",330,{"inputs":[{"name":"u16x2"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",327,{"inputs":[{"name":"i32x4"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",328,{"inputs":[{"name":"i16x8"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",313,{"inputs":[{"name":"__m128"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",342,{"inputs":[{"name":"u32x16"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",340,{"inputs":[{"name":"__m256d"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",327,{"inputs":[{"name":"b8x16"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",308,{"inputs":[{"name":"i8x64"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",325,{"inputs":[{"name":"f64x8"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",358,{"inputs":[{"name":"__m256i"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",323,{"inputs":[{"name":"u16x4"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",316,{"inputs":[{"name":"u8x64"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",311,{"inputs":[{"name":"__m64"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",325,{"inputs":[{"name":"u64x8"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",355,{"inputs":[{"name":"i32x8"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",353,{"inputs":[{"name":"i8x64"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",302,{"inputs":[{"name":"f32x16"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",312,{"inputs":[{"name":"u32x4"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",313,{"inputs":[{"name":"u16x8"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",333,{"inputs":[{"name":"f64x4"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",324,{"inputs":[{"name":"u32x2"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",316,{"inputs":[{"name":"u64x8"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",355,{"inputs":[{"name":"u8x32"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",345,{"inputs":[{"name":"u64x4"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",346,{"inputs":[{"name":"i8x8"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",354,{"inputs":[{"name":"u16x2"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",338,{"inputs":[{"name":"__m256i"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",311,{"inputs":[{"name":"b8x8"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",328,{"inputs":[{"name":"b8x16"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",340,{"inputs":[{"name":"i16x16"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",321,{"inputs":[{"name":"i32x4"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",340,{"inputs":[{"name":"i8x32"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",349,{"inputs":[{"name":"f64x8"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",325,{"inputs":[{"name":"i16x32"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",340,{"inputs":[{"name":"i64x4"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",315,{"inputs":[{"name":"f32x4"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",357,{"inputs":[{"name":"f32x4"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",338,{"inputs":[{"name":"i32x8"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",342,{"inputs":[{"name":"i64x8"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",351,{"inputs":[{"name":"u16x16"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",358,{"inputs":[{"name":"i16x16"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",308,{"inputs":[{"name":"i32x16"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",321,{"inputs":[{"name":"i16x8"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",313,{"inputs":[{"name":"i64x2"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",352,{"inputs":[{"name":"__m256"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",324,{"inputs":[{"name":"i32x2"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",326,{"inputs":[{"name":"i16x4"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",354,{"inputs":[{"name":"i8x4"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",357,{"inputs":[{"name":"f64x2"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",355,{"inputs":[{"name":"i16x16"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",344,{"inputs":[{"name":"u8x4"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",350,{"inputs":[{"name":"u8x64"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",350,{"inputs":[{"name":"i8x64"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",355,{"inputs":[{"name":"__m256d"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",346,{"inputs":[{"name":"b8x8"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",348,{"inputs":[{"name":"i32x2"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",356,{"inputs":[{"name":"u32x4"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",316,{"inputs":[{"name":"f64x8"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",328,{"inputs":[{"name":"i8x16"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",331,{"inputs":[{"name":"i32x8"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",354,{"inputs":[{"name":"u8x4"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",326,{"inputs":[{"name":"__m64"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",334,{"inputs":[{"name":"u64x8"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",337,{"inputs":[{"name":"u8x16"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"i32x8"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",308,{"inputs":[{"name":"b8x64"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",315,{"inputs":[{"name":"i64x2"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",338,{"inputs":[{"name":"i8x32"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",333,{"inputs":[{"name":"i8x32"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",347,{"inputs":[{"name":"i16x2"}],"output":{"name":"u8x4"}}],[11,"from_bits","","",305,{"inputs":[{"name":"__m128"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",338,{"inputs":[{"name":"u32x8"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",333,{"inputs":[{"name":"__m256i"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",338,{"inputs":[{"name":"f64x4"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",352,{"inputs":[{"name":"i8x32"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",334,{"inputs":[{"name":"i64x8"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",350,{"inputs":[{"name":"f32x16"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",303,{"inputs":[{"name":"f32x8"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",358,{"inputs":[{"name":"u32x8"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",327,{"inputs":[{"name":"__m128"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",358,{"inputs":[{"name":"u16x16"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",338,{"inputs":[{"name":"i64x4"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",315,{"inputs":[{"name":"i16x8"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",312,{"inputs":[{"name":"i64x2"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",355,{"inputs":[{"name":"f64x4"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",331,{"inputs":[{"name":"u32x8"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",311,{"inputs":[{"name":"i8x8"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",326,{"inputs":[{"name":"u8x8"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",303,{"inputs":[{"name":"b8x32"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",305,{"inputs":[{"name":"i16x8"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",323,{"inputs":[{"name":"b8x8"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",325,{"inputs":[{"name":"f32x16"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",327,{"inputs":[{"name":"f32x4"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",357,{"inputs":[{"name":"i64x2"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",358,{"inputs":[{"name":"b8x32"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",338,{"inputs":[{"name":"__m256d"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",311,{"inputs":[{"name":"i32x2"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",321,{"inputs":[{"name":"i8x16"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",345,{"inputs":[{"name":"u16x16"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",310,{"inputs":[{"name":"f32x2"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",334,{"inputs":[{"name":"f64x8"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",331,{"inputs":[{"name":"i16x16"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",349,{"inputs":[{"name":"i8x64"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",305,{"inputs":[{"name":"i64x2"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",357,{"inputs":[{"name":"b8x16"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",331,{"inputs":[{"name":"u64x4"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",345,{"inputs":[{"name":"u8x32"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",315,{"inputs":[{"name":"__m128i"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",357,{"inputs":[{"name":"u64x2"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",356,{"inputs":[{"name":"u8x16"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",302,{"inputs":[{"name":"u8x64"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",316,{"inputs":[{"name":"i16x32"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",351,{"inputs":[{"name":"__m256"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",346,{"inputs":[{"name":"i32x2"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",355,{"inputs":[{"name":"i64x4"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",305,{"inputs":[{"name":"u32x4"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",352,{"inputs":[{"name":"__m256i"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",305,{"inputs":[{"name":"u16x8"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",341,{"inputs":[{"name":"i16x32"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",302,{"inputs":[{"name":"f64x8"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",302,{"inputs":[{"name":"i8x64"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",305,{"inputs":[{"name":"i8x16"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",331,{"inputs":[{"name":"b8x32"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",315,{"inputs":[{"name":"u16x8"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",348,{"inputs":[{"name":"u32x2"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"f64x4"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",325,{"inputs":[{"name":"i32x16"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",330,{"inputs":[{"name":"i16x2"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",346,{"inputs":[{"name":"u8x8"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",303,{"inputs":[{"name":"__m256"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",352,{"inputs":[{"name":"u32x8"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",352,{"inputs":[{"name":"u16x16"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",303,{"inputs":[{"name":"u64x4"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",305,{"inputs":[{"name":"b8x16"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",303,{"inputs":[{"name":"__m256d"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",345,{"inputs":[{"name":"__m256"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",342,{"inputs":[{"name":"f32x16"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",341,{"inputs":[{"name":"f64x8"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",354,{"inputs":[{"name":"b8x4"}],"output":{"name":"i16x2"}}],[11,"from_bits","","",321,{"inputs":[{"name":"u16x8"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",349,{"inputs":[{"name":"i32x16"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",333,{"inputs":[{"name":"i32x8"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",324,{"inputs":[{"name":"b8x8"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",353,{"inputs":[{"name":"b8x64"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",328,{"inputs":[{"name":"__m128i"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",347,{"inputs":[{"name":"i8x4"}],"output":{"name":"u8x4"}}],[11,"from_bits","","",337,{"inputs":[{"name":"i32x4"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",305,{"inputs":[{"name":"u8x16"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",323,{"inputs":[{"name":"u8x8"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",348,{"inputs":[{"name":"i16x4"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",342,{"inputs":[{"name":"f64x8"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",356,{"inputs":[{"name":"b8x16"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",315,{"inputs":[{"name":"u64x2"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",315,{"inputs":[{"name":"i32x4"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",305,{"inputs":[{"name":"f32x4"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",353,{"inputs":[{"name":"u16x32"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",344,{"inputs":[{"name":"i8x4"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",308,{"inputs":[{"name":"i64x8"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",331,{"inputs":[{"name":"i64x4"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",357,{"inputs":[{"name":"u8x16"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",302,{"inputs":[{"name":"u16x32"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",330,{"inputs":[{"name":"u8x4"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",345,{"inputs":[{"name":"__m256d"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",313,{"inputs":[{"name":"b8x16"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",342,{"inputs":[{"name":"u64x8"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",334,{"inputs":[{"name":"i16x32"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",342,{"inputs":[{"name":"i32x16"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",326,{"inputs":[{"name":"f32x2"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",328,{"inputs":[{"name":"u32x4"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",340,{"inputs":[{"name":"__m256"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",308,{"inputs":[{"name":"u8x64"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",327,{"inputs":[{"name":"f64x2"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",326,{"inputs":[{"name":"i8x8"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",303,{"inputs":[{"name":"i64x4"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",355,{"inputs":[{"name":"f32x8"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",328,{"inputs":[{"name":"u16x8"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",357,{"inputs":[{"name":"__m128i"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",315,{"inputs":[{"name":"u32x4"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",358,{"inputs":[{"name":"i32x8"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",315,{"inputs":[{"name":"b8x16"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",303,{"inputs":[{"name":"u8x32"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"i16x16"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",311,{"inputs":[{"name":"u8x8"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",323,{"inputs":[{"name":"u32x2"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",310,{"inputs":[{"name":"__m64"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",356,{"inputs":[{"name":"i64x2"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",303,{"inputs":[{"name":"i8x32"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",346,{"inputs":[{"name":"i16x4"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",334,{"inputs":[{"name":"i32x16"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",342,{"inputs":[{"name":"b8x64"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",348,{"inputs":[{"name":"__m64"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",349,{"inputs":[{"name":"u16x32"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",310,{"inputs":[{"name":"u8x8"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",325,{"inputs":[{"name":"u16x32"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",340,{"inputs":[{"name":"b8x32"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",321,{"inputs":[{"name":"i64x2"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",327,{"inputs":[{"name":"__m128i"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",353,{"inputs":[{"name":"u8x64"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",323,{"inputs":[{"name":"__m64"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",340,{"inputs":[{"name":"i32x8"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",345,{"inputs":[{"name":"i8x32"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",331,{"inputs":[{"name":"__m256d"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",333,{"inputs":[{"name":"b8x32"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",358,{"inputs":[{"name":"i8x32"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",333,{"inputs":[{"name":"__m256d"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",330,{"inputs":[{"name":"b8x4"}],"output":{"name":"i8x4"}}],[11,"from_bits","","",311,{"inputs":[{"name":"u16x4"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",351,{"inputs":[{"name":"f32x8"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",321,{"inputs":[{"name":"u64x2"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",342,{"inputs":[{"name":"u8x64"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",312,{"inputs":[{"name":"__m128i"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",303,{"inputs":[{"name":"__m256i"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",334,{"inputs":[{"name":"b8x64"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",327,{"inputs":[{"name":"u64x2"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",356,{"inputs":[{"name":"i32x4"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",316,{"inputs":[{"name":"b8x64"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",324,{"inputs":[{"name":"__m64"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",313,{"inputs":[{"name":"__m128i"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",344,{"inputs":[{"name":"b8x4"}],"output":{"name":"u16x2"}}],[11,"from_bits","","",305,{"inputs":[{"name":"u64x2"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",347,{"inputs":[{"name":"b8x4"}],"output":{"name":"u8x4"}}],[11,"from_bits","","",305,{"inputs":[{"name":"__m128d"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",325,{"inputs":[{"name":"i64x8"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",333,{"inputs":[{"name":"f32x8"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",348,{"inputs":[{"name":"b8x8"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",357,{"inputs":[{"name":"i16x8"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",341,{"inputs":[{"name":"i8x64"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",350,{"inputs":[{"name":"i32x16"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",341,{"inputs":[{"name":"u16x32"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",350,{"inputs":[{"name":"b8x64"}],"output":{"name":"u32x16"}}],[11,"from_bits","","",349,{"inputs":[{"name":"i16x32"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",316,{"inputs":[{"name":"f32x16"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",353,{"inputs":[{"name":"f64x8"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"i8x32"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",353,{"inputs":[{"name":"u32x16"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",356,{"inputs":[{"name":"__m128d"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",341,{"inputs":[{"name":"i64x8"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",356,{"inputs":[{"name":"f64x2"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",349,{"inputs":[{"name":"b8x64"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",351,{"inputs":[{"name":"b8x32"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",337,{"inputs":[{"name":"i8x16"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",308,{"inputs":[{"name":"i16x32"}],"output":{"name":"f64x8"}}],[11,"from_bits","","",345,{"inputs":[{"name":"u32x8"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",337,{"inputs":[{"name":"f32x4"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",328,{"inputs":[{"name":"i64x2"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",312,{"inputs":[{"name":"b8x16"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",325,{"inputs":[{"name":"b8x64"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",316,{"inputs":[{"name":"i64x8"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",313,{"inputs":[{"name":"__m128d"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",341,{"inputs":[{"name":"u32x16"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",333,{"inputs":[{"name":"u8x32"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",357,{"inputs":[{"name":"i8x16"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",337,{"inputs":[{"name":"__m128d"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",305,{"inputs":[{"name":"f64x2"}],"output":{"name":"i32x4"}}],[11,"from_bits","","",342,{"inputs":[{"name":"i16x32"}],"output":{"name":"u16x32"}}],[11,"from_bits","","",313,{"inputs":[{"name":"u32x4"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",312,{"inputs":[{"name":"f64x2"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",345,{"inputs":[{"name":"i64x4"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",312,{"inputs":[{"name":"__m128"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",351,{"inputs":[{"name":"u64x4"}],"output":{"name":"u8x32"}}],[11,"from_bits","","",310,{"inputs":[{"name":"b8x8"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",331,{"inputs":[{"name":"__m256i"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",358,{"inputs":[{"name":"f64x4"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",331,{"inputs":[{"name":"f64x4"}],"output":{"name":"i8x32"}}],[11,"from_bits","","",358,{"inputs":[{"name":"__m256"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",323,{"inputs":[{"name":"i8x8"}],"output":{"name":"f32x2"}}],[11,"from_bits","","",313,{"inputs":[{"name":"u64x2"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",310,{"inputs":[{"name":"i8x8"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",313,{"inputs":[{"name":"u8x16"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",310,{"inputs":[{"name":"i32x2"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",357,{"inputs":[{"name":"__m128"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",321,{"inputs":[{"name":"__m128i"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",325,{"inputs":[{"name":"u8x64"}],"output":{"name":"i8x64"}}],[11,"from_bits","","",324,{"inputs":[{"name":"u16x4"}],"output":{"name":"u8x8"}}],[11,"from_bits","","",358,{"inputs":[{"name":"__m256d"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",357,{"inputs":[{"name":"i32x4"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",345,{"inputs":[{"name":"i32x8"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",358,{"inputs":[{"name":"u64x4"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",349,{"inputs":[{"name":"u8x64"}],"output":{"name":"f32x16"}}],[11,"from_bits","","",346,{"inputs":[{"name":"u32x2"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",345,{"inputs":[{"name":"i16x16"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",338,{"inputs":[{"name":"u16x16"}],"output":{"name":"i16x16"}}],[11,"from_bits","","",336,{"inputs":[{"name":"u8x2"}],"output":{"name":"i8x2"}}],[11,"from_bits","","",321,{"inputs":[{"name":"b8x16"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",334,{"inputs":[{"name":"f32x16"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",356,{"inputs":[{"name":"u64x2"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",302,{"inputs":[{"name":"i32x16"}],"output":{"name":"i16x32"}}],[11,"from_bits","","",340,{"inputs":[{"name":"__m256i"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",321,{"inputs":[{"name":"u8x16"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",310,{"inputs":[{"name":"u16x4"}],"output":{"name":"u32x2"}}],[11,"from_bits","","",348,{"inputs":[{"name":"u16x4"}],"output":{"name":"i8x8"}}],[11,"from_bits","","",328,{"inputs":[{"name":"u8x16"}],"output":{"name":"u64x2"}}],[11,"from_bits","","",321,{"inputs":[{"name":"__m128"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",352,{"inputs":[{"name":"u64x4"}],"output":{"name":"f64x4"}}],[11,"from_bits","","",334,{"inputs":[{"name":"u32x16"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",337,{"inputs":[{"name":"u16x8"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",353,{"inputs":[{"name":"i16x32"}],"output":{"name":"i64x8"}}],[11,"from_bits","","",303,{"inputs":[{"name":"u32x8"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",326,{"inputs":[{"name":"u32x2"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",347,{"inputs":[{"name":"u16x2"}],"output":{"name":"u8x4"}}],[11,"from_bits","","",355,{"inputs":[{"name":"i8x32"}],"output":{"name":"u64x4"}}],[11,"from_bits","","",336,{"inputs":[{"name":"b8x2"}],"output":{"name":"i8x2"}}],[11,"from_bits","","",337,{"inputs":[{"name":"u32x4"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",334,{"inputs":[{"name":"i8x64"}],"output":{"name":"u8x64"}}],[11,"from_bits","","",313,{"inputs":[{"name":"i32x4"}],"output":{"name":"i8x16"}}],[11,"from_bits","","",358,{"inputs":[{"name":"f32x8"}],"output":{"name":"i64x4"}}],[11,"from_bits","","",303,{"inputs":[{"name":"i16x16"}],"output":{"name":"i32x8"}}],[11,"from_bits","","",316,{"inputs":[{"name":"u32x16"}],"output":{"name":"i32x16"}}],[11,"from_bits","","",345,{"inputs":[{"name":"b8x32"}],"output":{"name":"f32x8"}}],[11,"from_bits","","",327,{"inputs":[{"name":"__m128d"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",315,{"inputs":[{"name":"__m128d"}],"output":{"name":"u8x16"}}],[11,"from_bits","","",356,{"inputs":[{"name":"__m128i"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",321,{"inputs":[{"name":"f32x4"}],"output":{"name":"f64x2"}}],[11,"from_bits","","",341,{"inputs":[{"name":"f32x16"}],"output":{"name":"u64x8"}}],[11,"from_bits","","",327,{"inputs":[{"name":"i16x8"}],"output":{"name":"i64x2"}}],[11,"from_bits","","",337,{"inputs":[{"name":"f64x2"}],"output":{"name":"i16x8"}}],[11,"from_bits","","",333,{"inputs":[{"name":"i64x4"}],"output":{"name":"u16x16"}}],[11,"from_bits","","",326,{"inputs":[{"name":"b8x8"}],"output":{"name":"i32x2"}}],[11,"from_bits","","",357,{"inputs":[{"name":"u16x8"}],"output":{"name":"u32x4"}}],[11,"from_bits","","",311,{"inputs":[{"name":"u32x2"}],"output":{"name":"i16x4"}}],[11,"from_bits","","",340,{"inputs":[{"name":"u16x16"}],"output":{"name":"u32x8"}}],[11,"from_bits","","",312,{"inputs":[{"name":"u8x16"}],"output":{"name":"u16x8"}}],[11,"from_bits","","",346,{"inputs":[{"name":"__m64"}],"output":{"name":"u16x4"}}],[11,"from_bits","","",356,{"inputs":[{"name":"i16x8"}],"output":{"name":"f32x4"}}],[11,"from_bits","","",351,{"inputs":[{"name":"u32x8"}],"output":{"name":"u8x32"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::fmt","",127,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",303,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",131,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",386,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::marker","",436,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",322,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",334,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",347,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",326,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ascii","",395,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::any","",428,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ptr","",427,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",462,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",440,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",320,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",130,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",129,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",332,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",387,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",195,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",299,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",469,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",293,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",380,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",383,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",354,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",327,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::result","",367,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",310,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",339,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",128,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",37,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::any","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",330,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",337,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",194,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",419,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",338,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",421,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",393,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",311,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",403,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",457,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",333,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",413,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",289,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",371,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",344,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",314,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::option","",430,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",296,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",425,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",415,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",312,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",405,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",434,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",417,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",302,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",359,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",325,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",389,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",321,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",381,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cmp","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",328,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",343,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",420,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",418,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",464,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",313,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",450,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",317,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",308,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::hash","",453,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",404,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",315,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",370,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",318,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",388,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",352,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cmp","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",340,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",298,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",324,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",451,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",463,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",425,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",394,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",122,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::panic","",474,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",365,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",304,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",406,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",323,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::mem","",426,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::option","",73,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",356,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::result","",400,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",398,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",473,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",336,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",461,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",353,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::option","",399,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",300,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",362,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",358,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::mem","",458,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",460,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::any","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",286,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",470,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",429,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",408,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",364,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",397,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",411,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",294,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",357,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",301,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",442,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",31,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",431,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",465,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",466,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",249,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",384,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",349,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",121,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections","",108,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",329,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",355,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",459,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",439,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str::pattern","",454,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",378,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",287,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::option","",379,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",331,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",369,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",407,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",350,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",342,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",433,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str::pattern","",443,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",416,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",447,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",290,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",295,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",335,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",438,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::panic","",475,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::cell","",455,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",368,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::fmt","",446,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",292,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",410,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",316,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",35,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",297,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",366,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",391,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",49,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",472,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::time","",309,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",441,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",412,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::char","",372,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",373,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",345,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::mem","",435,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",392,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",385,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",467,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",319,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",351,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",432,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",396,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",306,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str::pattern","",92,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::result","",360,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",471,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",402,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",375,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",346,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",448,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ptr","",445,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str::pattern","",452,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",341,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",348,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",291,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",305,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::option","",374,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",401,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",377,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::result","",72,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",34,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",288,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",363,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",48,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",376,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",422,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",361,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str::pattern","",437,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::slice","",382,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::hash","",449,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::simd","",444,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",409,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",307,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",468,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::iter","",390,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",424,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ops","",53,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",414,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"bitor_assign","","",195,null],[11,"bitor_assign","std","",322,null],[11,"bitor_assign","std::simd","",440,null],[11,"bitor_assign","","",312,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","","",195,null],[11,"bitor_assign","std::simd","",341,null],[11,"bitor_assign","","",447,null],[11,"bitor_assign","","",325,null],[11,"bitor_assign","","",311,null],[11,"bitor_assign","","",340,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std","",329,null],[11,"bitor_assign","std::simd","",333,null],[11,"bitor_assign","","",355,null],[11,"bitor_assign","","",328,null],[11,"bitor_assign","","",324,null],[11,"bitor_assign","","",354,null],[11,"bitor_assign","std","",318,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","","",195,null],[11,"bitor_assign","","",195,null],[11,"bitor_assign","std::simd","",334,null],[11,"bitor_assign","","",343,null],[11,"bitor_assign","","",302,null],[11,"bitor_assign","","",347,null],[11,"bitor_assign","std","",322,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","","",195,null],[11,"bitor_assign","std::simd","",450,null],[11,"bitor_assign","std","",320,null],[11,"bitor_assign","","",317,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",350,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std","",306,null],[11,"bitor_assign","std::simd","",348,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","","",195,null],[11,"bitor_assign","std","",318,null],[11,"bitor_assign","std::simd","",351,null],[11,"bitor_assign","","",344,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std","",335,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std","",307,null],[11,"bitor_assign","std::simd","",444,null],[11,"bitor_assign","","",313,null],[11,"bitor_assign","","",305,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std","",339,null],[11,"bitor_assign","","",306,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",310,null],[11,"bitor_assign","std","",431,null],[11,"bitor_assign","","",301,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std","",431,null],[11,"bitor_assign","std::simd","",303,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",330,null],[11,"bitor_assign","std","",339,null],[11,"bitor_assign","std::simd","",358,null],[11,"bitor_assign","std","",332,null],[11,"bitor_assign","","",301,null],[11,"bitor_assign","","",304,null],[11,"bitor_assign","","",317,null],[11,"bitor_assign","","",329,null],[11,"bitor_assign","std::simd","",331,null],[11,"bitor_assign","std","",304,null],[11,"bitor_assign","","",320,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",327,null],[11,"bitor_assign","","",353,null],[11,"bitor_assign","","",316,null],[11,"bitor_assign","","",338,null],[11,"bitor_assign","","",342,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",357,null],[11,"bitor_assign","","",442,null],[11,"bitor_assign","","",441,null],[11,"bitor_assign","","",315,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",336,null],[11,"bitor_assign","std","",307,null],[11,"bitor_assign","","",332,null],[11,"bitor_assign","std::simd","",337,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",326,null],[11,"bitor_assign","std","",335,null],[11,"bitor_assign","std::num","",195,null],[11,"bitor_assign","std::simd","",346,null],[11,"from_iter","std::option","Takes each element in the [`Iterator`]: if it is [`None`], no further elements are taken, and the [`None`] is returned. Should no [`None`] occur, a container with the values of each `Option` is returned.",73,{"inputs":[{"name":"i"}],"output":{"name":"option"}}],[11,"from_iter","std::result","Takes each element in the `Iterator`: if it is an `Err`, no further elements are taken, and the `Err` is returned. Should no `Err` occur, a container with the values of each `Result` is returned.",72,{"inputs":[{"name":"i"}],"output":{"name":"result"}}],[11,"from_iter","std","",434,null],[11,"into_result","std::result","",72,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"from_ok","","",72,{"inputs":[{"name":"t"}],"output":{"name":"result"}}],[11,"from_error","","",72,{"inputs":[{"name":"e"}],"output":{"name":"result"}}],[11,"into_result","std::option","",73,{"inputs":[{"name":"self"}],"output":{"generics":["noneerror"],"name":"result"}}],[11,"from_ok","","",73,{"inputs":[{"name":"t"}],"output":{"name":"option"}}],[11,"from_error","","",73,{"inputs":[{"name":"noneerror"}],"output":{"name":"option"}}],[11,"call_once","std","",285,null],[11,"call_once","","",285,null],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"product","std","",318,{"inputs":[{"name":"i"}],"output":{"name":"i128"}}],[11,"product","","",339,{"inputs":[{"name":"i"}],"output":{"name":"u128"}}],[11,"product","","",320,{"inputs":[{"name":"i"}],"output":{"name":"u8"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"product","std","",314,{"inputs":[{"name":"i"}],"output":{"name":"f64"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"product","std","",320,{"inputs":[{"name":"i"}],"output":{"name":"u8"}}],[11,"product","","",314,{"inputs":[{"name":"i"}],"output":{"name":"f64"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"product","std","",329,{"inputs":[{"name":"i"}],"output":{"name":"u16"}}],[11,"product","","",306,{"inputs":[{"name":"i"}],"output":{"name":"u64"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"product","std","",322,{"inputs":[{"name":"i"}],"output":{"name":"isize"}}],[11,"product","","",306,{"inputs":[{"name":"i"}],"output":{"name":"u64"}}],[11,"product","","",319,{"inputs":[{"name":"i"}],"output":{"name":"f32"}}],[11,"product","","",317,{"inputs":[{"name":"i"}],"output":{"name":"i16"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"product","std","",304,{"inputs":[{"name":"i"}],"output":{"name":"usize"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"product","std","",301,{"inputs":[{"name":"i"}],"output":{"name":"u32"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"product","std","",322,{"inputs":[{"name":"i"}],"output":{"name":"isize"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"product","std","",339,{"inputs":[{"name":"i"}],"output":{"name":"u128"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"product","std","",317,{"inputs":[{"name":"i"}],"output":{"name":"i16"}}],[11,"product","","",335,{"inputs":[{"name":"i"}],"output":{"name":"i8"}}],[11,"product","","",307,{"inputs":[{"name":"i"}],"output":{"name":"i32"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"product","std","",307,{"inputs":[{"name":"i"}],"output":{"name":"i32"}}],[11,"product","","",329,{"inputs":[{"name":"i"}],"output":{"name":"u16"}}],[11,"product","std::result","Takes each element in the `Iterator`: if it is an `Err`, no further elements are taken, and the `Err` is returned. Should no `Err` occur, the product of all elements is returned.",72,{"inputs":[{"name":"i"}],"output":{"name":"result"}}],[11,"product","std","",319,{"inputs":[{"name":"i"}],"output":{"name":"f32"}}],[11,"product","","",332,{"inputs":[{"name":"i"}],"output":{"name":"i64"}}],[11,"product","","",332,{"inputs":[{"name":"i"}],"output":{"name":"i64"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"product","std","",304,{"inputs":[{"name":"i"}],"output":{"name":"usize"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"product","std","",318,{"inputs":[{"name":"i"}],"output":{"name":"i128"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"product","std","",301,{"inputs":[{"name":"i"}],"output":{"name":"u32"}}],[11,"product","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"product","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"product","std","",335,{"inputs":[{"name":"i"}],"output":{"name":"i8"}}],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"mul","std","",314,null],[11,"mul","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"mul","std","",304,null],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"mul","","",195,null],[11,"mul","std","",317,null],[11,"mul","","",319,null],[11,"mul","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"mul","std::num","",195,null],[11,"mul","","",195,null],[11,"mul","std::simd","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"f32x2"}}],[11,"mul","std","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"mul","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"mul","","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"mul","std","",306,null],[11,"mul","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"mul","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"mul","","",306,null],[11,"mul","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"mul","std","",314,null],[11,"mul","","",301,null],[11,"mul","std::simd","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"f64x2"}}],[11,"mul","std::num","",195,null],[11,"mul","","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"mul","std","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"mul","","",332,null],[11,"mul","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"mul","","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"mul","std","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"mul","std::simd","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"f64x4"}}],[11,"mul","","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"mul","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"mul","std","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"mul","","",339,null],[11,"mul","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"mul","std","",317,null],[11,"mul","","",301,null],[11,"mul","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"mul","std::num","",195,null],[11,"mul","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"mul","std","",322,null],[11,"mul","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"mul","std::num","",195,null],[11,"mul","std","",318,null],[11,"mul","","",304,null],[11,"mul","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"mul","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"mul","","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"mul","std","",317,null],[11,"mul","","",307,null],[11,"mul","","",322,null],[11,"mul","","",335,null],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"mul","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"mul","std","",314,null],[11,"mul","std::simd","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"f32x8"}}],[11,"mul","std","",320,null],[11,"mul","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"mul","std","",329,null],[11,"mul","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"mul","std","",304,null],[11,"mul","","",319,null],[11,"mul","","",329,null],[11,"mul","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"mul","","",307,null],[11,"mul","","",335,null],[11,"mul","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"mul","std::num","",195,null],[11,"mul","std","",307,null],[11,"mul","std::simd","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"f32x4"}}],[11,"mul","std::num","",195,null],[11,"mul","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"mul","std::num","",195,null],[11,"mul","std","",306,null],[11,"mul","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"mul","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"mul","std","",339,null],[11,"mul","","",318,null],[11,"mul","std::num","",195,null],[11,"mul","std","",301,null],[11,"mul","","",332,null],[11,"mul","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"mul","std::num","",195,null],[11,"mul","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"mul","std","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"mul","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"mul","","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"mul","std","",339,null],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"mul","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"mul","std","",320,null],[11,"mul","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"mul","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"f32x16"}}],[11,"mul","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"mul","","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"mul","std","",329,null],[11,"mul","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"mul","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"mul","std::simd","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"f64x8"}}],[11,"mul","std","",332,null],[11,"mul","std::time","",309,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"duration"}}],[11,"mul","std","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"mul","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"mul","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"mul","std","",320,null],[11,"mul","","",319,null],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"mul","","",195,null],[11,"mul","","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"mul","std","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"mul","","",318,null],[11,"mul","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"mul","","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"mul","","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"mul","std","",335,null],[11,"mul","","",322,null],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"mul","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"mul","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"mul","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"rem","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"rem","std","",306,null],[11,"rem","","",318,null],[11,"rem","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"rem","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"rem","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"rem","","",317,null],[11,"rem","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"rem","std::num","",195,null],[11,"rem","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"rem","","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"rem","std","",307,null],[11,"rem","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"rem","std::num","",195,null],[11,"rem","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"rem","std","",329,null],[11,"rem","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"rem","","",195,null],[11,"rem","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"rem","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"rem","std","",329,null],[11,"rem","","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"rem","","",322,null],[11,"rem","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"rem","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"rem","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"rem","std","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"rem","","",317,null],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"rem","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"rem","","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"rem","std::num","",195,null],[11,"rem","std","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"rem","","",318,null],[11,"rem","std::num","",195,null],[11,"rem","std","",335,null],[11,"rem","","",319,null],[11,"rem","","",304,null],[11,"rem","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"rem","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"rem","std","",306,null],[11,"rem","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"rem","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"rem","std::simd","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"f32x16"}}],[11,"rem","std","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"rem","","",301,null],[11,"rem","","",301,null],[11,"rem","","",332,null],[11,"rem","std::simd","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"f64x4"}}],[11,"rem","std::num","",195,null],[11,"rem","std","",339,null],[11,"rem","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"rem","std","",318,null],[11,"rem","","",320,null],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"rem","std","",319,null],[11,"rem","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"rem","","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"rem","","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"rem","std","",314,null],[11,"rem","","",307,null],[11,"rem","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"rem","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"rem","std::simd","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"f64x2"}}],[11,"rem","std","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"rem","","",332,null],[11,"rem","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"rem","std","",306,null],[11,"rem","std::num","",195,null],[11,"rem","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"rem","std","",339,null],[11,"rem","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"rem","std::num","",195,null],[11,"rem","std","",314,null],[11,"rem","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"rem","std","",320,null],[11,"rem","","",322,null],[11,"rem","std::simd","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"f64x8"}}],[11,"rem","std","",314,null],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"rem","","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"rem","","",195,null],[11,"rem","","",195,null],[11,"rem","std","",339,null],[11,"rem","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"rem","std","",335,null],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"rem","","",195,null],[11,"rem","std","",304,null],[11,"rem","","",329,null],[11,"rem","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"rem","std","",322,null],[11,"rem","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"rem","","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"rem","std","",304,null],[11,"rem","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"rem","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"rem","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"rem","std","",320,null],[11,"rem","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"rem","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"rem","std","",335,null],[11,"rem","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"rem","std","",307,null],[11,"rem","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"rem","","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"rem","","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"f32x2"}}],[11,"rem","std","",301,null],[11,"rem","std::simd","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"f32x8"}}],[11,"rem","std::num","",195,null],[11,"rem","std::simd","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"f32x4"}}],[11,"rem","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"rem","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"rem","std","",332,null],[11,"rem","","",319,null],[11,"rem","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"rem","std","",317,null],[11,"as_ref","","",429,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"as_ref","","",409,null],[11,"as_ref","","",285,{"inputs":[{"name":"self"}],"output":{"name":"u"}}],[11,"as_ref","","",409,null],[11,"as_ref","","",433,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","std::slice","",289,null],[11,"as_ref","std","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",429,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",285,{"inputs":[{"name":"self"}],"output":{"name":"u"}}],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"as_ref","","",409,null],[11,"not","","",431,null],[11,"not","","",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"not","std::simd","",450,{"inputs":[{"name":"self"}],"output":{"name":"b8x2"}}],[11,"not","","",348,{"inputs":[{"name":"self"}],"output":{"name":"i8x8"}}],[11,"not","std","",431,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"not","","",307,null],[11,"not","std::simd","",333,{"inputs":[{"name":"self"}],"output":{"name":"u16x16"}}],[11,"not","std","",318,null],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"not","std","",320,null],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"not","std","",339,null],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"not","std","",335,null],[11,"not","std::simd","",316,{"inputs":[{"name":"self"}],"output":{"name":"i32x16"}}],[11,"not","","",337,{"inputs":[{"name":"self"}],"output":{"name":"i16x8"}}],[11,"not","","",442,{"inputs":[{"name":"self"}],"output":{"name":"b8x32"}}],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"not","","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"not","std","",332,null],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"not","","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"not","std::simd","",346,{"inputs":[{"name":"self"}],"output":{"name":"u16x4"}}],[11,"not","","",441,{"inputs":[{"name":"self"}],"output":{"name":"b8x16"}}],[11,"not","","",336,{"inputs":[{"name":"self"}],"output":{"name":"i8x2"}}],[11,"not","","",327,{"inputs":[{"name":"self"}],"output":{"name":"i64x2"}}],[11,"not","","",447,{"inputs":[{"name":"self"}],"output":{"name":"b8x8"}}],[11,"not","std","",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"not","std::simd","",338,{"inputs":[{"name":"self"}],"output":{"name":"i16x16"}}],[11,"not","std","",304,null],[11,"not","","",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"not","std::simd","",355,{"inputs":[{"name":"self"}],"output":{"name":"u64x4"}}],[11,"not","std","",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"not","std::simd","",303,{"inputs":[{"name":"self"}],"output":{"name":"i32x8"}}],[11,"not","","",305,{"inputs":[{"name":"self"}],"output":{"name":"i32x4"}}],[11,"not","","",326,{"inputs":[{"name":"self"}],"output":{"name":"i32x2"}}],[11,"not","std","",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"not","std::simd","",347,{"inputs":[{"name":"self"}],"output":{"name":"u8x4"}}],[11,"not","","",312,{"inputs":[{"name":"self"}],"output":{"name":"u16x8"}}],[11,"not","","",344,{"inputs":[{"name":"self"}],"output":{"name":"u16x2"}}],[11,"not","","",357,{"inputs":[{"name":"self"}],"output":{"name":"u32x4"}}],[11,"not","","",328,{"inputs":[{"name":"self"}],"output":{"name":"u64x2"}}],[11,"not","","",331,{"inputs":[{"name":"self"}],"output":{"name":"i8x32"}}],[11,"not","std","",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"not","std::simd","",350,{"inputs":[{"name":"self"}],"output":{"name":"u32x16"}}],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"not","std","",322,null],[11,"not","std::simd","",315,{"inputs":[{"name":"self"}],"output":{"name":"u8x16"}}],[11,"not","","",444,{"inputs":[{"name":"self"}],"output":{"name":"b8x4"}}],[11,"not","","",330,{"inputs":[{"name":"self"}],"output":{"name":"i8x4"}}],[11,"not","","",353,{"inputs":[{"name":"self"}],"output":{"name":"i64x8"}}],[11,"not","","",325,{"inputs":[{"name":"self"}],"output":{"name":"i8x64"}}],[11,"not","","",343,{"inputs":[{"name":"self"}],"output":{"name":"u8x2"}}],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"not","std","",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"not","","",306,null],[11,"not","std::simd","",440,{"inputs":[{"name":"self"}],"output":{"name":"b8x64"}}],[11,"not","std","",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"not","std::simd","",311,{"inputs":[{"name":"self"}],"output":{"name":"i16x4"}}],[11,"not","","",324,{"inputs":[{"name":"self"}],"output":{"name":"u8x8"}}],[11,"not","std","",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"not","","",329,null],[11,"not","std::simd","",351,{"inputs":[{"name":"self"}],"output":{"name":"u8x32"}}],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"not","std::simd","",341,{"inputs":[{"name":"self"}],"output":{"name":"u64x8"}}],[11,"not","","",342,{"inputs":[{"name":"self"}],"output":{"name":"u16x32"}}],[11,"not","","",302,{"inputs":[{"name":"self"}],"output":{"name":"i16x32"}}],[11,"not","std","",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"not","","",301,null],[11,"not","std::simd","",358,{"inputs":[{"name":"self"}],"output":{"name":"i64x4"}}],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"not","std","",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"not","std::simd","",354,{"inputs":[{"name":"self"}],"output":{"name":"i16x2"}}],[11,"not","","",340,{"inputs":[{"name":"self"}],"output":{"name":"u32x8"}}],[11,"not","std","",317,null],[11,"not","std::simd","",310,{"inputs":[{"name":"self"}],"output":{"name":"u32x2"}}],[11,"not","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"not","std::simd","",334,{"inputs":[{"name":"self"}],"output":{"name":"u8x64"}}],[11,"not","std","",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"not","std::simd","",313,{"inputs":[{"name":"self"}],"output":{"name":"i8x16"}}],[11,"start","std","",424,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",424,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","std::ops","",49,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",49,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",49,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",49,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",34,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",34,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",35,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",35,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",48,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",48,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",31,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",31,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",48,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",48,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",35,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",35,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","std","",424,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",424,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","std::ops","",31,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",31,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",34,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",34,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"start","","",422,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"end","","",422,{"inputs":[{"name":"self"}],"output":{"name":"bound"}}],[11,"fmt","std","",319,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",314,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"call_mut","","",285,null],[11,"call_mut","","",285,null],[11,"sum","","",306,{"inputs":[{"name":"i"}],"output":{"name":"u64"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"sum","std","",318,{"inputs":[{"name":"i"}],"output":{"name":"i128"}}],[11,"sum","","",320,{"inputs":[{"name":"i"}],"output":{"name":"u8"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"sum","std::result","Takes each element in the `Iterator`: if it is an `Err`, no further elements are taken, and the `Err` is returned. Should no `Err` occur, the sum of all elements is returned.",72,{"inputs":[{"name":"i"}],"output":{"name":"result"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"sum","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"sum","std","",322,{"inputs":[{"name":"i"}],"output":{"name":"isize"}}],[11,"sum","","",314,{"inputs":[{"name":"i"}],"output":{"name":"f64"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"sum","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"sum","std","",339,{"inputs":[{"name":"i"}],"output":{"name":"u128"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"sum","std","",304,{"inputs":[{"name":"i"}],"output":{"name":"usize"}}],[11,"sum","","",335,{"inputs":[{"name":"i"}],"output":{"name":"i8"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"sum","std","",332,{"inputs":[{"name":"i"}],"output":{"name":"i64"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"sum","std","",318,{"inputs":[{"name":"i"}],"output":{"name":"i128"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"sum","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"sum","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"sum","std","",301,{"inputs":[{"name":"i"}],"output":{"name":"u32"}}],[11,"sum","","",314,{"inputs":[{"name":"i"}],"output":{"name":"f64"}}],[11,"sum","","",319,{"inputs":[{"name":"i"}],"output":{"name":"f32"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"sum","std","",329,{"inputs":[{"name":"i"}],"output":{"name":"u16"}}],[11,"sum","","",320,{"inputs":[{"name":"i"}],"output":{"name":"u8"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"sum","std","",335,{"inputs":[{"name":"i"}],"output":{"name":"i8"}}],[11,"sum","","",307,{"inputs":[{"name":"i"}],"output":{"name":"i32"}}],[11,"sum","","",319,{"inputs":[{"name":"i"}],"output":{"name":"f32"}}],[11,"sum","","",306,{"inputs":[{"name":"i"}],"output":{"name":"u64"}}],[11,"sum","","",332,{"inputs":[{"name":"i"}],"output":{"name":"i64"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"sum","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"sum","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"sum","std","",307,{"inputs":[{"name":"i"}],"output":{"name":"i32"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"sum","","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"sum","std::time","",309,{"inputs":[{"name":"i"}],"output":{"name":"duration"}}],[11,"sum","std","",329,{"inputs":[{"name":"i"}],"output":{"name":"u16"}}],[11,"sum","std::time","",309,{"inputs":[{"name":"i"}],"output":{"name":"duration"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"sum","std","",317,{"inputs":[{"name":"i"}],"output":{"name":"i16"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"sum","std","",317,{"inputs":[{"name":"i"}],"output":{"name":"i16"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"sum","std","",304,{"inputs":[{"name":"i"}],"output":{"name":"usize"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"sum","std","",301,{"inputs":[{"name":"i"}],"output":{"name":"u32"}}],[11,"sum","","",322,{"inputs":[{"name":"i"}],"output":{"name":"isize"}}],[11,"sum","","",339,{"inputs":[{"name":"i"}],"output":{"name":"u128"}}],[11,"sum","std::num","",195,{"inputs":[{"name":"i"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"split_at","std","",433,null],[11,"iter","","",433,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"split","","",433,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"split"}}],[11,"rsplit","","",433,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rsplit"}}],[11,"splitn","","",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"splitn"}}],[11,"rsplitn","","",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"rsplitn"}}],[11,"windows","","",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"windows"}}],[11,"chunks","","",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"chunks"}}],[11,"exact_chunks","","",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"exactchunks"}}],[11,"get","","",433,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[11,"first","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_first","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_last","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"last","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"get_unchecked","","",433,null],[11,"as_ptr","","",433,null],[11,"binary_search_by","","",433,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"len","","",433,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"get_mut","","",433,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[11,"split_at_mut","","",433,null],[11,"iter_mut","","",433,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"last_mut","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"first_mut","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_first_mut","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_last_mut","","",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_mut","","",433,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"splitmut"}}],[11,"rsplit_mut","","",433,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rsplitmut"}}],[11,"splitn_mut","","",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"splitnmut"}}],[11,"rsplitn_mut","","",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"rsplitnmut"}}],[11,"chunks_mut","","",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"chunksmut"}}],[11,"exact_chunks_mut","","",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"exactchunksmut"}}],[11,"swap","","",433,null],[11,"reverse","","",433,null],[11,"get_unchecked_mut","","",433,null],[11,"as_mut_ptr","","",433,null],[11,"contains","","",433,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"starts_with","","",433,null],[11,"ends_with","","",433,null],[11,"binary_search","","",433,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"rotate_left","","",433,null],[11,"rotate_right","","",433,null],[11,"clone_from_slice","","",433,null],[11,"copy_from_slice","","",433,null],[11,"swap_with_slice","","",433,null],[11,"binary_search_by_key","","",433,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"sort_unstable","","",433,null],[11,"sort_unstable_by","","",433,null],[11,"sort_unstable_by_key","","",433,null],[11,"shl","","",322,null],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i128"}}],[11,"shl","","",307,null],[11,"shl","std::simd","",303,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x8"}}],[11,"shl","std","",339,null],[11,"shl","std::simd","",303,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x8"}}],[11,"shl","","",330,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x4"}}],[11,"shl","std","",318,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i128"}}],[11,"shl","std::simd","",344,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x2"}}],[11,"shl","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"shl","","",301,null],[11,"shl","std::simd","",328,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64x2"}}],[11,"shl","std","",304,null],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"usize"}}],[11,"shl","std::simd","",316,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x16"}}],[11,"shl","","",331,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x32"}}],[11,"shl","std","",317,null],[11,"shl","","",317,null],[11,"shl","","",332,null],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x2"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64x2"}}],[11,"shl","","",325,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x64"}}],[11,"shl","","",358,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64x4"}}],[11,"shl","","",350,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x16"}}],[11,"shl","std","",320,null],[11,"shl","std::simd","",353,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64x8"}}],[11,"shl","","",326,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x2"}}],[11,"shl","","",354,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x2"}}],[11,"shl","","",355,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64x4"}}],[11,"shl","std","",339,null],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64x4"}}],[11,"shl","std","",301,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32"}}],[11,"shl","std::simd","",313,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x16"}}],[11,"shl","","",344,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x2"}}],[11,"shl","","",327,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64x2"}}],[11,"shl","","",313,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x16"}}],[11,"shl","","",355,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64x4"}}],[11,"shl","std","",307,null],[11,"shl","","",335,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8"}}],[11,"shl","","",307,null],[11,"shl","","",301,null],[11,"shl","","",306,null],[11,"shl","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x2"}}],[11,"shl","","",354,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x2"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",316,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x16"}}],[11,"shl","","",303,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x8"}}],[11,"shl","","",348,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x8"}}],[11,"shl","std","",322,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"isize"}}],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x2"}}],[11,"shl","std","",329,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16"}}],[11,"shl","","",307,null],[11,"shl","","",339,null],[11,"shl","","",335,null],[11,"shl","","",306,null],[11,"shl","","",304,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x16"}}],[11,"shl","","",341,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64x8"}}],[11,"shl","","",340,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x8"}}],[11,"shl","std","",307,null],[11,"shl","std::simd","",311,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x4"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x32"}}],[11,"shl","std","",320,null],[11,"shl","","",304,null],[11,"shl","","",318,null],[11,"shl","","",306,null],[11,"shl","","",317,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16"}}],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x8"}}],[11,"shl","std","",307,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"shl","","",339,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"isize"}}],[11,"shl","","",317,null],[11,"shl","","",320,null],[11,"shl","std::simd","",337,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x8"}}],[11,"shl","","",342,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x32"}}],[11,"shl","std","",318,null],[11,"shl","","",332,null],[11,"shl","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64x4"}}],[11,"shl","std","",320,null],[11,"shl","","",322,null],[11,"shl","std::simd","",311,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x4"}}],[11,"shl","std","",304,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"usize"}}],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64x4"}}],[11,"shl","std","",318,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"isize"}}],[11,"shl","","",318,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x16"}}],[11,"shl","std","",339,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u128"}}],[11,"shl","","",329,null],[11,"shl","","",332,null],[11,"shl","","",304,null],[11,"shl","std::simd","",350,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x16"}}],[11,"shl","std","",320,null],[11,"shl","","",322,null],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x8"}}],[11,"shl","std","",306,null],[11,"shl","","",329,null],[11,"shl","","",317,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16"}}],[11,"shl","","",332,null],[11,"shl","","",329,null],[11,"shl","","",301,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u32"}}],[11,"shl","","",322,null],[11,"shl","","",306,null],[11,"shl","","",306,null],[11,"shl","","",301,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8"}}],[11,"shl","","",322,null],[11,"shl","","",301,null],[11,"shl","","",318,null],[11,"shl","","",304,null],[11,"shl","","",322,null],[11,"shl","","",317,null],[11,"shl","","",304,null],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64x4"}}],[11,"shl","std","",329,null],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i64"}}],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64"}}],[11,"shl","","",332,null],[11,"shl","std::simd","",330,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x4"}}],[11,"shl","std","",332,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64"}}],[11,"shl","","",329,null],[11,"shl","","",307,null],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x4"}}],[11,"shl","","",325,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x64"}}],[11,"shl","","",325,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x64"}}],[11,"shl","","",353,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64x8"}}],[11,"shl","","",355,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64x4"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x2"}}],[11,"shl","","",340,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x8"}}],[11,"shl","","",357,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x4"}}],[11,"shl","","",331,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x32"}}],[11,"shl","std","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"shl","","",322,null],[11,"shl","","",318,null],[11,"shl","std::simd","",312,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x8"}}],[11,"shl","std","",329,null],[11,"shl","","",318,null],[11,"shl","std::simd","",303,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x8"}}],[11,"shl","std","",335,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8"}}],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"shl","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x64"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x32"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"shl","std","",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"isize"}}],[11,"shl","","",317,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16"}}],[11,"shl","std::simd","",302,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x32"}}],[11,"shl","std","",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x32"}}],[11,"shl","std","",329,null],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x4"}}],[11,"shl","std","",322,null],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"shl","","",335,null],[11,"shl","","",304,null],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u128"}}],[11,"shl","","",307,null],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u128"}}],[11,"shl","","",335,null],[11,"shl","","",332,null],[11,"shl","std::simd","",353,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64x8"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x32"}}],[11,"shl","std","",335,null],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64"}}],[11,"shl","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x2"}}],[11,"shl","std","",317,null],[11,"shl","","",307,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32"}}],[11,"shl","std::simd","",350,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x16"}}],[11,"shl","","",338,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x16"}}],[11,"shl","std","",306,null],[11,"shl","","",301,null],[11,"shl","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64x8"}}],[11,"shl","","",327,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64x2"}}],[11,"shl","std","",301,null],[11,"shl","","",301,null],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64x4"}}],[11,"shl","","",346,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x4"}}],[11,"shl","","",312,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x8"}}],[11,"shl","std","",339,null],[11,"shl","","",329,null],[11,"shl","std::simd","",313,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x16"}}],[11,"shl","std","",335,null],[11,"shl","","",317,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"shl","","",332,null],[11,"shl","","",301,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"shl","","",335,null],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64x2"}}],[11,"shl","std","",306,null],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u128"}}],[11,"shl","std::simd","",310,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x2"}}],[11,"shl","std","",332,null],[11,"shl","std::simd","",313,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x16"}}],[11,"shl","std","",329,null],[11,"shl","","",307,null],[11,"shl","","",304,null],[11,"shl","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64x8"}}],[11,"shl","std","",322,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"isize"}}],[11,"shl","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x2"}}],[11,"shl","","",324,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x8"}}],[11,"shl","std","",320,null],[11,"shl","","",301,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32"}}],[11,"shl","","",332,null],[11,"shl","std::simd","",331,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x32"}}],[11,"shl","","",357,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x4"}}],[11,"shl","std","",306,null],[11,"shl","","",317,null],[11,"shl","","",301,null],[11,"shl","","",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"shl","","",317,null],[11,"shl","","",301,null],[11,"shl","","",329,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u16"}}],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x32"}}],[11,"shl","std","",306,null],[11,"shl","","",322,null],[11,"shl","std::simd","",336,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x2"}}],[11,"shl","std","",322,null],[11,"shl","","",301,null],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"usize"}}],[11,"shl","std::simd","",340,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x8"}}],[11,"shl","std","",301,null],[11,"shl","","",329,null],[11,"shl","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x16"}}],[11,"shl","std","",335,null],[11,"shl","","",304,null],[11,"shl","","",318,null],[11,"shl","","",304,null],[11,"shl","std::simd","",324,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x8"}}],[11,"shl","std","",339,null],[11,"shl","std::simd","",305,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x4"}}],[11,"shl","std","",307,null],[11,"shl","","",322,null],[11,"shl","","",307,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32"}}],[11,"shl","","",304,null],[11,"shl","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x8"}}],[11,"shl","","",326,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x2"}}],[11,"shl","std","",332,null],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64"}}],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"shl","std::simd","",311,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x4"}}],[11,"shl","","",357,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x4"}}],[11,"shl","std","",304,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"usize"}}],[11,"shl","","",301,null],[11,"shl","","",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"shl","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x8"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",325,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x64"}}],[11,"shl","","",341,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64x8"}}],[11,"shl","","",310,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x2"}}],[11,"shl","","",334,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x64"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x16"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",357,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x4"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x16"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"shl","std","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"shl","","",322,null],[11,"shl","std::simd","",350,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x16"}}],[11,"shl","std","",301,null],[11,"shl","","",318,null],[11,"shl","","",304,null],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x32"}}],[11,"shl","","",331,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x32"}}],[11,"shl","","",303,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x8"}}],[11,"shl","std","",317,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i16"}}],[11,"shl","","",304,null],[11,"shl","","",339,null],[11,"shl","","",307,null],[11,"shl","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x16"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",344,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x2"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",344,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x2"}}],[11,"shl","std","",306,null],[11,"shl","","",332,null],[11,"shl","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64x8"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64x2"}}],[11,"shl","","",337,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x8"}}],[11,"shl","","",357,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x4"}}],[11,"shl","","",355,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64x4"}}],[11,"shl","","",316,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x16"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"shl","std::simd","",325,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x64"}}],[11,"shl","","",333,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x16"}}],[11,"shl","std","",339,null],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i128"}}],[11,"shl","","",320,null],[11,"shl","","",301,null],[11,"shl","std::simd","",328,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64x2"}}],[11,"shl","","",336,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x2"}}],[11,"shl","std","",335,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8"}}],[11,"shl","std::simd","",354,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x2"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x16"}}],[11,"shl","std","",322,null],[11,"shl","std::simd","",353,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64x8"}}],[11,"shl","","",313,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x16"}}],[11,"shl","","",337,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x8"}}],[11,"shl","std","",322,null],[11,"shl","std::simd","",353,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64x8"}}],[11,"shl","","",302,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x32"}}],[11,"shl","","",342,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x32"}}],[11,"shl","std","",335,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8"}}],[11,"shl","","",306,null],[11,"shl","","",335,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8"}}],[11,"shl","","",322,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8"}}],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"shl","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x8"}}],[11,"shl","","",353,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64x8"}}],[11,"shl","","",330,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x4"}}],[11,"shl","","",333,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x16"}}],[11,"shl","std","",329,null],[11,"shl","","",301,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32"}}],[11,"shl","std::simd","",303,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x8"}}],[11,"shl","","",311,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x4"}}],[11,"shl","","",347,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x4"}}],[11,"shl","std","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x4"}}],[11,"shl","std","",318,null],[11,"shl","","",307,null],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x16"}}],[11,"shl","","",310,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x2"}}],[11,"shl","std","",301,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32"}}],[11,"shl","","",317,null],[11,"shl","","",320,null],[11,"shl","","",304,null],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x8"}}],[11,"shl","std","",322,null],[11,"shl","std::simd","",341,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64x8"}}],[11,"shl","std","",329,null],[11,"shl","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x4"}}],[11,"shl","std","",329,null],[11,"shl","","",306,null],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x4"}}],[11,"shl","","",331,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x32"}}],[11,"shl","std","",304,null],[11,"shl","","",332,null],[11,"shl","","",329,null],[11,"shl","","",307,null],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x32"}}],[11,"shl","std","",332,null],[11,"shl","","",317,null],[11,"shl","","",332,null],[11,"shl","","",317,null],[11,"shl","","",317,null],[11,"shl","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x2"}}],[11,"shl","std","",332,null],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x16"}}],[11,"shl","std","",339,null],[11,"shl","","",320,null],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"shl","","",339,null],[11,"shl","","",317,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16"}}],[11,"shl","","",339,null],[11,"shl","std::simd","",326,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x2"}}],[11,"shl","","",350,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x16"}}],[11,"shl","","",334,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x64"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"shl","std","",318,null],[11,"shl","","",320,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"shl","","",318,null],[11,"shl","","",320,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64"}}],[11,"shl","","",306,null],[11,"shl","","",304,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"isize"}}],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64"}}],[11,"shl","","",307,null],[11,"shl","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x8"}}],[11,"shl","","",344,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x2"}}],[11,"shl","","",312,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x8"}}],[11,"shl","std","",335,null],[11,"shl","","",301,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"isize"}}],[11,"shl","std::simd","",324,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x8"}}],[11,"shl","std","",320,null],[11,"shl","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x4"}}],[11,"shl","","",346,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x4"}}],[11,"shl","std","",320,null],[11,"shl","","",301,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32"}}],[11,"shl","","",304,null],[11,"shl","std::simd","",328,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64x2"}}],[11,"shl","std","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"shl","","",306,null],[11,"shl","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x8"}}],[11,"shl","std","",304,null],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64"}}],[11,"shl","","",339,null],[11,"shl","","",329,null],[11,"shl","","",335,null],[11,"shl","std::simd","",333,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x16"}}],[11,"shl","","",328,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64x2"}}],[11,"shl","std","",317,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i16"}}],[11,"shl","","",339,null],[11,"shl","","",339,null],[11,"shl","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x64"}}],[11,"shl","","",342,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x32"}}],[11,"shl","std","",317,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"shl","","",322,null],[11,"shl","","",335,null],[11,"shl","","",332,null],[11,"shl","","",307,null],[11,"shl","","",320,null],[11,"shl","","",306,null],[11,"shl","","",317,null],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"usize"}}],[11,"shl","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x64"}}],[11,"shl","","",326,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x2"}}],[11,"shl","","",331,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x32"}}],[11,"shl","","",340,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x8"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x16"}}],[11,"shl","std","",320,null],[11,"shl","","",317,null],[11,"shl","","",318,null],[11,"shl","","",301,null],[11,"shl","","",301,null],[11,"shl","std::simd","",354,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x2"}}],[11,"shl","","",346,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x4"}}],[11,"shl","","",342,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x32"}}],[11,"shl","std","",329,null],[11,"shl","","",320,null],[11,"shl","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x8"}}],[11,"shl","","",324,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x8"}}],[11,"shl","std","",335,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i8"}}],[11,"shl","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x4"}}],[11,"shl","std","",301,null],[11,"shl","","",329,null],[11,"shl","std::simd","",342,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x32"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",336,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x2"}}],[11,"shl","std","",322,null],[11,"shl","","",329,null],[11,"shl","","",335,null],[11,"shl","","",335,null],[11,"shl","","",306,null],[11,"shl","","",335,null],[11,"shl","","",329,null],[11,"shl","","",318,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"isize"}}],[11,"shl","","",320,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64"}}],[11,"shl","","",318,null],[11,"shl","","",339,null],[11,"shl","","",335,null],[11,"shl","","",306,null],[11,"shl","","",307,null],[11,"shl","","",329,null],[11,"shl","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x64"}}],[11,"shl","std","",307,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"shl","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x8"}}],[11,"shl","std","",318,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i128"}}],[11,"shl","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x4"}}],[11,"shl","","",305,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x4"}}],[11,"shl","","",316,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x16"}}],[11,"shl","std","",335,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i8"}}],[11,"shl","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x4"}}],[11,"shl","std","",318,null],[11,"shl","","",304,null],[11,"shl","","",332,null],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x4"}}],[11,"shl","std","",306,null],[11,"shl","","",306,null],[11,"shl","","",301,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32"}}],[11,"shl","std::simd","",333,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x16"}}],[11,"shl","","",305,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x4"}}],[11,"shl","std","",320,null],[11,"shl","","",318,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x8"}}],[11,"shl","std","",320,null],[11,"shl","std::simd","",355,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64x4"}}],[11,"shl","std","",301,null],[11,"shl","","",339,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8"}}],[11,"shl","","",335,null],[11,"shl","","",317,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16"}}],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"shl","","",317,null],[11,"shl","","",329,null],[11,"shl","","",329,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u16"}}],[11,"shl","","",332,null],[11,"shl","","",322,null],[11,"shl","","",335,null],[11,"shl","std::simd","",342,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x32"}}],[11,"shl","","",355,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64x4"}}],[11,"shl","std","",307,null],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u128"}}],[11,"shl","","",322,null],[11,"shl","","",320,null],[11,"shl","std::simd","",334,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x64"}}],[11,"shl","","",311,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x4"}}],[11,"shl","","",333,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x16"}}],[11,"shl","std","",320,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8"}}],[11,"shl","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x4"}}],[11,"shl","std","",307,null],[11,"shl","","",307,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32"}}],[11,"shl","","",317,null],[11,"shl","std::simd","",302,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x32"}}],[11,"shl","","",328,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64x2"}}],[11,"shl","","",312,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x8"}}],[11,"shl","std","",304,null],[11,"shl","","",307,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i32"}}],[11,"shl","","",307,null],[11,"shl","","",307,null],[11,"shl","","",301,null],[11,"shl","std::simd","",331,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x32"}}],[11,"shl","std","",332,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i64"}}],[11,"shl","","",318,null],[11,"shl","","",317,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16"}}],[11,"shl","std::simd","",305,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x4"}}],[11,"shl","std","",304,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"usize"}}],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x16"}}],[11,"shl","std","",306,null],[11,"shl","","",306,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"isize"}}],[11,"shl","","",301,null],[11,"shl","","",304,null],[11,"shl","","",320,null],[11,"shl","","",329,null],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x4"}}],[11,"shl","std","",318,null],[11,"shl","","",304,null],[11,"shl","","",307,null],[11,"shl","","",318,null],[11,"shl","std::simd","",302,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x32"}}],[11,"shl","std","",317,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64"}}],[11,"shl","std::simd","",330,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x4"}}],[11,"shl","","",311,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x4"}}],[11,"shl","","",340,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x8"}}],[11,"shl","std","",318,null],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x8"}}],[11,"shl","","",357,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x4"}}],[11,"shl","","",305,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x4"}}],[11,"shl","","",302,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x32"}}],[11,"shl","","",333,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x16"}}],[11,"shl","","",346,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x4"}}],[11,"shl","","",305,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x4"}}],[11,"shl","","",334,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x64"}}],[11,"shl","std","",329,null],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"usize"}}],[11,"shl","std::simd","",337,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x8"}}],[11,"shl","","",326,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x2"}}],[11,"shl","","",336,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x2"}}],[11,"shl","std","",329,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u8"}}],[11,"shl","std::simd","",310,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x2"}}],[11,"shl","std","",322,null],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x16"}}],[11,"shl","std","",320,null],[11,"shl","","",320,null],[11,"shl","","",304,null],[11,"shl","","",318,null],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u128"}}],[11,"shl","","",301,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32"}}],[11,"shl","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64x8"}}],[11,"shl","std","",317,null],[11,"shl","","",335,null],[11,"shl","","",317,null],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x2"}}],[11,"shl","std","",320,null],[11,"shl","","",301,null],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x16"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"shl","std","",304,null],[11,"shl","","",320,null],[11,"shl","","",335,null],[11,"shl","","",335,null],[11,"shl","std::simd","",312,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x8"}}],[11,"shl","","",341,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64x8"}}],[11,"shl","","",316,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x16"}}],[11,"shl","std","",329,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64"}}],[11,"shl","","",307,null],[11,"shl","","",317,null],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x16"}}],[11,"shl","std","",307,null],[11,"shl","","",332,null],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x2"}}],[11,"shl","std","",332,null],[11,"shl","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x4"}}],[11,"shl","std","",318,null],[11,"shl","","",301,null],[11,"shl","std::simd","",342,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x32"}}],[11,"shl","","",313,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x16"}}],[11,"shl","","",344,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x2"}}],[11,"shl","std","",304,null],[11,"shl","std::simd","",334,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x64"}}],[11,"shl","","",341,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64x8"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x32"}}],[11,"shl","","",312,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x8"}}],[11,"shl","std","",304,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x16"}}],[11,"shl","std","",318,null],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x32"}}],[11,"shl","","",336,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x2"}}],[11,"shl","std","",320,null],[11,"shl","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x2"}}],[11,"shl","","",336,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x2"}}],[11,"shl","","",342,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x32"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x32"}}],[11,"shl","std","",322,null],[11,"shl","","",332,null],[11,"shl","std::simd","",340,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x8"}}],[11,"shl","","",326,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x2"}}],[11,"shl","std","",307,null],[11,"shl","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"shl","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x4"}}],[11,"shl","std","",329,null],[11,"shl","","",318,null],[11,"shl","","",329,null],[11,"shl","std::simd","",312,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x8"}}],[11,"shl","std","",304,null],[11,"shl","","",306,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64"}}],[11,"shl","","",332,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8"}}],[11,"shl","","",322,null],[11,"shl","","",339,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64"}}],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x4"}}],[11,"shl","std","",318,null],[11,"shl","","",335,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8"}}],[11,"shl","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x8"}}],[11,"shl","std","",322,null],[11,"shl","","",329,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16"}}],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64x4"}}],[11,"shl","std","",320,null],[11,"shl","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x2"}}],[11,"shl","","",357,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x4"}}],[11,"shl","std","",306,null],[11,"shl","","",317,null],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64x4"}}],[11,"shl","","",351,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x32"}}],[11,"shl","","",330,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x4"}}],[11,"shl","std","",307,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32"}}],[11,"shl","","",329,null],[11,"shl","","",320,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u8"}}],[11,"shl","std::simd","",324,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x8"}}],[11,"shl","std","",339,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u128"}}],[11,"shl","","",332,null],[11,"shl","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x32"}}],[11,"shl","","",353,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64x8"}}],[11,"shl","std","",329,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16"}}],[11,"shl","","",318,null],[11,"shl","std::simd","",324,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x8"}}],[11,"shl","std","",304,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"usize"}}],[11,"shl","","",318,null],[11,"shl","","",332,null],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u128"}}],[11,"shl","std::simd","",346,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x4"}}],[11,"shl","std","",329,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16"}}],[11,"shl","","",339,null],[11,"shl","","",322,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64"}}],[11,"shl","","",317,null],[11,"shl","","",329,null],[11,"shl","","",306,null],[11,"shl","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x2"}}],[11,"shl","std","",318,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i128"}}],[11,"shl","","",307,null],[11,"shl","","",332,null],[11,"shl","","",307,null],[11,"shl","std::simd","",337,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x8"}}],[11,"shl","std","",318,null],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64x2"}}],[11,"shl","std","",301,null],[11,"shl","","",301,null],[11,"shl","","",339,null],[11,"shl","","",307,null],[11,"shl","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x4"}}],[11,"shl","","",324,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x8"}}],[11,"shl","std","",332,null],[11,"shl","std::simd","",325,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x64"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64x2"}}],[11,"shl","","",351,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x32"}}],[11,"shl","","",343,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x2"}}],[11,"shl","std","",332,null],[11,"shl","","",318,null],[11,"shl","std::simd","",311,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x4"}}],[11,"shl","","",341,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64x8"}}],[11,"shl","","",331,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x32"}}],[11,"shl","","",338,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x16"}}],[11,"shl","","",346,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x4"}}],[11,"shl","std","",317,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16"}}],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64x2"}}],[11,"shl","","",330,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x4"}}],[11,"shl","","",350,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x16"}}],[11,"shl","","",333,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x16"}}],[11,"shl","","",311,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x4"}}],[11,"shl","std","",318,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i128"}}],[11,"shl","std::simd","",326,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x2"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x4"}}],[11,"shl","std","",332,null],[11,"shl","","",320,null],[11,"shl","","",307,null],[11,"shl","std::simd","",357,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x4"}}],[11,"shl","std","",306,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u64"}}],[11,"shl","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64x8"}}],[11,"shl","std","",322,null],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64x4"}}],[11,"shl","std","",307,null],[11,"shl","","",339,null],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x2"}}],[11,"shl","std","",329,null],[11,"shl","","",320,null],[11,"shl","","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"shl","std::simd","",328,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64x2"}}],[11,"shl","","",303,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x8"}}],[11,"shl","","",325,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x64"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x16"}}],[11,"shl","std","",332,null],[11,"shl","","",301,null],[11,"shl","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64x4"}}],[11,"shl","std","",329,null],[11,"shl","","",306,null],[11,"shl","","",335,null],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"usize"}}],[11,"shl","","",306,null],[11,"shl","std::simd","",310,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x2"}}],[11,"shl","","",333,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x16"}}],[11,"shl","","",357,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x4"}}],[11,"shl","std","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x16"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"shl","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x2"}}],[11,"shl","","",328,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64x2"}}],[11,"shl","std","",318,null],[11,"shl","","",322,null],[11,"shl","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x8"}}],[11,"shl","","",302,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x32"}}],[11,"shl","std","",307,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i32"}}],[11,"shl","","",304,null],[11,"shl","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x16"}}],[11,"shl","","",313,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x16"}}],[11,"shl","","",350,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x16"}}],[11,"shl","std","",335,null],[11,"shl","","",320,null],[11,"shl","std::simd","",303,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x8"}}],[11,"shl","std","",306,null],[11,"shl","std::simd","",326,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x2"}}],[11,"shl","","",350,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x16"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"shl","std","",332,null],[11,"shl","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x32"}}],[11,"shl","","",355,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64x4"}}],[11,"shl","std","",320,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8"}}],[11,"shl","","",322,null],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i128"}}],[11,"shl","","",307,null],[11,"shl","","",329,null],[11,"shl","std::simd","",336,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x2"}}],[11,"shl","","",344,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x2"}}],[11,"shl","std","",306,null],[11,"shl","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x2"}}],[11,"shl","std","",304,null],[11,"shl","","",335,null],[11,"shl","","",322,null],[11,"shl","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"shl","","",317,null],[11,"shl","","",304,null],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i128"}}],[11,"shl","","",318,null],[11,"shl","","",339,null],[11,"shl","","",306,null],[11,"shl","std::simd","",310,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x2"}}],[11,"shl","std","",335,null],[11,"shl","","",339,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u128"}}],[11,"shl","","",304,null],[11,"shl","std::simd","",305,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x4"}}],[11,"shl","","",358,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64x4"}}],[11,"shl","std","",322,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"isize"}}],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64x2"}}],[11,"shl","std","",320,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8"}}],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64x2"}}],[11,"shl","","",337,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x8"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",340,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x8"}}],[11,"shl","std","",339,null],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x2"}}],[11,"shl","std","",329,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"shl","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x8"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",312,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x8"}}],[11,"shl","std","",322,null],[11,"shl","","",329,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16"}}],[11,"shl","","",317,null],[11,"shl","","",307,null],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x8"}}],[11,"shl","","",315,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x16"}}],[11,"shl","std","",307,null],[11,"shl","","",332,null],[11,"shl","","",339,null],[11,"shl","std::simd","",316,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x16"}}],[11,"shl","","",347,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x4"}}],[11,"shl","std","",301,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u32"}}],[11,"shl","","",320,null],[11,"shl","","",339,null],[11,"shl","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x2"}}],[11,"shl","std","",307,null],[11,"shl","std::simd","",355,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64x4"}}],[11,"shl","std","",304,null],[11,"shl","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x8"}}],[11,"shl","std","",320,null],[11,"shl","","",332,null],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x8"}}],[11,"shl","","",344,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x2"}}],[11,"shl","","",328,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64x2"}}],[11,"shl","","",334,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x64"}}],[11,"shl","std","",317,null],[11,"shl","std::simd","",338,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x16"}}],[11,"shl","std","",317,null],[11,"shl","","",307,null],[11,"shl","","",322,null],[11,"shl","","",304,null],[11,"shl","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x64"}}],[11,"shl","","",302,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x32"}}],[11,"shl","std","",306,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u64"}}],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x8"}}],[11,"shl","std","",332,null],[11,"shl","std::simd","",347,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x4"}}],[11,"shl","std","",318,null],[11,"shl","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x32"}}],[11,"shl","std","",304,null],[11,"shl","std::simd","",336,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x2"}}],[11,"shl","","",354,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x2"}}],[11,"shl","std","",329,null],[11,"shl","","",332,null],[11,"shl","","",306,null],[11,"shl","","",329,null],[11,"shl","","",329,null],[11,"shl","","",320,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x16"}}],[11,"shl","std","",318,null],[11,"shl","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x4"}}],[11,"shl","std","",335,null],[11,"shl","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x16"}}],[11,"shl","","",326,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x2"}}],[11,"shl","std","",332,null],[11,"shl","","",332,null],[11,"shl","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x32"}}],[11,"shl","std","",339,null],[11,"shl","","",332,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64"}}],[11,"shl","","",318,null],[11,"shl","","",339,null],[11,"shl","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x16"}}],[11,"shl","","",303,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x8"}}],[11,"shl","std","",301,null],[11,"shl","std::simd","",333,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x16"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"shl","std","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"shl","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64x8"}}],[11,"shl","std","",339,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u128"}}],[11,"shl","","",307,null],[11,"shl","","",320,null],[11,"shl","","",329,null],[11,"shl","","",307,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32"}}],[11,"shl","","",306,null],[11,"shl","","",339,null],[11,"shl","std::simd","",328,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64x2"}}],[11,"shl","std","",339,null],[11,"shl","","",307,null],[11,"shl","","",301,null],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x2"}}],[11,"shl","","",310,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x2"}}],[11,"shl","std","",322,null],[11,"shl","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x4"}}],[11,"shl","std","",306,null],[11,"shl","","",317,null],[11,"shl","","",339,null],[11,"shl","","",335,null],[11,"shl","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x8"}}],[11,"shl","std","",339,null],[11,"shl","","",335,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"shl","std::simd","",358,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64x4"}}],[11,"shl","","",310,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x2"}}],[11,"shl","std","",322,null],[11,"shl","","",335,null],[11,"shl","","",322,null],[11,"shl","","",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"shl","","",320,null],[11,"shl","","",306,null],[11,"shl","std::simd","",334,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x64"}}],[11,"shl","","",305,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x4"}}],[11,"shl","","",312,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x8"}}],[11,"shl","","",313,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x16"}}],[11,"shl","std","",301,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32"}}],[11,"shl","","",339,null],[11,"shl","","",306,null],[11,"shl","std::simd","",316,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x16"}}],[11,"shl","std","",339,null],[11,"shl","","",304,null],[11,"shl","std::simd","",341,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64x8"}}],[11,"shl","","",334,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x64"}}],[11,"shl","","",354,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x2"}}],[11,"shl","std","",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"shl","","",335,null],[11,"shl","","",318,null],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i128"}}],[11,"shl","","",301,null],[11,"shl","","",318,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i128"}}],[11,"shl","std::simd","",316,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x16"}}],[11,"shl","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"shl","std::simd","",346,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x4"}}],[11,"shl","","",343,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x2"}}],[11,"shl","std","",329,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16"}}],[11,"shl","","",306,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x16"}}],[11,"shl","","",324,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x8"}}],[11,"shl","std","",307,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32"}}],[11,"shl","","",304,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"usize"}}],[11,"shl","","",335,null],[11,"shl","","",339,null],[11,"shl","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x2"}}],[11,"shl","std","",307,null],[11,"shl","std::simd","",327,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64x2"}}],[11,"shl","std","",329,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16"}}],[11,"shl","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x32"}}],[11,"shl","std","",304,null],[11,"shl","std::simd","",315,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x16"}}],[11,"shl","std","",339,null],[11,"shl","","",339,null],[11,"shl","","",320,null],[11,"shl","","",335,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8"}}],[11,"shl","","",335,null],[11,"shl","","",322,null],[11,"shl","","",339,null],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",319,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",314,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"call","","",285,null],[11,"sub","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"sub","","",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"f32x16"}}],[11,"sub","std::num","",195,null],[11,"sub","std","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"sub","std::simd","",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"f32x4"}}],[11,"sub","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"sub","std","",306,null],[11,"sub","","",322,null],[11,"sub","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"sub","std::num","",195,null],[11,"sub","std::simd","",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"f64x2"}}],[11,"sub","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"sub","","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"sub","","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"sub","std::num","",195,null],[11,"sub","std","",304,null],[11,"sub","","",320,null],[11,"sub","","",322,null],[11,"sub","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"sub","","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"sub","","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"sub","std","",319,null],[11,"sub","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"sub","std","",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"sub","std","",319,null],[11,"sub","","",335,null],[11,"sub","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"sub","std","",335,null],[11,"sub","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"sub","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"sub","std","",320,null],[11,"sub","","",332,null],[11,"sub","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"sub","","",314,null],[11,"sub","std::simd","",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"f64x4"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"sub","","",195,null],[11,"sub","std","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"sub","std::num","",195,null],[11,"sub","","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"sub","std","",339,null],[11,"sub","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"sub","std::num","",195,null],[11,"sub","std","",332,null],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"sub","std","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"sub","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"sub","std","",329,null],[11,"sub","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"sub","std::num","",195,null],[11,"sub","std::simd","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"sub","","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"sub","std","",318,null],[11,"sub","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"sub","","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"sub","std","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"sub","","",304,null],[11,"sub","","",301,null],[11,"sub","","",329,null],[11,"sub","","",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"sub","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"sub","std","",304,null],[11,"sub","","",314,null],[11,"sub","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"sub","std","",322,null],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"sub","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"sub","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"sub","","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"sub","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"sub","std","",329,null],[11,"sub","","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"sub","std::simd","",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"f32x8"}}],[11,"sub","std","",339,null],[11,"sub","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"sub","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"sub","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"sub","","",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"f32x2"}}],[11,"sub","std::time","",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"name":"duration"}}],[11,"sub","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"sub","std","",306,null],[11,"sub","","",320,null],[11,"sub","","",307,null],[11,"sub","std::num","",195,null],[11,"sub","std","",317,null],[11,"sub","","",317,null],[11,"sub","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"sub","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"sub","","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"sub","","",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"f64x8"}}],[11,"sub","std","",335,null],[11,"sub","","",306,null],[11,"sub","","",301,null],[11,"sub","","",318,null],[11,"sub","","",332,null],[11,"sub","","",314,null],[11,"sub","std::num","",195,null],[11,"sub","std","",339,null],[11,"sub","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"sub","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"sub","std","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"sub","","",317,null],[11,"sub","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"sub","std::num","",195,null],[11,"sub","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"sub","std","",307,null],[11,"sub","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"sub","","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"sub","","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"sub","","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"sub","std","",319,null],[11,"sub","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"sub","std::num","",195,null],[11,"sub","","",195,null],[11,"sub","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"sub","std","",307,null],[11,"sub","","",301,null],[11,"sub","","",318,null],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"neg","std::simd","",358,{"inputs":[{"name":"self"}],"output":{"name":"i64x4"}}],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"neg","std::simd","",326,{"inputs":[{"name":"self"}],"output":{"name":"i32x2"}}],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"neg","","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"neg","","",195,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"neg","std::simd","",349,{"inputs":[{"name":"self"}],"output":{"name":"f32x16"}}],[11,"neg","std","",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"neg","std::simd","",308,{"inputs":[{"name":"self"}],"output":{"name":"f64x8"}}],[11,"neg","","",303,{"inputs":[{"name":"self"}],"output":{"name":"i32x8"}}],[11,"neg","std","",318,null],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"neg","std","",319,null],[11,"neg","","",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"neg","std::simd","",327,{"inputs":[{"name":"self"}],"output":{"name":"i64x2"}}],[11,"neg","","",331,{"inputs":[{"name":"self"}],"output":{"name":"i8x32"}}],[11,"neg","std","",307,null],[11,"neg","std::simd","",337,{"inputs":[{"name":"self"}],"output":{"name":"i16x8"}}],[11,"neg","","",336,{"inputs":[{"name":"self"}],"output":{"name":"i8x2"}}],[11,"neg","std","",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"neg","std::simd","",305,{"inputs":[{"name":"self"}],"output":{"name":"i32x4"}}],[11,"neg","","",321,{"inputs":[{"name":"self"}],"output":{"name":"f64x2"}}],[11,"neg","","",316,{"inputs":[{"name":"self"}],"output":{"name":"i32x16"}}],[11,"neg","","",356,{"inputs":[{"name":"self"}],"output":{"name":"f32x4"}}],[11,"neg","","",323,{"inputs":[{"name":"self"}],"output":{"name":"f32x2"}}],[11,"neg","std","",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"neg","std","",322,null],[11,"neg","","",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"neg","std::simd","",345,{"inputs":[{"name":"self"}],"output":{"name":"f32x8"}}],[11,"neg","","",352,{"inputs":[{"name":"self"}],"output":{"name":"f64x4"}}],[11,"neg","std","",314,null],[11,"neg","std::simd","",311,{"inputs":[{"name":"self"}],"output":{"name":"i16x4"}}],[11,"neg","","",338,{"inputs":[{"name":"self"}],"output":{"name":"i16x16"}}],[11,"neg","std","",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"neg","","",317,null],[11,"neg","","",335,null],[11,"neg","std::simd","",354,{"inputs":[{"name":"self"}],"output":{"name":"i16x2"}}],[11,"neg","std","",332,null],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"neg","std","",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"neg","std::simd","",325,{"inputs":[{"name":"self"}],"output":{"name":"i8x64"}}],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"neg","std::simd","",313,{"inputs":[{"name":"self"}],"output":{"name":"i8x16"}}],[11,"neg","","",353,{"inputs":[{"name":"self"}],"output":{"name":"i64x8"}}],[11,"neg","","",330,{"inputs":[{"name":"self"}],"output":{"name":"i8x4"}}],[11,"neg","","",348,{"inputs":[{"name":"self"}],"output":{"name":"i8x8"}}],[11,"neg","std","",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"neg","std::num","",195,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"neg","","",195,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"neg","std::simd","",302,{"inputs":[{"name":"self"}],"output":{"name":"i16x32"}}],[11,"build_hasher","std::hash","",453,{"inputs":[{"name":"self"}],"output":{"name":"h"}}],[11,"default","std::sync::atomic","",471,{"inputs":[],"output":{"name":"atomicisize"}}],[11,"default","std::simd","",316,{"inputs":[],"output":{"name":"i32x16"}}],[11,"default","std","",409,null],[11,"default","std::simd","",303,{"inputs":[],"output":{"name":"i32x8"}}],[11,"default","std","",409,null],[11,"default","","",424,null],[11,"default","","Returns the default value of `0`",301,{"inputs":[],"output":{"name":"u32"}}],[11,"default","std::sync::atomic","",465,{"inputs":[],"output":{"name":"atomici8"}}],[11,"default","std::simd","",447,{"inputs":[],"output":{"name":"b8x8"}}],[11,"default","std::cell","Creates an `UnsafeCell`, with the `Default` value for T.",470,{"inputs":[],"output":{"name":"unsafecell"}}],[11,"default","std","",409,null],[11,"default","std::simd","",352,{"inputs":[],"output":{"name":"f64x4"}}],[11,"default","std","",409,null],[11,"default","","Returns the default value of `0`",317,{"inputs":[],"output":{"name":"i16"}}],[11,"default","std::simd","",311,{"inputs":[],"output":{"name":"i16x4"}}],[11,"default","","",327,{"inputs":[],"output":{"name":"i64x2"}}],[11,"default","std","Creates a mutable empty slice.",433,null],[11,"default","std::simd","",349,{"inputs":[],"output":{"name":"f32x16"}}],[11,"default","","",323,{"inputs":[],"output":{"name":"f32x2"}}],[11,"default","std","Returns the default value of `0`",339,{"inputs":[],"output":{"name":"u128"}}],[11,"default","","",409,null],[11,"default","std::sync::atomic","",461,{"inputs":[],"output":{"name":"atomicu8"}}],[11,"default","std","",409,null],[11,"default","std::simd","",342,{"inputs":[],"output":{"name":"u16x32"}}],[11,"default","std","",409,null],[11,"default","","",424,null],[11,"default","std::num","",195,{"inputs":[],"output":{"name":"wrapping"}}],[11,"default","std::fmt","",127,{"inputs":[],"output":{"name":"error"}}],[11,"default","std::time","",309,{"inputs":[],"output":{"name":"duration"}}],[11,"default","std::simd","",353,{"inputs":[],"output":{"name":"i64x8"}}],[11,"default","","",356,{"inputs":[],"output":{"name":"f32x4"}}],[11,"default","","",355,{"inputs":[],"output":{"name":"u64x4"}}],[11,"default","std","",409,null],[11,"default","","",424,null],[11,"default","std::sync::atomic","Creates an `AtomicBool` initialized to `false`.",468,{"inputs":[],"output":{"name":"atomicbool"}}],[11,"default","std::simd","",450,{"inputs":[],"output":{"name":"b8x2"}}],[11,"default","std::sync::atomic","",460,{"inputs":[],"output":{"name":"atomici16"}}],[11,"default","std","",409,null],[11,"default","std::simd","",315,{"inputs":[],"output":{"name":"u8x16"}}],[11,"default","","",440,{"inputs":[],"output":{"name":"b8x64"}}],[11,"default","","",302,{"inputs":[],"output":{"name":"i16x32"}}],[11,"default","","",321,{"inputs":[],"output":{"name":"f64x2"}}],[11,"default","std","",409,null],[11,"default","","",409,null],[11,"default","std::sync::atomic","",469,{"inputs":[],"output":{"name":"atomicu64"}}],[11,"default","std::simd","",348,{"inputs":[],"output":{"name":"i8x8"}}],[11,"default","std::sync::atomic","",464,{"inputs":[],"output":{"name":"atomicusize"}}],[11,"default","std::simd","",350,{"inputs":[],"output":{"name":"u32x16"}}],[11,"default","std::cmp","",4,{"inputs":[],"output":{"name":"reverse"}}],[11,"default","std","Returns the default value of `0`",332,{"inputs":[],"output":{"name":"i64"}}],[11,"default","","",424,null],[11,"default","","Returns the default value of `()`",434,null],[11,"default","","",409,null],[11,"default","std::simd","",347,{"inputs":[],"output":{"name":"u8x4"}}],[11,"default","std","",409,null],[11,"default","std::sync::atomic","",472,{"inputs":[],"output":{"name":"atomicu16"}}],[11,"default","std","",409,null],[11,"default","std::mem","",426,{"inputs":[],"output":{"name":"manuallydrop"}}],[11,"default","std::simd","",354,{"inputs":[],"output":{"name":"i16x2"}}],[11,"default","std","Returns the default value of `\\x00`",432,{"inputs":[],"output":{"name":"char"}}],[11,"default","std::simd","",312,{"inputs":[],"output":{"name":"u16x8"}}],[11,"default","std","Returns the default value of `0`",306,{"inputs":[],"output":{"name":"u64"}}],[11,"default","std::sync::atomic","",463,{"inputs":[],"output":{"name":"atomici64"}}],[11,"default","std","",424,null],[11,"default","std::simd","",441,{"inputs":[],"output":{"name":"b8x16"}}],[11,"default","","",336,{"inputs":[],"output":{"name":"i8x2"}}],[11,"default","","",325,{"inputs":[],"output":{"name":"i8x64"}}],[11,"default","","",442,{"inputs":[],"output":{"name":"b8x32"}}],[11,"default","std","",424,null],[11,"default","std::simd","",338,{"inputs":[],"output":{"name":"i16x16"}}],[11,"default","std::sync::atomic","",462,{"inputs":[],"output":{"name":"atomicu32"}}],[11,"default","std::simd","",357,{"inputs":[],"output":{"name":"u32x4"}}],[11,"default","","",310,{"inputs":[],"output":{"name":"u32x2"}}],[11,"default","std","",409,null],[11,"default","","",409,null],[11,"default","std::option","Returns [`None`].",73,{"inputs":[],"output":{"name":"option"}}],[11,"default","std","",409,null],[11,"default","","",424,null],[11,"default","std::simd","",305,{"inputs":[],"output":{"name":"i32x4"}}],[11,"default","std","",409,null],[11,"default","","Returns the default value of `0`",318,{"inputs":[],"output":{"name":"i128"}}],[11,"default","std::simd","",330,{"inputs":[],"output":{"name":"i8x4"}}],[11,"default","","",345,{"inputs":[],"output":{"name":"f32x8"}}],[11,"default","std","Returns the default value of `0`",335,{"inputs":[],"output":{"name":"i8"}}],[11,"default","","",409,null],[11,"default","","Returns the default value of `0`",322,{"inputs":[],"output":{"name":"isize"}}],[11,"default","","",409,null],[11,"default","","Returns the default value of `false`",431,{"inputs":[],"output":{"name":"bool"}}],[11,"default","std::cell","Creates a `RefCell<T>`, with the `Default` value for T.",455,{"inputs":[],"output":{"name":"refcell"}}],[11,"default","std","",409,null],[11,"default","std::simd","",333,{"inputs":[],"output":{"name":"u16x16"}}],[11,"default","std","Returns the default value of `0.0`",314,{"inputs":[],"output":{"name":"f64"}}],[11,"default","","",409,null],[11,"default","","",424,null],[11,"default","std::simd","",343,{"inputs":[],"output":{"name":"u8x2"}}],[11,"default","std","",409,null],[11,"default","","",409,null],[11,"default","","",409,null],[11,"default","std::simd","",308,{"inputs":[],"output":{"name":"f64x8"}}],[11,"default","std","Returns the default value of `0`",307,{"inputs":[],"output":{"name":"i32"}}],[11,"default","","",409,null],[11,"default","","",424,null],[11,"default","","Returns the default value of `0`",304,{"inputs":[],"output":{"name":"usize"}}],[11,"default","","Returns the default value of `0`",320,{"inputs":[],"output":{"name":"u8"}}],[11,"default","std::simd","",313,{"inputs":[],"output":{"name":"i8x16"}}],[11,"default","","",358,{"inputs":[],"output":{"name":"i64x4"}}],[11,"default","std","",424,null],[11,"default","","Returns the default value of `0.0`",319,{"inputs":[],"output":{"name":"f32"}}],[11,"default","","",409,null],[11,"default","","",409,null],[11,"default","std::simd","",326,{"inputs":[],"output":{"name":"i32x2"}}],[11,"default","std","Returns the default value of `0`",329,{"inputs":[],"output":{"name":"u16"}}],[11,"default","","",409,null],[11,"default","std::simd","",341,{"inputs":[],"output":{"name":"u64x8"}}],[11,"default","std::hash","",453,{"inputs":[],"output":{"name":"buildhasherdefault"}}],[11,"default","std","",409,null],[11,"default","std::sync::atomic","Creates a null `AtomicPtr<T>`.",467,{"inputs":[],"output":{"name":"atomicptr"}}],[11,"default","std::marker","",436,{"inputs":[],"output":{"name":"phantomdata"}}],[11,"default","std::cell","Creates a `Cell<T>`, with the `Default` value for T.",451,{"inputs":[],"output":{"name":"cell"}}],[11,"default","std::simd","",334,{"inputs":[],"output":{"name":"u8x64"}}],[11,"default","","",346,{"inputs":[],"output":{"name":"u16x4"}}],[11,"default","","",324,{"inputs":[],"output":{"name":"u8x8"}}],[11,"default","std::iter","",298,{"inputs":[],"output":{"name":"empty"}}],[11,"default","std::simd","",331,{"inputs":[],"output":{"name":"i8x32"}}],[11,"default","","",344,{"inputs":[],"output":{"name":"u16x2"}}],[11,"default","std::sync::atomic","",466,{"inputs":[],"output":{"name":"atomici32"}}],[11,"default","std::simd","",328,{"inputs":[],"output":{"name":"u64x2"}}],[11,"default","std","",424,null],[11,"default","std::simd","",340,{"inputs":[],"output":{"name":"u32x8"}}],[11,"default","std","",424,null],[11,"default","std::hash","",449,{"inputs":[],"output":{"name":"siphasher"}}],[11,"default","std::simd","",351,{"inputs":[],"output":{"name":"u8x32"}}],[11,"default","std","Creates an empty str",429,{"inputs":[],"output":{"name":"str"}}],[11,"default","","",409,null],[11,"default","std::simd","",444,{"inputs":[],"output":{"name":"b8x4"}}],[11,"default","std","",409,null],[11,"default","","Creates an empty slice.",433,null],[11,"default","","",409,null],[11,"default","std::simd","",337,{"inputs":[],"output":{"name":"i16x8"}}],[11,"sub_assign","","",352,null],[11,"sub_assign","","",355,null],[11,"sub_assign","","",348,null],[11,"sub_assign","std","",306,null],[11,"sub_assign","std::simd","",323,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","","",195,null],[11,"sub_assign","std","",322,null],[11,"sub_assign","","",306,null],[11,"sub_assign","std::time","",309,null],[11,"sub_assign","std","",339,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std","",318,null],[11,"sub_assign","","",307,null],[11,"sub_assign","","",335,null],[11,"sub_assign","std::simd","",347,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std","",329,null],[11,"sub_assign","","",332,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","","",195,null],[11,"sub_assign","std::simd","",305,null],[11,"sub_assign","","",354,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",313,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",340,null],[11,"sub_assign","","",353,null],[11,"sub_assign","","",349,null],[11,"sub_assign","std","",314,null],[11,"sub_assign","std::simd","",357,null],[11,"sub_assign","","",336,null],[11,"sub_assign","","",338,null],[11,"sub_assign","","",326,null],[11,"sub_assign","std","",317,null],[11,"sub_assign","","",320,null],[11,"sub_assign","std::simd","",315,null],[11,"sub_assign","","",350,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std","",332,null],[11,"sub_assign","std::simd","",327,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",330,null],[11,"sub_assign","std","",307,null],[11,"sub_assign","std::simd","",310,null],[11,"sub_assign","std","",304,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",331,null],[11,"sub_assign","std","",314,null],[11,"sub_assign","std::simd","",312,null],[11,"sub_assign","","",343,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",358,null],[11,"sub_assign","","",311,null],[11,"sub_assign","","",333,null],[11,"sub_assign","","",356,null],[11,"sub_assign","","",341,null],[11,"sub_assign","","",345,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",324,null],[11,"sub_assign","","",321,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","","",195,null],[11,"sub_assign","std","",322,null],[11,"sub_assign","std::simd","",328,null],[11,"sub_assign","std","",319,null],[11,"sub_assign","","",329,null],[11,"sub_assign","","",318,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",351,null],[11,"sub_assign","","",344,null],[11,"sub_assign","","",316,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std","",304,null],[11,"sub_assign","std::simd","",302,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","","",195,null],[11,"sub_assign","std::simd","",346,null],[11,"sub_assign","","",303,null],[11,"sub_assign","std","",301,null],[11,"sub_assign","","",319,null],[11,"sub_assign","","",301,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","std::simd","",308,null],[11,"sub_assign","","",325,null],[11,"sub_assign","std","",317,null],[11,"sub_assign","std::num","",195,null],[11,"sub_assign","","",195,null],[11,"sub_assign","","",195,null],[11,"sub_assign","std::simd","",337,null],[11,"sub_assign","","",334,null],[11,"sub_assign","std","",335,null],[11,"sub_assign","std::simd","",342,null],[11,"sub_assign","std","",339,null],[11,"sub_assign","","",320,null],[11,"sub_assign","std::num","",195,null],[11,"rem_assign","std::simd","",346,null],[11,"rem_assign","","",303,null],[11,"rem_assign","std","",329,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","","",195,null],[11,"rem_assign","","",195,null],[11,"rem_assign","","",195,null],[11,"rem_assign","std","",306,null],[11,"rem_assign","std::simd","",353,null],[11,"rem_assign","","",343,null],[11,"rem_assign","std","",304,null],[11,"rem_assign","std::simd","",354,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",344,null],[11,"rem_assign","","",347,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std","",320,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std","",307,null],[11,"rem_assign","","",318,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","","",195,null],[11,"rem_assign","std::simd","",345,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","","",195,null],[11,"rem_assign","std::simd","",312,null],[11,"rem_assign","","",316,null],[11,"rem_assign","std","",335,null],[11,"rem_assign","","",329,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",349,null],[11,"rem_assign","","",351,null],[11,"rem_assign","","",310,null],[11,"rem_assign","std","",306,null],[11,"rem_assign","std::simd","",330,null],[11,"rem_assign","std","",317,null],[11,"rem_assign","std::simd","",341,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","","",195,null],[11,"rem_assign","std","",307,null],[11,"rem_assign","std::simd","",352,null],[11,"rem_assign","std","",335,null],[11,"rem_assign","std::simd","",313,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",315,null],[11,"rem_assign","","",334,null],[11,"rem_assign","std","",319,null],[11,"rem_assign","","",322,null],[11,"rem_assign","","",318,null],[11,"rem_assign","std::simd","",350,null],[11,"rem_assign","std","",314,null],[11,"rem_assign","","",314,null],[11,"rem_assign","std::simd","",308,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",327,null],[11,"rem_assign","","",326,null],[11,"rem_assign","","",311,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",331,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",348,null],[11,"rem_assign","","",302,null],[11,"rem_assign","","",324,null],[11,"rem_assign","","",325,null],[11,"rem_assign","","",340,null],[11,"rem_assign","","",336,null],[11,"rem_assign","std","",317,null],[11,"rem_assign","","",339,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std","",304,null],[11,"rem_assign","std::simd","",321,null],[11,"rem_assign","","",358,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std","",301,null],[11,"rem_assign","std::simd","",357,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",356,null],[11,"rem_assign","std","",320,null],[11,"rem_assign","","",339,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std","",332,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",323,null],[11,"rem_assign","","",342,null],[11,"rem_assign","std","",301,null],[11,"rem_assign","std::simd","",338,null],[11,"rem_assign","","",355,null],[11,"rem_assign","","",328,null],[11,"rem_assign","","",305,null],[11,"rem_assign","std","",322,null],[11,"rem_assign","std::num","",195,null],[11,"rem_assign","std::simd","",333,null],[11,"rem_assign","","",337,null],[11,"rem_assign","std","",319,null],[11,"rem_assign","","",332,null],[11,"bitxor_assign","std::simd","",355,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std","",431,null],[11,"bitxor_assign","std::simd","",336,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",325,null],[11,"bitxor_assign","","",343,null],[11,"bitxor_assign","std","",317,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",302,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",450,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",334,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",316,null],[11,"bitxor_assign","","",331,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",348,null],[11,"bitxor_assign","","",350,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","","",195,null],[11,"bitxor_assign","std::simd","",326,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std","",322,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std","",307,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std","",304,null],[11,"bitxor_assign","","",317,null],[11,"bitxor_assign","","",335,null],[11,"bitxor_assign","","",320,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","","",195,null],[11,"bitxor_assign","std::simd","",444,null],[11,"bitxor_assign","","",442,null],[11,"bitxor_assign","","",347,null],[11,"bitxor_assign","std","",335,null],[11,"bitxor_assign","std::simd","",328,null],[11,"bitxor_assign","","",303,null],[11,"bitxor_assign","std","",320,null],[11,"bitxor_assign","std::simd","",313,null],[11,"bitxor_assign","std","",332,null],[11,"bitxor_assign","","",431,null],[11,"bitxor_assign","std::simd","",333,null],[11,"bitxor_assign","std","",304,null],[11,"bitxor_assign","std::simd","",344,null],[11,"bitxor_assign","","",337,null],[11,"bitxor_assign","std","",318,null],[11,"bitxor_assign","","",306,null],[11,"bitxor_assign","std::simd","",340,null],[11,"bitxor_assign","","",441,null],[11,"bitxor_assign","std","",301,null],[11,"bitxor_assign","","",301,null],[11,"bitxor_assign","","",329,null],[11,"bitxor_assign","std::simd","",305,null],[11,"bitxor_assign","std","",329,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","","",195,null],[11,"bitxor_assign","std","",306,null],[11,"bitxor_assign","std::simd","",341,null],[11,"bitxor_assign","","",312,null],[11,"bitxor_assign","std","",322,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",346,null],[11,"bitxor_assign","","",357,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","","",195,null],[11,"bitxor_assign","std::simd","",315,null],[11,"bitxor_assign","std","",307,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",324,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",330,null],[11,"bitxor_assign","std","",339,null],[11,"bitxor_assign","std::simd","",351,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",447,null],[11,"bitxor_assign","","",327,null],[11,"bitxor_assign","","",440,null],[11,"bitxor_assign","std","",332,null],[11,"bitxor_assign","std::simd","",338,null],[11,"bitxor_assign","","",310,null],[11,"bitxor_assign","","",353,null],[11,"bitxor_assign","","",354,null],[11,"bitxor_assign","std","",339,null],[11,"bitxor_assign","","",318,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",311,null],[11,"bitxor_assign","","",342,null],[11,"bitxor_assign","std::num","",195,null],[11,"bitxor_assign","std::simd","",358,null],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",425,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ptr","",445,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",425,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::mem","",458,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync::atomic","",467,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::ptr","",427,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",423,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"next_back","std::result","",360,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::str","",378,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","std::iter","",404,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",369,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",369,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",369,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","std::str","",393,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",381,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","std::iter","",389,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",389,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",389,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","std::str","",386,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","std::iter","",290,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",290,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"r"}}],[11,"rfold","","",290,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"g"}],"output":{"name":"acc"}}],[11,"next_back","","",293,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::str","",365,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::ascii","",395,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"next_back","std::slice","",382,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",364,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",368,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",403,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",371,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::option","",399,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",374,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::iter","",286,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",286,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",286,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","std::str","",373,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","std::iter","",392,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",392,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",392,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","std::slice","",402,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::iter","",390,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",384,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std","",285,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::str","",391,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",295,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"rfind","","",295,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"next_back","std::iter","",299,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",299,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",299,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next_back","std::slice","",289,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",289,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",289,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","std::iter","",383,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",383,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",383,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next_back","std::str","",377,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::result","",367,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::str","",385,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next_back","","",394,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","std::iter","",294,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",294,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",294,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"rfind","","",294,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"next_back","std::option","",379,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::slice","",297,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::iter","",287,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",287,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",287,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","std::str","",406,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","std::iter","",298,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",288,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",288,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",288,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","","",366,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",366,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"next_back","std::slice","",291,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",291,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"rfold","","",291,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"next_back","std::ops","",34,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",34,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"name":"r"}}],[11,"next_back","std::slice","",296,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::result","",400,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::ops","",48,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::str","",396,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","std::slice","",375,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::iter","",398,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"try_rfold","","",398,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"r"}}],[11,"rfold","","",398,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"fold"}],"output":{"name":"acc"}}],[11,"from_str","std","",335,{"inputs":[{"name":"str"}],"output":{"generics":["i8","parseinterror"],"name":"result"}}],[11,"from_str","","",307,{"inputs":[{"name":"str"}],"output":{"generics":["i32","parseinterror"],"name":"result"}}],[11,"from_str","","",339,{"inputs":[{"name":"str"}],"output":{"generics":["u128","parseinterror"],"name":"result"}}],[11,"from_str","","",432,{"inputs":[{"name":"str"}],"output":{"generics":["char"],"name":"result"}}],[11,"from_str","","",304,{"inputs":[{"name":"str"}],"output":{"generics":["usize","parseinterror"],"name":"result"}}],[11,"from_str","","",322,{"inputs":[{"name":"str"}],"output":{"generics":["isize","parseinterror"],"name":"result"}}],[11,"from_str","","",318,{"inputs":[{"name":"str"}],"output":{"generics":["i128","parseinterror"],"name":"result"}}],[11,"from_str","","",317,{"inputs":[{"name":"str"}],"output":{"generics":["i16","parseinterror"],"name":"result"}}],[11,"from_str","","",320,{"inputs":[{"name":"str"}],"output":{"generics":["u8","parseinterror"],"name":"result"}}],[11,"from_str","","Parse a `bool` from a string.",431,{"inputs":[{"name":"str"}],"output":{"generics":["bool","parseboolerror"],"name":"result"}}],[11,"from_str","","",329,{"inputs":[{"name":"str"}],"output":{"generics":["u16","parseinterror"],"name":"result"}}],[11,"from_str","","Converts a string in base 10 to a float. Accepts an optional decimal exponent.",314,{"inputs":[{"name":"str"}],"output":{"generics":["f64","parsefloaterror"],"name":"result"}}],[11,"from_str","","Converts a string in base 10 to a float. Accepts an optional decimal exponent.",319,{"inputs":[{"name":"str"}],"output":{"generics":["f32","parsefloaterror"],"name":"result"}}],[11,"from_str","","",332,{"inputs":[{"name":"str"}],"output":{"generics":["i64","parseinterror"],"name":"result"}}],[11,"from_str","","",301,{"inputs":[{"name":"str"}],"output":{"generics":["u32","parseinterror"],"name":"result"}}],[11,"from_str","","",306,{"inputs":[{"name":"str"}],"output":{"generics":["u64","parseinterror"],"name":"result"}}],[11,"is_zero","","",307,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",304,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",339,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",317,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",301,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",332,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",318,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",335,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",329,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",425,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",306,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",425,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_zero","","",322,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"bitxor","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"bitxor","","",306,null],[11,"bitxor","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"u16x4"}}],[11,"bitxor","","",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"i8x32"}}],[11,"bitxor","std","",431,null],[11,"bitxor","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"bitxor","","",329,null],[11,"bitxor","","",301,null],[11,"bitxor","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"i16x16"}}],[11,"bitxor","std","",335,null],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"bitxor","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"u32x2"}}],[11,"bitxor","","",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"u64x8"}}],[11,"bitxor","std","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"bitxor","","",301,null],[11,"bitxor","std::simd","",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"bitxor","std","",307,null],[11,"bitxor","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"bitxor","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"u8x8"}}],[11,"bitxor","std","",317,null],[11,"bitxor","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"bitxor","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"u32x8"}}],[11,"bitxor","","",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"i64x8"}}],[11,"bitxor","","",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"u16x8"}}],[11,"bitxor","std","",431,null],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"bitxor","std::simd","",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"bitxor","std","",332,null],[11,"bitxor","","",307,null],[11,"bitxor","","",322,null],[11,"bitxor","","",301,null],[11,"bitxor","std::num","",195,null],[11,"bitxor","std::simd","",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"bitxor","std","",304,null],[11,"bitxor","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"bitxor","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"u8x4"}}],[11,"bitxor","std","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"bitxor","","",320,null],[11,"bitxor","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"i8x4"}}],[11,"bitxor","std","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"bitxor","std::num","",195,null],[11,"bitxor","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"u64x2"}}],[11,"bitxor","","",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"u16x32"}}],[11,"bitxor","std","",304,null],[11,"bitxor","","",329,null],[11,"bitxor","std::num","",195,null],[11,"bitxor","","",195,{"inputs":[{"name":"self"},{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"bitxor","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"u64x4"}}],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"bitxor","","",195,{"inputs":[{"name":"self"},{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"bitxor","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"u8x2"}}],[11,"bitxor","","",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"u8x64"}}],[11,"bitxor","std","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"bitxor","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"i16x32"}}],[11,"bitxor","std","",431,null],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"bitxor","","",195,{"inputs":[{"name":"self"},{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"bitxor","std","",322,null],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"bitxor","std::simd","",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"bitxor","","",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"u8x32"}}],[11,"bitxor","std","",318,null],[11,"bitxor","","",322,null],[11,"bitxor","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"i32x16"}}],[11,"bitxor","std","",329,null],[11,"bitxor","","",320,null],[11,"bitxor","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"i32x8"}}],[11,"bitxor","","",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"i8x8"}}],[11,"bitxor","std","",332,null],[11,"bitxor","","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"bitxor","","",304,null],[11,"bitxor","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"i32x4"}}],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"bitxor","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"u16x16"}}],[11,"bitxor","","",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"bitxor","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"u32x16"}}],[11,"bitxor","","",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"i8x64"}}],[11,"bitxor","std","",318,null],[11,"bitxor","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"bitxor","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"u32x4"}}],[11,"bitxor","std::num","",195,null],[11,"bitxor","std","",431,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"bool"}}],[11,"bitxor","std::simd","",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"bitxor","","",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"u16x2"}}],[11,"bitxor","","",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"i32x2"}}],[11,"bitxor","std","",317,null],[11,"bitxor","","",307,null],[11,"bitxor","std::num","",195,null],[11,"bitxor","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"bitxor","","",339,null],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"bitxor","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"i8x16"}}],[11,"bitxor","std::num","",195,null],[11,"bitxor","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"u8x16"}}],[11,"bitxor","std::num","",195,null],[11,"bitxor","std","",332,null],[11,"bitxor","","",318,null],[11,"bitxor","","",339,null],[11,"bitxor","","",320,null],[11,"bitxor","std::num","",195,{"inputs":[{"name":"self"},{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"bitxor","","",195,null],[11,"bitxor","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"i8x2"}}],[11,"bitxor","std","",339,null],[11,"bitxor","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"i16x4"}}],[11,"bitxor","std","",335,null],[11,"bitxor","","",335,null],[11,"bitxor","std::simd","",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"i64x4"}}],[11,"bitxor","std","",306,null],[11,"bitxor","","",317,null],[11,"bitxor","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"i16x2"}}],[11,"bitxor","std::num","",195,null],[11,"bitxor","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"i64x2"}}],[11,"bitxor","std::num","",195,null],[11,"bitxor","std","",306,null],[11,"bitxor","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"i16x8"}}],[11,"bitxor","std::num","",195,null],[11,"bitxor","","",195,null],[11,"haystack","std::str::pattern","",443,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",443,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",443,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","",443,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"haystack","","",452,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",452,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",452,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_reject","","",452,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"haystack","","",454,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",454,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",454,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"haystack","","",437,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next","","",437,{"inputs":[{"name":"self"}],"output":{"name":"searchstep"}}],[11,"next_match","","",437,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"borrow_mut","std","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",285,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"borrow_mut","","",409,null],[11,"shr","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x4"}}],[11,"shr","","",313,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x16"}}],[11,"shr","","",337,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x8"}}],[11,"shr","std","",317,null],[11,"shr","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x32"}}],[11,"shr","","",338,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x16"}}],[11,"shr","std","",322,null],[11,"shr","","",320,null],[11,"shr","","",306,null],[11,"shr","","",322,null],[11,"shr","","",318,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x8"}}],[11,"shr","std","",320,null],[11,"shr","","",307,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x8"}}],[11,"shr","std","",329,null],[11,"shr","std::simd","",337,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x8"}}],[11,"shr","std","",304,null],[11,"shr","","",332,null],[11,"shr","","",322,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"isize"}}],[11,"shr","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x2"}}],[11,"shr","","",330,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x4"}}],[11,"shr","std","",307,null],[11,"shr","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x16"}}],[11,"shr","","",338,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x16"}}],[11,"shr","","",343,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x2"}}],[11,"shr","std","",306,null],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u64"}}],[11,"shr","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x32"}}],[11,"shr","","",327,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64x2"}}],[11,"shr","std","",318,null],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x2"}}],[11,"shr","std","",339,null],[11,"shr","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x2"}}],[11,"shr","std","",317,null],[11,"shr","","",322,null],[11,"shr","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x2"}}],[11,"shr","","",326,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x2"}}],[11,"shr","std","",306,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64"}}],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8"}}],[11,"shr","std::simd","",353,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64x8"}}],[11,"shr","","",348,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x8"}}],[11,"shr","std","",339,null],[11,"shr","","",318,null],[11,"shr","","",318,null],[11,"shr","std::simd","",310,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x2"}}],[11,"shr","std","",322,null],[11,"shr","std::simd","",350,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x16"}}],[11,"shr","std","",322,null],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u32"}}],[11,"shr","std::simd","",316,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x16"}}],[11,"shr","std","",320,null],[11,"shr","","",318,null],[11,"shr","","",332,null],[11,"shr","","",306,null],[11,"shr","","",320,null],[11,"shr","","",304,null],[11,"shr","","",317,null],[11,"shr","","",320,null],[11,"shr","std::simd","",355,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64x4"}}],[11,"shr","std","",317,null],[11,"shr","","",317,null],[11,"shr","std::simd","",347,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x4"}}],[11,"shr","std","",320,null],[11,"shr","","",301,null],[11,"shr","std::simd","",357,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x4"}}],[11,"shr","std","",339,null],[11,"shr","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x8"}}],[11,"shr","","",351,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x32"}}],[11,"shr","std","",329,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16"}}],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"shr","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x16"}}],[11,"shr","","",326,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x2"}}],[11,"shr","","",313,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x16"}}],[11,"shr","","",343,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x2"}}],[11,"shr","std","",335,null],[11,"shr","","",304,null],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64x8"}}],[11,"shr","std","",317,null],[11,"shr","std::simd","",315,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x16"}}],[11,"shr","std","",318,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i128"}}],[11,"shr","","",301,null],[11,"shr","","",304,null],[11,"shr","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x16"}}],[11,"shr","","",350,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x16"}}],[11,"shr","std","",304,null],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"usize"}}],[11,"shr","","",329,null],[11,"shr","","",322,null],[11,"shr","","",304,null],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64"}}],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x2"}}],[11,"shr","","",313,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x16"}}],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"shr","std","",335,null],[11,"shr","","",329,null],[11,"shr","","",306,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16"}}],[11,"shr","","",335,null],[11,"shr","","",335,null],[11,"shr","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x16"}}],[11,"shr","std","",306,null],[11,"shr","","",329,null],[11,"shr","std::simd","",313,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x16"}}],[11,"shr","std","",339,null],[11,"shr","std::simd","",331,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x32"}}],[11,"shr","","",357,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x4"}}],[11,"shr","std","",332,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64"}}],[11,"shr","","",335,null],[11,"shr","","",322,null],[11,"shr","","",307,null],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"shr","std::simd","",346,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x4"}}],[11,"shr","","",315,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x16"}}],[11,"shr","std","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"shr","","",301,null],[11,"shr","std::simd","",310,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x2"}}],[11,"shr","","",336,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x2"}}],[11,"shr","std","",304,null],[11,"shr","","",329,null],[11,"shr","","",335,null],[11,"shr","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x4"}}],[11,"shr","std","",317,null],[11,"shr","","",322,null],[11,"shr","std::simd","",347,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x4"}}],[11,"shr","","",328,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64x2"}}],[11,"shr","std","",339,null],[11,"shr","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x4"}}],[11,"shr","std","",339,null],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"usize"}}],[11,"shr","","",322,null],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32"}}],[11,"shr","","",329,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"shr","","",320,null],[11,"shr","","",301,null],[11,"shr","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x4"}}],[11,"shr","std","",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"shr","","",317,null],[11,"shr","","",304,null],[11,"shr","","",332,null],[11,"shr","std::simd","",330,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x4"}}],[11,"shr","std","",329,null],[11,"shr","std::simd","",328,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64x2"}}],[11,"shr","std","",335,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8"}}],[11,"shr","","",307,null],[11,"shr","","",335,null],[11,"shr","","",335,null],[11,"shr","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x8"}}],[11,"shr","","",325,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x64"}}],[11,"shr","std","",339,null],[11,"shr","","",318,null],[11,"shr","","",318,null],[11,"shr","","",307,null],[11,"shr","","",307,null],[11,"shr","","",329,null],[11,"shr","std::simd","",325,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x64"}}],[11,"shr","","",341,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64x8"}}],[11,"shr","std","",304,null],[11,"shr","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x8"}}],[11,"shr","std","",329,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16"}}],[11,"shr","std::simd","",324,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x8"}}],[11,"shr","std","",317,null],[11,"shr","","",339,null],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u8"}}],[11,"shr","","",301,null],[11,"shr","std::simd","",334,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x64"}}],[11,"shr","std","",304,null],[11,"shr","","",320,null],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64x8"}}],[11,"shr","std","",318,null],[11,"shr","","",304,null],[11,"shr","std::simd","",328,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64x2"}}],[11,"shr","std","",301,null],[11,"shr","std::simd","",310,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x2"}}],[11,"shr","std","",307,null],[11,"shr","","",329,null],[11,"shr","std::simd","",334,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x64"}}],[11,"shr","","",350,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x16"}}],[11,"shr","std","",322,null],[11,"shr","std::simd","",315,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x16"}}],[11,"shr","","",353,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64x8"}}],[11,"shr","","",316,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x16"}}],[11,"shr","","",327,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64x2"}}],[11,"shr","std","",317,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"shr","std::simd","",302,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x32"}}],[11,"shr","std","",335,null],[11,"shr","std::simd","",355,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64x4"}}],[11,"shr","","",358,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64x4"}}],[11,"shr","","",326,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x2"}}],[11,"shr","","",331,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x32"}}],[11,"shr","","",333,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x16"}}],[11,"shr","std","",335,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8"}}],[11,"shr","","",332,null],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32"}}],[11,"shr","","",339,null],[11,"shr","","",329,null],[11,"shr","","",317,null],[11,"shr","","",335,null],[11,"shr","std::simd","",313,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x16"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u128"}}],[11,"shr","","",335,null],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x2"}}],[11,"shr","std","",301,null],[11,"shr","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x32"}}],[11,"shr","std","",339,null],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u64"}}],[11,"shr","","",307,null],[11,"shr","","",301,null],[11,"shr","","",329,null],[11,"shr","","",332,null],[11,"shr","std::simd","",354,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x2"}}],[11,"shr","","",311,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x4"}}],[11,"shr","std","",307,null],[11,"shr","","",335,null],[11,"shr","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x4"}}],[11,"shr","std","",320,null],[11,"shr","std::simd","",311,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x4"}}],[11,"shr","","",348,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x8"}}],[11,"shr","std","",318,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i128"}}],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32"}}],[11,"shr","","",322,null],[11,"shr","std::simd","",338,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x16"}}],[11,"shr","","",346,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x4"}}],[11,"shr","","",334,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x64"}}],[11,"shr","","",344,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x2"}}],[11,"shr","","",327,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64x2"}}],[11,"shr","","",354,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x2"}}],[11,"shr","std","",335,null],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x2"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"isize"}}],[11,"shr","std::simd","",348,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x8"}}],[11,"shr","","",313,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x16"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u128"}}],[11,"shr","std::simd","",357,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x4"}}],[11,"shr","","",316,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x16"}}],[11,"shr","","",342,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x32"}}],[11,"shr","","",325,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x64"}}],[11,"shr","","",358,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64x4"}}],[11,"shr","std","",307,null],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"shr","std","",329,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16"}}],[11,"shr","","",301,null],[11,"shr","","",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"shr","","",332,null],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x8"}}],[11,"shr","","",355,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64x4"}}],[11,"shr","std","",304,null],[11,"shr","","",320,null],[11,"shr","","",320,null],[11,"shr","std::simd","",305,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x4"}}],[11,"shr","std","",322,null],[11,"shr","","",304,null],[11,"shr","","",335,null],[11,"shr","","",306,null],[11,"shr","","",329,null],[11,"shr","","",307,null],[11,"shr","","",322,null],[11,"shr","","",307,null],[11,"shr","","",332,null],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32"}}],[11,"shr","","",318,null],[11,"shr","","",335,null],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16"}}],[11,"shr","","",301,null],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64"}}],[11,"shr","","",317,null],[11,"shr","","",306,null],[11,"shr","","",318,null],[11,"shr","","",304,null],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64"}}],[11,"shr","","",318,null],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32"}}],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16"}}],[11,"shr","","",318,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i128"}}],[11,"shr","","",304,null],[11,"shr","std::simd","",302,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x32"}}],[11,"shr","","",337,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x8"}}],[11,"shr","","",358,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64x4"}}],[11,"shr","std","",335,null],[11,"shr","","",318,null],[11,"shr","","",339,null],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64"}}],[11,"shr","std::simd","",351,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x32"}}],[11,"shr","","",334,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x64"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"shr","std::simd","",343,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x2"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"isize"}}],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8"}}],[11,"shr","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x16"}}],[11,"shr","","",328,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64x2"}}],[11,"shr","std","",320,null],[11,"shr","","",329,null],[11,"shr","std::simd","",353,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64x8"}}],[11,"shr","","",353,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i64x8"}}],[11,"shr","std","",301,null],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32"}}],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"shr","","",332,null],[11,"shr","","",339,null],[11,"shr","std::simd","",312,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x8"}}],[11,"shr","","",344,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x2"}}],[11,"shr","","",331,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x32"}}],[11,"shr","","",316,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x16"}}],[11,"shr","std","",322,null],[11,"shr","","",307,null],[11,"shr","","",317,null],[11,"shr","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x16"}}],[11,"shr","","",342,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x32"}}],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"shr","std","",320,null],[11,"shr","","",301,null],[11,"shr","","",322,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i16"}}],[11,"shr","","",304,null],[11,"shr","","",318,null],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"usize"}}],[11,"shr","","",306,null],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"shr","std::simd","",342,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x32"}}],[11,"shr","","",316,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x16"}}],[11,"shr","std","",307,null],[11,"shr","","",339,null],[11,"shr","","",304,null],[11,"shr","std::simd","",357,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x4"}}],[11,"shr","std","",304,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"usize"}}],[11,"shr","std::simd","",330,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x4"}}],[11,"shr","std","",306,null],[11,"shr","std::simd","",354,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x2"}}],[11,"shr","","",326,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x2"}}],[11,"shr","std","",301,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32"}}],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"shr","","",317,null],[11,"shr","","",307,null],[11,"shr","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64x2"}}],[11,"shr","std","",339,null],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i32"}}],[11,"shr","","",301,null],[11,"shr","","",332,null],[11,"shr","","",329,null],[11,"shr","","",304,null],[11,"shr","","",339,null],[11,"shr","","",307,null],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32"}}],[11,"shr","","",332,null],[11,"shr","std::simd","",337,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x8"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u128"}}],[11,"shr","","",339,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u128"}}],[11,"shr","","",322,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"isize"}}],[11,"shr","","",335,null],[11,"shr","","",317,null],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"usize"}}],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u8"}}],[11,"shr","","",301,null],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"shr","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x2"}}],[11,"shr","","",312,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x8"}}],[11,"shr","std","",318,null],[11,"shr","std::simd","",325,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x64"}}],[11,"shr","std","",335,null],[11,"shr","","",306,null],[11,"shr","","",317,null],[11,"shr","std::simd","",337,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x8"}}],[11,"shr","std","",301,null],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"usize"}}],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"shr","","",307,null],[11,"shr","std::simd","",327,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64x2"}}],[11,"shr","","",338,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x16"}}],[11,"shr","std","",306,null],[11,"shr","","",339,null],[11,"shr","","",332,null],[11,"shr","","",322,null],[11,"shr","","",339,null],[11,"shr","","",320,null],[11,"shr","","",320,null],[11,"shr","std::simd","",312,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x8"}}],[11,"shr","","",324,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x8"}}],[11,"shr","","",327,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64x2"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x16"}}],[11,"shr","","",357,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x4"}}],[11,"shr","std","",304,null],[11,"shr","std::simd","",346,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x4"}}],[11,"shr","","",337,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x8"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",331,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x32"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"isize"}}],[11,"shr","","",332,null],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64"}}],[11,"shr","","",307,null],[11,"shr","","",320,null],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u64x8"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",353,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64x8"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x2"}}],[11,"shr","std","",307,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32"}}],[11,"shr","","",307,null],[11,"shr","std::simd","",347,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x4"}}],[11,"shr","","",330,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x4"}}],[11,"shr","","",305,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x4"}}],[11,"shr","std","",339,null],[11,"shr","std::simd","",324,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x8"}}],[11,"shr","","",353,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64x8"}}],[11,"shr","","",351,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x32"}}],[11,"shr","std","",320,null],[11,"shr","","",329,null],[11,"shr","std::simd","",334,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x64"}}],[11,"shr","std","",317,null],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"shr","std::simd","",302,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x32"}}],[11,"shr","std","",304,null],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64"}}],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"usize"}}],[11,"shr","","",339,null],[11,"shr","std::simd","",333,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x16"}}],[11,"shr","std","",335,null],[11,"shr","","",329,null],[11,"shr","std::simd","",348,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x8"}}],[11,"shr","std","",304,null],[11,"shr","","",318,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i128"}}],[11,"shr","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x8"}}],[11,"shr","std","",332,null],[11,"shr","","",339,null],[11,"shr","","",322,null],[11,"shr","","",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16"}}],[11,"shr","","",318,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i128"}}],[11,"shr","","",301,null],[11,"shr","","",306,null],[11,"shr","","",339,null],[11,"shr","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x16"}}],[11,"shr","","",355,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64x4"}}],[11,"shr","std","",335,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i8"}}],[11,"shr","","",332,null],[11,"shr","","",329,null],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"shr","","",301,null],[11,"shr","","",322,null],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32"}}],[11,"shr","std::simd","",328,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64x2"}}],[11,"shr","std","",335,null],[11,"shr","std::simd","",334,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x64"}}],[11,"shr","","",342,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x32"}}],[11,"shr","std","",318,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i128"}}],[11,"shr","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x2"}}],[11,"shr","","",342,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x32"}}],[11,"shr","std","",301,null],[11,"shr","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x64"}}],[11,"shr","std","",306,null],[11,"shr","std::simd","",350,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x16"}}],[11,"shr","","",343,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x2"}}],[11,"shr","","",333,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x16"}}],[11,"shr","","",326,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x2"}}],[11,"shr","std","",301,null],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64x8"}}],[11,"shr","std","",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"shr","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x2"}}],[11,"shr","std","",329,null],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x2"}}],[11,"shr","std","",301,null],[11,"shr","","",332,null],[11,"shr","","",318,null],[11,"shr","","",335,null],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"shr","std::simd","",324,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x8"}}],[11,"shr","std","",322,null],[11,"shr","","",339,null],[11,"shr","std::simd","",305,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x4"}}],[11,"shr","std","",317,null],[11,"shr","","",318,null],[11,"shr","std::simd","",358,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64x4"}}],[11,"shr","std","",304,null],[11,"shr","","",304,null],[11,"shr","","",332,null],[11,"shr","std::simd","",313,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x16"}}],[11,"shr","std","",320,null],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32"}}],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x8"}}],[11,"shr","","",348,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x8"}}],[11,"shr","std","",320,null],[11,"shr","","",335,null],[11,"shr","std::simd","",338,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x16"}}],[11,"shr","","",302,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x32"}}],[11,"shr","std","",318,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i128"}}],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x2"}}],[11,"shr","","",315,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x16"}}],[11,"shr","","",346,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x4"}}],[11,"shr","std","",318,null],[11,"shr","std::simd","",312,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x8"}}],[11,"shr","","",340,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x8"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u128"}}],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64x8"}}],[11,"shr","std","",318,null],[11,"shr","","",306,null],[11,"shr","std::simd","",316,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x16"}}],[11,"shr","std","",306,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64"}}],[11,"shr","","",317,null],[11,"shr","std::simd","",305,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x4"}}],[11,"shr","","",315,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8x16"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x2"}}],[11,"shr","std","",307,null],[11,"shr","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x8"}}],[11,"shr","std","",339,null],[11,"shr","","",306,null],[11,"shr","","",301,null],[11,"shr","std::simd","",305,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x4"}}],[11,"shr","","",350,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x16"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"shr","std::simd","",343,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x2"}}],[11,"shr","","",347,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x4"}}],[11,"shr","","",354,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x2"}}],[11,"shr","std","",301,null],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"shr","std::simd","",327,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64x2"}}],[11,"shr","","",334,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x64"}}],[11,"shr","","",354,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x2"}}],[11,"shr","std","",306,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64"}}],[11,"shr","std::simd","",342,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x32"}}],[11,"shr","","",312,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x8"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"isize"}}],[11,"shr","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x32"}}],[11,"shr","std","",307,null],[11,"shr","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x4"}}],[11,"shr","","",305,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x4"}}],[11,"shr","","",353,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64x8"}}],[11,"shr","","",358,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64x4"}}],[11,"shr","std","",306,null],[11,"shr","","",322,null],[11,"shr","","",320,null],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"shr","std","",304,null],[11,"shr","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x8"}}],[11,"shr","std","",335,null],[11,"shr","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x32"}}],[11,"shr","std","",301,null],[11,"shr","std::simd","",353,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64x8"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"shr","","",317,null],[11,"shr","","",322,null],[11,"shr","","",335,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32x8"}}],[11,"shr","std","",306,null],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u16"}}],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"usize"}}],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"shr","std::simd","",333,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x16"}}],[11,"shr","std","",318,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i128"}}],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x8"}}],[11,"shr","std","",318,null],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x8"}}],[11,"shr","","",305,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x4"}}],[11,"shr","","",355,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64x4"}}],[11,"shr","std","",317,null],[11,"shr","","",317,null],[11,"shr","","",335,null],[11,"shr","","",320,null],[11,"shr","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x4"}}],[11,"shr","std","",335,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"shr","std::simd","",348,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x8"}}],[11,"shr","std","",339,null],[11,"shr","std::simd","",347,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x4"}}],[11,"shr","std","",306,null],[11,"shr","","",306,null],[11,"shr","","",335,null],[11,"shr","","",307,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x8"}}],[11,"shr","std","",301,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u32"}}],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u16"}}],[11,"shr","","",329,null],[11,"shr","std::simd","",342,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x32"}}],[11,"shr","std","",339,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16"}}],[11,"shr","","",339,null],[11,"shr","std::simd","",343,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x2"}}],[11,"shr","","",302,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x32"}}],[11,"shr","std","",301,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32"}}],[11,"shr","","",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"shr","","",320,null],[11,"shr","","",317,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i16"}}],[11,"shr","","",317,null],[11,"shr","","",304,null],[11,"shr","std::simd","",311,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x4"}}],[11,"shr","","",310,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x2"}}],[11,"shr","","",330,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8x4"}}],[11,"shr","std","",306,null],[11,"shr","","",335,null],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u32x8"}}],[11,"shr","std","",329,null],[11,"shr","","",322,null],[11,"shr","","",317,null],[11,"shr","","",307,null],[11,"shr","","",307,null],[11,"shr","std::simd","",351,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x32"}}],[11,"shr","","",344,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x2"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u128"}}],[11,"shr","std::simd","",354,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x2"}}],[11,"shr","std","",317,null],[11,"shr","","",318,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i128"}}],[11,"shr","std::simd","",338,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x16"}}],[11,"shr","std","",318,null],[11,"shr","","",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"shr","std::simd","",348,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x8"}}],[11,"shr","","",343,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x2"}}],[11,"shr","","",350,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x16"}}],[11,"shr","","",336,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8x2"}}],[11,"shr","","",355,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64x4"}}],[11,"shr","std","",320,null],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"usize"}}],[11,"shr","","",304,null],[11,"shr","","",301,null],[11,"shr","std::simd","",354,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16x2"}}],[11,"shr","std","",318,null],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64"}}],[11,"shr","","",332,null],[11,"shr","std::simd","",355,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64x4"}}],[11,"shr","std","",320,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u8"}}],[11,"shr","","",306,null],[11,"shr","","",339,null],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16"}}],[11,"shr","","",304,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16"}}],[11,"shr","std::simd","",350,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x16"}}],[11,"shr","std","",317,null],[11,"shr","","",301,null],[11,"shr","","",332,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16"}}],[11,"shr","std::simd","",336,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x2"}}],[11,"shr","std","",318,null],[11,"shr","","",318,null],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16"}}],[11,"shr","","",301,null],[11,"shr","","",304,null],[11,"shr","std::simd","",333,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x16"}}],[11,"shr","","",334,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x64"}}],[11,"shr","std","",339,null],[11,"shr","","",301,null],[11,"shr","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x16"}}],[11,"shr","","",358,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64x4"}}],[11,"shr","std","",320,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8"}}],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"shr","","",320,null],[11,"shr","","",322,null],[11,"shr","std::simd","",311,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x4"}}],[11,"shr","std","",306,null],[11,"shr","","",339,null],[11,"shr","","",329,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16"}}],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8"}}],[11,"shr","std::simd","",334,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x64"}}],[11,"shr","","",325,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x64"}}],[11,"shr","std","",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"shr","std::simd","",328,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64x2"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u128"}}],[11,"shr","","",306,null],[11,"shr","","",322,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"isize"}}],[11,"shr","","",306,null],[11,"shr","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x2"}}],[11,"shr","std","",329,null],[11,"shr","","",304,null],[11,"shr","std::simd","",331,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x32"}}],[11,"shr","","",358,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64x4"}}],[11,"shr","","",342,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x32"}}],[11,"shr","","",351,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x32"}}],[11,"shr","","",311,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x4"}}],[11,"shr","std","",322,null],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x8"}}],[11,"shr","std","",335,null],[11,"shr","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i16x16"}}],[11,"shr","std","",318,null],[11,"shr","std::simd","",325,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x64"}}],[11,"shr","","",342,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x32"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"isize"}}],[11,"shr","std::simd","",325,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x64"}}],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"shr","std::simd","",343,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x2"}}],[11,"shr","std","",322,null],[11,"shr","std::simd","",346,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u16x4"}}],[11,"shr","std","",306,null],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64x8"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",357,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u32x4"}}],[11,"shr","","",312,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x8"}}],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"shr","std::simd","",331,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8x32"}}],[11,"shr","std","",329,null],[11,"shr","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x16"}}],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"shr","std","",332,null],[11,"shr","","",317,null],[11,"shr","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64x2"}}],[11,"shr","","",347,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x4"}}],[11,"shr","std","",307,null],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"shr","std::simd","",328,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64x2"}}],[11,"shr","std","",320,null],[11,"shr","","",317,null],[11,"shr","std::simd","",334,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x64"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i32x8"}}],[11,"shr","","",311,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x4"}}],[11,"shr","std","",307,null],[11,"shr","","",339,null],[11,"shr","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x32"}}],[11,"shr","std","",318,null],[11,"shr","","",322,null],[11,"shr","std::simd","",315,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x16"}}],[11,"shr","","",324,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8x8"}}],[11,"shr","std","",329,null],[11,"shr","","",301,null],[11,"shr","","",329,null],[11,"shr","std::simd","",346,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u16x4"}}],[11,"shr","std","",329,null],[11,"shr","std::simd","",338,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x16"}}],[11,"shr","std","",317,null],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x8"}}],[11,"shr","std","",301,null],[11,"shr","","",301,null],[11,"shr","","",307,null],[11,"shr","std::simd","",344,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x2"}}],[11,"shr","std","",335,null],[11,"shr","","",304,null],[11,"shr","","",322,null],[11,"shr","","",306,null],[11,"shr","std::simd","",344,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x2"}}],[11,"shr","","",310,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u32x2"}}],[11,"shr","","",346,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x4"}}],[11,"shr","std","",301,null],[11,"shr","std::simd","",357,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x4"}}],[11,"shr","std","",322,null],[11,"shr","","",318,null],[11,"shr","","",332,null],[11,"shr","","",301,null],[11,"shr","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x4"}}],[11,"shr","","",350,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x16"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x64"}}],[11,"shr","std","",307,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i32"}}],[11,"shr","","",307,null],[11,"shr","","",318,null],[11,"shr","std::simd","",327,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i64x2"}}],[11,"shr","std","",335,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8"}}],[11,"shr","std::simd","",358,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64x4"}}],[11,"shr","","",348,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x8"}}],[11,"shr","","",341,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u64x8"}}],[11,"shr","","",344,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x2"}}],[11,"shr","std","",339,null],[11,"shr","std::simd","",344,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u16x2"}}],[11,"shr","","",312,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x8"}}],[11,"shr","","",353,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i64x8"}}],[11,"shr","","",327,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64x2"}}],[11,"shr","","",303,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32x8"}}],[11,"shr","std","",332,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i64"}}],[11,"shr","","",301,null],[11,"shr","","",339,null],[11,"shr","","",335,null],[11,"shr","","",318,null],[11,"shr","std::simd","",347,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x4"}}],[11,"shr","","",343,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u8x2"}}],[11,"shr","","",354,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16x2"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64x8"}}],[11,"shr","std","",306,null],[11,"shr","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16x8"}}],[11,"shr","","",333,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u16x16"}}],[11,"shr","","",355,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64x4"}}],[11,"shr","std","",304,null],[11,"shr","","",318,null],[11,"shr","","",301,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32"}}],[11,"shr","","",339,null],[11,"shr","std::simd","",305,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i32x4"}}],[11,"shr","std","",304,null],[11,"shr","","",317,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i16"}}],[11,"shr","std::simd","",315,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x16"}}],[11,"shr","std","",306,null],[11,"shr","","",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"shr","std::simd","",330,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i8x4"}}],[11,"shr","std","",335,null],[11,"shr","","",335,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i8"}}],[11,"shr","std::simd","",330,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8x4"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u128"}}],[11,"shr","std::simd","",337,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i16x8"}}],[11,"shr","std","",320,null],[11,"shr","std::simd","",358,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i64x4"}}],[11,"shr","std","",329,null],[11,"shr","","",320,null],[11,"shr","std::simd","",331,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i8x32"}}],[11,"shr","std","",329,null],[11,"shr","","",329,null],[11,"shr","std::simd","",325,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x64"}}],[11,"shr","std","",335,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i8"}}],[11,"shr","","",335,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i8"}}],[11,"shr","","",332,null],[11,"shr","","",318,null],[11,"shr","","",318,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i128"}}],[11,"shr","","",320,null],[11,"shr","","",335,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x8"}}],[11,"shr","std","",306,null],[11,"shr","std::simd","",354,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x2"}}],[11,"shr","","",340,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32x8"}}],[11,"shr","","",355,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64x4"}}],[11,"shr","","",358,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64x4"}}],[11,"shr","","",357,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x4"}}],[11,"shr","std","",318,null],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8"}}],[11,"shr","","",304,null],[11,"shr","","",320,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8"}}],[11,"shr","","",322,null],[11,"shr","","",307,null],[11,"shr","","",335,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"i8"}}],[11,"shr","","",306,null],[11,"shr","","",304,null],[11,"shr","","",320,null],[11,"shr","","",320,null],[11,"shr","","",301,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x8"}}],[11,"shr","std","",322,null],[11,"shr","","",339,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"u128"}}],[11,"shr","std::simd","",316,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32x16"}}],[11,"shr","std","",317,null],[11,"shr","","",317,null],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"i64"}}],[11,"shr","","",329,null],[11,"shr","std::simd","",324,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x8"}}],[11,"shr","","",310,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u32x2"}}],[11,"shr","std","",322,null],[11,"shr","","",329,null],[11,"shr","","",329,null],[11,"shr","std::simd","",303,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32x8"}}],[11,"shr","std","",318,null],[11,"shr","","",318,null],[11,"shr","","",332,null],[11,"shr","std::simd","",351,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x32"}}],[11,"shr","std","",307,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i32"}}],[11,"shr","","",306,null],[11,"shr","","",322,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"isize"}}],[11,"shr","std::simd","",315,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u8x16"}}],[11,"shr","std","",332,null],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u32x8"}}],[11,"shr","std","",320,null],[11,"shr","std::simd","",311,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x4"}}],[11,"shr","","",310,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32x2"}}],[11,"shr","","",302,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i16x32"}}],[11,"shr","std","",307,null],[11,"shr","","",322,null],[11,"shr","std::simd","",311,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x4"}}],[11,"shr","","",331,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8x32"}}],[11,"shr","std","",322,null],[11,"shr","std::simd","",330,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8x4"}}],[11,"shr","std","",339,null],[11,"shr","","",320,null],[11,"shr","std::simd","",346,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u16x4"}}],[11,"shr","","",347,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8x4"}}],[11,"shr","std","",332,null],[11,"shr","","",317,null],[11,"shr","","",332,null],[11,"shr","","",304,null],[11,"shr","std::simd","",326,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i32x2"}}],[11,"shr","std","",320,null],[11,"shr","std::simd","",344,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u16x2"}}],[11,"shr","","",353,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64x8"}}],[11,"shr","std","",329,null],[11,"shr","","",307,null],[11,"shr","","",329,null],[11,"shr","","",306,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u64"}}],[11,"shr","","",307,null],[11,"shr","","",335,null],[11,"shr","","",320,null],[11,"shr","std::simd","",355,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u64x4"}}],[11,"shr","std","",335,null],[11,"shr","","",339,null],[11,"shr","","",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"shr","std::simd","",305,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x4"}}],[11,"shr","","",316,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i32x16"}}],[11,"shr","std","",307,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i32"}}],[11,"shr","std::simd","",357,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u32x4"}}],[11,"shr","std","",335,null],[11,"shr","std::simd","",326,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"i32x2"}}],[11,"shr","std","",317,null],[11,"shr","std::simd","",324,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u8x8"}}],[11,"shr","std","",306,null],[11,"shr","","",332,null],[11,"shr","std::simd","",351,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u8x32"}}],[11,"shr","","",331,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x32"}}],[11,"shr","std","",322,null],[11,"shr","std::simd","",337,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i16x8"}}],[11,"shr","std","",307,null],[11,"shr","std::simd","",324,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"u8x8"}}],[11,"shr","std","",307,null],[11,"shr","","",332,null],[11,"shr","","",306,null],[11,"shr","std::simd","",333,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u16x16"}}],[11,"shr","","",324,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8x8"}}],[11,"shr","std","",322,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"isize"}}],[11,"shr","","",301,null],[11,"shr","std::simd","",341,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u64x8"}}],[11,"shr","std","",322,null],[11,"shr","","",318,null],[11,"shr","","",339,null],[11,"shr","","",318,null],[11,"shr","","",307,null],[11,"shr","std::simd","",310,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x2"}}],[11,"shr","std","",322,null],[11,"shr","std::simd","",350,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u32x16"}}],[11,"shr","std","",301,null],[11,"shr","std::simd","",312,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16x8"}}],[11,"shr","std","",329,null],[11,"shr","","",304,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"usize"}}],[11,"shr","","",306,null],[11,"shr","std::simd","",330,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i8x4"}}],[11,"shr","std","",335,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i8"}}],[11,"shr","","",317,null],[11,"shr","std::simd","",327,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"i64x2"}}],[11,"shr","std","",332,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i64"}}],[11,"shr","","",329,null],[11,"shr","std::num","",195,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"shr","std","",317,null],[11,"shr","","",329,null],[11,"shr","std::simd","",343,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"u8x2"}}],[11,"shr","","",328,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"u64x2"}}],[11,"shr","","",346,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16x4"}}],[11,"shr","","",313,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8x16"}}],[11,"shr","std","",306,null],[11,"shr","std::simd","",328,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"u64x2"}}],[11,"shr","std","",307,null],[11,"shr","std::simd","",340,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u32x8"}}],[11,"shr","","",302,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i16x32"}}],[11,"shr","std","",332,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"i64"}}],[11,"shr","std::simd","",302,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i16x32"}}],[11,"shr","std","",339,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"u128"}}],[11,"shr","","",320,null],[11,"shr","","",306,null],[11,"shr","","",320,null],[11,"shr","std::simd","",338,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16x16"}}],[11,"shr","std","",317,null],[11,"shr","std::simd","",316,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32x16"}}],[11,"shr","std","",335,null],[11,"shr","","",304,null],[11,"shr","","",318,null],[11,"shr","std::simd","",302,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16x32"}}],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",326,null],[11,"shr_assign","","",348,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",344,null],[11,"shr_assign","","",334,null],[11,"shr_assign","","",333,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",331,null],[11,"shr_assign","","",353,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",316,null],[11,"shr_assign","","",342,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",327,null],[11,"shr_assign","","",311,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",336,null],[11,"shr_assign","","",303,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",338,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",326,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",324,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",355,null],[11,"shr_assign","","",341,null],[11,"shr_assign","","",340,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",311,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",324,null],[11,"shr_assign","","",315,null],[11,"shr_assign","","",305,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","","",339,null],[11,"shr_assign","","",317,null],[11,"shr_assign","std::simd","",325,null],[11,"shr_assign","","",341,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",337,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",340,null],[11,"shr_assign","","",350,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","std::simd","",357,null],[11,"shr_assign","","",327,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",301,null],[11,"shr_assign","","",335,null],[11,"shr_assign","","",306,null],[11,"shr_assign","","",306,null],[11,"shr_assign","std::simd","",315,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",316,null],[11,"shr_assign","","",336,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",317,null],[11,"shr_assign","std::simd","",348,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",316,null],[11,"shr_assign","","",346,null],[11,"shr_assign","","",342,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",338,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",315,null],[11,"shr_assign","","",353,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","","",317,null],[11,"shr_assign","std::simd","",305,null],[11,"shr_assign","","",325,null],[11,"shr_assign","","",310,null],[11,"shr_assign","","",338,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","std::simd","",305,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","std::simd","",303,null],[11,"shr_assign","","",344,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","","",333,null],[11,"shr_assign","","",343,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",327,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",313,null],[11,"shr_assign","","",344,null],[11,"shr_assign","","",303,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","","",348,null],[11,"shr_assign","","",353,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",317,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",339,null],[11,"shr_assign","","",304,null],[11,"shr_assign","std::simd","",328,null],[11,"shr_assign","","",338,null],[11,"shr_assign","","",311,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",350,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",325,null],[11,"shr_assign","","",324,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","std::simd","",305,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",357,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",322,null],[11,"shr_assign","","",304,null],[11,"shr_assign","std::simd","",354,null],[11,"shr_assign","","",355,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",304,null],[11,"shr_assign","std::simd","",334,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",347,null],[11,"shr_assign","","",358,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",311,null],[11,"shr_assign","","",327,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","","",324,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",357,null],[11,"shr_assign","","",338,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",328,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",344,null],[11,"shr_assign","","",311,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",337,null],[11,"shr_assign","","",338,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",355,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","","",307,null],[11,"shr_assign","std::simd","",333,null],[11,"shr_assign","","",358,null],[11,"shr_assign","","",312,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",322,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",341,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","std::simd","",348,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","","",329,null],[11,"shr_assign","","",322,null],[11,"shr_assign","std::simd","",336,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","","",339,null],[11,"shr_assign","std::simd","",316,null],[11,"shr_assign","","",354,null],[11,"shr_assign","","",337,null],[11,"shr_assign","","",340,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",313,null],[11,"shr_assign","","",331,null],[11,"shr_assign","","",331,null],[11,"shr_assign","","",316,null],[11,"shr_assign","","",331,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","std::simd","",325,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",311,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","std::simd","",312,null],[11,"shr_assign","","",341,null],[11,"shr_assign","","",324,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",350,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",304,null],[11,"shr_assign","","",322,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",343,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",339,null],[11,"shr_assign","std::simd","",312,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","","",339,null],[11,"shr_assign","std::simd","",343,null],[11,"shr_assign","","",340,null],[11,"shr_assign","","",348,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",336,null],[11,"shr_assign","","",350,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",351,null],[11,"shr_assign","","",305,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",301,null],[11,"shr_assign","std::simd","",310,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","std::simd","",331,null],[11,"shr_assign","","",303,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","","",322,null],[11,"shr_assign","std::simd","",302,null],[11,"shr_assign","","",325,null],[11,"shr_assign","","",341,null],[11,"shr_assign","","",351,null],[11,"shr_assign","","",313,null],[11,"shr_assign","","",354,null],[11,"shr_assign","","",316,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",312,null],[11,"shr_assign","","",350,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","","",335,null],[11,"shr_assign","","",320,null],[11,"shr_assign","std::simd","",343,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","","",329,null],[11,"shr_assign","","",332,null],[11,"shr_assign","","",306,null],[11,"shr_assign","","",307,null],[11,"shr_assign","std::simd","",343,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",357,null],[11,"shr_assign","","",346,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","","",304,null],[11,"shr_assign","","",307,null],[11,"shr_assign","","",304,null],[11,"shr_assign","","",306,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",358,null],[11,"shr_assign","","",333,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","","",344,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",351,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",334,null],[11,"shr_assign","","",312,null],[11,"shr_assign","","",327,null],[11,"shr_assign","","",316,null],[11,"shr_assign","","",331,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","","",317,null],[11,"shr_assign","","",320,null],[11,"shr_assign","std::simd","",350,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","","",339,null],[11,"shr_assign","std::simd","",353,null],[11,"shr_assign","","",305,null],[11,"shr_assign","","",346,null],[11,"shr_assign","","",310,null],[11,"shr_assign","","",358,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",355,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",320,null],[11,"shr_assign","","",317,null],[11,"shr_assign","std::simd","",313,null],[11,"shr_assign","","",315,null],[11,"shr_assign","","",327,null],[11,"shr_assign","","",316,null],[11,"shr_assign","","",313,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","std::simd","",336,null],[11,"shr_assign","","",336,null],[11,"shr_assign","","",355,null],[11,"shr_assign","","",326,null],[11,"shr_assign","","",327,null],[11,"shr_assign","","",334,null],[11,"shr_assign","","",302,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","std::simd","",347,null],[11,"shr_assign","","",353,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",303,null],[11,"shr_assign","","",312,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",347,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",332,null],[11,"shr_assign","","",332,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",315,null],[11,"shr_assign","","",347,null],[11,"shr_assign","","",346,null],[11,"shr_assign","","",312,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",320,null],[11,"shr_assign","","",318,null],[11,"shr_assign","std::simd","",355,null],[11,"shr_assign","","",326,null],[11,"shr_assign","","",341,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","","",307,null],[11,"shr_assign","","",304,null],[11,"shr_assign","","",339,null],[11,"shr_assign","std::simd","",334,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","std::simd","",337,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",339,null],[11,"shr_assign","std::simd","",330,null],[11,"shr_assign","","",316,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",333,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","std::simd","",326,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",334,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",302,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","","",332,null],[11,"shr_assign","","",307,null],[11,"shr_assign","std::simd","",346,null],[11,"shr_assign","","",302,null],[11,"shr_assign","","",355,null],[11,"shr_assign","","",326,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",354,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",344,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","","",307,null],[11,"shr_assign","","",322,null],[11,"shr_assign","","",318,null],[11,"shr_assign","std::simd","",330,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","std::simd","",312,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",311,null],[11,"shr_assign","","",357,null],[11,"shr_assign","","",303,null],[11,"shr_assign","","",343,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",325,null],[11,"shr_assign","","",325,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",315,null],[11,"shr_assign","","",341,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","","",332,null],[11,"shr_assign","std::simd","",334,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",301,null],[11,"shr_assign","std::simd","",302,null],[11,"shr_assign","","",358,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","std::simd","",353,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","","",322,null],[11,"shr_assign","","",304,null],[11,"shr_assign","std::simd","",348,null],[11,"shr_assign","","",358,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","std::simd","",303,null],[11,"shr_assign","","",358,null],[11,"shr_assign","","",328,null],[11,"shr_assign","","",312,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",350,null],[11,"shr_assign","","",313,null],[11,"shr_assign","","",347,null],[11,"shr_assign","","",351,null],[11,"shr_assign","","",346,null],[11,"shr_assign","","",344,null],[11,"shr_assign","","",330,null],[11,"shr_assign","","",330,null],[11,"shr_assign","","",303,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",353,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",311,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","std::simd","",334,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",329,null],[11,"shr_assign","","",304,null],[11,"shr_assign","","",301,null],[11,"shr_assign","std::simd","",330,null],[11,"shr_assign","","",350,null],[11,"shr_assign","","",347,null],[11,"shr_assign","std","",322,null],[11,"shr_assign","std::simd","",313,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",328,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",354,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",306,null],[11,"shr_assign","","",301,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",347,null],[11,"shr_assign","","",340,null],[11,"shr_assign","","",310,null],[11,"shr_assign","","",303,null],[11,"shr_assign","","",328,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",358,null],[11,"shr_assign","","",337,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","std::simd","",324,null],[11,"shr_assign","","",305,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",340,null],[11,"shr_assign","","",305,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",302,null],[11,"shr_assign","","",355,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",315,null],[11,"shr_assign","","",315,null],[11,"shr_assign","","",327,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",344,null],[11,"shr_assign","","",340,null],[11,"shr_assign","","",313,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",328,null],[11,"shr_assign","","",354,null],[11,"shr_assign","","",326,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","","",322,null],[11,"shr_assign","std::simd","",353,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",357,null],[11,"shr_assign","","",330,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","","",329,null],[11,"shr_assign","","",301,null],[11,"shr_assign","","",306,null],[11,"shr_assign","","",335,null],[11,"shr_assign","","",317,null],[11,"shr_assign","","",306,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",348,null],[11,"shr_assign","","",333,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",312,null],[11,"shr_assign","","",328,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",355,null],[11,"shr_assign","","",351,null],[11,"shr_assign","","",357,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","","",307,null],[11,"shr_assign","std::simd","",324,null],[11,"shr_assign","","",355,null],[11,"shr_assign","","",351,null],[11,"shr_assign","","",326,null],[11,"shr_assign","","",313,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",336,null],[11,"shr_assign","","",346,null],[11,"shr_assign","","",346,null],[11,"shr_assign","","",305,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",310,null],[11,"shr_assign","","",325,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",351,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","std::simd","",328,null],[11,"shr_assign","","",324,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",311,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","std::simd","",331,null],[11,"shr_assign","","",341,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",343,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","std::simd","",328,null],[11,"shr_assign","","",337,null],[11,"shr_assign","","",331,null],[11,"shr_assign","","",354,null],[11,"shr_assign","","",347,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",343,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",311,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","std::simd","",336,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","","",317,null],[11,"shr_assign","","",307,null],[11,"shr_assign","","",306,null],[11,"shr_assign","std::simd","",310,null],[11,"shr_assign","","",343,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","std::simd","",327,null],[11,"shr_assign","","",346,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",306,null],[11,"shr_assign","std::simd","",303,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",310,null],[11,"shr_assign","","",331,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","","",322,null],[11,"shr_assign","","",329,null],[11,"shr_assign","std::simd","",351,null],[11,"shr_assign","","",324,null],[11,"shr_assign","","",338,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","","",322,null],[11,"shr_assign","std::simd","",354,null],[11,"shr_assign","","",310,null],[11,"shr_assign","","",350,null],[11,"shr_assign","","",310,null],[11,"shr_assign","","",327,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","std::simd","",346,null],[11,"shr_assign","std","",329,null],[11,"shr_assign","std::simd","",302,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",318,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","","",334,null],[11,"shr_assign","","",325,null],[11,"shr_assign","","",344,null],[11,"shr_assign","","",337,null],[11,"shr_assign","","",344,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","","",322,null],[11,"shr_assign","","",320,null],[11,"shr_assign","","",304,null],[11,"shr_assign","std::simd","",351,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","std::simd","",333,null],[11,"shr_assign","","",357,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",301,null],[11,"shr_assign","","",332,null],[11,"shr_assign","std::simd","",302,null],[11,"shr_assign","","",326,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","","",332,null],[11,"shr_assign","","",332,null],[11,"shr_assign","std::simd","",342,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","std::simd","",313,null],[11,"shr_assign","","",337,null],[11,"shr_assign","std","",318,null],[11,"shr_assign","","",329,null],[11,"shr_assign","","",318,null],[11,"shr_assign","std::simd","",315,null],[11,"shr_assign","","",353,null],[11,"shr_assign","","",302,null],[11,"shr_assign","","",357,null],[11,"shr_assign","","",358,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",340,null],[11,"shr_assign","","",305,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","","",322,null],[11,"shr_assign","std::simd","",347,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","std::simd","",316,null],[11,"shr_assign","std","",307,null],[11,"shr_assign","std::simd","",341,null],[11,"shr_assign","","",348,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","","",307,null],[11,"shr_assign","std::simd","",353,null],[11,"shr_assign","std","",301,null],[11,"shr_assign","std::simd","",302,null],[11,"shr_assign","","",357,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","","",332,null],[11,"shr_assign","std::simd","",328,null],[11,"shr_assign","","",325,null],[11,"shr_assign","","",354,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","std::simd","",351,null],[11,"shr_assign","std","",320,null],[11,"shr_assign","std::simd","",350,null],[11,"shr_assign","","",340,null],[11,"shr_assign","std","",332,null],[11,"shr_assign","std::simd","",330,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",334,null],[11,"shr_assign","","",310,null],[11,"shr_assign","","",333,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",358,null],[11,"shr_assign","","",338,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",330,null],[11,"shr_assign","","",338,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",354,null],[11,"shr_assign","","",331,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","std::simd","",315,null],[11,"shr_assign","","",338,null],[11,"shr_assign","","",347,null],[11,"shr_assign","std","",339,null],[11,"shr_assign","std::simd","",340,null],[11,"shr_assign","","",324,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","","",307,null],[11,"shr_assign","","",335,null],[11,"shr_assign","std::simd","",337,null],[11,"shr_assign","std","",335,null],[11,"shr_assign","","",306,null],[11,"shr_assign","std::simd","",333,null],[11,"shr_assign","","",348,null],[11,"shr_assign","std","",306,null],[11,"shr_assign","std::simd","",341,null],[11,"shr_assign","","",333,null],[11,"shr_assign","","",326,null],[11,"shr_assign","","",330,null],[11,"shr_assign","std::num","",195,null],[11,"shr_assign","std::simd","",343,null],[11,"shr_assign","","",348,null],[11,"shr_assign","std","",304,null],[11,"shr_assign","std::simd","",330,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",317,null],[11,"shr_assign","std::simd","",336,null],[11,"shr_assign","","",336,null],[11,"shr_assign","","",337,null],[11,"shr_assign","std","",317,null],[11,"shr_assign","","",339,null],[11,"shr_assign","","",318,null],[11,"shr_assign","","",332,null],[11,"fmt","","",335,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",320,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",412,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",420,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",415,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",322,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",418,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",416,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",307,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",195,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",332,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",413,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",306,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",329,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",339,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",318,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",301,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",421,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",317,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::num","",419,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",414,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",411,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",417,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",410,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std","",304,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",285,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"steps_between","","",306,{"inputs":[{"name":"u64"},{"name":"u64"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",306,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u64"],"name":"option"}}],[11,"replace_one","","",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"replace_zero","","",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"add_one","","",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"sub_one","","",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"steps_between","","",317,{"inputs":[{"name":"i16"},{"name":"i16"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",317,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i16"],"name":"option"}}],[11,"replace_one","","",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"replace_zero","","",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"add_one","","",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"sub_one","","",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"steps_between","","",335,{"inputs":[{"name":"i8"},{"name":"i8"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",335,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i8"],"name":"option"}}],[11,"replace_one","","",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"replace_zero","","",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"add_one","","",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"sub_one","","",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"steps_between","","",322,{"inputs":[{"name":"isize"},{"name":"isize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",322,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["isize"],"name":"option"}}],[11,"replace_one","","",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"replace_zero","","",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"add_one","","",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"sub_one","","",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"steps_between","","",320,{"inputs":[{"name":"u8"},{"name":"u8"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",320,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u8"],"name":"option"}}],[11,"replace_one","","",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"replace_zero","","",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"add_one","","",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"sub_one","","",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"steps_between","","",301,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",301,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u32"],"name":"option"}}],[11,"replace_one","","",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"replace_zero","","",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"add_one","","",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"sub_one","","",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"steps_between","","",329,{"inputs":[{"name":"u16"},{"name":"u16"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",329,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u16"],"name":"option"}}],[11,"replace_one","","",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"replace_zero","","",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"add_one","","",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"sub_one","","",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"steps_between","","",304,{"inputs":[{"name":"usize"},{"name":"usize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"replace_one","","",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"replace_zero","","",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"add_one","","",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"sub_one","","",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"steps_between","","",318,{"inputs":[{"name":"i128"},{"name":"i128"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",318,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i128"],"name":"option"}}],[11,"replace_one","","",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"replace_zero","","",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"add_one","","",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"sub_one","","",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"steps_between","","",339,{"inputs":[{"name":"u128"},{"name":"u128"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",339,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["u128"],"name":"option"}}],[11,"replace_one","","",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"replace_zero","","",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"add_one","","",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"sub_one","","",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"steps_between","","",332,{"inputs":[{"name":"i64"},{"name":"i64"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",332,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i64"],"name":"option"}}],[11,"replace_one","","",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"replace_zero","","",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"add_one","","",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"sub_one","","",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"steps_between","","",307,{"inputs":[{"name":"i32"},{"name":"i32"}],"output":{"generics":["usize"],"name":"option"}}],[11,"add_usize","","",307,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["i32"],"name":"option"}}],[11,"replace_one","","",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"replace_zero","","",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"add_one","","",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"sub_one","","",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"fmt","std::string","",124,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::boxed","",476,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",123,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::rc","",138,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",125,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync","",477,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::boxed","",120,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",141,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"default","std::string","Creates an empty `String`.",141,{"inputs":[],"output":{"name":"string"}}],[11,"default","std::borrow","Creates an owned Cow<'a, B> with the default value for the contained owned value.",76,{"inputs":[],"output":{"name":"cow"}}],[11,"default","std::collections::binary_heap","Creates an empty `BinaryHeap<T>`.",478,{"inputs":[],"output":{"name":"binaryheap"}}],[11,"default","std::heap","",479,{"inputs":[],"output":{"name":"heap"}}],[11,"default","std::sync","Creates a new `Arc<T>`, with the `Default` value for `T`.",477,{"inputs":[],"output":{"name":"arc"}}],[11,"default","","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",480,{"inputs":[],"output":{"name":"weak"}}],[11,"default","std::boxed","Creates a `Box<T>`, with the `Default` value for T.",120,{"inputs":[],"output":{"name":"box"}}],[11,"default","std::vec","Creates an empty `Vec<T>`.",137,{"inputs":[],"output":{"name":"vec"}}],[11,"default","std::rc","Creates a new `Rc<T>`, with the `Default` value for `T`.",138,{"inputs":[],"output":{"name":"rc"}}],[11,"default","std::boxed","",120,{"inputs":[],"output":{"generics":["str"],"name":"box"}}],[11,"default","std::rc","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",481,{"inputs":[],"output":{"name":"weak"}}],[11,"default","std::collections::linked_list","Creates an empty `LinkedList<T>`.",482,{"inputs":[],"output":{"name":"linkedlist"}}],[11,"default","std::boxed","",120,{"inputs":[],"output":{"name":"box"}}],[11,"default","std::collections::btree_set","Makes an empty `BTreeSet<T>` with a reasonable choice of B.",483,{"inputs":[],"output":{"name":"btreeset"}}],[11,"default","std::collections::btree_map","Creates an empty `BTreeMap<K, V>`.",484,{"inputs":[],"output":{"name":"btreemap"}}],[11,"default","std::collections::vec_deque","Creates an empty `VecDeque<T>`.",485,{"inputs":[],"output":{"name":"vecdeque"}}],[11,"hash","std::boxed","",120,null],[11,"hash","std::collections::btree_map","",484,null],[11,"hash","std::collections::vec_deque","",485,null],[11,"hash","std::collections::linked_list","",482,null],[11,"hash","std::rc","",138,null],[11,"hash","std::collections::btree_set","",483,null],[11,"hash","std::sync","",477,null],[11,"hash","std::string","",141,null],[11,"hash","std::vec","",137,null],[11,"hash","std::borrow","",76,null],[11,"fmt","std::collections::btree_set","",486,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::linked_list","",487,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::vec_deque","",488,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",125,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::vec","",489,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::vec_deque","",490,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",484,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",491,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::binary_heap","",478,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::vec_deque","",492,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",493,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync","",480,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::vec_deque","",494,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::vec","",495,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_set","",496,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",497,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",498,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::binary_heap","",499,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::linked_list","",500,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync","",477,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::boxed","",120,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",501,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",502,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::binary_heap","",503,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",124,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_set","",504,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::vec_deque","",485,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::linked_list","",482,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",505,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_set","",506,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::rc","",481,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",507,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::binary_heap","",508,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::linked_list","",509,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::vec","",510,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::rc","",138,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::boxed","",476,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::heap","",479,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",123,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",511,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",512,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_set","",483,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",513,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::vec_deque","",514,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::linked_list","",515,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::string","",141,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::binary_heap","",516,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::vec","",137,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",517,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::linked_list","",518,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",519,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_set","",520,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::binary_heap","",521,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_set","",522,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::btree_map","",523,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",107,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::vec","",524,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",525,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::collections::vec_deque","",526,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"add","std::string","",141,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"string"}}],[11,"add","std::borrow","",76,null],[11,"add","","",76,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std","",429,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ne","","",429,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::string","",141,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"ne","","",141,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::string","",141,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",141,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::borrow","",76,null],[11,"ne","","",76,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::collections::linked_list","",482,{"inputs":[{"name":"self"},{"name":"linkedlist"}],"output":{"name":"bool"}}],[11,"ne","","",482,{"inputs":[{"name":"self"},{"name":"linkedlist"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::btree_set","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"ne","","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::sync","Equality for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"ne","","Inequality for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::string","",141,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",141,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::collections::btree_map","",484,{"inputs":[{"name":"self"},{"name":"btreemap"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ne","","",76,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std","",429,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ne","","",429,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::boxed","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"ne","","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",76,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"ne","","",76,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,{"inputs":[{"name":"self"},{"name":"vecdeque"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::borrow","",76,null],[11,"ne","","",76,null],[11,"eq","","",76,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"ne","","",76,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std","",429,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"ne","","",429,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std","",429,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"ne","","",429,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"ne","","",137,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"bool"}}],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","","",137,null],[11,"ne","","",137,null],[11,"eq","std::string","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ne","","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::string","",125,{"inputs":[{"name":"self"},{"name":"parseerror"}],"output":{"name":"bool"}}],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","","",485,null],[11,"eq","std::rc","Equality for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"ne","","Inequality for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"eq","std::collections::vec_deque","",485,null],[11,"eq","std::vec","",137,null],[11,"ne","","",137,null],[11,"eq","std::collections::vec_deque","",485,null],[11,"call_once","std::boxed","",120,{"inputs":[{"name":"self"},{"name":"a"}],"output":{"name":"r"}}],[11,"call_once","","",120,{"inputs":[{"name":"self"},{"name":"a"}],"output":{"name":"r"}}],[11,"make_place","","",527,{"inputs":[{"name":"self"}],"output":{"name":"intermediatebox"}}],[11,"make_place","std::collections::linked_list","",518,{"inputs":[{"name":"self"}],"output":{"name":"frontplace"}}],[11,"make_place","std::vec","",524,{"inputs":[{"name":"self"}],"output":{"name":"placeback"}}],[11,"make_place","std::collections::linked_list","",515,{"inputs":[{"name":"self"}],"output":{"name":"backplace"}}],[11,"make_place","std::collections::vec_deque","",526,{"inputs":[{"name":"self"}],"output":{"name":"placeback"}}],[11,"make_place","","",488,{"inputs":[{"name":"self"}],"output":{"name":"placefront"}}],[11,"borrow_mut","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"borrow_mut","std::vec","",137,null],[11,"concat","std","",433,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"join","","",433,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"vec"}}],[11,"connect","","",433,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"vec"}}],[11,"concat","","",433,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"join","","",433,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"string"}}],[11,"connect","","",433,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"string"}}],[11,"finish","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"write","","",120,null],[11,"write_u8","","",120,null],[11,"write_u16","","",120,null],[11,"write_u32","","",120,null],[11,"write_u64","","",120,null],[11,"write_u128","","",120,null],[11,"write_usize","","",120,null],[11,"write_i8","","",120,null],[11,"write_i16","","",120,null],[11,"write_i32","","",120,null],[11,"write_i64","","",120,null],[11,"write_i128","","",120,null],[11,"write_isize","","",120,null],[11,"to_string","std","",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"to_string","std::borrow","",76,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"to_string","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"extend","std::collections::linked_list","",482,null],[11,"extend","std::collections::btree_set","",483,null],[11,"extend","std::string","",141,null],[11,"extend","std::collections::binary_heap","",478,null],[11,"extend","std::vec","",137,null],[11,"extend","std::collections::linked_list","",482,null],[11,"extend","std::string","",141,null],[11,"extend","std::collections::binary_heap","",478,null],[11,"extend","std::string","",141,null],[11,"extend","","",141,null],[11,"extend","std::collections::btree_map","",484,null],[11,"extend","std::vec","",137,null],[11,"extend","std::string","",141,null],[11,"extend","std::collections::btree_set","",483,null],[11,"extend","std::collections::vec_deque","",485,null],[11,"extend","","",485,null],[11,"extend","std::collections::btree_map","",484,null],[11,"as_mut","std::vec","",137,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"as_mut","","",137,null],[11,"as_mut","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"add_assign","std::string","",141,null],[11,"add_assign","std::borrow","",76,null],[11,"add_assign","","",76,null],[11,"index","std::collections::vec_deque","",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"a"}}],[11,"index","std::string","",141,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"str"}}],[11,"index","","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangetoinclusive"}],"output":{"name":"str"}}],[11,"index","","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangefrom"}],"output":{"name":"str"}}],[11,"index","std::vec","",137,null],[11,"index","std::string","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeinclusive"}],"output":{"name":"str"}}],[11,"index","","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"range"}],"output":{"name":"str"}}],[11,"index","","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeto"}],"output":{"name":"str"}}],[11,"index","std::collections::btree_map","Returns a reference to the value corresponding to the supplied key.",484,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"v"}}],[11,"resume","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"generatorstate"}}],[11,"to_owned","std","",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"clone_into","","",429,null],[11,"to_owned","","",433,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"clone_into","","",433,null],[11,"write_str","std::string","",141,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_char","","",141,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"generics":["error"],"name":"result"}}],[11,"into_iter","std::collections::btree_map","",484,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"into_iter","std::collections::vec_deque","Consumes the `VecDeque` into a front-to-back iterator yielding elements by value.",485,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"into_iter","std::vec","Creates a consuming iterator, that is, one that moves each value out of the vector (from start to end). The vector cannot be used after calling this.",137,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"into_iter","std::collections::linked_list","Consumes the list into an iterator yielding elements by value.",482,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"into_iter","std::collections::binary_heap","Creates a consuming iterator, that is, one that moves each value out of the binary heap in arbitrary order. The binary heap cannot be used after calling this.",478,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"into_iter","std::collections::btree_set","Gets an iterator for moving out the `BTreeSet`'s contents.",483,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"from_str","std::string","",141,{"inputs":[{"name":"str"}],"output":{"generics":["string","parseerror"],"name":"result"}}],[11,"borrow","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"borrow","std::sync","",477,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"borrow","std::vec","",137,null],[11,"borrow","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"borrow","std::borrow","",76,{"inputs":[{"name":"self"}],"output":{"name":"b"}}],[11,"borrow","std::rc","",138,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_ref","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_ref","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"as_ref","std::vec","",137,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"as_ref","","",137,null],[11,"as_ref","std::borrow","",76,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_ref","std::rc","",138,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_ref","std::string","",141,null],[11,"as_ref","std::sync","",477,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"fmt","std::boxed","",120,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",476,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::rc","",138,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::sync","",477,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"finalize","std::boxed","",120,{"inputs":[{"name":"intermediatebox"}],"output":{"name":"box"}}],[11,"alloc","std::heap","",479,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"oom","","",479,null],[11,"dealloc","","",479,null],[11,"usable_size","","",479,null],[11,"realloc","","",479,null],[11,"alloc_zeroed","","",479,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"alloc_excess","","",479,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["excess","allocerr"],"name":"result"}}],[11,"realloc_excess","","",479,null],[11,"grow_in_place","","",479,null],[11,"shrink_in_place","","",479,null],[11,"len","std::collections::btree_map","",523,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","",120,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","std::collections::binary_heap","",508,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::collections::btree_set","",496,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","std::collections::btree_map","",493,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","","",498,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","","",517,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","std::vec","",525,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","std::collections::vec_deque","",490,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","std::collections::binary_heap","",499,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","","",503,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_empty","std::vec","",489,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::collections::btree_set","",520,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","std::collections::vec_deque","",492,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","std::collections::btree_map","",513,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","","",519,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","std::collections::vec_deque","",494,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"t"}],"output":{"name":"rc"}}],[11,"from","std::sync","",477,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"arc"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"rc"}}],[11,"from","std::vec","",137,{"inputs":[{"name":"string"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"from","std::boxed","",120,{"inputs":[{"generics":["str"],"name":"box"}],"output":{"name":"box"}}],[11,"from","std::sync","",477,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"arc"}}],[11,"from","std::string","",141,{"inputs":[{"generics":["str"],"name":"cow"}],"output":{"name":"string"}}],[11,"from","std::vec","",137,null],[11,"from","std::boxed","",120,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"box"}}],[11,"from","std::rc","",138,null],[11,"from","std::borrow","",76,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"box"}}],[11,"from","std::sync","",477,{"inputs":[{"name":"vec"}],"output":{"name":"arc"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"str"}],"output":{"generics":["str"],"name":"rc"}}],[11,"from","std::sync","",477,null],[11,"from","std::vec","",137,{"inputs":[{"name":"box"}],"output":{"name":"vec"}}],[11,"from","std::collections::vec_deque","",485,{"inputs":[{"name":"vec"}],"output":{"name":"vecdeque"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"vec"}],"output":{"name":"rc"}}],[11,"from","std::vec","",137,{"inputs":[{"name":"binaryheap"}],"output":{"name":"vec"}}],[11,"from","","",137,{"inputs":[{"name":"str"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"from","std::borrow","",76,{"inputs":[{"name":"string"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from","","",76,null],[11,"from","std::boxed","",120,{"inputs":[{"name":"t"}],"output":{"name":"box"}}],[11,"from","","",120,{"inputs":[{"name":"vec"}],"output":{"name":"box"}}],[11,"from","std::sync","",477,{"inputs":[{"name":"box"}],"output":{"name":"arc"}}],[11,"from","","",477,{"inputs":[{"name":"t"}],"output":{"name":"arc"}}],[11,"from","std::boxed","",120,{"inputs":[{"name":"pinbox"}],"output":{"name":"box"}}],[11,"from","std::rc","",138,{"inputs":[{"name":"box"}],"output":{"name":"rc"}}],[11,"from","std::vec","",137,{"inputs":[{"name":"vecdeque"}],"output":{"name":"vec"}}],[11,"from","std::boxed","",476,{"inputs":[{"name":"box"}],"output":{"name":"pinbox"}}],[11,"from","","",120,null],[11,"from","std::borrow","",76,{"inputs":[{"name":"vec"}],"output":{"name":"cow"}}],[11,"from","std::string","",141,{"inputs":[{"name":"str"}],"output":{"name":"string"}}],[11,"from","std::vec","",137,{"inputs":[{"name":"cow"}],"output":{"name":"vec"}}],[11,"from","std::collections::binary_heap","",478,{"inputs":[{"name":"vec"}],"output":{"name":"binaryheap"}}],[11,"from","std::string","",141,{"inputs":[{"generics":["str"],"name":"box"}],"output":{"name":"string"}}],[11,"from","std::vec","",137,null],[11,"from_iter","std::collections::binary_heap","",478,{"inputs":[{"name":"i"}],"output":{"name":"binaryheap"}}],[11,"from_iter","std::string","",141,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","std::borrow","",76,{"inputs":[{"name":"i"}],"output":{"name":"cow"}}],[11,"from_iter","","",76,{"inputs":[{"name":"i"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from_iter","std::string","",141,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","","",141,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","std::collections::btree_set","",483,{"inputs":[{"name":"i"}],"output":{"name":"btreeset"}}],[11,"from_iter","std::collections::vec_deque","",485,{"inputs":[{"name":"t"}],"output":{"name":"vecdeque"}}],[11,"from_iter","std::string","",141,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","std::vec","",137,{"inputs":[{"name":"i"}],"output":{"name":"vec"}}],[11,"from_iter","std::collections::btree_map","",484,{"inputs":[{"name":"t"}],"output":{"name":"btreemap"}}],[11,"from_iter","std::string","",141,{"inputs":[{"name":"i"}],"output":{"name":"string"}}],[11,"from_iter","std::borrow","",76,{"inputs":[{"name":"i"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from_iter","","",76,{"inputs":[{"name":"i"}],"output":{"generics":["str"],"name":"cow"}}],[11,"from_iter","std::collections::linked_list","",482,{"inputs":[{"name":"i"}],"output":{"name":"linkedlist"}}],[11,"next","","",509,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",509,null],[11,"next","std::collections::binary_heap","",499,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",499,null],[11,"next","std::collections::linked_list","",487,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",487,null],[11,"next","","",500,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",500,null],[11,"next","std::collections::btree_set","",522,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",522,null],[11,"next","std::collections::btree_map","",523,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",523,null],[11,"next","std::collections::btree_set","",496,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",496,null],[11,"next","std::str","",511,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"option"}}],[11,"size_hint","","",511,null],[11,"next","std::collections::btree_map","",501,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::collections::btree_set","",497,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",497,null],[11,"next","std::collections::vec_deque","",514,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",514,null],[11,"next","std::vec","",525,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",525,null],[11,"count","","",525,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next","","",510,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",510,null],[11,"next","std::collections::btree_map","",498,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",498,null],[11,"next","","",512,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","","",493,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",493,null],[11,"next","std::collections::vec_deque","",492,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",492,null],[11,"next","std::vec","",489,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",489,null],[11,"next","std::collections::vec_deque","",490,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",490,null],[11,"fold","","",490,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",120,null],[11,"nth","","",120,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"next","std::collections::btree_map","",513,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",513,null],[11,"next","std::collections::btree_set","",520,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",520,null],[11,"next","","",504,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",504,null],[11,"next","std::vec","",495,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",495,null],[11,"next","std::collections::btree_set","",506,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",506,null],[11,"next","std::collections::linked_list","",505,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",505,null],[11,"next","std::collections::binary_heap","",503,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",503,null],[11,"next","std::collections::btree_map","",517,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",517,null],[11,"next","std::collections::vec_deque","",494,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",494,null],[11,"fold","","",494,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next","std::collections::btree_map","",519,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",519,null],[11,"next","std::collections::btree_set","",486,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next","std::string","",491,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",491,null],[11,"next","std::collections::binary_heap","",508,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",508,null],[11,"finalize","std::collections::vec_deque","",488,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"finalize","std::vec","",524,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"finalize","std::collections::linked_list","",518,null],[11,"finalize","std::collections::vec_deque","",526,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"finalize","std::boxed","",528,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"finalize","std::collections::binary_heap","",516,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"finalize","std::collections::linked_list","",515,null],[11,"partial_cmp","","",482,{"inputs":[{"name":"self"},{"name":"linkedlist"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::collections::btree_map","",484,{"inputs":[{"name":"self"},{"name":"btreemap"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::sync","Partial comparison for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","Less-than comparison for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"le","","'Less than or equal to' comparison for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"gt","","Greater-than comparison for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"ge","","'Greater than or equal to' comparison for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::collections::btree_set","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"le","","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"gt","","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"ge","","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::rc","Partial comparison for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","Less-than comparison for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"le","","'Less than or equal to' comparison for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"gt","","Greater-than comparison for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"ge","","'Greater than or equal to' comparison for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::vec","",137,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"partial_cmp","std::boxed","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"le","","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"ge","","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"gt","","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::string","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"le","","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"gt","","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"ge","","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"bool"}}],[11,"partial_cmp","std::collections::vec_deque","",485,{"inputs":[{"name":"self"},{"name":"vecdeque"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"pointer","std::vec","",524,null],[11,"pointer","std::collections::linked_list","",515,null],[11,"pointer","std::collections::vec_deque","",526,null],[11,"pointer","std::collections::linked_list","",518,null],[11,"pointer","std::boxed","",528,null],[11,"pointer","std::collections::binary_heap","",516,null],[11,"pointer","std::collections::vec_deque","",488,null],[11,"cmp","std::vec","",137,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"name":"ordering"}}],[11,"cmp","std::borrow","",76,{"inputs":[{"name":"self"},{"name":"cow"}],"output":{"name":"ordering"}}],[11,"cmp","std::string","",141,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"name":"ordering"}}],[11,"cmp","std::rc","Comparison for two `Rc`s.",138,{"inputs":[{"name":"self"},{"name":"rc"}],"output":{"name":"ordering"}}],[11,"cmp","std::boxed","",120,{"inputs":[{"name":"self"},{"name":"box"}],"output":{"name":"ordering"}}],[11,"cmp","std::collections::vec_deque","",485,{"inputs":[{"name":"self"},{"name":"vecdeque"}],"output":{"name":"ordering"}}],[11,"cmp","std::collections::btree_set","",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"ordering"}}],[11,"cmp","std::collections::linked_list","",482,{"inputs":[{"name":"self"},{"name":"linkedlist"}],"output":{"name":"ordering"}}],[11,"cmp","std::collections::btree_map","",484,{"inputs":[{"name":"self"},{"name":"btreemap"}],"output":{"name":"ordering"}}],[11,"cmp","std::sync","Comparison for two `Arc`s.",477,{"inputs":[{"name":"self"},{"name":"arc"}],"output":{"name":"ordering"}}],[11,"drop","std::vec","",489,null],[11,"drop","std::string","",491,null],[11,"drop","std::collections::vec_deque","",485,null],[11,"drop","std::vec","",137,null],[11,"drop","","",510,null],[11,"drop","std::rc","Drops the `Rc`.",138,null],[11,"drop","std::collections::btree_map","",484,null],[11,"drop","std::collections::linked_list","",482,null],[11,"drop","std::sync","Drops the `Weak` pointer.",480,null],[11,"drop","std::collections::btree_map","",517,null],[11,"drop","std::vec","",495,null],[11,"drop","std::rc","Drops the `Weak` pointer.",481,null],[11,"drop","std::collections::vec_deque","",514,null],[11,"drop","std::boxed","",528,null],[11,"drop","std::sync","Drops the `Arc`.",477,null],[11,"drop","std::vec","",525,null],[11,"drop","std::collections::binary_heap","",521,null],[11,"drop","std::boxed","",120,null],[11,"drop","std::collections::linked_list","",505,null],[11,"deref_mut","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"deref_mut","std::boxed","",476,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","std::vec","",137,null],[11,"deref_mut","std::collections::binary_heap","",521,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref_mut","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","","",476,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","std::rc","",138,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","std::borrow","",76,{"inputs":[{"name":"self"}],"output":{"name":"b"}}],[11,"len","std","Returns the length of `self`.",429,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if `self` has a length of zero bytes.",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_char_boundary","","Checks that `index`-th byte lies at the start and/or end of a UTF-8 code point sequence.",429,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"as_bytes","","Converts a string slice to a byte slice. To convert the byte slice back into a string slice, use the [`str::from_utf8`] function.",429,null],[11,"as_bytes_mut","","Converts a mutable string slice to a mutable byte slice. To convert the mutable byte slice back into a mutable string slice, use the [`str::from_utf8_mut`] function.",429,null],[11,"as_ptr","","Converts a string slice to a raw pointer.",429,null],[11,"get","","Returns a subslice of `str`.",429,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[11,"get_mut","","Returns a mutable subslice of `str`.",429,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[11,"get_unchecked","","Returns a unchecked subslice of `str`.",429,null],[11,"get_unchecked_mut","","Returns a mutable, unchecked subslice of `str`.",429,null],[11,"slice_unchecked","","Creates a string slice from another string slice, bypassing safety checks.",429,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":{"name":"str"}}],[11,"slice_mut_unchecked","","Creates a string slice from another string slice, bypassing safety checks. This is generally not recommended, use with caution! For a safe alternative see [`str`] and [`IndexMut`].",429,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"}],"output":{"name":"str"}}],[11,"split_at","","Divide one string slice into two at an index.",429,null],[11,"split_at_mut","","Divide one mutable string slice into two at an index.",429,null],[11,"chars","","Returns an iterator over the [`char`]s of a string slice.",429,{"inputs":[{"name":"self"}],"output":{"name":"chars"}}],[11,"char_indices","","Returns an iterator over the [`char`]s of a string slice, and their positions.",429,{"inputs":[{"name":"self"}],"output":{"name":"charindices"}}],[11,"bytes","","An iterator over the bytes of a string slice.",429,{"inputs":[{"name":"self"}],"output":{"name":"bytes"}}],[11,"split_whitespace","","Split a string slice by whitespace.",429,{"inputs":[{"name":"self"}],"output":{"name":"splitwhitespace"}}],[11,"lines","","An iterator over the lines of a string, as string slices.",429,{"inputs":[{"name":"self"}],"output":{"name":"lines"}}],[11,"lines_any","","An iterator over the lines of a string.",429,{"inputs":[{"name":"self"}],"output":{"name":"linesany"}}],[11,"encode_utf16","","Returns an iterator of `u16` over the string encoded as UTF-16.",429,{"inputs":[{"name":"self"}],"output":{"name":"encodeutf16"}}],[11,"contains","","Returns `true` if the given pattern matches a sub-slice of this string slice.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"bool"}}],[11,"starts_with","","Returns `true` if the given pattern matches a prefix of this string slice.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"bool"}}],[11,"ends_with","","Returns `true` if the given pattern matches a suffix of this string slice.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"bool"}}],[11,"find","","Returns the byte index of the first character of this string slice that matches the pattern.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"rfind","","Returns the byte index of the last character of this string slice that matches the pattern.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"generics":["usize"],"name":"option"}}],[11,"split","","An iterator over substrings of this string slice, separated by characters matched by a pattern.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"split"}}],[11,"rsplit","","An iterator over substrings of the given string slice, separated by characters matched by a pattern and yielded in reverse order.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rsplit"}}],[11,"split_terminator","","An iterator over substrings of the given string slice, separated by characters matched by a pattern.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"splitterminator"}}],[11,"rsplit_terminator","","An iterator over substrings of `self`, separated by characters matched by a pattern and yielded in reverse order.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rsplitterminator"}}],[11,"splitn","","An iterator over substrings of the given string slice, separated by a pattern, restricted to returning at most `n` items.",429,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"splitn"}}],[11,"rsplitn","","An iterator over substrings of this string slice, separated by a pattern, starting from the end of the string, restricted to returning at most `n` items.",429,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"p"}],"output":{"name":"rsplitn"}}],[11,"matches","","An iterator over the disjoint matches of a pattern within the given string slice.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"matches"}}],[11,"rmatches","","An iterator over the disjoint matches of a pattern within this string slice, yielded in reverse order.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rmatches"}}],[11,"match_indices","","An iterator over the disjoint matches of a pattern within this string slice as well as the index that the match starts at.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"matchindices"}}],[11,"rmatch_indices","","An iterator over the disjoint matches of a pattern within `self`, yielded in reverse order along with the index of the match.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"rmatchindices"}}],[11,"trim","","Returns a string slice with leading and trailing whitespace removed.",429,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"trim_left","","Returns a string slice with leading whitespace removed.",429,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"trim_right","","Returns a string slice with trailing whitespace removed.",429,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"trim_matches","","Returns a string slice with all prefixes and suffixes that match a pattern repeatedly removed.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"str"}}],[11,"trim_left_matches","","Returns a string slice with all prefixes that match a pattern repeatedly removed.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"str"}}],[11,"trim_right_matches","","Returns a string slice with all suffixes that match a pattern repeatedly removed.",429,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"str"}}],[11,"parse","","Parses this string slice into another type.",429,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"into_boxed_bytes","","Converts a `Box<str>` into a `Box<[u8]>` without copying or allocating.",429,{"inputs":[{"generics":["str"],"name":"box"}],"output":{"name":"box"}}],[11,"replace","","Replaces all matches of a pattern with another string.",429,{"inputs":[{"name":"self"},{"name":"p"},{"name":"str"}],"output":{"name":"string"}}],[11,"replacen","","Replaces first N matches of a pattern with another string.",429,{"inputs":[{"name":"self"},{"name":"p"},{"name":"str"},{"name":"usize"}],"output":{"name":"string"}}],[11,"to_lowercase","","Returns the lowercase equivalent of this string slice, as a new [`String`].",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"to_uppercase","","Returns the uppercase equivalent of this string slice, as a new [`String`].",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"escape_debug","","Escapes each char in `s` with [`char::escape_debug`].",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"escape_default","","Escapes each char in `s` with [`char::escape_default`].",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"escape_unicode","","Escapes each char in `s` with [`char::escape_unicode`].",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"into_string","","Converts a [`Box<str>`] into a [`String`] without copying or allocating.",429,{"inputs":[{"generics":["str"],"name":"box"}],"output":{"name":"string"}}],[11,"repeat","","Create a [`String`] by repeating a string `n` times.",429,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"string"}}],[11,"is_ascii","","Checks if all characters in this string are within the ASCII range.",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","Returns a copy of this string where each character is mapped to its ASCII upper case equivalent.",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"to_ascii_lowercase","","Returns a copy of this string where each character is mapped to its ASCII lower case equivalent.",429,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"eq_ignore_ascii_case","","Checks that two strings are an ASCII case-insensitive match.",429,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"bool"}}],[11,"make_ascii_uppercase","","Converts this string to its ASCII upper case equivalent in-place.",429,null],[11,"make_ascii_lowercase","","Converts this string to its ASCII lower case equivalent in-place.",429,null],[11,"deref","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"deref","std::collections::binary_heap","",521,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"deref","std::sync","",477,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"len","std","Returns the number of elements in the slice.",433,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the slice has a length of 0.",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"first","","Returns the first element of the slice, or `None` if it is empty.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"first_mut","","Returns a mutable pointer to the first element of the slice, or `None` if it is empty.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_first","","Returns the first and all the rest of the elements of the slice, or `None` if it is empty.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_first_mut","","Returns the first and all the rest of the elements of the slice, or `None` if it is empty.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_last","","Returns the last and all the rest of the elements of the slice, or `None` if it is empty.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_last_mut","","Returns the last and all the rest of the elements of the slice, or `None` if it is empty.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"last","","Returns the last element of the slice, or `None` if it is empty.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"last_mut","","Returns a mutable pointer to the last item in the slice.",433,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"get","","Returns a reference to an element or subslice depending on the type of index.",433,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[11,"get_mut","","Returns a mutable reference to an element or subslice depending on the type of index (see [`get`]) or `None` if the index is out of bounds.",433,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"option"}}],[11,"get_unchecked","","Returns a reference to an element or subslice, without doing bounds checking.",433,null],[11,"get_unchecked_mut","","Returns a mutable reference to an element or subslice, without doing bounds checking.",433,null],[11,"as_ptr","","Returns a raw pointer to the slice's buffer.",433,null],[11,"as_mut_ptr","","Returns an unsafe mutable pointer to the slice's buffer.",433,null],[11,"swap","","Swaps two elements in the slice.",433,null],[11,"reverse","","Reverses the order of elements in the slice, in place.",433,null],[11,"iter","","Returns an iterator over the slice.",433,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Returns an iterator that allows modifying each value.",433,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"windows","","Returns an iterator over all contiguous windows of length `size`. The windows overlap. If the slice is shorter than `size`, the iterator returns no values.",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"windows"}}],[11,"chunks","","Returns an iterator over `chunk_size` elements of the slice at a time. The chunks are slices and do not overlap. If `chunk_size` does not divide the length of the slice, then the last chunk will not have length `chunk_size`.",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"chunks"}}],[11,"exact_chunks","","Returns an iterator over `chunk_size` elements of the slice at a time. The chunks are slices and do not overlap. If `chunk_size` does not divide the length of the slice, then the last up to `chunk_size-1` elements will be omitted.",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"exactchunks"}}],[11,"chunks_mut","","Returns an iterator over `chunk_size` elements of the slice at a time. The chunks are mutable slices, and do not overlap. If `chunk_size` does not divide the length of the slice, then the last chunk will not have length `chunk_size`.",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"chunksmut"}}],[11,"exact_chunks_mut","","Returns an iterator over `chunk_size` elements of the slice at a time. The chunks are mutable slices, and do not overlap. If `chunk_size` does not divide the length of the slice, then the last up to `chunk_size-1` elements will be omitted.",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"exactchunksmut"}}],[11,"split_at","","Divides one slice into two at an index.",433,null],[11,"split_at_mut","","Divides one mutable slice into two at an index.",433,null],[11,"split","","Returns an iterator over subslices separated by elements that match `pred`. The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"split"}}],[11,"split_mut","","Returns an iterator over mutable subslices separated by elements that match `pred`. The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"splitmut"}}],[11,"rsplit","","Returns an iterator over subslices separated by elements that match `pred`, starting at the end of the slice and working backwards. The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"rsplit"}}],[11,"rsplit_mut","","Returns an iterator over mutable subslices separated by elements that match `pred`, starting at the end of the slice and working backwards. The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"rsplitmut"}}],[11,"splitn","","Returns an iterator over subslices separated by elements that match `pred`, limited to returning at most `n` items. The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f"}],"output":{"name":"splitn"}}],[11,"splitn_mut","","Returns an iterator over subslices separated by elements that match `pred`, limited to returning at most `n` items. The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f"}],"output":{"name":"splitnmut"}}],[11,"rsplitn","","Returns an iterator over subslices separated by elements that match `pred` limited to returning at most `n` items. This starts at the end of the slice and works backwards.  The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f"}],"output":{"name":"rsplitn"}}],[11,"rsplitn_mut","","Returns an iterator over subslices separated by elements that match `pred` limited to returning at most `n` items. This starts at the end of the slice and works backwards. The matched element is not contained in the subslices.",433,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f"}],"output":{"name":"rsplitnmut"}}],[11,"contains","","Returns `true` if the slice contains an element with the given value.",433,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"starts_with","","Returns `true` if `needle` is a prefix of the slice.",433,null],[11,"ends_with","","Returns `true` if `needle` is a suffix of the slice.",433,null],[11,"binary_search","","Binary searches this sorted slice for a given element.",433,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"binary_search_by","","Binary searches this sorted slice with a comparator function.",433,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"binary_search_by_key","","Binary searches this sorted slice with a key extraction function.",433,{"inputs":[{"name":"self"},{"name":"b"},{"name":"f"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"sort","","Sorts the slice.",433,null],[11,"sort_by","","Sorts the slice with a comparator function.",433,null],[11,"sort_by_key","","Sorts the slice with a key extraction function.",433,null],[11,"sort_by_cached_key","","Sorts the slice with a key extraction function.",433,null],[11,"sort_unstable","","Sorts the slice, but may not preserve the order of equal elements.",433,null],[11,"sort_unstable_by","","Sorts the slice with a comparator function, but may not preserve the order of equal elements.",433,null],[11,"sort_unstable_by_key","","Sorts the slice with a key extraction function, but may not preserve the order of equal elements.",433,null],[11,"rotate_left","","Rotates the slice in-place such that the first `mid` elements of the slice move to the end while the last `self.len() - mid` elements move to the front. After calling `rotate_left`, the element previously at index `mid` will become the first element in the slice.",433,null],[11,"rotate_right","","Rotates the slice in-place such that the first `self.len() - k` elements of the slice move to the end while the last `k` elements move to the front. After calling `rotate_right`, the element previously at index `self.len() - k` will become the first element in the slice.",433,null],[11,"clone_from_slice","","Copies the elements from `src` into `self`.",433,null],[11,"copy_from_slice","","Copies all elements from `src` into `self`, using a memcpy.",433,null],[11,"swap_with_slice","","Swaps all elements in `self` with those in `other`.",433,null],[11,"to_vec","","Copies `self` into a new `Vec`.",433,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"into_vec","","Converts `self` into a vector without clones or allocation.",433,{"inputs":[{"name":"box"}],"output":{"name":"vec"}}],[11,"deref","std::vec","",137,null],[11,"index_mut","std::string","",141,{"inputs":[{"name":"self"},{"name":"rangefull"}],"output":{"name":"str"}}],[11,"index_mut","std::collections::vec_deque","",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"a"}}],[11,"index_mut","std::string","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"range"}],"output":{"name":"str"}}],[11,"index_mut","","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeto"}],"output":{"name":"str"}}],[11,"index_mut","","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangeinclusive"}],"output":{"name":"str"}}],[11,"index_mut","","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangetoinclusive"}],"output":{"name":"str"}}],[11,"index_mut","std::vec","",137,null],[11,"index_mut","std::string","",141,{"inputs":[{"name":"self"},{"generics":["usize"],"name":"rangefrom"}],"output":{"name":"str"}}],[11,"next_back","std::vec","",489,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::btree_map","",517,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",519,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::vec_deque","",492,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::btree_map","",498,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::binary_heap","",503,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::vec","",510,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::binary_heap","",499,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::btree_map","",493,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::vec_deque","",494,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"rfold","","",494,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next_back","std::collections::btree_map","",513,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::btree_set","",520,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",496,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::string","",491,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next_back","std::collections::binary_heap","",508,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::vec","",525,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::btree_set","",486,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::vec_deque","",490,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"rfold","","",490,{"inputs":[{"name":"self"},{"name":"acc"},{"name":"f"}],"output":{"name":"acc"}}],[11,"next_back","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::linked_list","",487,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::btree_map","",512,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::vec_deque","",514,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::linked_list","",500,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::btree_map","",501,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","","",523,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"next_back","std::collections::linked_list","",509,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"make_place","std::boxed","",528,{"inputs":[],"output":{"name":"intermediatebox"}}],[11,"clone","std::collections::binary_heap","",499,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"clone","std::string","",125,{"inputs":[{"name":"self"}],"output":{"name":"parseerror"}}],[11,"clone","std::collections::vec_deque","",492,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"clone","std::collections::btree_map","",484,{"inputs":[{"name":"self"}],"output":{"name":"btreemap"}}],[11,"clone","std::collections::btree_set","",522,{"inputs":[{"name":"self"}],"output":{"name":"intersection"}}],[11,"clone","std::collections::btree_map","",501,{"inputs":[{"name":"self"}],"output":{"name":"range"}}],[11,"clone","std::heap","",479,{"inputs":[{"name":"self"}],"output":{"name":"heap"}}],[11,"clone","std::str","",511,{"inputs":[{"name":"self"}],"output":{"name":"encodeutf16"}}],[11,"clone","std::collections::linked_list","",509,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::collections::btree_set","",483,{"inputs":[{"name":"self"}],"output":{"name":"btreeset"}}],[11,"clone","std::collections::vec_deque","",485,{"inputs":[{"name":"self"}],"output":{"name":"vecdeque"}}],[11,"clone","std::vec","",525,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"clone","std::boxed","Returns a new box with a `clone()` of this box's contents.",120,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"clone_from","","Copies `source`'s contents into `self` without creating a new allocation.",120,null],[11,"clone","std::collections::btree_map","",523,{"inputs":[{"name":"self"}],"output":{"name":"keys"}}],[11,"clone","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"box"}}],[11,"clone","std::collections::btree_set","",504,{"inputs":[{"name":"self"}],"output":{"name":"symmetricdifference"}}],[11,"clone","std::collections::btree_map","",493,{"inputs":[{"name":"self"}],"output":{"name":"values"}}],[11,"clone","std::collections::btree_set","",486,{"inputs":[{"name":"self"}],"output":{"name":"range"}}],[11,"clone","std::boxed","",527,{"inputs":[{"name":"self"}],"output":{"name":"exchangeheapsingleton"}}],[11,"clone","std::string","",141,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"clone_from","","",141,null],[11,"clone","std::collections::btree_map","",498,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::vec","",137,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"clone_from","","",137,null],[11,"clone","std::sync","Makes a clone of the `Arc` pointer.",477,{"inputs":[{"name":"self"}],"output":{"name":"arc"}}],[11,"clone","std::collections::btree_set","",497,{"inputs":[{"name":"self"}],"output":{"name":"union"}}],[11,"clone","","",506,{"inputs":[{"name":"self"}],"output":{"name":"difference"}}],[11,"clone","std::collections::vec_deque","",494,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::rc","Makes a clone of the `Rc` pointer.",138,{"inputs":[{"name":"self"}],"output":{"name":"rc"}}],[11,"clone","std::borrow","",76,{"inputs":[{"name":"self"}],"output":{"name":"cow"}}],[11,"clone_from","","",76,null],[11,"clone","std::boxed","",120,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"clone","std::collections::binary_heap","",503,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::collections::linked_list","",482,{"inputs":[{"name":"self"}],"output":{"name":"linkedlist"}}],[11,"clone","std::collections::btree_set","",520,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"clone","std::sync","Makes a clone of the `Weak` pointer that points to the same value.",480,{"inputs":[{"name":"self"}],"output":{"name":"weak"}}],[11,"clone","std::collections::linked_list","",487,{"inputs":[{"name":"self"}],"output":{"name":"intoiter"}}],[11,"clone","std::collections::binary_heap","",478,{"inputs":[{"name":"self"}],"output":{"name":"binaryheap"}}],[11,"clone_from","","",478,null],[11,"clone","std::rc","Makes a clone of the `Weak` pointer that points to the same value.",481,{"inputs":[{"name":"self"}],"output":{"name":"weak"}}],[11,"next","std::char","",529,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next","","",530,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next","std::str","",531,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next","std::char","",532,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"size_hint","","",532,null],[11,"fmt","","",126,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",530,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",529,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"eq","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"ne","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"eq","","",126,{"inputs":[{"name":"self"},{"name":"decodeutf16error"}],"output":{"name":"bool"}}],[11,"ne","","",126,{"inputs":[{"name":"self"},{"name":"decodeutf16error"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"le","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"gt","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"ge","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"cmp","","",97,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"ordering"}}],[11,"split_whitespace","std","",429,{"inputs":[{"name":"self"}],"output":{"name":"splitwhitespace"}}],[11,"is_whitespace","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_alphanumeric","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"trim","","",429,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"trim_left","","",429,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"trim_right","","",429,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"next_back","std::str","",531,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"fmt","std::char","",529,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",97,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",532,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",126,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",530,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","std::str","",531,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"clone","","",531,{"inputs":[{"name":"self"}],"output":{"name":"splitwhitespace"}}],[11,"clone","std::char","",530,{"inputs":[{"name":"self"}],"output":{"name":"touppercase"}}],[11,"clone","","",529,{"inputs":[{"name":"self"}],"output":{"name":"tolowercase"}}],[11,"clone","","",126,{"inputs":[{"name":"self"}],"output":{"name":"decodeutf16error"}}],[11,"clone","","",532,{"inputs":[{"name":"self"}],"output":{"name":"decodeutf16"}}],[11,"clone","","",97,{"inputs":[{"name":"self"}],"output":{"name":"unicodeversion"}}],[11,"alloc","std::heap","",533,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"alloc_zeroed","","",533,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["allocerr"],"name":"result"}}],[11,"dealloc","","",533,null],[11,"realloc","","",533,null],[11,"oom","","",533,null],[11,"usable_size","","",533,null],[11,"alloc_excess","","",533,{"inputs":[{"name":"self"},{"name":"layout"}],"output":{"generics":["excess","allocerr"],"name":"result"}}],[11,"realloc_excess","","",533,null],[11,"grow_in_place","","",533,null],[11,"shrink_in_place","","",533,null],[11,"min_value","std","Returns the smallest value that can be represented by this integer type.",322,{"inputs":[],"output":{"name":"isize"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",322,{"inputs":[],"output":{"name":"isize"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",322,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["isize","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",322,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",322,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",322,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",322,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",322,{"inputs":[{"name":"isize"}],"output":{"name":"isize"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",322,{"inputs":[{"name":"isize"}],"output":{"name":"isize"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0` or the division results in overflow.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0` or the division results in overflow.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` if `self == MIN`.",322,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_abs","","Checked absolute value. Computes `self.abs()`, returning `None` if `self == MIN`.",322,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["isize"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"},{"name":"isize"}],"output":{"name":"isize"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"wrapping_abs","","Wrapping (modular) absolute value. Computes `self.abs()`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",322,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",322,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",322,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",322,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",322,null],[11,"overflowing_neg","","Negates self, overflowing if this is equal to the minimum value.",322,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",322,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",322,null],[11,"overflowing_abs","","Computes the absolute value of `self`.",322,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",322,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",322,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"isize"}}],[11,"abs","","Computes the absolute value of `self`.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"signum","","Returns a number representing sign of `self`.",322,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"is_positive","","Returns `true` if `self` is positive and `false` if the number is zero or negative.",322,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_negative","","Returns `true` if `self` is negative and `false` if the number is zero or positive.",322,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",335,{"inputs":[],"output":{"name":"i8"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",335,{"inputs":[],"output":{"name":"i8"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",335,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["i8","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",335,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",335,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",335,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",335,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",335,{"inputs":[{"name":"i8"}],"output":{"name":"i8"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",335,{"inputs":[{"name":"i8"}],"output":{"name":"i8"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0` or the division results in overflow.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0` or the division results in overflow.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` if `self == MIN`.",335,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_abs","","Checked absolute value. Computes `self.abs()`, returning `None` if `self == MIN`.",335,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i8"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"},{"name":"i8"}],"output":{"name":"i8"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"wrapping_abs","","Wrapping (modular) absolute value. Computes `self.abs()`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",335,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",335,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",335,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",335,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",335,null],[11,"overflowing_neg","","Negates self, overflowing if this is equal to the minimum value.",335,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",335,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",335,null],[11,"overflowing_abs","","Computes the absolute value of `self`.",335,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",335,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",335,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i8"}}],[11,"abs","","Computes the absolute value of `self`.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"signum","","Returns a number representing sign of `self`.",335,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"is_positive","","Returns `true` if `self` is positive and `false` if the number is zero or negative.",335,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_negative","","Returns `true` if `self` is negative and `false` if the number is zero or positive.",335,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",317,{"inputs":[],"output":{"name":"i16"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",317,{"inputs":[],"output":{"name":"i16"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",317,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["i16","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",317,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",317,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",317,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",317,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",317,{"inputs":[{"name":"i16"}],"output":{"name":"i16"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",317,{"inputs":[{"name":"i16"}],"output":{"name":"i16"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0` or the division results in overflow.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0` or the division results in overflow.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` if `self == MIN`.",317,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_abs","","Checked absolute value. Computes `self.abs()`, returning `None` if `self == MIN`.",317,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i16"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"},{"name":"i16"}],"output":{"name":"i16"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"wrapping_abs","","Wrapping (modular) absolute value. Computes `self.abs()`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",317,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",317,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",317,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",317,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",317,null],[11,"overflowing_neg","","Negates self, overflowing if this is equal to the minimum value.",317,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",317,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",317,null],[11,"overflowing_abs","","Computes the absolute value of `self`.",317,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",317,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",317,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i16"}}],[11,"abs","","Computes the absolute value of `self`.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"signum","","Returns a number representing sign of `self`.",317,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"is_positive","","Returns `true` if `self` is positive and `false` if the number is zero or negative.",317,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_negative","","Returns `true` if `self` is negative and `false` if the number is zero or positive.",317,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",307,{"inputs":[],"output":{"name":"i32"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",307,{"inputs":[],"output":{"name":"i32"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",307,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["i32","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",307,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",307,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",307,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",307,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",307,{"inputs":[{"name":"i32"}],"output":{"name":"i32"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",307,{"inputs":[{"name":"i32"}],"output":{"name":"i32"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0` or the division results in overflow.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0` or the division results in overflow.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` if `self == MIN`.",307,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_abs","","Checked absolute value. Computes `self.abs()`, returning `None` if `self == MIN`.",307,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i32"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"i32"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"wrapping_abs","","Wrapping (modular) absolute value. Computes `self.abs()`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",307,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",307,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",307,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",307,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",307,null],[11,"overflowing_neg","","Negates self, overflowing if this is equal to the minimum value.",307,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",307,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",307,null],[11,"overflowing_abs","","Computes the absolute value of `self`.",307,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",307,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",307,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i32"}}],[11,"abs","","Computes the absolute value of `self`.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"signum","","Returns a number representing sign of `self`.",307,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"is_positive","","Returns `true` if `self` is positive and `false` if the number is zero or negative.",307,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_negative","","Returns `true` if `self` is negative and `false` if the number is zero or positive.",307,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",332,{"inputs":[],"output":{"name":"i64"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",332,{"inputs":[],"output":{"name":"i64"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",332,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["i64","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",332,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",332,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",332,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",332,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",332,{"inputs":[{"name":"i64"}],"output":{"name":"i64"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",332,{"inputs":[{"name":"i64"}],"output":{"name":"i64"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0` or the division results in overflow.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0` or the division results in overflow.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` if `self == MIN`.",332,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_abs","","Checked absolute value. Computes `self.abs()`, returning `None` if `self == MIN`.",332,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i64"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"},{"name":"i64"}],"output":{"name":"i64"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"wrapping_abs","","Wrapping (modular) absolute value. Computes `self.abs()`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",332,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",332,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",332,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",332,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",332,null],[11,"overflowing_neg","","Negates self, overflowing if this is equal to the minimum value.",332,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",332,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",332,null],[11,"overflowing_abs","","Computes the absolute value of `self`.",332,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",332,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",332,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i64"}}],[11,"abs","","Computes the absolute value of `self`.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"signum","","Returns a number representing sign of `self`.",332,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"is_positive","","Returns `true` if `self` is positive and `false` if the number is zero or negative.",332,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_negative","","Returns `true` if `self` is negative and `false` if the number is zero or positive.",332,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",318,{"inputs":[],"output":{"name":"i128"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",318,{"inputs":[],"output":{"name":"i128"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",318,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["i128","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",318,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",318,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",318,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",318,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",318,{"inputs":[{"name":"i128"}],"output":{"name":"i128"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",318,{"inputs":[{"name":"i128"}],"output":{"name":"i128"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0` or the division results in overflow.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0` or the division results in overflow.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` if `self == MIN`.",318,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_abs","","Checked absolute value. Computes `self.abs()`, returning `None` if `self == MIN`.",318,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i128"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"},{"name":"i128"}],"output":{"name":"i128"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"wrapping_abs","","Wrapping (modular) absolute value. Computes `self.abs()`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",318,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",318,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",318,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",318,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",318,null],[11,"overflowing_neg","","Negates self, overflowing if this is equal to the minimum value.",318,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",318,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",318,null],[11,"overflowing_abs","","Computes the absolute value of `self`.",318,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",318,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",318,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"i128"}}],[11,"abs","","Computes the absolute value of `self`.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"signum","","Returns a number representing sign of `self`.",318,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"is_positive","","Returns `true` if `self` is positive and `false` if the number is zero or negative.",318,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_negative","","Returns `true` if `self` is negative and `false` if the number is zero or positive.",318,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",304,{"inputs":[],"output":{"name":"usize"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",304,{"inputs":[],"output":{"name":"usize"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",304,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["usize","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",304,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",304,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",304,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",304,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",304,{"inputs":[{"name":"usize"}],"output":{"name":"usize"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",304,{"inputs":[{"name":"usize"}],"output":{"name":"usize"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0`.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0`.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` unless `self == 0`.",304,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["usize"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["usize"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`. Wrapped division on unsigned types is just normal division. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`. Wrapped remainder calculation on unsigned types is just the regular remainder calculation. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",304,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",304,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",304,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",304,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",304,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",304,null],[11,"overflowing_neg","","Negates self in an overflowing fashion.",304,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",304,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",304,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",304,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",304,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"usize"}}],[11,"is_power_of_two","","Returns `true` if and only if `self == 2^k` for some `k`.",304,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_power_of_two","","Returns the smallest power of two greater than or equal to `self`.",304,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"checked_next_power_of_two","","Returns the smallest power of two greater than or equal to `n`. If the next power of two is greater than the type's maximum value, `None` is returned, otherwise the power of two is wrapped in `Some`.",304,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",320,{"inputs":[],"output":{"name":"u8"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",320,{"inputs":[],"output":{"name":"u8"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",320,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["u8","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",320,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",320,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",320,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",320,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",320,{"inputs":[{"name":"u8"}],"output":{"name":"u8"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",320,{"inputs":[{"name":"u8"}],"output":{"name":"u8"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0`.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0`.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` unless `self == 0`.",320,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u8"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u8"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`. Wrapped division on unsigned types is just normal division. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`. Wrapped remainder calculation on unsigned types is just the regular remainder calculation. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"u8"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",320,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",320,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",320,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",320,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",320,null],[11,"overflowing_neg","","Negates self in an overflowing fashion.",320,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",320,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",320,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",320,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",320,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u8"}}],[11,"is_power_of_two","","Returns `true` if and only if `self == 2^k` for some `k`.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_power_of_two","","Returns the smallest power of two greater than or equal to `self`.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"checked_next_power_of_two","","Returns the smallest power of two greater than or equal to `n`. If the next power of two is greater than the type's maximum value, `None` is returned, otherwise the power of two is wrapped in `Some`.",320,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"option"}}],[11,"is_ascii","","Checks if the value is within the ASCII range.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","Makes a copy of the value in its ASCII upper case equivalent.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"to_ascii_lowercase","","Makes a copy of the value in its ASCII lower case equivalent.",320,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"eq_ignore_ascii_case","","Checks that two values are an ASCII case-insensitive match.",320,{"inputs":[{"name":"self"},{"name":"u8"}],"output":{"name":"bool"}}],[11,"make_ascii_uppercase","","Converts this value to its ASCII upper case equivalent in-place.",320,null],[11,"make_ascii_lowercase","","Converts this value to its ASCII lower case equivalent in-place.",320,null],[11,"is_ascii_alphabetic","","Checks if the value is an ASCII alphabetic character:",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_uppercase","","Checks if the value is an ASCII uppercase character: U+0041 'A' ... U+005A 'Z'.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_lowercase","","Checks if the value is an ASCII lowercase character: U+0061 'a' ... U+007A 'z'.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_alphanumeric","","Checks if the value is an ASCII alphanumeric character:",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_digit","","Checks if the value is an ASCII decimal digit: U+0030 '0' ... U+0039 '9'.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_hexdigit","","Checks if the value is an ASCII hexadecimal digit:",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_punctuation","","Checks if the value is an ASCII punctuation character:",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_graphic","","Checks if the value is an ASCII graphic character: U+0021 '!' ... U+007E '~'.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_whitespace","","Checks if the value is an ASCII whitespace character: U+0020 SPACE, U+0009 HORIZONTAL TAB, U+000A LINE FEED, U+000C FORM FEED, or U+000D CARRIAGE RETURN.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_control","","Checks if the value is an ASCII control character: U+0000 NUL ... U+001F UNIT SEPARATOR, or U+007F DELETE. Note that most ASCII whitespace characters are control characters, but SPACE is not.",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",329,{"inputs":[],"output":{"name":"u16"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",329,{"inputs":[],"output":{"name":"u16"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",329,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["u16","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",329,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",329,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",329,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",329,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",329,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",329,{"inputs":[{"name":"u16"}],"output":{"name":"u16"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0`.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0`.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` unless `self == 0`.",329,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u16"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u16"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`. Wrapped division on unsigned types is just normal division. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`. Wrapped remainder calculation on unsigned types is just the regular remainder calculation. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",329,{"inputs":[{"name":"self"},{"name":"u16"}],"output":{"name":"u16"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",329,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",329,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",329,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",329,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",329,null],[11,"overflowing_neg","","Negates self in an overflowing fashion.",329,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",329,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",329,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",329,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",329,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u16"}}],[11,"is_power_of_two","","Returns `true` if and only if `self == 2^k` for some `k`.",329,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_power_of_two","","Returns the smallest power of two greater than or equal to `self`.",329,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"checked_next_power_of_two","","Returns the smallest power of two greater than or equal to `n`. If the next power of two is greater than the type's maximum value, `None` is returned, otherwise the power of two is wrapped in `Some`.",329,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"option"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",301,{"inputs":[],"output":{"name":"u32"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",301,{"inputs":[],"output":{"name":"u32"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",301,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["u32","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",301,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",301,{"inputs":[{"name":"u32"}],"output":{"name":"u32"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0`.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0`.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` unless `self == 0`.",301,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`. Wrapped division on unsigned types is just normal division. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`. Wrapped remainder calculation on unsigned types is just the regular remainder calculation. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",301,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",301,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",301,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",301,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",301,null],[11,"overflowing_neg","","Negates self in an overflowing fashion.",301,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",301,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",301,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",301,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",301,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u32"}}],[11,"is_power_of_two","","Returns `true` if and only if `self == 2^k` for some `k`.",301,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_power_of_two","","Returns the smallest power of two greater than or equal to `self`.",301,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"checked_next_power_of_two","","Returns the smallest power of two greater than or equal to `n`. If the next power of two is greater than the type's maximum value, `None` is returned, otherwise the power of two is wrapped in `Some`.",301,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"option"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",306,{"inputs":[],"output":{"name":"u64"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",306,{"inputs":[],"output":{"name":"u64"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",306,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["u64","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",306,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",306,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",306,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",306,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",306,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",306,{"inputs":[{"name":"u64"}],"output":{"name":"u64"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0`.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0`.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` unless `self == 0`.",306,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u64"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u64"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`. Wrapped division on unsigned types is just normal division. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`. Wrapped remainder calculation on unsigned types is just the regular remainder calculation. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",306,{"inputs":[{"name":"self"},{"name":"u64"}],"output":{"name":"u64"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",306,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",306,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",306,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",306,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",306,null],[11,"overflowing_neg","","Negates self in an overflowing fashion.",306,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",306,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",306,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",306,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",306,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u64"}}],[11,"is_power_of_two","","Returns `true` if and only if `self == 2^k` for some `k`.",306,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_power_of_two","","Returns the smallest power of two greater than or equal to `self`.",306,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"checked_next_power_of_two","","Returns the smallest power of two greater than or equal to `n`. If the next power of two is greater than the type's maximum value, `None` is returned, otherwise the power of two is wrapped in `Some`.",306,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"option"}}],[11,"min_value","","Returns the smallest value that can be represented by this integer type.",339,{"inputs":[],"output":{"name":"u128"}}],[11,"max_value","","Returns the largest value that can be represented by this integer type.",339,{"inputs":[],"output":{"name":"u128"}}],[11,"from_str_radix","","Converts a string slice in a given base to an integer.",339,{"inputs":[{"name":"str"},{"name":"u32"}],"output":{"generics":["u128","parseinterror"],"name":"result"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",339,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",339,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",339,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",339,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"reverse_bits","","Reverses the bit pattern of the integer.",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",339,{"inputs":[{"name":"u128"}],"output":{"name":"u128"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",339,{"inputs":[{"name":"u128"}],"output":{"name":"u128"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"checked_add","","Checked integer addition. Computes `self + rhs`, returning `None` if overflow occurred.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_sub","","Checked integer subtraction. Computes `self - rhs`, returning `None` if overflow occurred.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_mul","","Checked integer multiplication. Computes `self * rhs`, returning `None` if overflow occurred.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_div","","Checked integer division. Computes `self / rhs`, returning `None` if `rhs == 0`.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_rem","","Checked integer remainder. Computes `self % rhs`, returning `None` if `rhs == 0`.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_neg","","Checked negation. Computes `-self`, returning `None` unless `self == 0`.",339,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_shl","","Checked shift left. Computes `self << rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_shr","","Checked shift right. Computes `self >> rhs`, returning `None` if `rhs` is larger than or equal to the number of bits in `self`.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u128"],"name":"option"}}],[11,"checked_pow","","Checked exponentiation. Computes `self.pow(exp)`, returning `None` if overflow occurred.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u128"],"name":"option"}}],[11,"saturating_add","","Saturating integer addition. Computes `self + rhs`, saturating at the numeric bounds instead of overflowing.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"saturating_sub","","Saturating integer subtraction. Computes `self - rhs`, saturating at the numeric bounds instead of overflowing.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"saturating_mul","","Saturating integer multiplication. Computes `self * rhs`, saturating at the numeric bounds instead of overflowing.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"saturating_pow","","Saturating integer exponentiation. Computes `self.pow(exp)`, saturating at the numeric bounds instead of overflowing.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"wrapping_add","","Wrapping (modular) addition. Computes `self + rhs`, wrapping around at the boundary of the type.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"wrapping_sub","","Wrapping (modular) subtraction. Computes `self - rhs`, wrapping around at the boundary of the type.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"wrapping_mul","","Wrapping (modular) multiplication. Computes `self * rhs`, wrapping around at the boundary of the type.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"wrapping_div","","Wrapping (modular) division. Computes `self / rhs`. Wrapped division on unsigned types is just normal division. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"wrapping_rem","","Wrapping (modular) remainder. Computes `self % rhs`. Wrapped remainder calculation on unsigned types is just the regular remainder calculation. There's no way wrapping could ever happen. This function exists, so that all operations are accounted for in the wrapping operations.",339,{"inputs":[{"name":"self"},{"name":"u128"}],"output":{"name":"u128"}}],[11,"wrapping_neg","","Wrapping (modular) negation. Computes `-self`, wrapping around at the boundary of the type.",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"wrapping_shl","","Panic-free bitwise shift-left; yields `self << mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"wrapping_shr","","Panic-free bitwise shift-right; yields `self >> mask(rhs)`, where `mask` removes any high-order bits of `rhs` that would cause the shift to exceed the bitwidth of the type.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"wrapping_pow","","Wrapping (modular) exponentiation. Computes `self.pow(exp)`, wrapping around at the boundary of the type.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"overflowing_add","","Calculates `self` + `rhs`",339,null],[11,"overflowing_sub","","Calculates `self` - `rhs`",339,null],[11,"overflowing_mul","","Calculates the multiplication of `self` and `rhs`.",339,null],[11,"overflowing_div","","Calculates the divisor when `self` is divided by `rhs`.",339,null],[11,"overflowing_rem","","Calculates the remainder when `self` is divided by `rhs`.",339,null],[11,"overflowing_neg","","Negates self in an overflowing fashion.",339,null],[11,"overflowing_shl","","Shifts self left by `rhs` bits.",339,null],[11,"overflowing_shr","","Shifts self right by `rhs` bits.",339,null],[11,"overflowing_pow","","Raises self to the power of `exp`, using exponentiation by squaring.",339,null],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",339,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"u128"}}],[11,"is_power_of_two","","Returns `true` if and only if `self == 2^k` for some `k`.",339,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"next_power_of_two","","Returns the smallest power of two greater than or equal to `self`.",339,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"checked_next_power_of_two","","Returns the smallest power of two greater than or equal to `n`. If the next power of two is greater than the type's maximum value, `None` is returned, otherwise the power of two is wrapped in `Some`.",339,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"option"}}],[11,"is_digit","","Checks if a `char` is a digit in the given radix.",432,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"name":"bool"}}],[11,"to_digit","","Converts a `char` to a digit in the given radix.",432,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"option"}}],[11,"escape_unicode","","Returns an iterator that yields the hexadecimal Unicode escape of a character as `char`s.",432,{"inputs":[{"name":"self"}],"output":{"name":"escapeunicode"}}],[11,"escape_debug","","Returns an iterator that yields the literal escape code of a character as `char`s.",432,{"inputs":[{"name":"self"}],"output":{"name":"escapedebug"}}],[11,"escape_default","","Returns an iterator that yields the literal escape code of a character as `char`s.",432,{"inputs":[{"name":"self"}],"output":{"name":"escapedefault"}}],[11,"len_utf8","","Returns the number of bytes this `char` would need if encoded in UTF-8.",432,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len_utf16","","Returns the number of 16-bit code units this `char` would need if encoded in UTF-16.",432,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"encode_utf8","","Encodes this character as UTF-8 into the provided byte buffer, and then returns the subslice of the buffer that contains the encoded character.",432,null],[11,"encode_utf16","","Encodes this character as UTF-16 into the provided `u16` buffer, and then returns the subslice of the buffer that contains the encoded character.",432,null],[11,"is_alphabetic","","Returns true if this `char` is an alphabetic code point, and false if not.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_xid_start","","Returns true if this `char` satisfies the 'XID_Start' Unicode property, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_xid_continue","","Returns true if this `char` satisfies the 'XID_Continue' Unicode property, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_lowercase","","Returns true if this `char` is lowercase, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_uppercase","","Returns true if this `char` is uppercase, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_whitespace","","Returns true if this `char` is whitespace, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_alphanumeric","","Returns true if this `char` is alphanumeric, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_control","","Returns true if this `char` is a control code point, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_numeric","","Returns true if this `char` is numeric, and false otherwise.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_lowercase","","Returns an iterator that yields the lowercase equivalent of a `char` as one or more `char`s.",432,{"inputs":[{"name":"self"}],"output":{"name":"tolowercase"}}],[11,"to_uppercase","","Returns an iterator that yields the uppercase equivalent of a `char` as one or more `char`s.",432,{"inputs":[{"name":"self"}],"output":{"name":"touppercase"}}],[11,"is_ascii","","Checks if the value is within the ASCII range.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","Makes a copy of the value in its ASCII upper case equivalent.",432,{"inputs":[{"name":"self"}],"output":{"name":"char"}}],[11,"to_ascii_lowercase","","Makes a copy of the value in its ASCII lower case equivalent.",432,{"inputs":[{"name":"self"}],"output":{"name":"char"}}],[11,"eq_ignore_ascii_case","","Checks that two values are an ASCII case-insensitive match.",432,{"inputs":[{"name":"self"},{"name":"char"}],"output":{"name":"bool"}}],[11,"make_ascii_uppercase","","Converts this type to its ASCII upper case equivalent in-place.",432,null],[11,"make_ascii_lowercase","","Converts this type to its ASCII lower case equivalent in-place.",432,null],[11,"is_ascii_alphabetic","","Checks if the value is an ASCII alphabetic character:",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_uppercase","","Checks if the value is an ASCII uppercase character: U+0041 'A' ... U+005A 'Z'.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_lowercase","","Checks if the value is an ASCII lowercase character: U+0061 'a' ... U+007A 'z'.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_alphanumeric","","Checks if the value is an ASCII alphanumeric character:",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_digit","","Checks if the value is an ASCII decimal digit: U+0030 '0' ... U+0039 '9'.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_hexdigit","","Checks if the value is an ASCII hexadecimal digit:",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_punctuation","","Checks if the value is an ASCII punctuation character:",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_graphic","","Checks if the value is an ASCII graphic character: U+0021 '!' ... U+007E '~'.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_whitespace","","Checks if the value is an ASCII whitespace character: U+0020 SPACE, U+0009 HORIZONTAL TAB, U+000A LINE FEED, U+000C FORM FEED, or U+000D CARRIAGE RETURN.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_control","","Checks if the value is an ASCII control character: U+0000 NUL ... U+001F UNIT SEPARATOR, or U+007F DELETE. Note that most ASCII whitespace characters are control characters, but SPACE is not.",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii","","Checks if all bytes in this slice are within the ASCII range.",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","Returns a vector containing a copy of this slice where each byte is mapped to its ASCII upper case equivalent.",433,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"to_ascii_lowercase","","Returns a vector containing a copy of this slice where each byte is mapped to its ASCII lower case equivalent.",433,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"eq_ignore_ascii_case","","Checks that two slices are an ASCII case-insensitive match.",433,null],[11,"make_ascii_uppercase","","Converts this slice to its ASCII upper case equivalent in-place.",433,null],[11,"make_ascii_lowercase","","Converts this slice to its ASCII lower case equivalent in-place.",433,null],[11,"is_null","","Returns `true` if the pointer is null.",425,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"as_ref","","Returns `None` if the pointer is null, or else returns a reference to the value wrapped in `Some`.",425,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"offset","","Calculates the offset from a pointer.",425,null],[11,"wrapping_offset","","Calculates the offset from a pointer using wrapping arithmetic.",425,null],[11,"offset_to","","Calculates the distance between two pointers. The returned value is in units of T: the distance in bytes is divided by `mem::size_of::<T>()`.",425,null],[11,"offset_from","","Calculates the distance between two pointers. The returned value is in units of T: the distance in bytes is divided by `mem::size_of::<T>()`.",425,null],[11,"wrapping_offset_from","","Calculates the distance between two pointers. The returned value is in units of T: the distance in bytes is divided by `mem::size_of::<T>()`.",425,null],[11,"add","","Calculates the offset from a pointer (convenience for `.offset(count as isize)`).",425,null],[11,"sub","","Calculates the offset from a pointer (convenience for `.offset((count as isize).wrapping_neg())`).",425,null],[11,"wrapping_add","","Calculates the offset from a pointer using wrapping arithmetic. (convenience for `.wrapping_offset(count as isize)`)",425,null],[11,"wrapping_sub","","Calculates the offset from a pointer using wrapping arithmetic. (convenience for `.wrapping_offset((count as isize).wrapping_sub())`)",425,null],[11,"read","","Reads the value from `self` without moving it. This leaves the memory in `self` unchanged.",425,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"read_volatile","","Performs a volatile read of the value from `self` without moving it. This leaves the memory in `self` unchanged.",425,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"read_unaligned","","Reads the value from `self` without moving it. This leaves the memory in `self` unchanged.",425,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"copy_to","","Copies `count * size_of<T>` bytes from `self` to `dest`. The source and destination may overlap.",425,null],[11,"copy_to_nonoverlapping","","Copies `count * size_of<T>` bytes from `self` to `dest`. The source and destination may not overlap.",425,null],[11,"align_offset","","Computes the byte offset that needs to be applied in order to make the pointer aligned to `align`. If it is not possible to align the pointer, the implementation returns `usize::max_value()`.",425,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"is_null","","Returns `true` if the pointer is null.",425,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"as_ref","","Returns `None` if the pointer is null, or else returns a reference to the value wrapped in `Some`.",425,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"offset","","Calculates the offset from a pointer.",425,null],[11,"wrapping_offset","","Calculates the offset from a pointer using wrapping arithmetic. `count` is in units of T; e.g. a `count` of 3 represents a pointer offset of `3 * size_of::<T>()` bytes.",425,null],[11,"as_mut","","Returns `None` if the pointer is null, or else returns a mutable reference to the value wrapped in `Some`.",425,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"offset_to","","Calculates the distance between two pointers. The returned value is in units of T: the distance in bytes is divided by `mem::size_of::<T>()`.",425,null],[11,"offset_from","","Calculates the distance between two pointers. The returned value is in units of T: the distance in bytes is divided by `mem::size_of::<T>()`.",425,null],[11,"wrapping_offset_from","","Calculates the distance between two pointers. The returned value is in units of T: the distance in bytes is divided by `mem::size_of::<T>()`.",425,null],[11,"align_offset","","Computes the byte offset that needs to be applied in order to make the pointer aligned to `align`. If it is not possible to align the pointer, the implementation returns `usize::max_value()`.",425,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"usize"}}],[11,"add","","Calculates the offset from a pointer (convenience for `.offset(count as isize)`).",425,null],[11,"sub","","Calculates the offset from a pointer (convenience for `.offset((count as isize).wrapping_neg())`).",425,null],[11,"wrapping_add","","Calculates the offset from a pointer using wrapping arithmetic. (convenience for `.wrapping_offset(count as isize)`)",425,null],[11,"wrapping_sub","","Calculates the offset from a pointer using wrapping arithmetic. (convenience for `.wrapping_offset((count as isize).wrapping_sub())`)",425,null],[11,"read","","Reads the value from `self` without moving it. This leaves the memory in `self` unchanged.",425,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"read_volatile","","Performs a volatile read of the value from `self` without moving it. This leaves the memory in `self` unchanged.",425,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"read_unaligned","","Reads the value from `self` without moving it. This leaves the memory in `self` unchanged.",425,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"copy_to","","Copies `count * size_of<T>` bytes from `self` to `dest`. The source and destination may overlap.",425,null],[11,"copy_to_nonoverlapping","","Copies `count * size_of<T>` bytes from `self` to `dest`. The source and destination may not overlap.",425,null],[11,"copy_from","","Copies `count * size_of<T>` bytes from `src` to `self`. The source and destination may overlap.",425,null],[11,"copy_from_nonoverlapping","","Copies `count * size_of<T>` bytes from `src` to `self`. The source and destination may not overlap.",425,null],[11,"drop_in_place","","Executes the destructor (if any) of the pointed-to value.",425,null],[11,"write","","Overwrites a memory location with the given value without reading or dropping the old value.",425,null],[11,"write_bytes","","Invokes memset on the specified pointer, setting `count * size_of::<T>()` bytes of memory starting at `self` to `val`.",425,null],[11,"write_volatile","","Performs a volatile write of a memory location with the given value without reading or dropping the old value.",425,null],[11,"write_unaligned","","Overwrites a memory location with the given value without reading or dropping the old value.",425,null],[11,"replace","","Replaces the value at `self` with `src`, returning the old value, without dropping either.",425,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"swap","","Swaps the values at two mutable locations of the same type, without deinitializing either. They may overlap, unlike `mem::swap` which is otherwise equivalent.",425,null],[11,"of","std::any","Returns the `TypeId` of the type this generic function has been instantiated with.",428,{"inputs":[],"output":{"name":"typeid"}}],[11,"get","std::cell","Returns a copy of the contained value.",451,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"new","","Creates a new `Cell` containing the given value.",451,{"inputs":[{"name":"t"}],"output":{"name":"cell"}}],[11,"as_ptr","","Returns a raw pointer to the underlying data in this cell.",451,null],[11,"get_mut","","Returns a mutable reference to the underlying data.",451,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"set","","Sets the contained value.",451,null],[11,"swap","","Swaps the values of two Cells. Difference with `std::mem::swap` is that this function doesn't require `&mut` reference.",451,null],[11,"replace","","Replaces the contained value, and returns it.",451,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"into_inner","","Unwraps the value.",451,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"take","","Takes the value of the cell, leaving `Default::default()` in its place.",451,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"new","","Creates a new `RefCell` containing `value`.",455,{"inputs":[{"name":"t"}],"output":{"name":"refcell"}}],[11,"into_inner","","Consumes the `RefCell`, returning the wrapped value.",455,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"replace","","Replaces the wrapped value with a new one, returning the old value, without deinitializing either one.",455,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"replace_with","","Replaces the wrapped value with a new one computed from `f`, returning the old value, without deinitializing either one.",455,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"swap","","Swaps the wrapped value of `self` with the wrapped value of `other`, without deinitializing either one.",455,null],[11,"borrow","","Immutably borrows the wrapped value.",455,{"inputs":[{"name":"self"}],"output":{"name":"ref"}}],[11,"try_borrow","","Immutably borrows the wrapped value, returning an error if the value is currently mutably borrowed.",455,{"inputs":[{"name":"self"}],"output":{"generics":["ref","borrowerror"],"name":"result"}}],[11,"borrow_mut","","Mutably borrows the wrapped value.",455,{"inputs":[{"name":"self"}],"output":{"name":"refmut"}}],[11,"try_borrow_mut","","Mutably borrows the wrapped value, returning an error if the value is currently borrowed.",455,{"inputs":[{"name":"self"}],"output":{"generics":["refmut","borrowmuterror"],"name":"result"}}],[11,"as_ptr","","Returns a raw pointer to the underlying data in this cell.",455,null],[11,"get_mut","","Returns a mutable reference to the underlying data.",455,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"clone","","Copies a `Ref`.",459,{"inputs":[{"name":"ref"}],"output":{"name":"ref"}}],[11,"map","","Make a new `Ref` for a component of the borrowed data.",459,{"inputs":[{"name":"ref"},{"name":"f"}],"output":{"name":"ref"}}],[11,"map","","Make a new `RefMut` for a component of the borrowed data, e.g. an enum variant.",457,{"inputs":[{"name":"refmut"},{"name":"f"}],"output":{"name":"refmut"}}],[11,"new","","Constructs a new instance of `UnsafeCell` which will wrap the specified value.",470,{"inputs":[{"name":"t"}],"output":{"name":"unsafecell"}}],[11,"into_inner","","Unwraps the value.",470,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"get","","Gets a mutable pointer to the wrapped value.",470,null],[11,"reverse","std::cmp","Reverses the `Ordering`.",3,{"inputs":[{"name":"self"}],"output":{"name":"ordering"}}],[11,"then","","Chains two orderings.",3,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"ordering"}}],[11,"then_with","","Chains the ordering with the given function.",3,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"ordering"}}],[11,"new","std::hash","Creates a new `SipHasher` with the two initial keys set to 0.",449,{"inputs":[],"output":{"name":"siphasher"}}],[11,"new_with_keys","","Creates a `SipHasher` that is keyed off the provided keys.",449,{"inputs":[{"name":"u64"},{"name":"u64"}],"output":{"name":"siphasher"}}],[11,"peek","std::iter","Returns a reference to the next() value without advancing the iterator.",405,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"new","std::mem","Wrap a value to be manually dropped.",426,{"inputs":[{"name":"t"}],"output":{"name":"manuallydrop"}}],[11,"into_inner","","Extract the value from the ManuallyDrop container.",426,{"inputs":[{"name":"manuallydrop"}],"output":{"name":"t"}}],[11,"drop","","Manually drops the contained value.",426,null],[11,"new","","Construct a new `Pin` around a reference to some data of a type that implements `Unpin`.",458,{"inputs":[{"name":"t"}],"output":{"name":"pin"}}],[11,"new_unchecked","","Construct a new `Pin` around a reference to some data of a type that may or may not implement `Unpin`.",458,{"inputs":[{"name":"t"}],"output":{"name":"pin"}}],[11,"borrow","","Borrow a Pin for a shorter lifetime than it already has.",458,{"inputs":[{"name":"pin"}],"output":{"name":"pin"}}],[11,"get_mut","","Get a mutable reference to the data inside of this `Pin`.",458,{"inputs":[{"name":"pin"}],"output":{"name":"t"}}],[11,"map","","Construct a new pin by mapping the interior value.",458,{"inputs":[{"name":"pin"},{"name":"f"}],"output":{"name":"pin"}}],[11,"contains","std::ops","Returns `true` if `item` is contained in the range.",31,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",34,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"is_empty","","Returns `true` if the range contains no items.",34,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",35,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",48,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"is_empty","","Returns `true` if the range contains no items.",48,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"contains","","Returns `true` if `item` is contained in the range.",49,{"inputs":[{"name":"self"},{"name":"idx"}],"output":{"name":"bool"}}],[11,"empty","std::ptr","Creates a new `Unique` that is dangling, but well-aligned.",445,{"inputs":[],"output":{"name":"unique"}}],[11,"new_unchecked","","Creates a new `Unique`.",445,null],[11,"new","","Creates a new `Unique` if `ptr` is non-null.",445,null],[11,"as_ptr","","Acquires the underlying `*mut` pointer.",445,null],[11,"as_ref","","Dereferences the content.",445,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_mut","","Mutably dereferences the content.",445,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"dangling","","Creates a new `NonNull` that is dangling, but well-aligned.",427,{"inputs":[],"output":{"name":"nonnull"}}],[11,"new_unchecked","","Creates a new `NonNull`.",427,null],[11,"new","","Creates a new `NonNull` if `ptr` is non-null.",427,null],[11,"as_ptr","","Acquires the underlying `*mut` pointer.",427,null],[11,"as_ref","","Dereferences the content.",427,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"as_mut","","Mutably dereferences the content.",427,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"cast","","Cast to a pointer of another type",427,{"inputs":[{"name":"self"}],"output":{"name":"nonnull"}}],[11,"is_ok","std::result","Returns `true` if the result is [`Ok`].",72,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_err","","Returns `true` if the result is [`Err`].",72,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"ok","","Converts from `Result<T, E>` to [`Option<T>`].",72,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"err","","Converts from `Result<T, E>` to [`Option<E>`].",72,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"as_ref","","Converts from `Result<T, E>` to `Result<&T, &E>`.",72,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"as_mut","","Converts from `Result<T, E>` to `Result<&mut T, &mut E>`.",72,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"map","","Maps a `Result<T, E>` to `Result<U, E>` by applying a function to a contained [`Ok`] value, leaving an [`Err`] value untouched.",72,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"result"}}],[11,"map_err","","Maps a `Result<T, E>` to `Result<T, F>` by applying a function to a contained [`Err`] value, leaving an [`Ok`] value untouched.",72,{"inputs":[{"name":"self"},{"name":"o"}],"output":{"name":"result"}}],[11,"iter","","Returns an iterator over the possibly contained value.",72,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Returns a mutable iterator over the possibly contained value.",72,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"and","","Returns `res` if the result is [`Ok`], otherwise returns the [`Err`] value of `self`.",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"result"}}],[11,"and_then","","Calls `op` if the result is [`Ok`], otherwise returns the [`Err`] value of `self`.",72,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"result"}}],[11,"or","","Returns `res` if the result is [`Err`], otherwise returns the [`Ok`] value of `self`.",72,{"inputs":[{"name":"self"},{"name":"result"}],"output":{"name":"result"}}],[11,"or_else","","Calls `op` if the result is [`Err`], otherwise returns the [`Ok`] value of `self`.",72,{"inputs":[{"name":"self"},{"name":"o"}],"output":{"name":"result"}}],[11,"unwrap_or","","Unwraps a result, yielding the content of an [`Ok`]. Else, it returns `optb`.",72,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"unwrap_or_else","","Unwraps a result, yielding the content of an [`Ok`]. If the value is an [`Err`] then it calls `op` with its value.",72,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"unwrap","","Unwraps a result, yielding the content of an [`Ok`].",72,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"expect","","Unwraps a result, yielding the content of an [`Ok`].",72,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"t"}}],[11,"unwrap_err","","Unwraps a result, yielding the content of an [`Err`].",72,{"inputs":[{"name":"self"}],"output":{"name":"e"}}],[11,"expect_err","","Unwraps a result, yielding the content of an [`Err`].",72,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"e"}}],[11,"unwrap_or_default","","Returns the contained value or a default",72,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"transpose","","Transposes a `Result` of an `Option` into an `Option` of a `Result`.",72,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"is_some","std::option","Returns `true` if the option is a [`Some`] value.",73,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_none","","Returns `true` if the option is a [`None`] value.",73,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"as_ref","","Converts from `Option<T>` to `Option<&T>`.",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"as_mut","","Converts from `Option<T>` to `Option<&mut T>`.",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"expect","","Unwraps an option, yielding the content of a [`Some`].",73,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"t"}}],[11,"unwrap","","Moves the value `v` out of the `Option<T>` if it is [`Some(v)`].",73,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"unwrap_or","","Returns the contained value or a default.",73,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"unwrap_or_else","","Returns the contained value or computes it from a closure.",73,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"map","","Maps an `Option<T>` to `Option<U>` by applying a function to a contained value.",73,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"map_or","","Applies a function to the contained value (if any), or returns the provided default (if not).",73,{"inputs":[{"name":"self"},{"name":"u"},{"name":"f"}],"output":{"name":"u"}}],[11,"map_or_else","","Applies a function to the contained value (if any), or computes a default (if not).",73,{"inputs":[{"name":"self"},{"name":"d"},{"name":"f"}],"output":{"name":"u"}}],[11,"ok_or","","Transforms the `Option<T>` into a [`Result<T, E>`], mapping [`Some(v)`] to [`Ok(v)`] and [`None`] to [`Err(err)`].",73,{"inputs":[{"name":"self"},{"name":"e"}],"output":{"name":"result"}}],[11,"ok_or_else","","Transforms the `Option<T>` into a [`Result<T, E>`], mapping [`Some(v)`] to [`Ok(v)`] and [`None`] to [`Err(err())`].",73,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"result"}}],[11,"iter","","Returns an iterator over the possibly contained value.",73,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Returns a mutable iterator over the possibly contained value.",73,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"and","","Returns [`None`] if the option is [`None`], otherwise returns `optb`.",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"option"}}],[11,"and_then","","Returns [`None`] if the option is [`None`], otherwise calls `f` with the wrapped value and returns the result.",73,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"filter","","Returns `None` if the option is `None`, otherwise calls `predicate` with the wrapped value and returns:",73,{"inputs":[{"name":"self"},{"name":"p"}],"output":{"name":"option"}}],[11,"or","","Returns the option if it contains a value, otherwise returns `optb`.",73,{"inputs":[{"name":"self"},{"name":"option"}],"output":{"name":"option"}}],[11,"or_else","","Returns the option if it contains a value, otherwise calls `f` and returns the result.",73,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"option"}}],[11,"get_or_insert","","Inserts `v` into the option if it is [`None`], then returns a mutable reference to the contained value.",73,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"t"}}],[11,"get_or_insert_with","","Inserts a value computed from `f` into the option if it is [`None`], then returns a mutable reference to the contained value.",73,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"t"}}],[11,"take","","Takes the value out of the option, leaving a [`None`] in its place.",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"cloned","","Maps an `Option<&T>` to an `Option<T>` by cloning the contents of the option.",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"cloned","","Maps an `Option<&mut T>` to an `Option<T>` by cloning the contents of the option.",73,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"unwrap_or_default","","Returns the contained value or a default",73,{"inputs":[{"name":"self"}],"output":{"name":"t"}}],[11,"transpose","","Transposes an `Option` of a `Result` into a `Result` of an `Option`.",73,{"inputs":[{"name":"self"}],"output":{"generics":["option"],"name":"result"}}],[11,"new","std::boxed","Allocates memory on the heap and then places `x` into it.",120,{"inputs":[{"name":"t"}],"output":{"name":"box"}}],[11,"from_raw","","Constructs a box from a raw pointer.",120,null],[11,"into_raw","","Consumes the `Box`, returning the wrapped raw pointer.",120,null],[11,"into_raw_non_null","","Consumes the `Box`, returning the wrapped pointer as `NonNull<T>`.",120,{"inputs":[{"name":"box"}],"output":{"name":"nonnull"}}],[11,"into_unique","","",120,{"inputs":[{"name":"box"}],"output":{"name":"unique"}}],[11,"leak","","Consumes and leaks the `Box`, returning a mutable reference, `&'a mut T`. Here, the lifetime `'a` may be chosen to be `'static`.",120,{"inputs":[{"name":"box"}],"output":{"name":"t"}}],[11,"downcast","","Attempt to downcast the box to a concrete type.",120,{"inputs":[{"name":"self"}],"output":{"generics":["box","box"],"name":"result"}}],[11,"downcast","","Attempt to downcast the box to a concrete type.",120,{"inputs":[{"name":"self"}],"output":{"generics":["box","box"],"name":"result"}}],[11,"new","","Allocate memory on the heap, move the data into it and pin it.",476,{"inputs":[{"name":"t"}],"output":{"name":"pinbox"}}],[11,"as_pin","","Get a pinned reference to the data in this PinBox.",476,{"inputs":[{"name":"self"}],"output":{"name":"pin"}}],[11,"get_mut","","Get a mutable reference to the data inside this PinBox.",476,{"inputs":[{"name":"pinbox"}],"output":{"name":"t"}}],[11,"unpin","","Convert this PinBox into an unpinned Box.",476,{"inputs":[{"name":"pinbox"}],"output":{"name":"box"}}],[11,"new","std::rc","Constructs a new `Rc<T>`.",138,{"inputs":[{"name":"t"}],"output":{"name":"rc"}}],[11,"try_unwrap","","Returns the contained value, if the `Rc` has exactly one strong reference.",138,{"inputs":[{"name":"rc"}],"output":{"generics":["rc"],"name":"result"}}],[11,"into_raw","","Consumes the `Rc`, returning the wrapped pointer.",138,null],[11,"from_raw","","Constructs an `Rc` from a raw pointer.",138,null],[11,"downgrade","","Creates a new [`Weak`][weak] pointer to this value.",138,{"inputs":[{"name":"rc"}],"output":{"name":"weak"}}],[11,"weak_count","","Gets the number of [`Weak`][weak] pointers to this value.",138,{"inputs":[{"name":"rc"}],"output":{"name":"usize"}}],[11,"strong_count","","Gets the number of strong (`Rc`) pointers to this value.",138,{"inputs":[{"name":"rc"}],"output":{"name":"usize"}}],[11,"get_mut","","Returns a mutable reference to the inner value, if there are no other `Rc` or [`Weak`][weak] pointers to the same value.",138,{"inputs":[{"name":"rc"}],"output":{"name":"option"}}],[11,"ptr_eq","","Returns true if the two `Rc`s point to the same value (not just values that compare as equal).",138,{"inputs":[{"name":"rc"},{"name":"rc"}],"output":{"name":"bool"}}],[11,"make_mut","","Makes a mutable reference into the given `Rc`.",138,{"inputs":[{"name":"rc"}],"output":{"name":"t"}}],[11,"downcast","","Attempt to downcast the `Rc<Any>` to a concrete type.",138,{"inputs":[{"name":"self"}],"output":{"generics":["rc","rc"],"name":"result"}}],[11,"new","","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",481,{"inputs":[],"output":{"name":"weak"}}],[11,"upgrade","","Attempts to upgrade the `Weak` pointer to an [`Rc`], extending the lifetime of the value if successful.",481,{"inputs":[{"name":"self"}],"output":{"generics":["rc"],"name":"option"}}],[11,"to_mut","std::borrow","Acquires a mutable reference to the owned form of the data.",76,null],[11,"into_owned","","Extracts the owned data.",76,null],[11,"entry","std::fmt","Adds a new entry to the set output.",534,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debugset"}}],[11,"entries","","Adds the contents of an iterator of entries to the set output.",534,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debugset"}}],[11,"finish","","Finishes output and returns any error encountered.",534,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"field","","Adds a new field to the generated struct output.",535,{"inputs":[{"name":"self"},{"name":"str"},{"name":"debug"}],"output":{"name":"debugstruct"}}],[11,"finish","","Finishes output and returns any error encountered.",535,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"entry","","Adds a new entry to the map output.",536,{"inputs":[{"name":"self"},{"name":"debug"},{"name":"debug"}],"output":{"name":"debugmap"}}],[11,"entries","","Adds the contents of an iterator of entries to the map output.",536,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debugmap"}}],[11,"finish","","Finishes output and returns any error encountered.",536,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"field","","Adds a new field to the generated tuple struct output.",537,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debugtuple"}}],[11,"finish","","Finishes output and returns any error encountered.",537,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"entry","","Adds a new entry to the list output.",538,{"inputs":[{"name":"self"},{"name":"debug"}],"output":{"name":"debuglist"}}],[11,"entries","","Adds the contents of an iterator of entries to the list output.",538,{"inputs":[{"name":"self"},{"name":"i"}],"output":{"name":"debuglist"}}],[11,"finish","","Finishes output and returns any error encountered.",538,{"inputs":[{"name":"self"}],"output":{"generics":["error"],"name":"result"}}],[11,"pad_integral","","Performs the correct padding for an integer which has already been emitted into a str. The str should not contain the sign for the integer, that will be added by this method.",456,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"str"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"pad","","This function takes a string slice and emits it to the internal buffer after applying the relevant formatting flags specified. The flags recognized for generic strings are:",456,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_str","","Writes some data to the underlying buffer contained within this formatter.",456,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"generics":["error"],"name":"result"}}],[11,"write_fmt","","Writes some formatted information into this instance",456,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"generics":["error"],"name":"result"}}],[11,"flags","","Flags for formatting",456,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"fill","","Character used as 'fill' whenever there is alignment",456,{"inputs":[{"name":"self"}],"output":{"name":"char"}}],[11,"align","","Flag indicating what form of alignment was requested",456,{"inputs":[{"name":"self"}],"output":{"name":"alignment"}}],[11,"width","","Optionally specified integer width that the output should be.",456,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"precision","","Optionally specified precision for numeric types.",456,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"sign_plus","","Determines if the `+` flag was specified.",456,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"sign_minus","","Determines if the `-` flag was specified.",456,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"alternate","","Determines if the `#` flag was specified.",456,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"sign_aware_zero_pad","","Determines if the `0` flag was specified.",456,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"debug_struct","","Creates a [`DebugStruct`] builder designed to assist with creation of [`fmt::Debug`] implementations for structs.",456,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"debugstruct"}}],[11,"debug_tuple","","Creates a `DebugTuple` builder designed to assist with creation of `fmt::Debug` implementations for tuple structs.",456,{"inputs":[{"name":"self"},{"name":"str"}],"output":{"name":"debugtuple"}}],[11,"debug_list","","Creates a `DebugList` builder designed to assist with creation of `fmt::Debug` implementations for list-like structures.",456,{"inputs":[{"name":"self"}],"output":{"name":"debuglist"}}],[11,"debug_set","","Creates a `DebugSet` builder designed to assist with creation of `fmt::Debug` implementations for set-like structures.",456,{"inputs":[{"name":"self"}],"output":{"name":"debugset"}}],[11,"debug_map","","Creates a `DebugMap` builder designed to assist with creation of `fmt::Debug` implementations for map-like structures.",456,{"inputs":[{"name":"self"}],"output":{"name":"debugmap"}}],[11,"as_slice","std::slice","View the underlying data as a subslice of the original data.",289,null],[11,"into_slice","","View the underlying data as a subslice of the original data.",291,null],[11,"as_str","std::str","View the underlying data as a subslice of the original data.",377,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"valid_up_to","","Returns the index in the given string up to which valid UTF-8 was verified.",122,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"error_len","","Provide more information about the failure:",122,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"option"}}],[11,"as_str","","View the underlying data as a subslice of the original data.",385,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"new","std::string","Creates a new empty `String`.",141,{"inputs":[],"output":{"name":"string"}}],[11,"with_capacity","","Creates a new empty `String` with a particular capacity.",141,{"inputs":[{"name":"usize"}],"output":{"name":"string"}}],[11,"from_utf8","","Converts a vector of bytes to a `String`.",141,{"inputs":[{"generics":["u8"],"name":"vec"}],"output":{"generics":["string","fromutf8error"],"name":"result"}}],[11,"from_utf8_lossy","","Converts a slice of bytes to a string, including invalid characters.",141,null],[11,"from_utf16","","Decode a UTF-16 encoded vector `v` into a `String`, returning [`Err`] if `v` contains any invalid data.",141,null],[11,"from_utf16_lossy","","Decode a UTF-16 encoded slice `v` into a `String`, replacing invalid data with the replacement character (U+FFFD).",141,null],[11,"from_raw_parts","","Creates a new `String` from a length, capacity, and pointer.",141,null],[11,"from_utf8_unchecked","","Converts a vector of bytes to a `String` without checking that the string contains valid UTF-8.",141,{"inputs":[{"generics":["u8"],"name":"vec"}],"output":{"name":"string"}}],[11,"into_bytes","","Converts a `String` into a byte vector.",141,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"as_str","","Extracts a string slice containing the entire string.",141,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"as_mut_str","","Converts a `String` into a mutable string slice.",141,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"push_str","","Appends a given string slice onto the end of this `String`.",141,null],[11,"capacity","","Returns this `String`'s capacity, in bytes.",141,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve","","Ensures that this `String`'s capacity is at least `additional` bytes larger than its length.",141,null],[11,"reserve_exact","","Ensures that this `String`'s capacity is `additional` bytes larger than its length.",141,null],[11,"try_reserve","","Tries to reserve capacity for at least `additional` more elements to be inserted in the given `String`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",141,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"try_reserve_exact","","Tries to reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `String`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",141,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"shrink_to_fit","","Shrinks the capacity of this `String` to match its length.",141,null],[11,"shrink_to","","Shrinks the capacity of this `String` with a lower bound.",141,null],[11,"push","","Appends the given [`char`] to the end of this `String`.",141,null],[11,"as_bytes","","Returns a byte slice of this `String`'s contents.",141,null],[11,"truncate","","Shortens this `String` to the specified length.",141,null],[11,"pop","","Removes the last character from the string buffer and returns it.",141,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"remove","","Removes a [`char`] from this `String` at a byte position and returns it.",141,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"char"}}],[11,"retain","","Retains only the characters specified by the predicate.",141,null],[11,"insert","","Inserts a character into this `String` at a byte position.",141,null],[11,"insert_str","","Inserts a string slice into this `String` at a byte position.",141,null],[11,"as_mut_vec","","Returns a mutable reference to the contents of this `String`.",141,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"len","","Returns the length of this `String`, in bytes.",141,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if this `String` has a length of zero.",141,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"split_off","","Splits the string into two at the given index.",141,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"string"}}],[11,"clear","","Truncates this `String`, removing all contents.",141,null],[11,"drain","","Creates a draining iterator that removes the specified range in the string and yields the removed chars.",141,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"drain"}}],[11,"splice","","Creates a splicing iterator that removes the specified range in the string, and replaces it with the given string. The given string doesn't need to be the same length as the range.",141,null],[11,"into_boxed_str","","Converts this `String` into a [`Box`]`<`[`str`]`>`.",141,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"box"}}],[11,"as_bytes","","Returns a slice of [`u8`]s bytes that were attempted to convert to a `String`.",123,null],[11,"into_bytes","","Returns the bytes that were attempted to convert to a `String`.",123,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"vec"}}],[11,"utf8_error","","Fetch a `Utf8Error` to get more details about the conversion failure.",123,{"inputs":[{"name":"self"}],"output":{"name":"utf8error"}}],[11,"new","std::vec","Constructs a new, empty `Vec<T>`.",137,{"inputs":[],"output":{"name":"vec"}}],[11,"with_capacity","","Constructs a new, empty `Vec<T>` with the specified capacity.",137,{"inputs":[{"name":"usize"}],"output":{"name":"vec"}}],[11,"from_raw_parts","","Creates a `Vec<T>` directly from the raw components of another vector.",137,null],[11,"capacity","","Returns the number of elements the vector can hold without reallocating.",137,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the given `Vec<T>`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",137,null],[11,"reserve_exact","","Reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `Vec<T>`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",137,null],[11,"try_reserve","","Tries to reserve capacity for at least `additional` more elements to be inserted in the given `Vec<T>`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",137,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"try_reserve_exact","","Tries to reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `Vec<T>`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",137,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"shrink_to_fit","","Shrinks the capacity of the vector as much as possible.",137,null],[11,"shrink_to","","Shrinks the capacity of the vector with a lower bound.",137,null],[11,"into_boxed_slice","","Converts the vector into [`Box<[T]>`][owned slice].",137,{"inputs":[{"name":"self"}],"output":{"name":"box"}}],[11,"truncate","","Shortens the vector, keeping the first `len` elements and dropping the rest.",137,null],[11,"as_slice","","Extracts a slice containing the entire vector.",137,null],[11,"as_mut_slice","","Extracts a mutable slice of the entire vector.",137,null],[11,"set_len","","Sets the length of a vector.",137,null],[11,"swap_remove","","Removes an element from the vector and returns it.",137,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"t"}}],[11,"insert","","Inserts an element at position `index` within the vector, shifting all elements after it to the right.",137,null],[11,"remove","","Removes and returns the element at position `index` within the vector, shifting all elements after it to the left.",137,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"t"}}],[11,"retain","","Retains only the elements specified by the predicate.",137,null],[11,"dedup_by_key","","Removes all but the first of consecutive elements in the vector that resolve to the same key.",137,null],[11,"dedup_by","","Removes all but the first of consecutive elements in the vector satisfying a given equality relation.",137,null],[11,"push","","Appends an element to the back of a collection.",137,null],[11,"place_back","","Returns a place for insertion at the back of the `Vec`.",137,{"inputs":[{"name":"self"}],"output":{"name":"placeback"}}],[11,"pop","","Removes the last element from a vector and returns it, or [`None`] if it is empty.",137,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"append","","Moves all the elements of `other` into `Self`, leaving `other` empty.",137,null],[11,"drain","","Creates a draining iterator that removes the specified range in the vector and yields the removed items.",137,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"drain"}}],[11,"clear","","Clears the vector, removing all values.",137,null],[11,"len","","Returns the number of elements in the vector, also referred to as its 'length'.",137,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the vector contains no elements.",137,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"split_off","","Splits the collection into two at the given index.",137,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"vec"}}],[11,"resize","","Resizes the `Vec` in-place so that `len` is equal to `new_len`.",137,null],[11,"extend_from_slice","","Clones and appends all elements in a slice to the `Vec`.",137,null],[11,"resize_default","","Resizes the `Vec` in-place so that `len` is equal to `new_len`.",137,null],[11,"dedup","","Removes consecutive repeated elements in the vector.",137,null],[11,"remove_item","","Removes the first instance of `item` from the vector if the item exists.",137,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[11,"splice","","Creates a splicing iterator that replaces the specified range in the vector with the given `replace_with` iterator and yields the removed items. `replace_with` does not need to be the same length as `range`.",137,{"inputs":[{"name":"self"},{"name":"r"},{"name":"i"}],"output":{"name":"splice"}}],[11,"drain_filter","","Creates an iterator which uses a closure to determine if an element should be removed.",137,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"drainfilter"}}],[11,"as_slice","","Returns the remaining items of this iterator as a slice.",525,null],[11,"as_mut_slice","","Returns the remaining items of this iterator as a mutable slice.",525,null],[11,"unpaired_surrogate","std::char","Returns the unpaired surrogate which caused this error.",126,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"new","std::simd","Creates a new instance with each vector elements initialized with the provided values.",356,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"f32x4"}}],[11,"lanes","","Returns the number of vector lanes.",356,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",356,{"inputs":[{"name":"f32"}],"output":{"name":"f32x4"}}],[11,"extract","","Extracts the value at `index`.",356,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",356,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",356,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",356,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",356,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",356,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",356,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",356,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",356,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",356,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",356,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",356,null],[11,"eq","","Lane-wise equality comparison.",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",356,{"inputs":[{"name":"self"},{"name":"f32x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",356,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",356,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",356,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",356,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",308,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"f64x8"}}],[11,"lanes","","Returns the number of vector lanes.",308,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",308,{"inputs":[{"name":"f64"}],"output":{"name":"f64x8"}}],[11,"extract","","Extracts the value at `index`.",308,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",308,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",308,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"f64x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",308,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"f64x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",308,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",308,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",308,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",308,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",308,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",308,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",308,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",308,null],[11,"eq","","Lane-wise equality comparison.",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",308,{"inputs":[{"name":"self"},{"name":"f64x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",308,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",308,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"max","","Largest vector value.",308,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"min","","Smallest vector value.",308,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",340,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"u32x8"}}],[11,"lanes","","Returns the number of vector lanes.",340,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",340,{"inputs":[{"name":"u32"}],"output":{"name":"u32x8"}}],[11,"extract","","Extracts the value at `index`.",340,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",340,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",340,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",340,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",340,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",340,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",340,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",340,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",340,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",340,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",340,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",340,null],[11,"eq","","Lane-wise equality comparison.",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",340,{"inputs":[{"name":"self"},{"name":"u32x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",340,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",340,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",340,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",340,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",340,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",340,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",340,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",324,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"u8x8"}}],[11,"lanes","","Returns the number of vector lanes.",324,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",324,{"inputs":[{"name":"u8"}],"output":{"name":"u8x8"}}],[11,"extract","","Extracts the value at `index`.",324,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",324,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",324,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",324,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",324,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",324,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",324,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",324,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",324,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",324,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",324,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",324,null],[11,"eq","","Lane-wise equality comparison.",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",324,{"inputs":[{"name":"self"},{"name":"u8x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",324,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",324,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",324,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",324,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",324,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",324,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",324,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",305,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32x4"}}],[11,"lanes","","Returns the number of vector lanes.",305,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",305,{"inputs":[{"name":"i32"}],"output":{"name":"i32x4"}}],[11,"extract","","Extracts the value at `index`.",305,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",305,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",305,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",305,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",305,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",305,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",305,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",305,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",305,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",305,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",305,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",305,null],[11,"eq","","Lane-wise equality comparison.",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",305,{"inputs":[{"name":"self"},{"name":"i32x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",305,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",305,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",305,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",305,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",305,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",305,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",305,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",349,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"f32x16"}}],[11,"lanes","","Returns the number of vector lanes.",349,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",349,{"inputs":[{"name":"f32"}],"output":{"name":"f32x16"}}],[11,"extract","","Extracts the value at `index`.",349,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",349,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",349,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",349,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x16"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",349,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",349,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",349,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",349,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",349,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",349,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",349,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",349,null],[11,"eq","","Lane-wise equality comparison.",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",349,{"inputs":[{"name":"self"},{"name":"f32x16"}],"output":{"name":"b8x16"}}],[11,"sum","","Lane-wise addition of the vector elements.",349,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",349,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",349,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",349,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",315,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"u8x16"}}],[11,"lanes","","Returns the number of vector lanes.",315,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",315,{"inputs":[{"name":"u8"}],"output":{"name":"u8x16"}}],[11,"extract","","Extracts the value at `index`.",315,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",315,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",315,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",315,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x16"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",315,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",315,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",315,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",315,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",315,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",315,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",315,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",315,null],[11,"eq","","Lane-wise equality comparison.",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",315,{"inputs":[{"name":"self"},{"name":"u8x16"}],"output":{"name":"b8x16"}}],[11,"sum","","Lane-wise addition of the vector elements.",315,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",315,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",315,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",315,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",315,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",315,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",315,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",338,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"i16x16"}}],[11,"lanes","","Returns the number of vector lanes.",338,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",338,{"inputs":[{"name":"i16"}],"output":{"name":"i16x16"}}],[11,"extract","","Extracts the value at `index`.",338,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",338,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",338,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",338,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x16"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",338,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",338,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",338,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",338,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",338,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",338,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",338,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",338,null],[11,"eq","","Lane-wise equality comparison.",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",338,{"inputs":[{"name":"self"},{"name":"i16x16"}],"output":{"name":"b8x16"}}],[11,"sum","","Lane-wise addition of the vector elements.",338,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",338,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",338,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",338,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",338,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",338,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",338,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",348,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"i8x8"}}],[11,"lanes","","Returns the number of vector lanes.",348,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",348,{"inputs":[{"name":"i8"}],"output":{"name":"i8x8"}}],[11,"extract","","Extracts the value at `index`.",348,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",348,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",348,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",348,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",348,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",348,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",348,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",348,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",348,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",348,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",348,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",348,null],[11,"eq","","Lane-wise equality comparison.",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",348,{"inputs":[{"name":"self"},{"name":"i8x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",348,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",348,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",348,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",348,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",348,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",348,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",348,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",331,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"i8x32"}}],[11,"lanes","","Returns the number of vector lanes.",331,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",331,{"inputs":[{"name":"i8"}],"output":{"name":"i8x32"}}],[11,"extract","","Extracts the value at `index`.",331,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",331,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",331,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x32"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",331,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x32"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",331,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",331,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",331,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",331,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",331,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",331,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",331,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",331,null],[11,"eq","","Lane-wise equality comparison.",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",331,{"inputs":[{"name":"self"},{"name":"i8x32"}],"output":{"name":"b8x32"}}],[11,"sum","","Lane-wise addition of the vector elements.",331,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",331,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",331,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",331,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",331,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",331,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",331,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",316,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32x16"}}],[11,"lanes","","Returns the number of vector lanes.",316,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",316,{"inputs":[{"name":"i32"}],"output":{"name":"i32x16"}}],[11,"extract","","Extracts the value at `index`.",316,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",316,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",316,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",316,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x16"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",316,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",316,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",316,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",316,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",316,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",316,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",316,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",316,null],[11,"eq","","Lane-wise equality comparison.",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",316,{"inputs":[{"name":"self"},{"name":"i32x16"}],"output":{"name":"b8x16"}}],[11,"sum","","Lane-wise addition of the vector elements.",316,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",316,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",316,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",316,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",316,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",316,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",316,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",344,{"inputs":[{"name":"u16"},{"name":"u16"}],"output":{"name":"u16x2"}}],[11,"lanes","","Returns the number of vector lanes.",344,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",344,{"inputs":[{"name":"u16"}],"output":{"name":"u16x2"}}],[11,"extract","","Extracts the value at `index`.",344,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",344,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",344,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",344,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",344,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",344,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",344,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",344,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",344,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",344,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",344,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",344,null],[11,"eq","","Lane-wise equality comparison.",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",344,{"inputs":[{"name":"self"},{"name":"u16x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",344,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",344,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",344,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",344,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",344,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",344,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",344,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",312,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"u16x8"}}],[11,"lanes","","Returns the number of vector lanes.",312,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",312,{"inputs":[{"name":"u16"}],"output":{"name":"u16x8"}}],[11,"extract","","Extracts the value at `index`.",312,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",312,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",312,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",312,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",312,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",312,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",312,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",312,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",312,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",312,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",312,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",312,null],[11,"eq","","Lane-wise equality comparison.",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",312,{"inputs":[{"name":"self"},{"name":"u16x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",312,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",312,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",312,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",312,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",312,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",312,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",312,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",350,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"u32x16"}}],[11,"lanes","","Returns the number of vector lanes.",350,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",350,{"inputs":[{"name":"u32"}],"output":{"name":"u32x16"}}],[11,"extract","","Extracts the value at `index`.",350,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",350,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",350,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",350,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x16"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",350,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",350,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",350,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",350,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",350,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",350,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",350,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",350,null],[11,"eq","","Lane-wise equality comparison.",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",350,{"inputs":[{"name":"self"},{"name":"u32x16"}],"output":{"name":"b8x16"}}],[11,"sum","","Lane-wise addition of the vector elements.",350,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",350,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",350,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",350,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",350,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",350,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",350,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",303,{"inputs":[{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"},{"name":"i32"}],"output":{"name":"i32x8"}}],[11,"lanes","","Returns the number of vector lanes.",303,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",303,{"inputs":[{"name":"i32"}],"output":{"name":"i32x8"}}],[11,"extract","","Extracts the value at `index`.",303,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",303,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",303,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",303,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",303,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",303,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",303,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",303,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",303,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",303,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",303,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",303,null],[11,"eq","","Lane-wise equality comparison.",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",303,{"inputs":[{"name":"self"},{"name":"i32x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",303,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",303,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",303,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",303,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",303,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",303,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",303,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",302,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"i16x32"}}],[11,"lanes","","Returns the number of vector lanes.",302,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",302,{"inputs":[{"name":"i16"}],"output":{"name":"i16x32"}}],[11,"extract","","Extracts the value at `index`.",302,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",302,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",302,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x32"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",302,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x32"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",302,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",302,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",302,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",302,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",302,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",302,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",302,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",302,null],[11,"eq","","Lane-wise equality comparison.",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",302,{"inputs":[{"name":"self"},{"name":"i16x32"}],"output":{"name":"b8x32"}}],[11,"sum","","Lane-wise addition of the vector elements.",302,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",302,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",302,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",302,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",302,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",302,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",302,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",342,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"u16x32"}}],[11,"lanes","","Returns the number of vector lanes.",342,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",342,{"inputs":[{"name":"u16"}],"output":{"name":"u16x32"}}],[11,"extract","","Extracts the value at `index`.",342,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",342,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",342,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x32"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",342,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x32"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",342,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",342,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",342,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",342,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",342,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",342,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",342,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",342,null],[11,"eq","","Lane-wise equality comparison.",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",342,{"inputs":[{"name":"self"},{"name":"u16x32"}],"output":{"name":"b8x32"}}],[11,"sum","","Lane-wise addition of the vector elements.",342,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",342,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",342,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",342,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",342,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",342,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",342,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",330,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"i8x4"}}],[11,"lanes","","Returns the number of vector lanes.",330,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",330,{"inputs":[{"name":"i8"}],"output":{"name":"i8x4"}}],[11,"extract","","Extracts the value at `index`.",330,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",330,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",330,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",330,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",330,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",330,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",330,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",330,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",330,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",330,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",330,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",330,null],[11,"eq","","Lane-wise equality comparison.",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",330,{"inputs":[{"name":"self"},{"name":"i8x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",330,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",330,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",330,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",330,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",330,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",330,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",330,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",313,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"i8x16"}}],[11,"lanes","","Returns the number of vector lanes.",313,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",313,{"inputs":[{"name":"i8"}],"output":{"name":"i8x16"}}],[11,"extract","","Extracts the value at `index`.",313,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",313,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",313,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",313,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x16"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",313,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",313,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",313,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",313,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",313,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",313,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",313,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",313,null],[11,"eq","","Lane-wise equality comparison.",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",313,{"inputs":[{"name":"self"},{"name":"i8x16"}],"output":{"name":"b8x16"}}],[11,"sum","","Lane-wise addition of the vector elements.",313,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",313,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",313,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",313,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",313,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",313,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",313,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",444,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"b8x4"}}],[11,"lanes","","Returns the number of vector lanes.",444,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",444,{"inputs":[{"name":"bool"}],"output":{"name":"b8x4"}}],[11,"extract","","Extracts the value at `index`.",444,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",444,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",444,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",444,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x4"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",444,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",444,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",444,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",444,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",444,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",444,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",444,{"inputs":[{"name":"self"},{"name":"b8x4"}],"output":{"name":"b8x4"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",321,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"f64x2"}}],[11,"lanes","","Returns the number of vector lanes.",321,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",321,{"inputs":[{"name":"f64"}],"output":{"name":"f64x2"}}],[11,"extract","","Extracts the value at `index`.",321,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",321,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",321,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"f64x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",321,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"f64x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",321,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",321,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",321,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",321,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",321,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",321,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",321,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",321,null],[11,"eq","","Lane-wise equality comparison.",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",321,{"inputs":[{"name":"self"},{"name":"f64x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",321,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",321,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"max","","Largest vector value.",321,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"min","","Smallest vector value.",321,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",334,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"u8x64"}}],[11,"lanes","","Returns the number of vector lanes.",334,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",334,{"inputs":[{"name":"u8"}],"output":{"name":"u8x64"}}],[11,"extract","","Extracts the value at `index`.",334,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",334,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",334,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x64"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",334,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x64"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",334,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",334,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",334,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",334,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",334,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",334,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",334,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",334,null],[11,"eq","","Lane-wise equality comparison.",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"ne","","Lane-wise inequality comparison.",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"lt","","Lane-wise less-than comparison.",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"gt","","Lane-wise greater-than comparison.",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",334,{"inputs":[{"name":"self"},{"name":"u8x64"}],"output":{"name":"b8x64"}}],[11,"sum","","Lane-wise addition of the vector elements.",334,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",334,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",334,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",334,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",334,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",334,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",334,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",440,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"b8x64"}}],[11,"lanes","","Returns the number of vector lanes.",440,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",440,{"inputs":[{"name":"bool"}],"output":{"name":"b8x64"}}],[11,"extract","","Extracts the value at `index`.",440,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",440,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",440,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x64"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",440,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x64"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",440,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",440,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",440,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",440,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",440,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",440,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"ne","","Lane-wise inequality comparison.",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"lt","","Lane-wise less-than comparison.",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"gt","","Lane-wise greater-than comparison.",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",440,{"inputs":[{"name":"self"},{"name":"b8x64"}],"output":{"name":"b8x64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",346,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"u16x4"}}],[11,"lanes","","Returns the number of vector lanes.",346,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",346,{"inputs":[{"name":"u16"}],"output":{"name":"u16x4"}}],[11,"extract","","Extracts the value at `index`.",346,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",346,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",346,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",346,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",346,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",346,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",346,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",346,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",346,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",346,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",346,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",346,null],[11,"eq","","Lane-wise equality comparison.",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",346,{"inputs":[{"name":"self"},{"name":"u16x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",346,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",346,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",346,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",346,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",346,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",346,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",346,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",327,{"inputs":[{"name":"i64"},{"name":"i64"}],"output":{"name":"i64x2"}}],[11,"lanes","","Returns the number of vector lanes.",327,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",327,{"inputs":[{"name":"i64"}],"output":{"name":"i64x2"}}],[11,"extract","","Extracts the value at `index`.",327,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",327,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",327,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"i64x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",327,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"i64x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",327,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",327,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",327,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",327,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",327,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",327,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",327,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",327,null],[11,"eq","","Lane-wise equality comparison.",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",327,{"inputs":[{"name":"self"},{"name":"i64x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",327,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",327,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"max","","Largest vector value.",327,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"min","","Smallest vector value.",327,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",327,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",327,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",327,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",333,{"inputs":[{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"},{"name":"u16"}],"output":{"name":"u16x16"}}],[11,"lanes","","Returns the number of vector lanes.",333,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",333,{"inputs":[{"name":"u16"}],"output":{"name":"u16x16"}}],[11,"extract","","Extracts the value at `index`.",333,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",333,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",333,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",333,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u16"}],"output":{"name":"u16x16"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",333,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",333,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",333,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",333,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",333,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",333,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",333,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",333,null],[11,"eq","","Lane-wise equality comparison.",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",333,{"inputs":[{"name":"self"},{"name":"u16x16"}],"output":{"name":"b8x16"}}],[11,"sum","","Lane-wise addition of the vector elements.",333,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",333,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"max","","Largest vector value.",333,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"min","","Smallest vector value.",333,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",333,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",333,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",333,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",345,{"inputs":[{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"},{"name":"f32"}],"output":{"name":"f32x8"}}],[11,"lanes","","Returns the number of vector lanes.",345,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",345,{"inputs":[{"name":"f32"}],"output":{"name":"f32x8"}}],[11,"extract","","Extracts the value at `index`.",345,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",345,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",345,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",345,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",345,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",345,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",345,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",345,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",345,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",345,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",345,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",345,null],[11,"eq","","Lane-wise equality comparison.",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",345,{"inputs":[{"name":"self"},{"name":"f32x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",345,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",345,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",345,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",345,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",311,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"i16x4"}}],[11,"lanes","","Returns the number of vector lanes.",311,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",311,{"inputs":[{"name":"i16"}],"output":{"name":"i16x4"}}],[11,"extract","","Extracts the value at `index`.",311,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",311,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",311,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",311,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",311,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",311,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",311,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",311,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",311,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",311,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",311,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",311,null],[11,"eq","","Lane-wise equality comparison.",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",311,{"inputs":[{"name":"self"},{"name":"i16x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",311,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",311,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",311,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",311,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",311,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",311,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",311,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",341,{"inputs":[{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"}],"output":{"name":"u64x8"}}],[11,"lanes","","Returns the number of vector lanes.",341,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",341,{"inputs":[{"name":"u64"}],"output":{"name":"u64x8"}}],[11,"extract","","Extracts the value at `index`.",341,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",341,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",341,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"u64x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",341,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"u64x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",341,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",341,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",341,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",341,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",341,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",341,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",341,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",341,null],[11,"eq","","Lane-wise equality comparison.",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",341,{"inputs":[{"name":"self"},{"name":"u64x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",341,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",341,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"max","","Largest vector value.",341,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"min","","Smallest vector value.",341,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",341,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",341,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",341,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",358,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"i64x4"}}],[11,"lanes","","Returns the number of vector lanes.",358,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",358,{"inputs":[{"name":"i64"}],"output":{"name":"i64x4"}}],[11,"extract","","Extracts the value at `index`.",358,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",358,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",358,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"i64x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",358,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"i64x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",358,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",358,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",358,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",358,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",358,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",358,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",358,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",358,null],[11,"eq","","Lane-wise equality comparison.",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",358,{"inputs":[{"name":"self"},{"name":"i64x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",358,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",358,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"max","","Largest vector value.",358,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"min","","Smallest vector value.",358,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",358,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",358,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",358,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",357,{"inputs":[{"name":"u32"},{"name":"u32"},{"name":"u32"},{"name":"u32"}],"output":{"name":"u32x4"}}],[11,"lanes","","Returns the number of vector lanes.",357,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",357,{"inputs":[{"name":"u32"}],"output":{"name":"u32x4"}}],[11,"extract","","Extracts the value at `index`.",357,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",357,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",357,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",357,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",357,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",357,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",357,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",357,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",357,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",357,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",357,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",357,null],[11,"eq","","Lane-wise equality comparison.",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",357,{"inputs":[{"name":"self"},{"name":"u32x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",357,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",357,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",357,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",357,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",357,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",357,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",357,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",355,{"inputs":[{"name":"u64"},{"name":"u64"},{"name":"u64"},{"name":"u64"}],"output":{"name":"u64x4"}}],[11,"lanes","","Returns the number of vector lanes.",355,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",355,{"inputs":[{"name":"u64"}],"output":{"name":"u64x4"}}],[11,"extract","","Extracts the value at `index`.",355,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",355,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",355,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"u64x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",355,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"u64x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",355,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",355,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",355,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",355,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",355,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",355,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",355,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",355,null],[11,"eq","","Lane-wise equality comparison.",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",355,{"inputs":[{"name":"self"},{"name":"u64x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",355,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",355,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"max","","Largest vector value.",355,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"min","","Smallest vector value.",355,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",355,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",355,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",355,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",343,{"inputs":[{"name":"u8"},{"name":"u8"}],"output":{"name":"u8x2"}}],[11,"lanes","","Returns the number of vector lanes.",343,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",343,{"inputs":[{"name":"u8"}],"output":{"name":"u8x2"}}],[11,"extract","","Extracts the value at `index`.",343,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",343,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",343,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",343,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",343,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",343,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",343,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",343,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",343,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",343,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",343,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",343,null],[11,"eq","","Lane-wise equality comparison.",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",343,{"inputs":[{"name":"self"},{"name":"u8x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",343,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",343,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",343,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",343,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",343,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",343,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",343,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",442,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"b8x32"}}],[11,"lanes","","Returns the number of vector lanes.",442,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",442,{"inputs":[{"name":"bool"}],"output":{"name":"b8x32"}}],[11,"extract","","Extracts the value at `index`.",442,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",442,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",442,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x32"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",442,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",442,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",442,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",442,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",442,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",442,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",442,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",442,{"inputs":[{"name":"self"},{"name":"b8x32"}],"output":{"name":"b8x32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",336,{"inputs":[{"name":"i8"},{"name":"i8"}],"output":{"name":"i8x2"}}],[11,"lanes","","Returns the number of vector lanes.",336,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",336,{"inputs":[{"name":"i8"}],"output":{"name":"i8x2"}}],[11,"extract","","Extracts the value at `index`.",336,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",336,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",336,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",336,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",336,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",336,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",336,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",336,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",336,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",336,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",336,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",336,null],[11,"eq","","Lane-wise equality comparison.",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",336,{"inputs":[{"name":"self"},{"name":"i8x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",336,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",336,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",336,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",336,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",336,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",336,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",336,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",354,{"inputs":[{"name":"i16"},{"name":"i16"}],"output":{"name":"i16x2"}}],[11,"lanes","","Returns the number of vector lanes.",354,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",354,{"inputs":[{"name":"i16"}],"output":{"name":"i16x2"}}],[11,"extract","","Extracts the value at `index`.",354,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",354,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",354,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",354,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",354,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",354,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",354,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",354,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",354,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",354,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",354,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",354,null],[11,"eq","","Lane-wise equality comparison.",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",354,{"inputs":[{"name":"self"},{"name":"i16x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",354,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",354,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",354,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",354,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",354,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",354,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",354,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",310,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"name":"u32x2"}}],[11,"lanes","","Returns the number of vector lanes.",310,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",310,{"inputs":[{"name":"u32"}],"output":{"name":"u32x2"}}],[11,"extract","","Extracts the value at `index`.",310,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",310,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",310,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",310,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u32"}],"output":{"name":"u32x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",310,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",310,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",310,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",310,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",310,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",310,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",310,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",310,null],[11,"eq","","Lane-wise equality comparison.",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",310,{"inputs":[{"name":"self"},{"name":"u32x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",310,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",310,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"max","","Largest vector value.",310,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"min","","Smallest vector value.",310,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",310,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",310,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",310,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",337,{"inputs":[{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"},{"name":"i16"}],"output":{"name":"i16x8"}}],[11,"lanes","","Returns the number of vector lanes.",337,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",337,{"inputs":[{"name":"i16"}],"output":{"name":"i16x8"}}],[11,"extract","","Extracts the value at `index`.",337,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"extract_unchecked","","Extracts the value at `index`.",337,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i16"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",337,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",337,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i16"}],"output":{"name":"i16x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",337,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",337,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",337,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",337,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",337,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",337,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",337,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",337,null],[11,"eq","","Lane-wise equality comparison.",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",337,{"inputs":[{"name":"self"},{"name":"i16x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",337,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"product","","Lane-wise multiplication of the vector elements.",337,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"max","","Largest vector value.",337,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"min","","Smallest vector value.",337,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",337,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",337,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",337,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",351,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"u8x32"}}],[11,"lanes","","Returns the number of vector lanes.",351,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",351,{"inputs":[{"name":"u8"}],"output":{"name":"u8x32"}}],[11,"extract","","Extracts the value at `index`.",351,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",351,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",351,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x32"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",351,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x32"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",351,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",351,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",351,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",351,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",351,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",351,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",351,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",351,null],[11,"eq","","Lane-wise equality comparison.",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"ne","","Lane-wise inequality comparison.",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"lt","","Lane-wise less-than comparison.",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"gt","","Lane-wise greater-than comparison.",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",351,{"inputs":[{"name":"self"},{"name":"u8x32"}],"output":{"name":"b8x32"}}],[11,"sum","","Lane-wise addition of the vector elements.",351,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",351,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",351,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",351,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",351,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",351,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",351,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",325,{"inputs":[{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"},{"name":"i8"}],"output":{"name":"i8x64"}}],[11,"lanes","","Returns the number of vector lanes.",325,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",325,{"inputs":[{"name":"i8"}],"output":{"name":"i8x64"}}],[11,"extract","","Extracts the value at `index`.",325,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",325,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",325,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x64"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",325,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i8"}],"output":{"name":"i8x64"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",325,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",325,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",325,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",325,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",325,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",325,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",325,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",325,null],[11,"eq","","Lane-wise equality comparison.",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"ne","","Lane-wise inequality comparison.",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"lt","","Lane-wise less-than comparison.",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"gt","","Lane-wise greater-than comparison.",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",325,{"inputs":[{"name":"self"},{"name":"i8x64"}],"output":{"name":"b8x64"}}],[11,"sum","","Lane-wise addition of the vector elements.",325,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",325,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"max","","Largest vector value.",325,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"min","","Smallest vector value.",325,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",325,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",325,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",325,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",353,{"inputs":[{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"},{"name":"i64"}],"output":{"name":"i64x8"}}],[11,"lanes","","Returns the number of vector lanes.",353,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",353,{"inputs":[{"name":"i64"}],"output":{"name":"i64x8"}}],[11,"extract","","Extracts the value at `index`.",353,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",353,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",353,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"i64x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",353,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i64"}],"output":{"name":"i64x8"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",353,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",353,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",353,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",353,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",353,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",353,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",353,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",353,null],[11,"eq","","Lane-wise equality comparison.",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",353,{"inputs":[{"name":"self"},{"name":"i64x8"}],"output":{"name":"b8x8"}}],[11,"sum","","Lane-wise addition of the vector elements.",353,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",353,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"max","","Largest vector value.",353,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"min","","Smallest vector value.",353,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",353,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",353,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",353,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",450,{"inputs":[{"name":"bool"},{"name":"bool"}],"output":{"name":"b8x2"}}],[11,"lanes","","Returns the number of vector lanes.",450,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",450,{"inputs":[{"name":"bool"}],"output":{"name":"b8x2"}}],[11,"extract","","Extracts the value at `index`.",450,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",450,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",450,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",450,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x2"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",450,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",450,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",450,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",450,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",450,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",450,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",450,{"inputs":[{"name":"self"},{"name":"b8x2"}],"output":{"name":"b8x2"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",323,{"inputs":[{"name":"f32"},{"name":"f32"}],"output":{"name":"f32x2"}}],[11,"lanes","","Returns the number of vector lanes.",323,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",323,{"inputs":[{"name":"f32"}],"output":{"name":"f32x2"}}],[11,"extract","","Extracts the value at `index`.",323,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",323,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",323,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",323,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f32"}],"output":{"name":"f32x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",323,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",323,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",323,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",323,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",323,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",323,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",323,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",323,null],[11,"eq","","Lane-wise equality comparison.",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",323,{"inputs":[{"name":"self"},{"name":"f32x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",323,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",323,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Largest vector value.",323,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"min","","Smallest vector value.",323,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",352,{"inputs":[{"name":"f64"},{"name":"f64"},{"name":"f64"},{"name":"f64"}],"output":{"name":"f64x4"}}],[11,"lanes","","Returns the number of vector lanes.",352,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",352,{"inputs":[{"name":"f64"}],"output":{"name":"f64x4"}}],[11,"extract","","Extracts the value at `index`.",352,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",352,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"f64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",352,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"f64x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",352,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"f64"}],"output":{"name":"f64x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",352,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",352,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",352,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",352,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",352,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",352,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",352,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",352,null],[11,"eq","","Lane-wise equality comparison.",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",352,{"inputs":[{"name":"self"},{"name":"f64x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",352,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",352,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"max","","Largest vector value.",352,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"min","","Smallest vector value.",352,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",347,{"inputs":[{"name":"u8"},{"name":"u8"},{"name":"u8"},{"name":"u8"}],"output":{"name":"u8x4"}}],[11,"lanes","","Returns the number of vector lanes.",347,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",347,{"inputs":[{"name":"u8"}],"output":{"name":"u8x4"}}],[11,"extract","","Extracts the value at `index`.",347,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"extract_unchecked","","Extracts the value at `index`.",347,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u8"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",347,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x4"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",347,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u8"}],"output":{"name":"u8x4"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",347,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",347,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",347,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",347,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",347,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",347,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",347,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",347,null],[11,"eq","","Lane-wise equality comparison.",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"ne","","Lane-wise inequality comparison.",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"lt","","Lane-wise less-than comparison.",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"gt","","Lane-wise greater-than comparison.",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",347,{"inputs":[{"name":"self"},{"name":"u8x4"}],"output":{"name":"b8x4"}}],[11,"sum","","Lane-wise addition of the vector elements.",347,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"product","","Lane-wise multiplication of the vector elements.",347,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"max","","Largest vector value.",347,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"min","","Smallest vector value.",347,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",347,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",347,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",347,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",441,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"b8x16"}}],[11,"lanes","","Returns the number of vector lanes.",441,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",441,{"inputs":[{"name":"bool"}],"output":{"name":"b8x16"}}],[11,"extract","","Extracts the value at `index`.",441,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",441,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",441,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x16"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",441,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x16"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",441,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",441,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",441,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",441,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",441,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",441,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"ne","","Lane-wise inequality comparison.",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"lt","","Lane-wise less-than comparison.",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"gt","","Lane-wise greater-than comparison.",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",441,{"inputs":[{"name":"self"},{"name":"b8x16"}],"output":{"name":"b8x16"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",326,{"inputs":[{"name":"i32"},{"name":"i32"}],"output":{"name":"i32x2"}}],[11,"lanes","","Returns the number of vector lanes.",326,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",326,{"inputs":[{"name":"i32"}],"output":{"name":"i32x2"}}],[11,"extract","","Extracts the value at `index`.",326,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"extract_unchecked","","Extracts the value at `index`.",326,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"i32"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",326,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",326,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"i32"}],"output":{"name":"i32x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",326,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",326,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",326,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",326,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",326,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",326,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",326,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",326,null],[11,"eq","","Lane-wise equality comparison.",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",326,{"inputs":[{"name":"self"},{"name":"i32x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",326,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"product","","Lane-wise multiplication of the vector elements.",326,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"max","","Largest vector value.",326,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"min","","Smallest vector value.",326,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",326,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",326,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",326,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",447,{"inputs":[{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"},{"name":"bool"}],"output":{"name":"b8x8"}}],[11,"lanes","","Returns the number of vector lanes.",447,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",447,{"inputs":[{"name":"bool"}],"output":{"name":"b8x8"}}],[11,"extract","","Extracts the value at `index`.",447,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"extract_unchecked","","Extracts the value at `index`.",447,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"bool"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",447,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x8"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",447,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"bool"}],"output":{"name":"b8x8"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",447,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",447,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",447,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"all","","Are `all` vector lanes `true`?",447,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"any","","Is `any` vector lanes `true`?",447,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"none","","Are `all` vector lanes `false`?",447,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"eq","","Lane-wise equality comparison.",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"ne","","Lane-wise inequality comparison.",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"lt","","Lane-wise less-than comparison.",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"gt","","Lane-wise greater-than comparison.",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",447,{"inputs":[{"name":"self"},{"name":"b8x8"}],"output":{"name":"b8x8"}}],[11,"new","","Creates a new instance with each vector elements initialized with the provided values.",328,{"inputs":[{"name":"u64"},{"name":"u64"}],"output":{"name":"u64x2"}}],[11,"lanes","","Returns the number of vector lanes.",328,{"inputs":[],"output":{"name":"usize"}}],[11,"splat","","Constructs a new instance with each element initialized to `value`.",328,{"inputs":[{"name":"u64"}],"output":{"name":"u64x2"}}],[11,"extract","","Extracts the value at `index`.",328,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"extract_unchecked","","Extracts the value at `index`.",328,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"u64"}}],[11,"replace","","Returns a new vector where the value at `index` is replaced by `new_value`.",328,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"u64x2"}}],[11,"replace_unchecked","","Returns a new vector where the value at `index` is replaced by `new_value`.",328,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"u64"}],"output":{"name":"u64x2"}}],[11,"store_aligned","","Writes the values of the vector to the `slice`.",328,null],[11,"store_unaligned","","Writes the values of the vector to the `slice`.",328,null],[11,"store_aligned_unchecked","","Writes the values of the vector to the `slice`.",328,null],[11,"store_unaligned_unchecked","","Writes the values of the vector to the `slice`.",328,null],[11,"load_aligned","","Instantiates a new vector with the values of the `slice`.",328,null],[11,"load_unaligned","","Instantiates a new vector with the values of the `slice`.",328,null],[11,"load_aligned_unchecked","","Instantiates a new vector with the values of the `slice`.",328,null],[11,"load_unaligned_unchecked","","Instantiates a new vector with the values of the `slice`.",328,null],[11,"eq","","Lane-wise equality comparison.",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"ne","","Lane-wise inequality comparison.",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"lt","","Lane-wise less-than comparison.",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"le","","Lane-wise less-than-or-equals comparison.",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"gt","","Lane-wise greater-than comparison.",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"ge","","Lane-wise greater-than-or-equals comparison.",328,{"inputs":[{"name":"self"},{"name":"u64x2"}],"output":{"name":"b8x2"}}],[11,"sum","","Lane-wise addition of the vector elements.",328,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"product","","Lane-wise multiplication of the vector elements.",328,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"max","","Largest vector value.",328,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"min","","Smallest vector value.",328,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"and","","Lane-wise bitwise `and` of the vector elements.",328,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"or","","Lane-wise bitwise `or` of the vector elements.",328,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"xor","","Lane-wise bitwise `xor` of the vector elements.",328,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"is_nan","std","Returns `true` if this value is `NaN` and false otherwise.",319,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_infinite","","Returns `true` if this value is positive infinity or negative infinity and false otherwise.",319,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_finite","","Returns `true` if this number is neither infinite nor `NaN`.",319,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_normal","","Returns `true` if the number is neither zero, infinite, [subnormal][subnormal], or `NaN`.",319,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"classify","","Returns the floating point category of the number. If only one property is going to be tested, it is generally faster to use the specific predicate instead.",319,{"inputs":[{"name":"self"}],"output":{"name":"fpcategory"}}],[11,"floor","","Returns the largest integer less than or equal to a number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"ceil","","Returns the smallest integer greater than or equal to a number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"round","","Returns the nearest integer to a number. Round half-way cases away from `0.0`.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"trunc","","Returns the integer part of a number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"fract","","Returns the fractional part of a number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"abs","","Computes the absolute value of `self`. Returns `NAN` if the number is `NAN`.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"signum","","Returns a number that represents the sign of `self`.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"is_sign_positive","","Returns `true` if and only if `self` has a positive sign, including `+0.0`, `NaN`s with positive sign bit and positive infinity.",319,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_sign_negative","","Returns `true` if and only if `self` has a negative sign, including `-0.0`, `NaN`s with negative sign bit and negative infinity.",319,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"mul_add","","Fused multiply-add. Computes `(self * a) + b` with only one rounding error. This produces a more accurate result with better performance than a separate multiplication operation followed by an add.",319,{"inputs":[{"name":"self"},{"name":"f32"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"recip","","Takes the reciprocal (inverse) of a number, `1/x`.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"powi","","Raises a number to an integer power.",319,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"f32"}}],[11,"powf","","Raises a number to a floating point power.",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"sqrt","","Takes the square root of a number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"exp","","Returns `e^(self)`, (the exponential function).",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"exp2","","Returns `2^(self)`.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"ln","","Returns the natural logarithm of the number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"log","","Returns the logarithm of the number with respect to an arbitrary base.",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"log2","","Returns the base 2 logarithm of the number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"log10","","Returns the base 10 logarithm of the number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"to_degrees","","Converts radians to degrees.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"to_radians","","Converts degrees to radians.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"max","","Returns the maximum of the two numbers.",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"min","","Returns the minimum of the two numbers.",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"abs_sub","","The positive difference of two numbers.",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"cbrt","","Takes the cubic root of a number.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"hypot","","Calculates the length of the hypotenuse of a right-angle triangle given legs of length `x` and `y`.",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"sin","","Computes the sine of a number (in radians).",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"cos","","Computes the cosine of a number (in radians).",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"tan","","Computes the tangent of a number (in radians).",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"asin","","Computes the arcsine of a number. Return value is in radians in the range [-pi/2, pi/2] or NaN if the number is outside the range [-1, 1].",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"acos","","Computes the arccosine of a number. Return value is in radians in the range [0, pi] or NaN if the number is outside the range [-1, 1].",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"atan","","Computes the arctangent of a number. Return value is in radians in the range [-pi/2, pi/2];",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"atan2","","Computes the four quadrant arctangent of `self` (`y`) and `other` (`x`) in radians.",319,{"inputs":[{"name":"self"},{"name":"f32"}],"output":{"name":"f32"}}],[11,"sin_cos","","Simultaneously computes the sine and cosine of the number, `x`. Returns `(sin(x), cos(x))`.",319,null],[11,"exp_m1","","Returns `e^(self) - 1` in a way that is accurate even if the number is close to zero.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"ln_1p","","Returns `ln(1+n)` (natural logarithm) more accurately than if the operations were performed separately.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"sinh","","Hyperbolic sine function.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"cosh","","Hyperbolic cosine function.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"tanh","","Hyperbolic tangent function.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"asinh","","Inverse hyperbolic sine function.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"acosh","","Inverse hyperbolic cosine function.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"atanh","","Inverse hyperbolic tangent function.",319,{"inputs":[{"name":"self"}],"output":{"name":"f32"}}],[11,"to_bits","","Raw transmutation to `u32`.",319,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"from_bits","","Raw transmutation from `u32`.",319,{"inputs":[{"name":"u32"}],"output":{"name":"self"}}],[11,"is_nan","","Returns `true` if this value is `NaN` and false otherwise.",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_infinite","","Returns `true` if this value is positive infinity or negative infinity and false otherwise.",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_finite","","Returns `true` if this number is neither infinite nor `NaN`.",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_normal","","Returns `true` if the number is neither zero, infinite, [subnormal][subnormal], or `NaN`.",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"classify","","Returns the floating point category of the number. If only one property is going to be tested, it is generally faster to use the specific predicate instead.",314,{"inputs":[{"name":"self"}],"output":{"name":"fpcategory"}}],[11,"floor","","Returns the largest integer less than or equal to a number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"ceil","","Returns the smallest integer greater than or equal to a number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"round","","Returns the nearest integer to a number. Round half-way cases away from `0.0`.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"trunc","","Returns the integer part of a number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"fract","","Returns the fractional part of a number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"abs","","Computes the absolute value of `self`. Returns `NAN` if the number is `NAN`.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"signum","","Returns a number that represents the sign of `self`.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"is_sign_positive","","Returns `true` if and only if `self` has a positive sign, including `+0.0`, `NaN`s with positive sign bit and positive infinity.",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_positive","","",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_sign_negative","","Returns `true` if and only if `self` has a negative sign, including `-0.0`, `NaN`s with negative sign bit and negative infinity.",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_negative","","",314,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"mul_add","","Fused multiply-add. Computes `(self * a) + b` with only one rounding error. This produces a more accurate result with better performance than a separate multiplication operation followed by an add.",314,{"inputs":[{"name":"self"},{"name":"f64"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"recip","","Takes the reciprocal (inverse) of a number, `1/x`.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"powi","","Raises a number to an integer power.",314,{"inputs":[{"name":"self"},{"name":"i32"}],"output":{"name":"f64"}}],[11,"powf","","Raises a number to a floating point power.",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"sqrt","","Takes the square root of a number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"exp","","Returns `e^(self)`, (the exponential function).",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"exp2","","Returns `2^(self)`.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"ln","","Returns the natural logarithm of the number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"log","","Returns the logarithm of the number with respect to an arbitrary base.",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"log2","","Returns the base 2 logarithm of the number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"log10","","Returns the base 10 logarithm of the number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"to_degrees","","Converts radians to degrees.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"to_radians","","Converts degrees to radians.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"max","","Returns the maximum of the two numbers.",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"min","","Returns the minimum of the two numbers.",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"abs_sub","","The positive difference of two numbers.",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"cbrt","","Takes the cubic root of a number.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"hypot","","Calculates the length of the hypotenuse of a right-angle triangle given legs of length `x` and `y`.",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"sin","","Computes the sine of a number (in radians).",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"cos","","Computes the cosine of a number (in radians).",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"tan","","Computes the tangent of a number (in radians).",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"asin","","Computes the arcsine of a number. Return value is in radians in the range [-pi/2, pi/2] or NaN if the number is outside the range [-1, 1].",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"acos","","Computes the arccosine of a number. Return value is in radians in the range [0, pi] or NaN if the number is outside the range [-1, 1].",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"atan","","Computes the arctangent of a number. Return value is in radians in the range [-pi/2, pi/2];",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"atan2","","Computes the four quadrant arctangent of `self` (`y`) and `other` (`x`) in radians.",314,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[11,"sin_cos","","Simultaneously computes the sine and cosine of the number, `x`. Returns `(sin(x), cos(x))`.",314,null],[11,"exp_m1","","Returns `e^(self) - 1` in a way that is accurate even if the number is close to zero.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"ln_1p","","Returns `ln(1+n)` (natural logarithm) more accurately than if the operations were performed separately.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"sinh","","Hyperbolic sine function.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"cosh","","Hyperbolic cosine function.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"tanh","","Hyperbolic tangent function.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"asinh","","Inverse hyperbolic sine function.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"acosh","","Inverse hyperbolic cosine function.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"atanh","","Inverse hyperbolic tangent function.",314,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"to_bits","","Raw transmutation to `u64`.",314,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"from_bits","","Raw transmutation from `u64`.",314,{"inputs":[{"name":"u64"}],"output":{"name":"self"}}],[11,"is_ascii","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","",320,null],[11,"to_ascii_lowercase","","",320,null],[11,"eq_ignore_ascii_case","","",320,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"make_ascii_uppercase","","",320,{"inputs":[{"name":"self"}],"output":null}],[11,"make_ascii_lowercase","","",320,{"inputs":[{"name":"self"}],"output":null}],[11,"is_ascii_alphabetic","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_uppercase","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_lowercase","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_alphanumeric","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_digit","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_hexdigit","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_punctuation","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_graphic","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_whitespace","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_control","","",320,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","",432,null],[11,"to_ascii_lowercase","","",432,null],[11,"eq_ignore_ascii_case","","",432,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"make_ascii_uppercase","","",432,{"inputs":[{"name":"self"}],"output":null}],[11,"make_ascii_lowercase","","",432,{"inputs":[{"name":"self"}],"output":null}],[11,"is_ascii_alphabetic","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_uppercase","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_lowercase","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_alphanumeric","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_digit","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_hexdigit","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_punctuation","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_graphic","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_whitespace","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_control","","",432,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","",433,null],[11,"to_ascii_lowercase","","",433,null],[11,"eq_ignore_ascii_case","","",433,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"make_ascii_uppercase","","",433,{"inputs":[{"name":"self"}],"output":null}],[11,"make_ascii_lowercase","","",433,{"inputs":[{"name":"self"}],"output":null}],[11,"is_ascii_alphabetic","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_uppercase","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_lowercase","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_alphanumeric","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_digit","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_hexdigit","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_punctuation","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_graphic","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_whitespace","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_control","","",433,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"to_ascii_uppercase","","",429,null],[11,"to_ascii_lowercase","","",429,null],[11,"eq_ignore_ascii_case","","",429,{"inputs":[{"name":"self"},{"name":"self"}],"output":{"name":"bool"}}],[11,"make_ascii_uppercase","","",429,{"inputs":[{"name":"self"}],"output":null}],[11,"make_ascii_lowercase","","",429,{"inputs":[{"name":"self"}],"output":null}],[11,"is_ascii_alphabetic","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_uppercase","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_lowercase","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_alphanumeric","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_digit","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_hexdigit","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_punctuation","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_graphic","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_whitespace","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"is_ascii_control","","",429,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"new","std::collections::binary_heap","Creates an empty `BinaryHeap` as a max-heap.",478,{"inputs":[],"output":{"name":"binaryheap"}}],[11,"with_capacity","","Creates an empty `BinaryHeap` with a specific capacity. This preallocates enough memory for `capacity` elements, so that the `BinaryHeap` does not have to be reallocated until it contains at least that many values.",478,{"inputs":[{"name":"usize"}],"output":{"name":"binaryheap"}}],[11,"iter","","Returns an iterator visiting all values in the underlying vector, in arbitrary order.",478,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"peek","","Returns the greatest item in the binary heap, or `None` if it is empty.",478,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"peek_mut","","Returns a mutable reference to the greatest item in the binary heap, or `None` if it is empty.",478,{"inputs":[{"name":"self"}],"output":{"generics":["peekmut"],"name":"option"}}],[11,"capacity","","Returns the number of elements the binary heap can hold without reallocating.",478,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve_exact","","Reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `BinaryHeap`. Does nothing if the capacity is already sufficient.",478,null],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the `BinaryHeap`. The collection may reserve more space to avoid frequent reallocations.",478,null],[11,"shrink_to_fit","","Discards as much additional capacity as possible.",478,null],[11,"shrink_to","","Discards capacity with a lower bound.",478,null],[11,"pop","","Removes the greatest item from the binary heap and returns it, or `None` if it is empty.",478,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push","","Pushes an item onto the binary heap.",478,null],[11,"into_vec","","Consumes the `BinaryHeap` and returns the underlying vector in arbitrary order.",478,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"into_sorted_vec","","Consumes the `BinaryHeap` and returns a vector in sorted (ascending) order.",478,{"inputs":[{"name":"self"}],"output":{"name":"vec"}}],[11,"len","","Returns the length of the binary heap.",478,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Checks if the binary heap is empty.",478,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"drain","","Clears the binary heap, returning an iterator over the removed elements.",478,{"inputs":[{"name":"self"}],"output":{"name":"drain"}}],[11,"clear","","Drops all items from the binary heap.",478,null],[11,"append","","Moves all the elements of `other` into `self`, leaving `other` empty.",478,null],[11,"new","std::collections::btree_map","Makes a new empty BTreeMap with a reasonable choice for B.",484,{"inputs":[],"output":{"name":"btreemap"}}],[11,"clear","","Clears the map, removing all values.",484,null],[11,"get","","Returns a reference to the value corresponding to the key.",484,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"get_key_value","","Returns the key-value pair corresponding to the supplied key.",484,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"contains_key","","Returns `true` if the map contains a value for the specified key.",484,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"get_mut","","Returns a mutable reference to the value corresponding to the key.",484,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"insert","","Inserts a key-value pair into the map.",484,{"inputs":[{"name":"self"},{"name":"k"},{"name":"v"}],"output":{"name":"option"}}],[11,"remove","","Removes a key from the map, returning the value at the key if the key was previously in the map.",484,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"append","","Moves all elements from `other` into `Self`, leaving `other` empty.",484,null],[11,"range","","Constructs a double-ended iterator over a sub-range of elements in the map. The simplest way is to use the range syntax `min..max`, thus `range(min..max)` will yield elements from min (inclusive) to max (exclusive). The range may also be entered as `(Bound<T>, Bound<T>)`, so for example `range((Excluded(4), Included(10)))` will yield a left-exclusive, right-inclusive range from 4 to 10.",484,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"range"}}],[11,"range_mut","","Constructs a mutable double-ended iterator over a sub-range of elements in the map. The simplest way is to use the range syntax `min..max`, thus `range(min..max)` will yield elements from min (inclusive) to max (exclusive). The range may also be entered as `(Bound<T>, Bound<T>)`, so for example `range((Excluded(4), Included(10)))` will yield a left-exclusive, right-inclusive range from 4 to 10.",484,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"rangemut"}}],[11,"entry","","Gets the given key's corresponding entry in the map for in-place manipulation.",484,{"inputs":[{"name":"self"},{"name":"k"}],"output":{"name":"entry"}}],[11,"split_off","","Splits the collection into two at the given key. Returns everything after the given key, including the key.",484,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"btreemap"}}],[11,"iter","","Gets an iterator over the entries of the map, sorted by key.",484,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Gets a mutable iterator over the entries of the map, sorted by key.",484,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"keys","","Gets an iterator over the keys of the map, in sorted order.",484,{"inputs":[{"name":"self"}],"output":{"name":"keys"}}],[11,"values","","Gets an iterator over the values of the map, in order by key.",484,{"inputs":[{"name":"self"}],"output":{"name":"values"}}],[11,"values_mut","","Gets a mutable iterator over the values of the map, in order by key.",484,{"inputs":[{"name":"self"}],"output":{"name":"valuesmut"}}],[11,"len","","Returns the number of elements in the map.",484,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the map contains no elements.",484,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"new","std::collections::btree_set","Makes a new `BTreeSet` with a reasonable choice of B.",483,{"inputs":[],"output":{"name":"btreeset"}}],[11,"range","","Constructs a double-ended iterator over a sub-range of elements in the set. The simplest way is to use the range syntax `min..max`, thus `range(min..max)` will yield elements from min (inclusive) to max (exclusive). The range may also be entered as `(Bound<T>, Bound<T>)`, so for example `range((Excluded(4), Included(10)))` will yield a left-exclusive, right-inclusive range from 4 to 10.",483,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"range"}}],[11,"difference","","Visits the values representing the difference, i.e. the values that are in `self` but not in `other`, in ascending order.",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"difference"}}],[11,"symmetric_difference","","Visits the values representing the symmetric difference, i.e. the values that are in `self` or in `other` but not in both, in ascending order.",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"symmetricdifference"}}],[11,"intersection","","Visits the values representing the intersection, i.e. the values that are both in `self` and `other`, in ascending order.",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"intersection"}}],[11,"union","","Visits the values representing the union, i.e. all the values in `self` or `other`, without duplicates, in ascending order.",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"union"}}],[11,"clear","","Clears the set, removing all values.",483,null],[11,"contains","","Returns `true` if the set contains a value.",483,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"get","","Returns a reference to the value in the set, if any, that is equal to the given value.",483,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"is_disjoint","","Returns `true` if `self` has no elements in common with `other`. This is equivalent to checking for an empty intersection.",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"is_subset","","Returns `true` if the set is a subset of another, i.e. `other` contains at least all the values in `self`.",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"is_superset","","Returns `true` if the set is a superset of another, i.e. `self` contains at least all the values in `other`.",483,{"inputs":[{"name":"self"},{"name":"btreeset"}],"output":{"name":"bool"}}],[11,"insert","","Adds a value to the set.",483,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"replace","","Adds a value to the set, replacing the existing value, if any, that is equal to the given one. Returns the replaced value.",483,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"option"}}],[11,"remove","","Removes a value from the set. Returns `true` if the value was present in the set.",483,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"bool"}}],[11,"take","","Removes and returns the value in the set, if any, that is equal to the given one.",483,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"option"}}],[11,"append","","Moves all elements from `other` into `Self`, leaving `other` empty.",483,null],[11,"split_off","","Splits the collection into two at the given key. Returns everything after the given key, including the key.",483,{"inputs":[{"name":"self"},{"name":"q"}],"output":{"name":"btreeset"}}],[11,"iter","","Gets an iterator that visits the values in the `BTreeSet` in ascending order.",483,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"len","","Returns the number of elements in the set.",483,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the set contains no elements.",483,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"new","std::collections::linked_list","Creates an empty `LinkedList`.",482,{"inputs":[],"output":{"name":"linkedlist"}}],[11,"append","","Moves all elements from `other` to the end of the list.",482,null],[11,"iter","","Provides a forward iterator.",482,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Provides a forward iterator with mutable references.",482,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"is_empty","","Returns `true` if the `LinkedList` is empty.",482,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"len","","Returns the length of the `LinkedList`.",482,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"clear","","Removes all elements from the `LinkedList`.",482,null],[11,"contains","","Returns `true` if the `LinkedList` contains an element equal to the given value.",482,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"front","","Provides a reference to the front element, or `None` if the list is empty.",482,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"front_mut","","Provides a mutable reference to the front element, or `None` if the list is empty.",482,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back","","Provides a reference to the back element, or `None` if the list is empty.",482,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back_mut","","Provides a mutable reference to the back element, or `None` if the list is empty.",482,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push_front","","Adds an element first in the list.",482,null],[11,"pop_front","","Removes the first element and returns it, or `None` if the list is empty.",482,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push_back","","Appends an element to the back of a list",482,null],[11,"pop_back","","Removes the last element from a list and returns it, or `None` if it is empty.",482,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"split_off","","Splits the list into two at the given index. Returns everything after the given index, including the index.",482,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"linkedlist"}}],[11,"drain_filter","","Creates an iterator which uses a closure to determine if an element should be removed.",482,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"drainfilter"}}],[11,"front_place","","Returns a place for insertion at the front of the list.",482,{"inputs":[{"name":"self"}],"output":{"name":"frontplace"}}],[11,"back_place","","Returns a place for insertion at the back of the list.",482,{"inputs":[{"name":"self"}],"output":{"name":"backplace"}}],[11,"new","std::collections::vec_deque","Creates an empty `VecDeque`.",485,{"inputs":[],"output":{"name":"vecdeque"}}],[11,"with_capacity","","Creates an empty `VecDeque` with space for at least `n` elements.",485,{"inputs":[{"name":"usize"}],"output":{"name":"vecdeque"}}],[11,"get","","Retrieves an element in the `VecDeque` by index.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"get_mut","","Retrieves an element in the `VecDeque` mutably by index.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"swap","","Swaps elements at indices `i` and `j`.",485,null],[11,"capacity","","Returns the number of elements the `VecDeque` can hold without reallocating.",485,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"reserve_exact","","Reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `VecDeque`. Does nothing if the capacity is already sufficient.",485,null],[11,"reserve","","Reserves capacity for at least `additional` more elements to be inserted in the given `VecDeque`. The collection may reserve more space to avoid frequent reallocations.",485,null],[11,"try_reserve_exact","","Tries to reserves the minimum capacity for exactly `additional` more elements to be inserted in the given `VecDeque<T>`. After calling `reserve_exact`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if the capacity is already sufficient.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"try_reserve","","Tries to reserve capacity for at least `additional` more elements to be inserted in the given `VecDeque<T>`. The collection may reserve more space to avoid frequent reallocations. After calling `reserve`, capacity will be greater than or equal to `self.len() + additional`. Does nothing if capacity is already sufficient.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["collectionallocerr"],"name":"result"}}],[11,"shrink_to_fit","","Shrinks the capacity of the `VecDeque` as much as possible.",485,null],[11,"shrink_to","","Shrinks the capacity of the `VecDeque` with a lower bound.",485,null],[11,"truncate","","Shortens the `VecDeque`, dropping excess elements from the back.",485,null],[11,"iter","","Returns a front-to-back iterator.",485,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"iter_mut","","Returns a front-to-back iterator that returns mutable references.",485,{"inputs":[{"name":"self"}],"output":{"name":"itermut"}}],[11,"as_slices","","Returns a pair of slices which contain, in order, the contents of the `VecDeque`.",485,null],[11,"as_mut_slices","","Returns a pair of slices which contain, in order, the contents of the `VecDeque`.",485,null],[11,"len","","Returns the number of elements in the `VecDeque`.",485,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"is_empty","","Returns `true` if the `VecDeque` is empty.",485,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"drain","","Create a draining iterator that removes the specified range in the `VecDeque` and yields the removed items.",485,{"inputs":[{"name":"self"},{"name":"r"}],"output":{"name":"drain"}}],[11,"clear","","Clears the `VecDeque`, removing all values.",485,null],[11,"contains","","Returns `true` if the `VecDeque` contains an element equal to the given value.",485,{"inputs":[{"name":"self"},{"name":"t"}],"output":{"name":"bool"}}],[11,"front","","Provides a reference to the front element, or `None` if the `VecDeque` is empty.",485,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"front_mut","","Provides a mutable reference to the front element, or `None` if the `VecDeque` is empty.",485,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back","","Provides a reference to the back element, or `None` if the `VecDeque` is empty.",485,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"back_mut","","Provides a mutable reference to the back element, or `None` if the `VecDeque` is empty.",485,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"pop_front","","Removes the first element and returns it, or `None` if the `VecDeque` is empty.",485,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"push_front","","Prepends an element to the `VecDeque`.",485,null],[11,"push_back","","Appends an element to the back of the `VecDeque`.",485,null],[11,"pop_back","","Removes the last element from the `VecDeque` and returns it, or `None` if it is empty.",485,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"swap_remove_back","","Removes an element from anywhere in the `VecDeque` and returns it, replacing it with the last element.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"swap_remove_front","","Removes an element from anywhere in the `VecDeque` and returns it, replacing it with the first element.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"insert","","Inserts an element at `index` within the `VecDeque`, shifting all elements with indices greater than or equal to `index` towards the back.",485,null],[11,"remove","","Removes and returns the element at `index` from the `VecDeque`. Whichever end is closer to the removal point will be moved to make room, and all the affected elements will be moved to new positions. Returns `None` if `index` is out of bounds.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"option"}}],[11,"split_off","","Splits the `VecDeque` into two at the given index.",485,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"name":"vecdeque"}}],[11,"append","","Moves all the elements of `other` into `Self`, leaving `other` empty.",485,null],[11,"retain","","Retains only the elements specified by the predicate.",485,null],[11,"place_back","","Returns a place for insertion at the back of the `VecDeque`.",485,{"inputs":[{"name":"self"}],"output":{"name":"placeback"}}],[11,"place_front","","Returns a place for insertion at the front of the `VecDeque`.",485,{"inputs":[{"name":"self"}],"output":{"name":"placefront"}}],[11,"resize","","Modifies the `VecDeque` in-place so that `len()` is equal to new_len, either by removing excess elements from the back or by appending clones of `value` to the back.",485,null],[11,"pop","std::collections::binary_heap","Removes the peeked value from the heap and returns it.",521,{"inputs":[{"name":"peekmut"}],"output":{"name":"t"}}],[11,"key","std::collections::btree_map","Gets a reference to the key in the entry.",507,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"remove_entry","","Take ownership of the key and value from the map.",507,null],[11,"get","","Gets a reference to the value in the entry.",507,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"get_mut","","Gets a mutable reference to the value in the entry.",507,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"into_mut","","Converts the entry into a mutable reference to its value.",507,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"insert","","Sets the value of the entry with the `OccupiedEntry`'s key, and returns the entry's old value.",507,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"remove","","Takes the value of the entry out of the map, and returns it.",507,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"key","","Gets a reference to the key that would be used when inserting a value through the VacantEntry.",502,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"into_key","","Take ownership of the key.",502,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"insert","","Sets the value of the entry with the `VacantEntry`'s key, and returns a mutable reference to it.",502,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"or_insert","","Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.",107,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"or_insert_with","","Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.",107,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"v"}}],[11,"key","","Returns a reference to this entry's key.",107,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"and_modify","","Provides in-place mutable access to an occupied entry before any potential inserts into the map.",107,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"entry"}}],[11,"or_default","","Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.",107,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"insert_next","std::collections::linked_list","Inserts the given element just after the element most recently returned by `.next()`. The inserted element does not appear in the iteration.",500,null],[11,"peek_next","","Provides a reference to the next element, without changing the iterator.",500,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"clone","std::collections::hash_map","",539,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"fmt","","",539,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",540,{"inputs":[{"name":"self"}],"output":{"name":"keys"}}],[11,"fmt","","",540,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",541,{"inputs":[{"name":"self"}],"output":{"name":"values"}}],[11,"fmt","","",541,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",111,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",542,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",543,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",539,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",539,null],[11,"len","","",539,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next","","",544,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",544,null],[11,"len","","",544,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",544,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",545,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",545,null],[11,"len","","",545,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",545,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",540,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",540,null],[11,"len","","",540,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next","","",541,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",541,null],[11,"len","","",541,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next","","",546,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",546,null],[11,"len","","",546,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",546,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",547,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",547,null],[11,"len","","",547,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",547,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",548,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"drop","","",548,{"inputs":[{"name":"self"}],"output":null}],[11,"make_place","","",111,{"inputs":[{"name":"self"}],"output":{"name":"entryplace"}}],[11,"pointer","","",548,null],[11,"finalize","","",548,{"inputs":[{"name":"self"}],"output":null}],[11,"or_insert","","Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.",111,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"or_insert_with","","Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.",111,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"v"}}],[11,"key","","Returns a reference to this entry's key.",111,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"and_modify","","Provides in-place mutable access to an occupied entry before any potential inserts into the map.",111,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"name":"self"}}],[11,"or_default","","Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.",111,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"key","","Gets a reference to the key in the entry.",542,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"remove_entry","","Take the ownership of the key and value from the map.",542,null],[11,"get","","Gets a reference to the value in the entry.",542,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"get_mut","","Gets a mutable reference to the value in the entry.",542,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"into_mut","","Converts the OccupiedEntry into a mutable reference to the value in the entry with a lifetime bound to the map itself.",542,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"insert","","Sets the value of the entry, and returns the entry's old value.",542,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"remove","","Takes the value out of the entry, and returns it.",542,{"inputs":[{"name":"self"}],"output":{"name":"v"}}],[11,"replace_entry","","Replaces the entry, returning the old key and value. The new key in the hash map will be the key used to create this entry.",542,null],[11,"replace_key","","Replaces the key in the hash map with the key used to create this entry.",542,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"key","","Gets a reference to the key that would be used when inserting a value through the `VacantEntry`.",543,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"into_key","","Take ownership of the key.",543,{"inputs":[{"name":"self"}],"output":{"name":"k"}}],[11,"insert","","Sets the value of the entry with the VacantEntry's key, and returns a mutable reference to it.",543,{"inputs":[{"name":"self"},{"name":"v"}],"output":{"name":"v"}}],[11,"clone","","",549,{"inputs":[{"name":"self"}],"output":{"name":"randomstate"}}],[11,"new","","Constructs a new `RandomState` that is initialized with random keys.",549,{"inputs":[],"output":{"name":"randomstate"}}],[11,"build_hasher","","",549,{"inputs":[{"name":"self"}],"output":{"name":"defaulthasher"}}],[11,"clone","","",550,{"inputs":[{"name":"self"}],"output":{"name":"defaulthasher"}}],[11,"fmt","","",550,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","Creates a new `DefaultHasher`.",550,{"inputs":[],"output":{"name":"defaulthasher"}}],[11,"default","","Creates a new `DefaultHasher` using [`new`]. See its documentation for more.",550,{"inputs":[],"output":{"name":"defaulthasher"}}],[11,"write","","",550,null],[11,"finish","","",550,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"default","","Constructs a new `RandomState`.",549,{"inputs":[],"output":{"name":"randomstate"}}],[11,"fmt","","",549,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","std::collections::hash_set","",551,{"inputs":[{"name":"self"}],"output":{"name":"iter"}}],[11,"next","","",551,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",551,null],[11,"len","","",551,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",551,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",552,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",552,null],[11,"len","","",552,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",552,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",553,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",553,null],[11,"len","","",553,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"fmt","","",553,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",554,{"inputs":[{"name":"self"}],"output":{"name":"intersection"}}],[11,"next","","",554,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",554,null],[11,"fmt","","",554,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",555,{"inputs":[{"name":"self"}],"output":{"name":"difference"}}],[11,"next","","",555,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",555,null],[11,"fmt","","",555,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",556,{"inputs":[{"name":"self"}],"output":{"name":"symmetricdifference"}}],[11,"next","","",556,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",556,null],[11,"fmt","","",556,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",557,{"inputs":[{"name":"self"}],"output":{"name":"union"}}],[11,"fmt","","",557,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",557,{"inputs":[{"name":"self"}],"output":{"name":"option"}}],[11,"size_hint","","",557,null],[11,"description","std","",473,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","std::num","",448,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",439,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"description","","",438,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"from","std::sync","",477,{"inputs":[{"name":"cstring"}],"output":{"generics":["cstr"],"name":"arc"}}],[11,"from","","",477,{"inputs":[{"name":"cstr"}],"output":{"generics":["cstr"],"name":"arc"}}],[11,"from","std::io","",156,{"inputs":[{"name":"nulerror"}],"output":{"name":"error"}}],[11,"eq","std","",429,{"inputs":[{"name":"self"},{"name":"osstring"}],"output":{"name":"bool"}}],[11,"from","std::sync","",477,{"inputs":[{"name":"osstring"}],"output":{"generics":["osstr"],"name":"arc"}}],[11,"from","","",477,{"inputs":[{"name":"osstr"}],"output":{"generics":["osstr"],"name":"arc"}}],[11,"eq","std","",429,{"inputs":[{"name":"self"},{"name":"osstr"}],"output":{"name":"bool"}}],[11,"as_ref","","",429,{"inputs":[{"name":"self"}],"output":{"name":"osstr"}}],[11,"read","","",285,null],[11,"initializer","","",285,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"read_to_end","","",285,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_to_string","","",285,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_exact","","",285,null],[11,"write","","",285,null],[11,"flush","","",285,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"write_all","","",285,null],[11,"write_fmt","","",285,{"inputs":[{"name":"self"},{"name":"arguments"}],"output":{"name":"result"}}],[11,"seek","","",285,{"inputs":[{"name":"self"},{"name":"seekfrom"}],"output":{"generics":["u64"],"name":"result"}}],[11,"fill_buf","","",285,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",285,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"read_until","","",285,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read_line","","",285,{"inputs":[{"name":"self"},{"name":"string"}],"output":{"generics":["usize"],"name":"result"}}],[11,"read","","",433,null],[11,"initializer","","",433,{"inputs":[{"name":"self"}],"output":{"name":"initializer"}}],[11,"read_exact","","",433,null],[11,"read_to_end","","",433,{"inputs":[{"name":"self"},{"name":"vec"}],"output":{"generics":["usize"],"name":"result"}}],[11,"fill_buf","","",433,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"consume","","",433,{"inputs":[{"name":"self"},{"name":"usize"}],"output":null}],[11,"write","","",433,null],[11,"write_all","","",433,null],[11,"flush","","",433,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"from","","Convert an `Ipv4Addr` into a host byte order `u32`.",301,{"inputs":[{"name":"ipv4addr"}],"output":{"name":"u32"}}],[11,"from","","",339,{"inputs":[{"name":"ipv6addr"}],"output":{"name":"u128"}}],[11,"to_socket_addrs","","",424,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","","",424,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","","",424,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","","",424,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","","",429,{"inputs":[{"name":"self"}],"output":{"generics":["intoiter"],"name":"result"}}],[11,"to_socket_addrs","","",433,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"to_socket_addrs","","",285,{"inputs":[{"name":"self"}],"output":{"name":"result"}}],[11,"count_ones","std::num","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["usize"],"name":"wrapping"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["usize"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["u8"],"name":"wrapping"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u8"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["u16"],"name":"wrapping"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u16"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["u32"],"name":"wrapping"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u32"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["u64"],"name":"wrapping"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u64"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["u128"],"name":"wrapping"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["u128"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["isize"],"name":"wrapping"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["isize"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["i8"],"name":"wrapping"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i8"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["i16"],"name":"wrapping"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i16"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["i32"],"name":"wrapping"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i32"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["i64"],"name":"wrapping"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i64"],"name":"wrapping"}}],[11,"count_ones","","Returns the number of ones in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"count_zeros","","Returns the number of zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"leading_zeros","","Returns the number of leading zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"trailing_zeros","","Returns the number of trailing zeros in the binary representation of `self`.",195,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"rotate_left","","Shifts the bits to the left by a specified amount, `n`, wrapping the truncated bits to the end of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"rotate_right","","Shifts the bits to the right by a specified amount, `n`, wrapping the truncated bits to the beginning of the resulting integer.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"swap_bytes","","Reverses the byte order of the integer.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"from_be","","Converts an integer from big endian to the target's endianness.",195,{"inputs":[{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"from_le","","Converts an integer from little endian to the target's endianness.",195,{"inputs":[{"generics":["i128"],"name":"wrapping"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"to_be","","Converts `self` to big endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"to_le","","Converts `self` to little endian from the target's endianness.",195,{"inputs":[{"name":"self"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"pow","","Raises self to the power of `exp`, using exponentiation by squaring.",195,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["i128"],"name":"wrapping"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",418,{"inputs":[{"name":"u8"}],"output":{"name":"nonzerou8"}}],[11,"new","","Create a non-zero if the given value is not zero.",418,{"inputs":[{"name":"u8"}],"output":{"generics":["nonzerou8"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",418,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",421,{"inputs":[{"name":"i8"}],"output":{"name":"nonzeroi8"}}],[11,"new","","Create a non-zero if the given value is not zero.",421,{"inputs":[{"name":"i8"}],"output":{"generics":["nonzeroi8"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",421,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",412,{"inputs":[{"name":"u16"}],"output":{"name":"nonzerou16"}}],[11,"new","","Create a non-zero if the given value is not zero.",412,{"inputs":[{"name":"u16"}],"output":{"generics":["nonzerou16"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",412,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",410,{"inputs":[{"name":"i16"}],"output":{"name":"nonzeroi16"}}],[11,"new","","Create a non-zero if the given value is not zero.",410,{"inputs":[{"name":"i16"}],"output":{"generics":["nonzeroi16"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",410,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",417,{"inputs":[{"name":"u32"}],"output":{"name":"nonzerou32"}}],[11,"new","","Create a non-zero if the given value is not zero.",417,{"inputs":[{"name":"u32"}],"output":{"generics":["nonzerou32"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",417,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",416,{"inputs":[{"name":"i32"}],"output":{"name":"nonzeroi32"}}],[11,"new","","Create a non-zero if the given value is not zero.",416,{"inputs":[{"name":"i32"}],"output":{"generics":["nonzeroi32"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",416,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",413,{"inputs":[{"name":"u64"}],"output":{"name":"nonzerou64"}}],[11,"new","","Create a non-zero if the given value is not zero.",413,{"inputs":[{"name":"u64"}],"output":{"generics":["nonzerou64"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",413,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",419,{"inputs":[{"name":"i64"}],"output":{"name":"nonzeroi64"}}],[11,"new","","Create a non-zero if the given value is not zero.",419,{"inputs":[{"name":"i64"}],"output":{"generics":["nonzeroi64"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",419,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",420,{"inputs":[{"name":"u128"}],"output":{"name":"nonzerou128"}}],[11,"new","","Create a non-zero if the given value is not zero.",420,{"inputs":[{"name":"u128"}],"output":{"generics":["nonzerou128"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",420,{"inputs":[{"name":"self"}],"output":{"name":"u128"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",414,{"inputs":[{"name":"i128"}],"output":{"name":"nonzeroi128"}}],[11,"new","","Create a non-zero if the given value is not zero.",414,{"inputs":[{"name":"i128"}],"output":{"generics":["nonzeroi128"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",414,{"inputs":[{"name":"self"}],"output":{"name":"i128"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",411,{"inputs":[{"name":"usize"}],"output":{"name":"nonzerousize"}}],[11,"new","","Create a non-zero if the given value is not zero.",411,{"inputs":[{"name":"usize"}],"output":{"generics":["nonzerousize"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",411,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"new_unchecked","","Create a non-zero without checking the value.",415,{"inputs":[{"name":"isize"}],"output":{"name":"nonzeroisize"}}],[11,"new","","Create a non-zero if the given value is not zero.",415,{"inputs":[{"name":"isize"}],"output":{"generics":["nonzeroisize"],"name":"option"}}],[11,"get","","Returns the value as a primitive type.",415,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"payload","std::panic","Returns the payload associated with the panic.",474,{"inputs":[{"name":"self"}],"output":{"name":"any"}}],[11,"message","","If the `panic!` macro from the `core` crate (not from `std`) was used with a formatting string and some additional arguments, returns that message ready to be used for example with [`fmt::write`]",474,{"inputs":[{"name":"self"}],"output":{"generics":["arguments"],"name":"option"}}],[11,"location","","Returns information about the location from which the panic originated, if available.",474,{"inputs":[{"name":"self"}],"output":{"generics":["location"],"name":"option"}}],[11,"file","","Returns the name of the source file from which the panic originated.",475,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[11,"line","","Returns the line number from which the panic originated.",475,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"column","","Returns the column from which the panic originated.",475,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"from","std::sync","",477,{"inputs":[{"name":"pathbuf"}],"output":{"generics":["path"],"name":"arc"}}],[11,"from","","",477,{"inputs":[{"name":"path"}],"output":{"generics":["path"],"name":"arc"}}],[11,"as_ref","std","",429,{"inputs":[{"name":"self"}],"output":{"name":"path"}}],[11,"report","","",434,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"report","","",473,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"new","std::sync","Constructs a new `Arc<T>`.",477,{"inputs":[{"name":"t"}],"output":{"name":"arc"}}],[11,"try_unwrap","","Returns the contained value, if the `Arc` has exactly one strong reference.",477,{"inputs":[{"name":"arc"}],"output":{"generics":["arc"],"name":"result"}}],[11,"into_raw","","Consumes the `Arc`, returning the wrapped pointer.",477,null],[11,"from_raw","","Constructs an `Arc` from a raw pointer.",477,null],[11,"downgrade","","Creates a new [`Weak`][weak] pointer to this value.",477,{"inputs":[{"name":"arc"}],"output":{"name":"weak"}}],[11,"weak_count","","Gets the number of [`Weak`][weak] pointers to this value.",477,{"inputs":[{"name":"arc"}],"output":{"name":"usize"}}],[11,"strong_count","","Gets the number of strong (`Arc`) pointers to this value.",477,{"inputs":[{"name":"arc"}],"output":{"name":"usize"}}],[11,"ptr_eq","","Returns true if the two `Arc`s point to the same value (not just values that compare as equal).",477,{"inputs":[{"name":"arc"},{"name":"arc"}],"output":{"name":"bool"}}],[11,"make_mut","","Makes a mutable reference into the given `Arc`.",477,{"inputs":[{"name":"arc"}],"output":{"name":"t"}}],[11,"get_mut","","Returns a mutable reference to the inner value, if there are no other `Arc` or [`Weak`][weak] pointers to the same value.",477,{"inputs":[{"name":"arc"}],"output":{"name":"option"}}],[11,"new","","Constructs a new `Weak<T>`, allocating memory for `T` without initializing it. Calling [`upgrade`] on the return value always gives [`None`].",480,{"inputs":[],"output":{"name":"weak"}}],[11,"upgrade","","Attempts to upgrade the `Weak` pointer to an [`Arc`], extending the lifetime of the value if successful.",480,{"inputs":[{"name":"self"}],"output":{"generics":["arc"],"name":"option"}}],[11,"new","std::sync::atomic","Creates a new `AtomicBool`.",468,{"inputs":[{"name":"bool"}],"output":{"name":"atomicbool"}}],[11,"get_mut","","Returns a mutable reference to the underlying [`bool`].",468,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",468,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[11,"load","","Loads a value from the bool.",468,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"store","","Stores a value into the bool.",468,null],[11,"swap","","Stores a value into the bool, returning the previous value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"compare_and_swap","","Stores a value into the [`bool`] if the current value is the same as the `current` value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"compare_exchange","","Stores a value into the [`bool`] if the current value is the same as the `current` value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"bool"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["bool","bool"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the [`bool`] if the current value is the same as the `current` value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"bool"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["bool","bool"],"name":"result"}}],[11,"fetch_and","","Logical \"and\" with a boolean value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"fetch_nand","","Logical \"nand\" with a boolean value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"fetch_or","","Logical \"or\" with a boolean value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"fetch_xor","","Logical \"xor\" with a boolean value.",468,{"inputs":[{"name":"self"},{"name":"bool"},{"name":"ordering"}],"output":{"name":"bool"}}],[11,"new","","Creates a new `AtomicPtr`.",467,null],[11,"get_mut","","Returns a mutable reference to the underlying pointer.",467,null],[11,"into_inner","","Consumes the atomic and returns the contained value.",467,null],[11,"load","","Loads a value from the pointer.",467,null],[11,"store","","Stores a value into the pointer.",467,null],[11,"swap","","Stores a value into the pointer, returning the previous value.",467,null],[11,"compare_and_swap","","Stores a value into the pointer if the current value is the same as the `current` value.",467,null],[11,"compare_exchange","","Stores a value into the pointer if the current value is the same as the `current` value.",467,null],[11,"compare_exchange_weak","","Stores a value into the pointer if the current value is the same as the `current` value.",467,null],[11,"new","","Creates a new atomic integer.",465,{"inputs":[{"name":"i8"}],"output":{"name":"atomici8"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",465,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",465,{"inputs":[{"name":"self"}],"output":{"name":"i8"}}],[11,"load","","Loads a value from the atomic integer.",465,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"store","","Stores a value into the atomic integer.",465,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"i8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i8","i8"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"i8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i8","i8"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",465,{"inputs":[{"name":"self"},{"name":"i8"},{"name":"ordering"}],"output":{"name":"i8"}}],[11,"new","","Creates a new atomic integer.",461,{"inputs":[{"name":"u8"}],"output":{"name":"atomicu8"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",461,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",461,{"inputs":[{"name":"self"}],"output":{"name":"u8"}}],[11,"load","","Loads a value from the atomic integer.",461,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"store","","Stores a value into the atomic integer.",461,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"u8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u8","u8"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"u8"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u8","u8"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",461,{"inputs":[{"name":"self"},{"name":"u8"},{"name":"ordering"}],"output":{"name":"u8"}}],[11,"new","","Creates a new atomic integer.",460,{"inputs":[{"name":"i16"}],"output":{"name":"atomici16"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",460,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",460,{"inputs":[{"name":"self"}],"output":{"name":"i16"}}],[11,"load","","Loads a value from the atomic integer.",460,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"store","","Stores a value into the atomic integer.",460,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"i16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i16","i16"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"i16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i16","i16"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",460,{"inputs":[{"name":"self"},{"name":"i16"},{"name":"ordering"}],"output":{"name":"i16"}}],[11,"new","","Creates a new atomic integer.",472,{"inputs":[{"name":"u16"}],"output":{"name":"atomicu16"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",472,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",472,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"load","","Loads a value from the atomic integer.",472,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"store","","Stores a value into the atomic integer.",472,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"u16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u16","u16"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"u16"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u16","u16"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",472,{"inputs":[{"name":"self"},{"name":"u16"},{"name":"ordering"}],"output":{"name":"u16"}}],[11,"new","","Creates a new atomic integer.",466,{"inputs":[{"name":"i32"}],"output":{"name":"atomici32"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",466,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",466,{"inputs":[{"name":"self"}],"output":{"name":"i32"}}],[11,"load","","Loads a value from the atomic integer.",466,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"store","","Stores a value into the atomic integer.",466,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"i32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i32","i32"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"i32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i32","i32"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",466,{"inputs":[{"name":"self"},{"name":"i32"},{"name":"ordering"}],"output":{"name":"i32"}}],[11,"new","","Creates a new atomic integer.",462,{"inputs":[{"name":"u32"}],"output":{"name":"atomicu32"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",462,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",462,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"load","","Loads a value from the atomic integer.",462,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"store","","Stores a value into the atomic integer.",462,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"u32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u32","u32"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"u32"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u32","u32"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",462,{"inputs":[{"name":"self"},{"name":"u32"},{"name":"ordering"}],"output":{"name":"u32"}}],[11,"new","","Creates a new atomic integer.",463,{"inputs":[{"name":"i64"}],"output":{"name":"atomici64"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",463,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",463,{"inputs":[{"name":"self"}],"output":{"name":"i64"}}],[11,"load","","Loads a value from the atomic integer.",463,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"store","","Stores a value into the atomic integer.",463,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"i64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i64","i64"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"i64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["i64","i64"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",463,{"inputs":[{"name":"self"},{"name":"i64"},{"name":"ordering"}],"output":{"name":"i64"}}],[11,"new","","Creates a new atomic integer.",469,{"inputs":[{"name":"u64"}],"output":{"name":"atomicu64"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",469,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",469,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"load","","Loads a value from the atomic integer.",469,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"store","","Stores a value into the atomic integer.",469,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"u64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u64","u64"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"u64"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["u64","u64"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",469,{"inputs":[{"name":"self"},{"name":"u64"},{"name":"ordering"}],"output":{"name":"u64"}}],[11,"new","","Creates a new atomic integer.",471,{"inputs":[{"name":"isize"}],"output":{"name":"atomicisize"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",471,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",471,{"inputs":[{"name":"self"}],"output":{"name":"isize"}}],[11,"load","","Loads a value from the atomic integer.",471,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"store","","Stores a value into the atomic integer.",471,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"isize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["isize","isize"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"isize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["isize","isize"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",471,{"inputs":[{"name":"self"},{"name":"isize"},{"name":"ordering"}],"output":{"name":"isize"}}],[11,"new","","Creates a new atomic integer.",464,{"inputs":[{"name":"usize"}],"output":{"name":"atomicusize"}}],[11,"get_mut","","Returns a mutable reference to the underlying integer.",464,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"into_inner","","Consumes the atomic and returns the contained value.",464,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"load","","Loads a value from the atomic integer.",464,{"inputs":[{"name":"self"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"store","","Stores a value into the atomic integer.",464,null],[11,"swap","","Stores a value into the atomic integer, returning the previous value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"compare_and_swap","","Stores a value into the atomic integer if the current value is the same as the `current` value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"compare_exchange","","Stores a value into the atomic integer if the current value is the same as the `current` value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"compare_exchange_weak","","Stores a value into the atomic integer if the current value is the same as the `current` value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"usize"},{"name":"ordering"},{"name":"ordering"}],"output":{"generics":["usize","usize"],"name":"result"}}],[11,"fetch_add","","Adds to the current value, returning the previous value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_sub","","Subtracts from the current value, returning the previous value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_and","","Bitwise \"and\" with the current value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_nand","","Bitwise \"nand\" with the current value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_or","","Bitwise \"or\" with the current value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"fetch_xor","","Bitwise \"xor\" with the current value.",464,{"inputs":[{"name":"self"},{"name":"usize"},{"name":"ordering"}],"output":{"name":"usize"}}],[11,"new","std::time","Creates a new `Duration` from the specified number of whole seconds and additional nanoseconds.",309,{"inputs":[{"name":"u64"},{"name":"u32"}],"output":{"name":"duration"}}],[11,"from_secs","","Creates a new `Duration` from the specified number of whole seconds.",309,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"from_millis","","Creates a new `Duration` from the specified number of milliseconds.",309,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"from_micros","","Creates a new `Duration` from the specified number of microseconds.",309,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"from_nanos","","Creates a new `Duration` from the specified number of nanoseconds.",309,{"inputs":[{"name":"u64"}],"output":{"name":"duration"}}],[11,"as_secs","","Returns the number of whole seconds contained by this `Duration`.",309,{"inputs":[{"name":"self"}],"output":{"name":"u64"}}],[11,"subsec_millis","","Returns the fractional part of this `Duration`, in milliseconds.",309,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"subsec_micros","","Returns the fractional part of this `Duration`, in microseconds.",309,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"subsec_nanos","","Returns the fractional part of this `Duration`, in nanoseconds.",309,{"inputs":[{"name":"self"}],"output":{"name":"u32"}}],[11,"checked_add","","Checked `Duration` addition. Computes `self + other`, returning [`None`] if overflow occurred.",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"generics":["duration"],"name":"option"}}],[11,"checked_sub","","Checked `Duration` subtraction. Computes `self - other`, returning [`None`] if the result would be negative or if overflow occurred.",309,{"inputs":[{"name":"self"},{"name":"duration"}],"output":{"generics":["duration"],"name":"option"}}],[11,"checked_mul","","Checked `Duration` multiplication. Computes `self * other`, returning [`None`] if overflow occurred.",309,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["duration"],"name":"option"}}],[11,"checked_div","","Checked `Duration` division. Computes `self / other`, returning [`None`] if `other == 0`.",309,{"inputs":[{"name":"self"},{"name":"u32"}],"output":{"generics":["duration"],"name":"option"}}]],"paths":[[8,"Any"],[8,"Clone"],[8,"PartialEq"],[4,"Ordering"],[3,"Reverse"],[8,"Ord"],[8,"PartialOrd"],[8,"AsRef"],[8,"AsMut"],[8,"Into"],[8,"From"],[8,"TryInto"],[8,"TryFrom"],[8,"Default"],[8,"Hash"],[8,"Hasher"],[8,"BuildHasher"],[8,"IntoIterator"],[8,"Iterator"],[8,"Product"],[8,"Sum"],[8,"Extend"],[8,"DoubleEndedIterator"],[8,"ExactSizeIterator"],[8,"Step"],[8,"FromIterator"],[8,"SubAssign"],[8,"Fn"],[8,"FnOnce"],[8,"ShrAssign"],[8,"Mul"],[3,"RangeTo"],[8,"Sub"],[8,"MulAssign"],[3,"RangeInclusive"],[3,"RangeToInclusive"],[8,"RangeBounds"],[4,"GeneratorState"],[8,"Place"],[8,"Rem"],[8,"ShlAssign"],[8,"BitOr"],[8,"InPlace"],[8,"DerefMut"],[8,"Shr"],[8,"BitOrAssign"],[8,"BitAnd"],[8,"Drop"],[3,"Range"],[3,"RangeFrom"],[8,"AddAssign"],[8,"Index"],[8,"IndexMut"],[4,"Bound"],[8,"Add"],[8,"DivAssign"],[8,"Try"],[8,"Deref"],[8,"FnMut"],[8,"Div"],[8,"Shl"],[8,"Not"],[8,"Generator"],[8,"BoxPlace"],[8,"BitXor"],[8,"BitXorAssign"],[8,"Placer"],[8,"RemAssign"],[8,"Boxed"],[8,"Neg"],[8,"BitAndAssign"],[3,"TraitObject"],[4,"Result"],[4,"Option"],[8,"FnBox"],[8,"ToOwned"],[4,"Cow"],[8,"Borrow"],[8,"BorrowMut"],[8,"UpperExp"],[8,"Debug"],[8,"Pointer"],[8,"Display"],[8,"Binary"],[8,"Octal"],[8,"LowerHex"],[8,"UpperHex"],[8,"Write"],[8,"LowerExp"],[8,"SliceConcatExt"],[8,"SliceIndex"],[8,"Pattern"],[4,"SearchStep"],[8,"Searcher"],[8,"ReverseSearcher"],[8,"FromStr"],[8,"ToString"],[3,"UnicodeVersion"],[8,"IntoBits"],[8,"FromBits"],[3,"LocalKey"],[3,"AccessError"],[3,"Builder"],[3,"ThreadId"],[3,"Thread"],[3,"JoinHandle"],[8,"AsciiExt"],[4,"Entry"],[4,"CollectionAllocErr"],[3,"HashMap"],[3,"HashSet"],[4,"Entry"],[4,"VarError"],[3,"Vars"],[3,"VarsOs"],[3,"SplitPaths"],[3,"JoinPathsError"],[3,"Args"],[3,"ArgsOs"],[8,"Error"],[3,"Box"],[3,"ParseBoolError"],[3,"Utf8Error"],[3,"FromUtf8Error"],[3,"FromUtf16Error"],[4,"ParseError"],[3,"DecodeUtf16Error"],[3,"Error"],[3,"BorrowError"],[3,"BorrowMutError"],[3,"CharTryFromError"],[3,"ParseCharError"],[3,"CString"],[3,"CStr"],[3,"NulError"],[3,"FromBytesWithNulError"],[3,"IntoStringError"],[3,"Vec"],[3,"Rc"],[3,"OsString"],[3,"OsStr"],[3,"String"],[3,"Metadata"],[3,"ReadDir"],[3,"OpenOptions"],[3,"Permissions"],[3,"FileType"],[3,"DirBuilder"],[3,"File"],[3,"DirEntry"],[4,"ErrorKind"],[4,"SeekFrom"],[4,"CharsError"],[3,"BufReader"],[3,"IntoInnerError"],[3,"BufWriter"],[3,"Error"],[3,"LineWriter"],[3,"Cursor"],[3,"Empty"],[3,"Repeat"],[3,"Sink"],[3,"Stdin"],[3,"StdinLock"],[3,"Stdout"],[3,"StdoutLock"],[3,"Stderr"],[3,"StderrLock"],[8,"Read"],[8,"Write"],[8,"Seek"],[8,"BufRead"],[3,"Initializer"],[3,"Chain"],[3,"Take"],[3,"Bytes"],[3,"Chars"],[3,"Split"],[3,"Lines"],[4,"IpAddr"],[4,"Ipv6MulticastScope"],[4,"SocketAddr"],[4,"Shutdown"],[3,"Ipv4Addr"],[3,"Ipv6Addr"],[3,"SocketAddrV4"],[3,"SocketAddrV6"],[3,"Incoming"],[3,"TcpStream"],[3,"TcpListener"],[3,"UdpSocket"],[3,"AddrParseError"],[8,"ToSocketAddrs"],[3,"LookupHost"],[4,"FpCategory"],[3,"Wrapping"],[8,"AsRawFd"],[8,"FromRawFd"],[8,"IntoRawFd"],[8,"OsStringExt"],[8,"OsStrExt"],[8,"FileExt"],[8,"PermissionsExt"],[8,"OpenOptionsExt"],[8,"MetadataExt"],[8,"FileTypeExt"],[8,"DirEntryExt"],[8,"DirBuilderExt"],[8,"CommandExt"],[8,"ExitStatusExt"],[8,"JoinHandleExt"],[8,"OsStringExt"],[8,"OsStrExt"],[8,"FileExt"],[8,"OpenOptionsExt"],[8,"MetadataExt"],[8,"FileTypeExt"],[8,"AsRawHandle"],[8,"FromRawHandle"],[8,"IntoRawHandle"],[8,"AsRawSocket"],[8,"FromRawSocket"],[8,"IntoRawSocket"],[8,"ExitStatusExt"],[8,"CommandExt"],[3,"stat"],[8,"MetadataExt"],[4,"c_void"],[3,"AssertUnwindSafe"],[4,"Prefix"],[4,"Component"],[3,"PrefixComponent"],[3,"Components"],[3,"Iter"],[3,"Ancestors"],[3,"PathBuf"],[3,"Path"],[3,"StripPrefixError"],[3,"Display"],[3,"Child"],[3,"Output"],[8,"Termination"],[3,"ChildStdin"],[3,"ChildStdout"],[3,"ChildStderr"],[3,"Command"],[3,"Stdio"],[3,"ExitStatus"],[3,"ExitCode"],[4,"Ordering"],[4,"TryLockError"],[3,"SendError"],[4,"TryRecvError"],[4,"RecvTimeoutError"],[4,"TrySendError"],[3,"Select"],[3,"Handle"],[3,"Iter"],[3,"TryIter"],[3,"IntoIter"],[3,"RecvError"],[3,"Sender"],[3,"SyncSender"],[3,"Receiver"],[3,"Barrier"],[3,"BarrierWaitResult"],[3,"WaitTimeoutResult"],[3,"Condvar"],[3,"Mutex"],[3,"MutexGuard"],[3,"OnceState"],[3,"Once"],[3,"RwLock"],[3,"RwLockReadGuard"],[3,"RwLockWriteGuard"],[3,"Instant"],[3,"SystemTime"],[3,"SystemTimeError"],[3,"PoisonError"],[3,"EncodeWide"],[3,"SocketAddr"],[3,"UnixStream"],[3,"UnixListener"],[3,"Incoming"],[3,"UnixDatagram"],[15,"reference"],[3,"Inspect"],[3,"Fuse"],[3,"Enumerate"],[3,"Iter"],[3,"Map"],[3,"IterMut"],[3,"EscapeUnicode"],[3,"Once"],[3,"Rev"],[3,"Bytes"],[3,"ExactChunks"],[3,"ExactChunksMut"],[3,"Empty"],[3,"Cloned"],[3,"EscapeDefault"],[15,"u32"],[3,"i16x32"],[3,"i32x8"],[15,"usize"],[3,"i32x4"],[15,"u64"],[15,"i32"],[3,"f64x8"],[3,"Duration"],[3,"u32x2"],[3,"i16x4"],[3,"u16x8"],[3,"i8x16"],[15,"f64"],[3,"u8x16"],[3,"i32x16"],[15,"i16"],[15,"i128"],[15,"f32"],[15,"u8"],[3,"f64x2"],[15,"isize"],[3,"f32x2"],[3,"u8x8"],[3,"i8x64"],[3,"i32x2"],[3,"i64x2"],[3,"u64x2"],[15,"u16"],[3,"i8x4"],[3,"i8x32"],[15,"i64"],[3,"u16x16"],[3,"u8x64"],[15,"i8"],[3,"i8x2"],[3,"i16x8"],[3,"i16x16"],[15,"u128"],[3,"u32x8"],[3,"u64x8"],[3,"u16x32"],[3,"u8x2"],[3,"u16x2"],[3,"f32x8"],[3,"u16x4"],[3,"u8x4"],[3,"i8x8"],[3,"f32x16"],[3,"u32x16"],[3,"u8x32"],[3,"f64x4"],[3,"i64x8"],[3,"i16x2"],[3,"u64x4"],[3,"f32x4"],[3,"u32x4"],[3,"i64x4"],[3,"DecodeUtf8"],[3,"IterMut"],[3,"TakeWhile"],[3,"Cycle"],[3,"SplitN"],[3,"Windows"],[3,"MatchIndices"],[3,"Skip"],[3,"Iter"],[3,"ChunksMut"],[3,"FilterMap"],[3,"RSplitN"],[3,"SplitMut"],[3,"EscapeDebug"],[3,"Split"],[3,"IntoIter"],[3,"RSplitMut"],[3,"Scan"],[3,"CharIndices"],[3,"RSplitTerminator"],[3,"Iter"],[3,"SkipWhile"],[3,"SplitTerminator"],[3,"RSplit"],[3,"Chain"],[3,"Repeat"],[3,"Chars"],[3,"Lines"],[3,"Take"],[3,"SplitNMut"],[3,"Filter"],[3,"Zip"],[3,"RSplit"],[3,"Flatten"],[3,"RMatchIndices"],[3,"LinesAny"],[3,"EscapeDefault"],[3,"RMatches"],[3,"StepBy"],[3,"FlatMap"],[3,"IterMut"],[3,"IntoIter"],[3,"RSplitNMut"],[3,"Chunks"],[3,"Split"],[3,"RepeatWith"],[3,"Peekable"],[3,"Matches"],[3,"SplitN"],[3,"RSplitN"],[15,"array"],[3,"NonZeroI16"],[3,"NonZeroUsize"],[3,"NonZeroU16"],[3,"NonZeroU64"],[3,"NonZeroI128"],[3,"NonZeroIsize"],[3,"NonZeroI32"],[3,"NonZeroU32"],[3,"NonZeroU8"],[3,"NonZeroI64"],[3,"NonZeroU128"],[3,"NonZeroI8"],[3,"RangeFull"],[15,"fn"],[15,"tuple"],[15,"pointer"],[19,"ManuallyDrop"],[3,"NonNull"],[3,"TypeId"],[15,"str"],[3,"NoneError"],[15,"bool"],[15,"char"],[15,"slice"],[15,"unit"],[3,"Discriminant"],[3,"PhantomData"],[3,"StrSearcher"],[3,"ParseFloatError"],[3,"TryFromIntError"],[3,"b8x64"],[3,"b8x16"],[3,"b8x32"],[3,"CharSliceSearcher"],[3,"b8x4"],[3,"Unique"],[3,"Arguments"],[3,"b8x8"],[3,"ParseIntError"],[3,"SipHasher"],[3,"b8x2"],[3,"Cell"],[3,"CharPredicateSearcher"],[3,"BuildHasherDefault"],[3,"CharSearcher"],[3,"RefCell"],[3,"Formatter"],[3,"RefMut"],[3,"Pin"],[3,"Ref"],[3,"AtomicI16"],[3,"AtomicU8"],[3,"AtomicU32"],[3,"AtomicI64"],[3,"AtomicUsize"],[3,"AtomicI8"],[3,"AtomicI32"],[3,"AtomicPtr"],[3,"AtomicBool"],[3,"AtomicU64"],[3,"UnsafeCell"],[3,"AtomicIsize"],[3,"AtomicU16"],[15,"never"],[3,"PanicInfo"],[3,"Location"],[3,"PinBox"],[3,"Arc"],[3,"BinaryHeap"],[3,"Heap"],[3,"Weak"],[3,"Weak"],[3,"LinkedList"],[3,"BTreeSet"],[3,"BTreeMap"],[3,"VecDeque"],[3,"Range"],[3,"IntoIter"],[3,"PlaceFront"],[3,"Drain"],[3,"IterMut"],[3,"Drain"],[3,"IntoIter"],[3,"Values"],[3,"Iter"],[3,"DrainFilter"],[3,"IntoIter"],[3,"Union"],[3,"Iter"],[3,"IntoIter"],[3,"IterMut"],[3,"Range"],[3,"VacantEntry"],[3,"Iter"],[3,"SymmetricDifference"],[3,"DrainFilter"],[3,"Difference"],[3,"OccupiedEntry"],[3,"Drain"],[3,"Iter"],[3,"Splice"],[3,"EncodeUtf16"],[3,"RangeMut"],[3,"ValuesMut"],[3,"Drain"],[3,"BackPlace"],[3,"BinaryHeapPlace"],[3,"IntoIter"],[3,"FrontPlace"],[3,"IterMut"],[3,"Iter"],[3,"PeekMut"],[3,"Intersection"],[3,"Keys"],[3,"PlaceBack"],[3,"IntoIter"],[3,"PlaceBack"],[3,"ExchangeHeapSingleton"],[3,"IntermediateBox"],[3,"ToLowercase"],[3,"ToUppercase"],[3,"SplitWhitespace"],[3,"DecodeUtf16"],[3,"System"],[3,"DebugSet"],[3,"DebugStruct"],[3,"DebugMap"],[3,"DebugTuple"],[3,"DebugList"],[3,"Iter"],[3,"Keys"],[3,"Values"],[3,"OccupiedEntry"],[3,"VacantEntry"],[3,"IterMut"],[3,"IntoIter"],[3,"ValuesMut"],[3,"Drain"],[3,"EntryPlace"],[3,"RandomState"],[3,"DefaultHasher"],[3,"Iter"],[3,"IntoIter"],[3,"Drain"],[3,"Intersection"],[3,"Difference"],[3,"SymmetricDifference"],[3,"Union"]]};
searchIndex["std_unicode"] = {"doc":"The Unicode Library","items":[[0,"char","std_unicode","A character type.",null,null],[17,"MAX","std_unicode::char","The highest valid code point a `char` can have.",null,null],[5,"from_digit","","Converts a digit in the given radix to a `char`.",null,{"inputs":[{"name":"u32"},{"name":"u32"}],"output":{"generics":["char"],"name":"option"}}],[5,"from_u32","","Converts a `u32` to a `char`.",null,{"inputs":[{"name":"u32"}],"output":{"generics":["char"],"name":"option"}}],[5,"from_u32_unchecked","","Converts a `u32` to a `char`, ignoring validity.",null,{"inputs":[{"name":"u32"}],"output":{"name":"char"}}],[3,"EscapeDebug","","An iterator that yields the literal escape code of a `char`.",null,null],[3,"EscapeDefault","","An iterator that yields the literal escape code of a `char`.",null,null],[3,"EscapeUnicode","","Returns an iterator that yields the hexadecimal Unicode escape of a character, as `char`s.",null,null],[3,"ParseCharError","","An error which can be returned when parsing a char.",null,null],[3,"CharTryFromError","","The error type returned when a conversion from u32 to char fails.",null,null],[3,"DecodeUtf8","","An iterator over an iterator of bytes of the characters the bytes represent as UTF-8",null,null],[5,"decode_utf8","","Decodes an `Iterator` of bytes as UTF-8.",null,{"inputs":[{"name":"i"}],"output":{"name":"decodeutf8"}}],[3,"UnicodeVersion","","Represents a Unicode Version.",null,null],[12,"major","","Major version.",0,null],[12,"minor","","Minor version.",0,null],[12,"micro","","Micro (or Update) version.",0,null],[3,"ToLowercase","","Returns an iterator that yields the lowercase equivalent of a `char`.",null,null],[3,"ToUppercase","","Returns an iterator that yields the uppercase equivalent of a `char`.",null,null],[3,"DecodeUtf16","","An iterator that decodes UTF-16 encoded code points from an iterator of `u16`s.",null,null],[3,"DecodeUtf16Error","","An error that can be returned when decoding UTF-16 code points.",null,null],[5,"decode_utf16","","Create an iterator over the UTF-16 encoded code points in `iter`, returning unpaired surrogates as `Err`s.",null,{"inputs":[{"name":"i"}],"output":{"name":"decodeutf16"}}],[17,"UNICODE_VERSION","","The version of Unicode that the Unicode parts of `CharExt` and `UnicodeStrPrelude` traits are based on.",null,null],[17,"REPLACEMENT_CHARACTER","","`U+FFFD REPLACEMENT CHARACTER` (�) is used in Unicode to represent a decoding error.",null,null],[11,"fmt","","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",1,{"inputs":[{"name":"self"}],"output":{"name":"tolowercase"}}],[11,"next","","",1,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"fmt","","",2,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",2,{"inputs":[{"name":"self"}],"output":{"name":"touppercase"}}],[11,"next","","",2,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"fmt","","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",2,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",3,{"inputs":[{"name":"self"}],"output":{"name":"decodeutf16"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",4,{"inputs":[{"name":"self"}],"output":{"name":"decodeutf16error"}}],[11,"eq","","",4,{"inputs":[{"name":"self"},{"name":"decodeutf16error"}],"output":{"name":"bool"}}],[11,"ne","","",4,{"inputs":[{"name":"self"},{"name":"decodeutf16error"}],"output":{"name":"bool"}}],[11,"next","","",3,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"size_hint","","",3,null],[11,"unpaired_surrogate","","Returns the unpaired surrogate which caused this error.",4,{"inputs":[{"name":"self"}],"output":{"name":"u16"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"lossy","std_unicode","",null,null],[3,"Utf8Lossy","std_unicode::lossy","Lossy UTF-8 string.",null,null],[3,"Utf8LossyChunksIter","","Iterator over lossy UTF-8 string",null,null],[3,"Utf8LossyChunk","","",null,null],[12,"valid","","Sequence of valid chars. Can be empty between broken UTF-8 chars.",5,null],[12,"broken","","Single broken char, empty if none. Empty iff iterator item is last.",5,null],[11,"from_str","","",6,{"inputs":[{"name":"str"}],"output":{"name":"utf8lossy"}}],[11,"from_bytes","","",6,null],[11,"chunks","","",6,{"inputs":[{"name":"self"}],"output":{"name":"utf8lossychunksiter"}}],[11,"eq","","",5,{"inputs":[{"name":"self"},{"name":"utf8lossychunk"}],"output":{"name":"bool"}}],[11,"ne","","",5,{"inputs":[{"name":"self"},{"name":"utf8lossychunk"}],"output":{"name":"bool"}}],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"next","","",7,{"inputs":[{"name":"self"}],"output":{"generics":["utf8lossychunk"],"name":"option"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[0,"str","std_unicode","",null,null],[3,"SplitWhitespace","std_unicode::str","An iterator over the non-whitespace substrings of a string, separated by any amount of whitespace.",null,null],[3,"Utf16Encoder","","Iterator adaptor for encoding `char`s to UTF-16.",null,null],[8,"UnicodeStr","","Methods for Unicode string slices",null,null],[10,"split_whitespace","","",8,{"inputs":[{"name":"self"}],"output":{"name":"splitwhitespace"}}],[10,"is_whitespace","","",8,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"is_alphanumeric","","",8,{"inputs":[{"name":"self"}],"output":{"name":"bool"}}],[10,"trim","","",8,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[10,"trim_left","","",8,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[10,"trim_right","","",8,{"inputs":[{"name":"self"}],"output":{"name":"str"}}],[0,"derived_property","std_unicode","",null,null],[5,"Case_Ignorable","std_unicode::derived_property","",null,{"inputs":[{"name":"char"}],"output":{"name":"bool"}}],[5,"Cased","","",null,{"inputs":[{"name":"char"}],"output":{"name":"bool"}}],[0,"property","std_unicode","",null,null],[5,"Pattern_White_Space","std_unicode::property","",null,{"inputs":[{"name":"char"}],"output":{"name":"bool"}}],[11,"clone","std_unicode::str","",9,{"inputs":[{"name":"self"}],"output":{"name":"splitwhitespace"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",10,{"inputs":[{"name":"self"}],"output":{"name":"utf16encoder"}}],[11,"new","","Create a UTF-16 encoder from any `char` iterator.",10,{"inputs":[{"name":"i"}],"output":{"name":"utf16encoder"}}],[11,"next","","",10,{"inputs":[{"name":"self"}],"output":{"generics":["u16"],"name":"option"}}],[11,"size_hint","","",10,null],[11,"next","","",9,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"next_back","","",9,{"inputs":[{"name":"self"}],"output":{"generics":["str"],"name":"option"}}],[11,"clone","std_unicode::char","",0,{"inputs":[{"name":"self"}],"output":{"name":"unicodeversion"}}],[11,"fmt","","",0,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"cmp","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"ordering"}}],[11,"eq","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"ne","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"partial_cmp","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"generics":["ordering"],"name":"option"}}],[11,"lt","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"le","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"gt","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"ge","","",0,{"inputs":[{"name":"self"},{"name":"unicodeversion"}],"output":{"name":"bool"}}],[11,"len","","",11,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"len","","",12,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"next","","",13,{"inputs":[{"name":"self"}],"output":{"generics":["result"],"name":"option"}}],[11,"size_hint","","",13,null],[11,"next","","",14,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",14,null],[11,"next","","",12,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",12,null],[11,"count","","",12,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"nth","","",12,{"inputs":[{"name":"self"},{"name":"usize"}],"output":{"generics":["char"],"name":"option"}}],[11,"last","","",12,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"next","","",11,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"size_hint","","",11,null],[11,"count","","",11,{"inputs":[{"name":"self"}],"output":{"name":"usize"}}],[11,"last","","",11,{"inputs":[{"name":"self"}],"output":{"generics":["char"],"name":"option"}}],[11,"clone","","",11,{"inputs":[{"name":"self"}],"output":{"name":"escapeunicode"}}],[11,"clone","","",12,{"inputs":[{"name":"self"}],"output":{"name":"escapedefault"}}],[11,"clone","","",15,{"inputs":[{"name":"self"}],"output":{"name":"chartryfromerror"}}],[11,"clone","","",13,{"inputs":[{"name":"self"}],"output":{"name":"decodeutf8"}}],[11,"clone","","",16,{"inputs":[{"name":"self"}],"output":{"name":"parsecharerror"}}],[11,"clone","","",14,{"inputs":[{"name":"self"}],"output":{"name":"escapedebug"}}],[11,"eq","","",16,{"inputs":[{"name":"self"},{"name":"parsecharerror"}],"output":{"name":"bool"}}],[11,"ne","","",16,{"inputs":[{"name":"self"},{"name":"parsecharerror"}],"output":{"name":"bool"}}],[11,"eq","","",15,{"inputs":[{"name":"self"},{"name":"chartryfromerror"}],"output":{"name":"bool"}}],[11,"ne","","",15,{"inputs":[{"name":"self"},{"name":"chartryfromerror"}],"output":{"name":"bool"}}],[11,"fmt","","",15,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",16,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",16,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",15,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",13,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",12,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",11,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}],[11,"fmt","","",14,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"generics":["error"],"name":"result"}}]],"paths":[[3,"UnicodeVersion"],[3,"ToLowercase"],[3,"ToUppercase"],[3,"DecodeUtf16"],[3,"DecodeUtf16Error"],[3,"Utf8LossyChunk"],[3,"Utf8Lossy"],[3,"Utf8LossyChunksIter"],[8,"UnicodeStr"],[3,"SplitWhitespace"],[3,"Utf16Encoder"],[3,"EscapeUnicode"],[3,"EscapeDefault"],[3,"DecodeUtf8"],[3,"EscapeDebug"],[3,"CharTryFromError"],[3,"ParseCharError"]]};
searchIndex["test"] = {"doc":"Support code for rustc's built in unit-test and micro-benchmarking framework.","items":[[3,"Bencher","test","Manager of the benchmarking runs.",null,null],[12,"bytes","","",0,null],[3,"TestDesc","","",null,null],[12,"name","","",1,null],[12,"ignore","","",1,null],[12,"should_panic","","",1,null],[12,"allow_fail","","",1,null],[3,"TestDescAndFn","","",null,null],[12,"desc","","",2,null],[12,"testfn","","",2,null],[3,"Metric","","",null,null],[3,"Options","","In case we want to add other options as well, just add them in this struct.",null,null],[3,"TestOpts","","",null,null],[12,"list","","",3,null],[12,"filter","","",3,null],[12,"filter_exact","","",3,null],[12,"run_ignored","","",3,null],[12,"run_tests","","",3,null],[12,"bench_benchmarks","","",3,null],[12,"logfile","","",3,null],[12,"nocapture","","",3,null],[12,"color","","",3,null],[12,"format","","",3,null],[12,"test_threads","","",3,null],[12,"skip","","",3,null],[12,"options","","",3,null],[3,"BenchSamples","","",null,null],[3,"MetricMap","","",null,null],[4,"TestName","","",null,null],[13,"StaticTestName","","",4,null],[13,"DynTestName","","",4,null],[13,"AlignedTestName","","",4,null],[4,"NamePadding","","",null,null],[13,"PadNone","","",5,null],[13,"PadOnRight","","",5,null],[4,"TestFn","","",null,null],[13,"StaticTestFn","","",6,null],[13,"StaticBenchFn","","",6,null],[13,"DynTestFn","","",6,null],[13,"DynBenchFn","","",6,null],[4,"BenchMode","","",null,null],[13,"Auto","","",7,null],[13,"Single","","",7,null],[4,"ShouldPanic","","",null,null],[13,"No","","",8,null],[13,"Yes","","",8,null],[13,"YesWithMessage","","",8,null],[4,"ColorConfig","","",null,null],[13,"AutoColor","","",9,null],[13,"AlwaysColor","","",9,null],[13,"NeverColor","","",9,null],[4,"OutputFormat","","",null,null],[13,"Pretty","","",10,null],[13,"Terse","","",10,null],[13,"Json","","",10,null],[4,"TestResult","","",null,null],[13,"TrOk","","",11,null],[13,"TrFailed","","",11,null],[13,"TrFailedMsg","","",11,null],[13,"TrIgnored","","",11,null],[13,"TrAllowedFail","","",11,null],[13,"TrBench","","",11,null],[4,"TestEvent","","",null,null],[13,"TeFiltered","","",12,null],[13,"TeWait","","",12,null],[13,"TeResult","","",12,null],[13,"TeTimeout","","",12,null],[13,"TeFilteredOut","","",12,null],[5,"test_main","","",null,null],[5,"test_main_static","","",null,null],[5,"assert_test_result","","Invoked when unit tests terminate. Should panic if the unit test is considered a failure. By default, invokes `report()` and checks for a `0` result.",null,{"inputs":[{"name":"t"}],"output":null}],[5,"parse_opts","","",null,null],[5,"fmt_bench_samples","","",null,{"inputs":[{"name":"benchsamples"}],"output":{"name":"string"}}],[5,"list_tests_console","","",null,{"inputs":[{"name":"testopts"},{"generics":["testdescandfn"],"name":"vec"}],"output":{"name":"result"}}],[5,"run_tests_console","","",null,{"inputs":[{"name":"testopts"},{"generics":["testdescandfn"],"name":"vec"}],"output":{"generics":["bool"],"name":"result"}}],[5,"run_tests","","",null,{"inputs":[{"name":"testopts"},{"generics":["testdescandfn"],"name":"vec"},{"name":"f"}],"output":{"name":"result"}}],[5,"filter_tests","","",null,{"inputs":[{"name":"testopts"},{"generics":["testdescandfn"],"name":"vec"}],"output":{"generics":["testdescandfn"],"name":"vec"}}],[5,"convert_benchmarks_to_tests","","",null,{"inputs":[{"generics":["testdescandfn"],"name":"vec"}],"output":{"generics":["testdescandfn"],"name":"vec"}}],[5,"run_test","","",null,{"inputs":[{"name":"testopts"},{"name":"bool"},{"name":"testdescandfn"},{"generics":["monitormsg"],"name":"sender"}],"output":null}],[5,"black_box","","A function that is opaque to the optimizer, to allow benchmarks to pretend to use outputs to assist in avoiding dead-code elimination.",null,{"inputs":[{"name":"t"}],"output":{"name":"t"}}],[5,"iter","","",null,{"inputs":[{"name":"f"}],"output":{"name":"summary"}}],[0,"test","","",null,null],[0,"stats","","",null,null],[3,"Summary","test::stats","Extracted collection of all the summary statistics of a sample set.",null,null],[12,"sum","","",13,null],[12,"min","","",13,null],[12,"max","","",13,null],[12,"mean","","",13,null],[12,"median","","",13,null],[12,"var","","",13,null],[12,"std_dev","","",13,null],[12,"std_dev_pct","","",13,null],[12,"median_abs_dev","","",13,null],[12,"median_abs_dev_pct","","",13,null],[12,"quartiles","","",13,null],[12,"iqr","","",13,null],[5,"winsorize","","Winsorize a set of samples, replacing values above the `100-pct` percentile and below the `pct` percentile with those percentiles themselves. This is a way of minimizing the effect of outliers, at the cost of biasing the sample. It differs from trimming in that it does not change the number of samples, just changes the values of those that are outliers.",null,null],[8,"Stats","","Trait that provides simple descriptive statistics on a univariate set of numeric samples.",null,null],[10,"sum","","Sum of the samples.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"min","","Minimum value of the samples.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"max","","Maximum value of the samples.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"mean","","Arithmetic mean (average) of the samples: sum divided by sample-count.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"median","","Median of the samples: value separating the lower half of the samples from the higher half. Equal to `self.percentile(50.0)`.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"var","","Variance of the samples: bias-corrected mean of the squares of the differences of each sample from the sample mean. Note that this calculates the sample variance rather than the population variance, which is assumed to be unknown. It therefore corrects the `(n-1)/n` bias that would appear if we calculated a population variance, by dividing by `(n-1)` rather than `n`.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"std_dev","","Standard deviation: the square root of the sample variance.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"std_dev_pct","","Standard deviation as a percent of the mean value. See `std_dev` and `mean`.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"median_abs_dev","","Scaled median of the absolute deviations of each sample from the sample median. This is a robust (distribution-agnostic) estimator of sample variability. Use this in preference to `std_dev` if you cannot assume your sample is normally distributed. Note that this is scaled by the constant `1.4826` to allow its use as a consistent estimator for the standard deviation.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"median_abs_dev_pct","","Median absolute deviation as a percent of the median. See `median_abs_dev` and `median`.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[10,"percentile","","Percentile: the value below which `pct` percent of the values in `self` fall. For example, percentile(95.0) will return the value `v` such that 95% of the samples `s` in `self` satisfy `s <= v`.",14,{"inputs":[{"name":"self"},{"name":"f64"}],"output":{"name":"f64"}}],[10,"quartiles","","Quartiles of the sample: three values that divide the sample into four equal groups, each with 1/4 of the data. The middle value is the median. See `median` and `percentile`. This function may calculate the 3 quartiles more efficiently than 3 calls to `percentile`, but is otherwise equivalent.",14,null],[10,"iqr","","Inter-quartile range: the difference between the 25th percentile (1st quartile) and the 75th percentile (3rd quartile). See `quartiles`.",14,{"inputs":[{"name":"self"}],"output":{"name":"f64"}}],[11,"clone","","",13,{"inputs":[{"name":"self"}],"output":{"name":"summary"}}],[11,"eq","","",13,{"inputs":[{"name":"self"},{"name":"summary"}],"output":{"name":"bool"}}],[11,"ne","","",13,{"inputs":[{"name":"self"},{"name":"summary"}],"output":{"name":"bool"}}],[11,"new","","Construct a new summary of a sample set.",13,null],[0,"bench","test","",null,null],[5,"benchmark","test::bench","",null,{"inputs":[{"name":"testdesc"},{"generics":["monitormsg"],"name":"sender"},{"name":"bool"},{"name":"f"}],"output":null}],[5,"run_once","","",null,{"inputs":[{"name":"f"}],"output":null}],[6,"OptRes","test","Result of parsing the options.",null,null],[6,"MonitorMsg","","",null,null],[8,"TDynBenchFn","","Represents a benchmark function.",null,null],[10,"run","","",15,{"inputs":[{"name":"self"},{"name":"bencher"}],"output":null}],[11,"clone","","",4,{"inputs":[{"name":"self"}],"output":{"name":"testname"}}],[11,"eq","","",4,{"inputs":[{"name":"self"},{"name":"testname"}],"output":{"name":"bool"}}],[11,"ne","","",4,{"inputs":[{"name":"self"},{"name":"testname"}],"output":{"name":"bool"}}],[11,"hash","","",4,null],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",4,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",5,{"inputs":[{"name":"self"}],"output":{"name":"namepadding"}}],[11,"eq","","",5,{"inputs":[{"name":"self"},{"name":"namepadding"}],"output":{"name":"bool"}}],[11,"hash","","",5,null],[11,"fmt","","",5,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"fmt","","",6,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",0,{"inputs":[{"name":"self"}],"output":{"name":"bencher"}}],[11,"clone","","",7,{"inputs":[{"name":"self"}],"output":{"name":"benchmode"}}],[11,"eq","","",7,{"inputs":[{"name":"self"},{"name":"benchmode"}],"output":{"name":"bool"}}],[11,"clone","","",8,{"inputs":[{"name":"self"}],"output":{"name":"shouldpanic"}}],[11,"fmt","","",8,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",8,{"inputs":[{"name":"self"},{"name":"shouldpanic"}],"output":{"name":"bool"}}],[11,"ne","","",8,{"inputs":[{"name":"self"},{"name":"shouldpanic"}],"output":{"name":"bool"}}],[11,"hash","","",8,null],[11,"clone","","",1,{"inputs":[{"name":"self"}],"output":{"name":"testdesc"}}],[11,"fmt","","",1,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",1,{"inputs":[{"name":"self"},{"name":"testdesc"}],"output":{"name":"bool"}}],[11,"ne","","",1,{"inputs":[{"name":"self"},{"name":"testdesc"}],"output":{"name":"bool"}}],[11,"hash","","",1,null],[11,"fmt","","",2,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",16,{"inputs":[{"name":"self"}],"output":{"name":"metric"}}],[11,"eq","","",16,{"inputs":[{"name":"self"},{"name":"metric"}],"output":{"name":"bool"}}],[11,"ne","","",16,{"inputs":[{"name":"self"},{"name":"metric"}],"output":{"name":"bool"}}],[11,"fmt","","",16,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","",16,{"inputs":[{"name":"f64"},{"name":"f64"}],"output":{"name":"metric"}}],[11,"clone","","",17,{"inputs":[{"name":"self"}],"output":{"name":"options"}}],[11,"fmt","","",17,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"new","","",17,{"inputs":[],"output":{"name":"options"}}],[11,"display_output","","",17,{"inputs":[{"name":"self"},{"name":"bool"}],"output":{"name":"options"}}],[11,"clone","","",9,{"inputs":[{"name":"self"}],"output":{"name":"colorconfig"}}],[11,"fmt","","",9,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",10,{"inputs":[{"name":"self"}],"output":{"name":"outputformat"}}],[11,"fmt","","",10,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"eq","","",10,{"inputs":[{"name":"self"},{"name":"outputformat"}],"output":{"name":"bool"}}],[11,"fmt","","",3,{"inputs":[{"name":"self"},{"name":"formatter"}],"output":{"name":"result"}}],[11,"clone","","",18,{"inputs":[{"name":"self"}],"output":{"name":"benchsamples"}}],[11,"eq","","",18,{"inputs":[{"name":"self"},{"name":"benchsamples"}],"output":{"name":"bool"}}],[11,"ne","","",18,{"inputs":[{"name":"self"},{"name":"benchsamples"}],"output":{"name":"bool"}}],[11,"clone","","",11,{"inputs":[{"name":"self"}],"output":{"name":"testresult"}}],[11,"eq","","",11,{"inputs":[{"name":"self"},{"name":"testresult"}],"output":{"name":"bool"}}],[11,"ne","","",11,{"inputs":[{"name":"self"},{"name":"testresult"}],"output":{"name":"bool"}}],[11,"clone","","",12,{"inputs":[{"name":"self"}],"output":{"name":"testevent"}}],[11,"clone","","",19,{"inputs":[{"name":"self"}],"output":{"name":"metricmap"}}],[11,"eq","","",19,{"inputs":[{"name":"self"},{"name":"metricmap"}],"output":{"name":"bool"}}],[11,"ne","","",19,{"inputs":[{"name":"self"},{"name":"metricmap"}],"output":{"name":"bool"}}],[11,"new","","",19,{"inputs":[],"output":{"name":"metricmap"}}],[11,"insert_metric","","Insert a named `value` (+/- `noise`) metric into the map. The value must be non-negative. The `noise` indicates the uncertainty of the metric, which doubles as the \"noise range\" of acceptable pairwise-regressions on this named value, when comparing from one metric to the next using `compare_to_old`.",19,{"inputs":[{"name":"self"},{"name":"str"},{"name":"f64"},{"name":"f64"}],"output":null}],[11,"fmt_metrics","","",19,{"inputs":[{"name":"self"}],"output":{"name":"string"}}],[11,"iter","","Callback for benchmark functions to run in their body.",0,{"inputs":[{"name":"self"},{"name":"f"}],"output":null}],[11,"bench","","",0,{"inputs":[{"name":"self"},{"name":"f"}],"output":{"generics":["summary"],"name":"option"}}]],"paths":[[3,"Bencher"],[3,"TestDesc"],[3,"TestDescAndFn"],[3,"TestOpts"],[4,"TestName"],[4,"NamePadding"],[4,"TestFn"],[4,"BenchMode"],[4,"ShouldPanic"],[4,"ColorConfig"],[4,"OutputFormat"],[4,"TestResult"],[4,"TestEvent"],[3,"Summary"],[8,"Stats"],[8,"TDynBenchFn"],[3,"Metric"],[3,"Options"],[3,"BenchSamples"],[3,"MetricMap"]]};
initSearch(searchIndex);
